--
-- Licensed Materials - Property of IBM
-- 5655-FLW (C) Copyright IBM Corporation 2006, 2010.
-- All Rights Reserved.
-- US Government Users Restricted Rights- 
-- Use, duplication or disclosure restricted 
-- by GSA ADP Schedule Contract with IBM Corp.
--
-- Scriptfile to create schema (tables) in DB2 z/OS v9
----------------------------------------------------------------------
-- Following variables needs to be changed for customization and
-- before running this script:
--   @STOGRP@ = DB2 Storage group name
--   @DB_NAME@ = DB2 Database name
--   @WLMID@  = WLM environment name to run UDF 
--   @SCHEMA@ = DB2 Schema qualifier
----------------------------------------------------------------------
-- Process this script in the DB2 command line processor
-- example: db2 -tf createSchema_Observer.sql
-- 
-- If the user id that performs this script is not @SCHEMA@, 
-- the GRANT SQL statements located at label GRANT_EXECUTE must be
-- activated by removing the comment signs.


-------------------
-- Create tables --
-------------------

CREATE TABLE @SCHEMA@.OBSERVER_VERSION
(
 OBSERVER_VERSION INTEGER NOT NULL ,
 DATA_MIGRATION SMALLINT NOT NULL ,
  PRIMARY KEY (OBSERVER_VERSION)
) IN @DB_NAME@.OBSVR01;

CREATE UNIQUE INDEX 
  @SCHEMA@.SCHEMA_O
  ON @SCHEMA@.OBSERVER_VERSION
(   
  OBSERVER_VERSION
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.INST_PRC_T
(
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 PRC_TEMPL_NAME VARCHAR(254) NOT NULL ,
 VALID_FROM TIMESTAMP NOT NULL ,
 PRC_DELETED TIMESTAMP ,
 PTID CHAR(16) FOR BIT DATA NOT NULL ,
 PRC_STARTED TIMESTAMP ,
 PRC_COMPLETED TIMESTAMP ,
 PRC_EVENT_CNT INTEGER NOT NULL ,
 PRC_WORK_TIME INTEGER NOT NULL ,
 PRC_ACT_CNT INTEGER NOT NULL ,
 PRC_ACT_EVENT_CNT INTEGER NOT NULL ,
 PRC_LAST_USER VARCHAR(128) ,
  PRIMARY KEY (PIID)
) IN @DB_NAME@.OBSVR02;

CREATE UNIQUE INDEX 
  @SCHEMA@.INST_PRC_P
  ON @SCHEMA@.INST_PRC_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX 
  @SCHEMA@.INST_PRC_PIPTID
  ON @SCHEMA@.INST_PRC_T
(   
  PIID, 
  PTID
)
USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX 
  @SCHEMA@.INST_PRC_PITEMPL
  ON @SCHEMA@.INST_PRC_T
(   
  PIID, 
  PRC_TEMPL_NAME, 
  VALID_FROM, 
  PTID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX 
  @SCHEMA@.INST_PRC_PITIMES
  ON @SCHEMA@.INST_PRC_T
(   
  PIID, 
  PRC_COMPLETED, 
  PRC_STARTED, 
  VALID_FROM, 
  PRC_TEMPL_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.INST_PRC_PTPIID
  ON @SCHEMA@.INST_PRC_T
(   
  PTID, 
  PIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.INST_PRC_PTID
  ON @SCHEMA@.INST_PRC_T
(   
  PTID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.INST_PRC_STARTED
  ON @SCHEMA@.INST_PRC_T
(   
  PRC_STARTED
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.INST_PRC_COMPLET
  ON @SCHEMA@.INST_PRC_T
(   
  PRC_COMPLETED
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.INST_PRC_DELETE
  ON @SCHEMA@.INST_PRC_T
(   
  PRC_DELETED
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.INST_ACT_T
(
 ACT_NAME VARCHAR(254) ,
 ACT_KIND INTEGER NOT NULL ,
 ATID CHAR(16) FOR BIT DATA NOT NULL ,
 AIID CHAR(16) FOR BIT DATA NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 ACT_STARTED TIMESTAMP ,
 ACT_COMPLETED TIMESTAMP ,
 ACT_EVENT_CNT INTEGER NOT NULL ,
 ACT_LAST_USER VARCHAR(128) ,
  PRIMARY KEY (AIID)
) IN @DB_NAME@.OBSVR03;

CREATE UNIQUE INDEX 
  @SCHEMA@.INST_ACT_P
  ON @SCHEMA@.INST_ACT_T
(   
  AIID
)
USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX 
  @SCHEMA@.INST_ACT_AIATID
  ON @SCHEMA@.INST_ACT_T
(   
  AIID, 
  ATID
)
USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX 
  @SCHEMA@.INST_ACT_AIPIID
  ON @SCHEMA@.INST_ACT_T
(   
  AIID, 
  PIID
)
USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX 
  @SCHEMA@.INST_ACT_AITIMES
  ON @SCHEMA@.INST_ACT_T
(   
  AIID, 
  ACT_NAME, 
  ACT_STARTED, 
  ACT_COMPLETED, 
  PIID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.INST_ACT_NAME
  ON @SCHEMA@.INST_ACT_T
(   
  ACT_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.INST_ACT_ATID
  ON @SCHEMA@.INST_ACT_T
(   
  ATID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.INST_ACT_PIID
  ON @SCHEMA@.INST_ACT_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.INST_ACT_STARTED
  ON @SCHEMA@.INST_ACT_T
(   
  ACT_STARTED
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.INST_ACT_COMPLET
  ON @SCHEMA@.INST_ACT_T
(   
  ACT_COMPLETED
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.ATID_NAME_AIID
  ON @SCHEMA@.INST_ACT_T
(   
  ATID, 
  ACT_NAME, 
  AIID
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.EVENT_PRC_T
(
 EVENT_TIME TIMESTAMP NOT NULL ,
 PRC_EVENT INTEGER NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 EXCEPTION_TEXT CLOB(4096) ,
 USER_NAME VARCHAR(128) ,
 PRC_STATE INTEGER NOT NULL ,
  PRIMARY KEY (EVENT_TIME, PIID)
) IN @DB_NAME@.OBSVR04;

CREATE UNIQUE INDEX 
  @SCHEMA@.EVENT_PRC_P
  ON @SCHEMA@.EVENT_PRC_T
(   
  EVENT_TIME, 
  PIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column EXCEPTION_TEXT
CREATE AUX TABLE @SCHEMA@.OT26201
   IN @DB_NAME@.OS26201
   STORES @SCHEMA@.EVENT_PRC_T COLUMN EXCEPTION_TEXT;
-- auxiliary index for LOB column EXCEPTION_TEXT
CREATE UNIQUE INDEX @SCHEMA@.OT26201I
  ON @SCHEMA@.OT26201
   USING STOGROUP @STOGRP@;


CREATE UNIQUE INDEX 
  @SCHEMA@.EVENT_PRC_TIMEPI
  ON @SCHEMA@.EVENT_PRC_T
(   
  EVENT_TIME, 
  PIID, 
  PRC_STATE
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.EVENT_PRC_EVTIME
  ON @SCHEMA@.EVENT_PRC_T
(   
  PRC_EVENT, 
  EVENT_TIME, 
  PIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.EVENT_PRC_PIID
  ON @SCHEMA@.EVENT_PRC_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.EVENT_PRC_USER
  ON @SCHEMA@.EVENT_PRC_T
(   
  USER_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.EVENT_PRC_T_ONLY
  ON @SCHEMA@.EVENT_PRC_T
(   
  EVENT_TIME
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.EVENT_ACT_T
(
 EVENT_TIME TIMESTAMP NOT NULL ,
 ACT_EVENT INTEGER NOT NULL ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 AIID CHAR(16) FOR BIT DATA NOT NULL ,
 ACT_STATE INTEGER NOT NULL ,
 EXCEPTION_TEXT CLOB(4096) ,
 USER_NAME VARCHAR(128) ,
  PRIMARY KEY (EVENT_TIME, AIID)
) IN @DB_NAME@.OBSVR05;

CREATE UNIQUE INDEX 
  @SCHEMA@.EVENT_ACT_P
  ON @SCHEMA@.EVENT_ACT_T
(   
  EVENT_TIME, 
  AIID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column EXCEPTION_TEXT
CREATE AUX TABLE @SCHEMA@.OT26202
   IN @DB_NAME@.OS26202
   STORES @SCHEMA@.EVENT_ACT_T COLUMN EXCEPTION_TEXT;
-- auxiliary index for LOB column EXCEPTION_TEXT
CREATE UNIQUE INDEX @SCHEMA@.OT26202I
  ON @SCHEMA@.OT26202
   USING STOGROUP @STOGRP@;


CREATE UNIQUE INDEX 
  @SCHEMA@.EVENT_ACT_TIMEAI
  ON @SCHEMA@.EVENT_ACT_T
(   
  EVENT_TIME, 
  AIID, 
  ACT_STATE
)
USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX 
  @SCHEMA@.EVENT_ACT_AITIME
  ON @SCHEMA@.EVENT_ACT_T
(   
  AIID, 
  EVENT_TIME
)
USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX 
  @SCHEMA@.EVENT_ACT_AIEVTI
  ON @SCHEMA@.EVENT_ACT_T
(   
  AIID, 
  ACT_EVENT, 
  EVENT_TIME
)
USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX 
  @SCHEMA@.AIID_TIME_EVNT
  ON @SCHEMA@.EVENT_ACT_T
(   
  AIID, 
  EVENT_TIME, 
  ACT_EVENT
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.EVENT_ACT_PIID
  ON @SCHEMA@.EVENT_ACT_T
(   
  PIID
)
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.EVENT_ACT_USER
  ON @SCHEMA@.EVENT_ACT_T
(   
  USER_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.EVENT_ACT_T_ONLY
  ON @SCHEMA@.EVENT_ACT_T
(   
  EVENT_TIME
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.QUERY_T
(
 ID INTEGER NOT NULL ,
 LAST_UPD TIMESTAMP NOT NULL ,
 DISPLAY_NAME VARCHAR(254) NOT NULL ,
 TYPE SMALLINT NOT NULL ,
 TEXT CLOB(1000000) NOT NULL ,
  PRIMARY KEY (ID)
) IN @DB_NAME@.OBSVR06;

CREATE UNIQUE INDEX 
  @SCHEMA@.QUERY_P
  ON @SCHEMA@.QUERY_T
(   
  ID
)
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column TEXT
CREATE AUX TABLE @SCHEMA@.OT26203
   IN @DB_NAME@.OS26203
   STORES @SCHEMA@.QUERY_T COLUMN TEXT;
-- auxiliary index for LOB column TEXT
CREATE UNIQUE INDEX @SCHEMA@.OT26203I
  ON @SCHEMA@.OT26203
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.QUERY_TYPE_NAME
  ON @SCHEMA@.QUERY_T
(   
  TYPE, 
  DISPLAY_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE INDEX 
  @SCHEMA@.QUERY_DISPLAY_NAME
  ON @SCHEMA@.QUERY_T
(   
  DISPLAY_NAME
) NOT PADDED
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.SLICES_T
(
 ID INTEGER NOT NULL ,
  PRIMARY KEY (ID)
) IN @DB_NAME@.OBSVR07;

CREATE UNIQUE INDEX 
  @SCHEMA@.SLICES_P
  ON @SCHEMA@.SLICES_T
(   
  ID
)
USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.OPEN_EVENTS_T
(
 GLOBAL_ID VARCHAR(64) NOT NULL ,
 SEQUENCE INTEGER NOT NULL ,
 EVENT_TIME_UTC TIMESTAMP NOT NULL ,
 AUDIT_EVENT INTEGER NOT NULL ,
 PTID CHAR(16) FOR BIT DATA ,
 PIID CHAR(16) FOR BIT DATA NOT NULL ,
 PROCESS_TEMPL_NAME VARCHAR(254) ,
 VALID_FROM_UTC TIMESTAMP ,
 ATID CHAR(16) FOR BIT DATA ,
 AIID CHAR(16) FOR BIT DATA ,
 ACTIVITY_NAME VARCHAR(254) ,
 ACTIVITY_KIND INTEGER ,
 ACTIVITY_STATE INTEGER ,
 EXCEPTION_TEXT CLOB(4096) ,
 PROCESS_STATE INTEGER ,
 USER_NAME VARCHAR(128) ,
 EXTENSION_NAME VARCHAR(128) ,
  PRIMARY KEY (GLOBAL_ID)
) IN @DB_NAME@.OBSVR08;

CREATE UNIQUE INDEX 
  @SCHEMA@.OPEN_EVENTS_P
  ON @SCHEMA@.OPEN_EVENTS_T
(   
  GLOBAL_ID
) NOT PADDED
USING STOGROUP @STOGRP@;
-- auxiliary table for LOB column EXCEPTION_TEXT
CREATE AUX TABLE @SCHEMA@.OT26204
   IN @DB_NAME@.OS26204
   STORES @SCHEMA@.OPEN_EVENTS_T COLUMN EXCEPTION_TEXT;
-- auxiliary index for LOB column EXCEPTION_TEXT
CREATE UNIQUE INDEX @SCHEMA@.OT26204I
  ON @SCHEMA@.OT26204
   USING STOGROUP @STOGRP@;


CREATE INDEX 
  @SCHEMA@.OPEN_EVNTS_PIID_TS
  ON @SCHEMA@.OPEN_EVENTS_T
(   
  PIID, 
  EVENT_TIME_UTC
)
USING STOGROUP @STOGRP@;
-- set schema version to: 610
INSERT INTO @SCHEMA@.OBSERVER_VERSION(OBSERVER_VERSION, DATA_MIGRATION)
 VALUES( 610, 0 );

--------------------------------------------------------------------
--  Licensed Materials - Property of IBM
--  5655-FLW (C) Copyright IBM Corporation 2005,2008.
--  All Rights Reserved.
--  US Government Users Restricted Rights-
--  Use, duplication or disclosure restricted
--  by GSA ADP Schedule Contract with IBM Corp.
--------------------------------------------------------------------
--   Version %I%
--   Last update: %E% %U%
--------------------------------------------------------------------
--
-- SQL snippet for Observer SQL based UDFs
-- for DB2 v9 on z/OS
--
--------------------------------------------------------------------
--
-- Please ensure that the lines are not longer than 70 characters!
--
--------------------------------------------------------------------
--
-- Following variables needs to be changed for customization and
-- before running this script:
--
--   @SCHEMA@ = DB2 SQLID (Schema Qualifier)
--
-- If the user id that performs this script is not @SCHEMA@,
-- the GRANT statements located at label GRANT_EXECUTE must be
-- activated by removing the comment signs.
--
--------------------------------------------------------------------
----------------------
-- Create functions --
----------------------

CREATE FUNCTION @SCHEMA@.INTERVALIN (INTERVAL INT,
                                     TS_START TIMESTAMP,
                                     TS_END TIMESTAMP)
  RETURNS INTEGER
  LANGUAGE SQL
  SPECIFIC @SCHEMA@.INTERVALIN_TS_TS
  READS SQL DATA
  NO EXTERNAL ACTION
  DETERMINISTIC
  RETURN TIMESTAMPDIFF(INTERVAL,CHAR(TS_END - TS_START));

CREATE FUNCTION @SCHEMA@.INTERVALIN (INTERVAL INT,
                                     TS_START TIMESTAMP,
                                     VC_END VARCHAR(26))
  RETURNS INTEGER
  LANGUAGE SQL
  SPECIFIC @SCHEMA@.INTERVALIN_TS_VC
  CONTAINS SQL
  NO EXTERNAL ACTION
  DETERMINISTIC
  RETURN
 TIMESTAMPDIFF(INTERVAL,CHAR(CAST(VC_END AS TIMESTAMP) - TS_START));

CREATE FUNCTION @SCHEMA@.INTERVALIN (INTERVAL INT,
                                     VC_START VARCHAR(26),
                                     TS_END TIMESTAMP)
  RETURNS INTEGER
  LANGUAGE SQL
  SPECIFIC @SCHEMA@.INTERVALIN_VC_TS
  READS SQL DATA
  NO EXTERNAL ACTION
  DETERMINISTIC
  RETURN
 TIMESTAMPDIFF(INTERVAL,CHAR(TS_END - CAST(VC_START AS TIMESTAMP)));

CREATE FUNCTION @SCHEMA@.INTERVALIN (INTERVAL INT,
                                     VC_START VARCHAR(26),
                                     VC_END VARCHAR(26))
  RETURNS INTEGER
  LANGUAGE SQL
  SPECIFIC @SCHEMA@.INTERVALIN_VC_VC
  READS SQL DATA
  NO EXTERNAL ACTION
  DETERMINISTIC
  RETURN
    TIMESTAMPDIFF(INTERVAL,CHAR(CAST(VC_END AS TIMESTAMP) -
                        CAST(VC_START AS TIMESTAMP)));

CREATE FUNCTION @SCHEMA@.OBSVR_JAR_ACTIVE ()
  RETURNS INTEGER
  LANGUAGE SQL
  NO EXTERNAL ACTION
  DETERMINISTIC
  RETURN 0;

----------------------------------------------------------------------
-- GRANT_EXECUTE
-- Activate the following GRANT statements by removing the comment
-- signs when the user id that performes this script is not @SCHEMA@
----------------------------------------------------------------------
-- GRANT EXECUTE ON SPECIFIC FUNCTION
--    @SCHEMA@.INTERVALIN_TS_VC TO @SCHEMA@;
--
-- GRANT EXECUTE ON SPECIFIC FUNCTION
--    @SCHEMA@.INTERVALIN_TS_TS TO @SCHEMA@;
--
-- GRANT EXECUTE ON SPECIFIC FUNCTION
--    @SCHEMA@.INTERVALIN_VC_VC TO @SCHEMA@;
--
-- GRANT EXECUTE ON SPECIFIC FUNCTION
--    @SCHEMA@.INTERVALIN_VC_TS TO @SCHEMA@;
--------------------------------------------------------------------
--  Licensed Materials - Property of IBM
--  5655-FLW (C) Copyright IBM Corporation 2005,2008.
--  All Rights Reserved.
--  US Government Users Restricted Rights-
--  Use, duplication or disclosure restricted
--  by GSA ADP Schedule Contract with IBM Corp.
--------------------------------------------------------------------
--   Version %I%
--   Last update: %E% %U%
--------------------------------------------------------------------
--
-- SQL snippet for filling the the SLICES_T table with values
-- for DB2 v9 on z/OS
--
--------------------------------------------------------------------

INSERT INTO @SCHEMA@.SLICES_T VALUES(   1);
INSERT INTO @SCHEMA@.SLICES_T VALUES(   2);
INSERT INTO @SCHEMA@.SLICES_T VALUES(   3);
INSERT INTO @SCHEMA@.SLICES_T VALUES(   4);
INSERT INTO @SCHEMA@.SLICES_T VALUES(   5);
INSERT INTO @SCHEMA@.SLICES_T VALUES(   6);
INSERT INTO @SCHEMA@.SLICES_T VALUES(   7);
INSERT INTO @SCHEMA@.SLICES_T VALUES(   8);
INSERT INTO @SCHEMA@.SLICES_T VALUES(   9);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  10);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  11);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  12);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  13);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  14);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  15);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  16);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  17);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  18);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  19);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  20);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  21);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  22);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  23);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  24);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  25);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  26);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  27);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  28);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  29);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  30);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  31);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  32);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  33);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  34);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  35);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  36);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  37);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  38);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  39);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  40);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  41);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  42);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  43);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  44);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  45);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  46);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  47);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  48);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  49);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  50);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  51);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  52);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  53);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  54);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  55);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  56);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  57);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  58);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  59);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  60);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  61);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  62);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  63);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  64);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  65);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  66);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  67);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  68);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  69);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  70);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  71);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  72);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  73);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  74);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  75);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  76);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  77);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  78);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  79);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  80);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  81);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  82);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  83);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  84);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  85);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  86);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  87);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  88);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  89);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  90);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  91);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  92);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  93);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  94);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  95);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  96);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  97);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  98);
INSERT INTO @SCHEMA@.SLICES_T VALUES(  99);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 100);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 101);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 102);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 103);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 104);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 105);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 106);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 107);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 108);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 109);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 110);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 111);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 112);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 113);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 114);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 115);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 116);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 117);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 118);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 119);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 120);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 121);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 122);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 123);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 124);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 125);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 126);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 127);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 128);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 129);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 130);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 131);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 132);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 133);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 134);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 135);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 136);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 137);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 138);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 139);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 140);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 141);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 142);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 143);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 144);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 145);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 146);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 147);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 148);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 149);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 150);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 151);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 152);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 153);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 154);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 155);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 156);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 157);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 158);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 159);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 160);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 161);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 162);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 163);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 164);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 165);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 166);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 167);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 168);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 169);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 170);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 171);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 172);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 173);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 174);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 175);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 176);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 177);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 178);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 179);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 180);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 181);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 182);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 183);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 184);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 185);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 186);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 187);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 188);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 189);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 190);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 191);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 192);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 193);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 194);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 195);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 196);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 197);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 198);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 199);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 200);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 201);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 202);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 203);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 204);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 205);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 206);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 207);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 208);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 209);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 210);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 211);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 212);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 213);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 214);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 215);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 216);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 217);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 218);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 219);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 220);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 221);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 222);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 223);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 224);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 225);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 226);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 227);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 228);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 229);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 230);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 231);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 232);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 233);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 234);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 235);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 236);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 237);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 238);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 239);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 240);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 241);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 242);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 243);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 244);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 245);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 246);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 247);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 248);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 249);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 250);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 251);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 252);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 253);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 254);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 255);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 256);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 257);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 258);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 259);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 260);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 261);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 262);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 263);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 264);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 265);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 266);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 267);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 268);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 269);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 270);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 271);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 272);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 273);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 274);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 275);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 276);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 277);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 278);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 279);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 280);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 281);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 282);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 283);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 284);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 285);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 286);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 287);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 288);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 289);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 290);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 291);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 292);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 293);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 294);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 295);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 296);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 297);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 298);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 299);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 300);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 301);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 302);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 303);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 304);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 305);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 306);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 307);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 308);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 309);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 310);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 311);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 312);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 313);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 314);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 315);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 316);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 317);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 318);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 319);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 320);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 321);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 322);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 323);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 324);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 325);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 326);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 327);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 328);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 329);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 330);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 331);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 332);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 333);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 334);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 335);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 336);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 337);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 338);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 339);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 340);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 341);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 342);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 343);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 344);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 345);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 346);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 347);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 348);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 349);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 350);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 351);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 352);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 353);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 354);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 355);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 356);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 357);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 358);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 359);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 360);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 361);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 362);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 363);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 364);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 365);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 366);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 367);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 368);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 369);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 370);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 371);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 372);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 373);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 374);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 375);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 376);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 377);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 378);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 379);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 380);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 381);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 382);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 383);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 384);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 385);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 386);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 387);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 388);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 389);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 390);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 391);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 392);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 393);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 394);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 395);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 396);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 397);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 398);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 399);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 400);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 401);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 402);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 403);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 404);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 405);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 406);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 407);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 408);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 409);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 410);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 411);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 412);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 413);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 414);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 415);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 416);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 417);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 418);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 419);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 420);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 421);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 422);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 423);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 424);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 425);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 426);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 427);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 428);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 429);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 430);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 431);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 432);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 433);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 434);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 435);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 436);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 437);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 438);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 439);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 440);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 441);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 442);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 443);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 444);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 445);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 446);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 447);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 448);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 449);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 450);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 451);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 452);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 453);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 454);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 455);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 456);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 457);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 458);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 459);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 460);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 461);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 462);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 463);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 464);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 465);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 466);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 467);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 468);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 469);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 470);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 471);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 472);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 473);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 474);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 475);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 476);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 477);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 478);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 479);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 480);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 481);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 482);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 483);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 484);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 485);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 486);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 487);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 488);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 489);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 490);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 491);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 492);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 493);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 494);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 495);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 496);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 497);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 498);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 499);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 500);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 501);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 502);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 503);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 504);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 505);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 506);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 507);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 508);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 509);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 510);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 511);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 512);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 513);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 514);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 515);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 516);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 517);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 518);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 519);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 520);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 521);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 522);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 523);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 524);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 525);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 526);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 527);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 528);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 529);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 530);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 531);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 532);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 533);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 534);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 535);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 536);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 537);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 538);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 539);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 540);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 541);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 542);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 543);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 544);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 545);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 546);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 547);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 548);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 549);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 550);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 551);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 552);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 553);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 554);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 555);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 556);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 557);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 558);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 559);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 560);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 561);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 562);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 563);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 564);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 565);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 566);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 567);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 568);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 569);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 570);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 571);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 572);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 573);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 574);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 575);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 576);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 577);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 578);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 579);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 580);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 581);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 582);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 583);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 584);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 585);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 586);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 587);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 588);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 589);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 590);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 591);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 592);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 593);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 594);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 595);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 596);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 597);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 598);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 599);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 600);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 601);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 602);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 603);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 604);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 605);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 606);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 607);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 608);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 609);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 610);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 611);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 612);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 613);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 614);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 615);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 616);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 617);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 618);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 619);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 620);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 621);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 622);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 623);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 624);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 625);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 626);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 627);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 628);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 629);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 630);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 631);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 632);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 633);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 634);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 635);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 636);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 637);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 638);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 639);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 640);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 641);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 642);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 643);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 644);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 645);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 646);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 647);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 648);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 649);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 650);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 651);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 652);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 653);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 654);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 655);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 656);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 657);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 658);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 659);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 660);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 661);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 662);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 663);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 664);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 665);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 666);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 667);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 668);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 669);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 670);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 671);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 672);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 673);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 674);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 675);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 676);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 677);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 678);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 679);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 680);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 681);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 682);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 683);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 684);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 685);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 686);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 687);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 688);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 689);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 690);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 691);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 692);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 693);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 694);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 695);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 696);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 697);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 698);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 699);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 700);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 701);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 702);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 703);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 704);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 705);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 706);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 707);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 708);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 709);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 710);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 711);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 712);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 713);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 714);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 715);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 716);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 717);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 718);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 719);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 720);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 721);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 722);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 723);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 724);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 725);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 726);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 727);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 728);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 729);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 730);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 731);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 732);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 733);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 734);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 735);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 736);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 737);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 738);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 739);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 740);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 741);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 742);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 743);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 744);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 745);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 746);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 747);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 748);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 749);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 750);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 751);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 752);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 753);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 754);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 755);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 756);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 757);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 758);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 759);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 760);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 761);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 762);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 763);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 764);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 765);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 766);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 767);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 768);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 769);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 770);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 771);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 772);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 773);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 774);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 775);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 776);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 777);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 778);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 779);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 780);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 781);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 782);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 783);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 784);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 785);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 786);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 787);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 788);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 789);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 790);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 791);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 792);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 793);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 794);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 795);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 796);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 797);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 798);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 799);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 800);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 801);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 802);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 803);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 804);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 805);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 806);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 807);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 808);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 809);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 810);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 811);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 812);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 813);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 814);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 815);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 816);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 817);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 818);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 819);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 820);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 821);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 822);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 823);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 824);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 825);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 826);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 827);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 828);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 829);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 830);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 831);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 832);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 833);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 834);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 835);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 836);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 837);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 838);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 839);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 840);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 841);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 842);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 843);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 844);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 845);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 846);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 847);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 848);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 849);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 850);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 851);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 852);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 853);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 854);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 855);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 856);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 857);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 858);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 859);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 860);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 861);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 862);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 863);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 864);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 865);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 866);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 867);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 868);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 869);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 870);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 871);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 872);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 873);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 874);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 875);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 876);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 877);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 878);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 879);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 880);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 881);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 882);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 883);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 884);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 885);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 886);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 887);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 888);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 889);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 890);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 891);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 892);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 893);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 894);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 895);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 896);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 897);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 898);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 899);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 900);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 901);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 902);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 903);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 904);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 905);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 906);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 907);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 908);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 909);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 910);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 911);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 912);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 913);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 914);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 915);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 916);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 917);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 918);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 919);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 920);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 921);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 922);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 923);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 924);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 925);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 926);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 927);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 928);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 929);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 930);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 931);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 932);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 933);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 934);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 935);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 936);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 937);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 938);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 939);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 940);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 941);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 942);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 943);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 944);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 945);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 946);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 947);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 948);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 949);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 950);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 951);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 952);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 953);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 954);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 955);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 956);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 957);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 958);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 959);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 960);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 961);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 962);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 963);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 964);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 965);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 966);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 967);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 968);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 969);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 970);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 971);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 972);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 973);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 974);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 975);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 976);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 977);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 978);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 979);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 980);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 981);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 982);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 983);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 984);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 985);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 986);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 987);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 988);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 989);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 990);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 991);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 992);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 993);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 994);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 995);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 996);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 997);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 998);
INSERT INTO @SCHEMA@.SLICES_T VALUES( 999);
INSERT INTO @SCHEMA@.SLICES_T VALUES(1000);
