--
-- Licensed Materials - Property of IBM
-- 5655-FLW (C) Copyright IBM Corporation 2006, 2010.
-- All Rights Reserved.
-- US Government Users Restricted Rights- 
-- Use, duplication or disclosure restricted 
-- by GSA ADP Schedule Contract with IBM Corp.
--
----------------------------------------------------------------------
-- The following variable needs to be changed for customization and
-- before running this script.
-- @SCHEMA@ = Schema name
----------------------------------------------------------------------
-- Scriptfile to upgrade schema for DB2 UDB
-- Process this script in the DB2 command line processor
--
-- Example:
--             db2 connect to BPEDB
--             db2 -tf upgradeSchema602.sql
--


----------------
-- Drop views --
----------------

DROP VIEW @SCHEMA@.PROCESS_TEMPLATE;

DROP VIEW @SCHEMA@.PROCESS_TEMPL_ATTR;

DROP VIEW @SCHEMA@.PROCESS_INSTANCE;

DROP VIEW @SCHEMA@.PROCESS_ATTRIBUTE;

DROP VIEW @SCHEMA@.ACTIVITY;

DROP VIEW @SCHEMA@.ACTIVITY_ATTRIBUTE;

DROP VIEW @SCHEMA@.EVENT;

DROP VIEW @SCHEMA@.WORK_ITEM;

DROP VIEW @SCHEMA@.ACTIVITY_SERVICE;

DROP VIEW @SCHEMA@.QUERY_PROPERTY;

DROP VIEW @SCHEMA@.AUDIT_LOG;

DROP VIEW @SCHEMA@.AUDIT_LOG_B;

DROP VIEW @SCHEMA@.APPLICATION_COMP;

DROP VIEW @SCHEMA@.TASK;

DROP VIEW @SCHEMA@.TASK_TEMPL;

DROP VIEW @SCHEMA@.ESCALATION;

DROP VIEW @SCHEMA@.ESC_TEMPL;

DROP VIEW @SCHEMA@.ESC_TEMPL_DESC;

DROP VIEW @SCHEMA@.TASK_TEMPL_CPROP;

DROP VIEW @SCHEMA@.ESC_TEMPL_CPROP;

DROP VIEW @SCHEMA@.TASK_TEMPL_DESC;

DROP VIEW @SCHEMA@.TASK_CPROP;

DROP VIEW @SCHEMA@.TASK_DESC;

DROP VIEW @SCHEMA@.ESCALATION_CPROP;

DROP VIEW @SCHEMA@.ESCALATION_DESC;

DROP VIEW @SCHEMA@.CUSTOM_PROPERTY;

DROP VIEW @SCHEMA@.DESCRIPTION;

DROP VIEW @SCHEMA@.TASK_AUDIT_LOG;

------------------
-- Drop indexes --
------------------

DROP INDEX @SCHEMA@.AIB_ATID_PI_EH_FE;

DROP INDEX @SCHEMA@.EI_PIID_VTID;

DROP INDEX @SCHEMA@.EI_STATE_VTID;

DROP INDEX @SCHEMA@.WI_ASSOBJ_REASON;

DROP INDEX @SCHEMA@.WI_EVERYBODY;

DROP INDEX @SCHEMA@.WI_ASSOBJ_QIID;

DROP INDEX @SCHEMA@.COS_PIID;

DROP INDEX @SCHEMA@.CP_COORDHOME;

-------------------
-- Create tables --
-------------------

CREATE TABLE @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(
  MPTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  SOURCE_PTID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  TARGET_PTID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  PRIMARY KEY ( MPTID )
) IN @TEMPLATE@;

CREATE UNIQUE INDEX @SCHEMA@.MPT_PTIDS ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(   
  SOURCE_PTID, TARGET_PTID
);

CREATE INDEX @SCHEMA@.MPT_TPTID ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(   
  TARGET_PTID
);

CREATE TABLE @SCHEMA@.IDMAPPING_TEMPLATE_T
(
  MPTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  SOURCE_OID                         CHAR(16)            FOR BIT DATA  NOT NULL ,
  TARGET_OID                         CHAR(16)            FOR BIT DATA  NOT NULL ,
  SOURCE_PTID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  PRIMARY KEY ( MPTID, SOURCE_OID )
) IN @TEMPLATE@;

CREATE INDEX @SCHEMA@.IDMT_PTID ON @SCHEMA@.IDMAPPING_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(
  CGTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  MPTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  SOURCE_PTID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  MANDATORY                          SMALLINT                          NOT NULL ,
  CHANGES                            CLOB(3900K)                       NOT NULL ,
  PRIMARY KEY ( CGTID )
) IN @TEMPLATE@;

CREATE INDEX @SCHEMA@.CGT_MT ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(   
  MPTID
);

CREATE INDEX @SCHEMA@.CGT_PT ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(
  CGTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  SOURCE_ATID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  MPTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  SOURCE_PTID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  RELATIONSHIP                       INTEGER                           NOT NULL ,
  PRIMARY KEY ( CGTID, SOURCE_ATID )
) IN @TEMPLATE@;

CREATE INDEX @SCHEMA@.CGIT_MT ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
  MPTID
);

CREATE INDEX @SCHEMA@.CGIT_PT ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
(
  MPTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  TARGET_CTID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  TARGET_STID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  SOURCE_PTID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  PRIMARY KEY ( MPTID, TARGET_CTID )
) IN @TEMPLATE@;

CREATE INDEX @SCHEMA@.MPVT_PT ON @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE @SCHEMA@.REGION_TEMPLATE_T
(
  RTID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  PTID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  BEGIN_ATID                         CHAR(16)            FOR BIT DATA           ,
  END_ATID                           CHAR(16)            FOR BIT DATA           ,
  REGION_TYPE                        INTEGER                           NOT NULL ,
  BEGIN_ORDER_NUMBER                 INTEGER                           NOT NULL ,
  PARENT_RTID                        CHAR(16)            FOR BIT DATA           ,
  PRIMARY KEY ( RTID )
) IN @TEMPLATE@;

CREATE INDEX @SCHEMA@.RGT_PTID ON @SCHEMA@.REGION_TEMPLATE_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.REGION_CONTENT_TEMPLATE_T
(
  RTID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  CONTAINED_ATID                     CHAR(16)            FOR BIT DATA  NOT NULL ,
  PTID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  PRIMARY KEY ( RTID, CONTAINED_ATID )
) IN @TEMPLATE@;

CREATE INDEX @SCHEMA@.RCT_PTID ON @SCHEMA@.REGION_CONTENT_TEMPLATE_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.CHANGE_TEMPLATE_T
(
  PKID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  MPTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  PROPERTY                           INTEGER                           NOT NULL ,
  DISPLAY_ID_EXT                     VARCHAR(32)                       NOT NULL ,
  CHANGE_TYPE                        INTEGER                           NOT NULL ,
  SOURCE_PTID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  PRIMARY KEY ( PKID )
) IN @TEMPLATE@;

CREATE UNIQUE INDEX @SCHEMA@.CT_MTPDIS ON @SCHEMA@.CHANGE_TEMPLATE_T
(   
  MPTID, PROPERTY, DISPLAY_ID_EXT
);

CREATE INDEX @SCHEMA@.CGT_PTID ON @SCHEMA@.CHANGE_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE @SCHEMA@.PROGRESS_COUNTER_T
(
  PIID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  COUNTER                            BIGINT                            NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( PIID )
) IN @INSTANCE@;

ALTER TABLE @SCHEMA@.PROGRESS_COUNTER_T VOLATILE;

CREATE TABLE @SCHEMA@.RELEVANT_SCOPE_ATASK_T
(
  SIID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  TKIID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  PIID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( SIID, TKIID )
) IN @INSTANCE@;

ALTER TABLE @SCHEMA@.RELEVANT_SCOPE_ATASK_T VOLATILE;

CREATE INDEX @SCHEMA@.RSAT_PIID ON @SCHEMA@.RELEVANT_SCOPE_ATASK_T
(   
  PIID
);

CREATE TABLE @SCHEMA@.CONFIG_INFO_T
(
  IDENTIFIER                         VARCHAR(64)                       NOT NULL ,
  DESCRIPTION                        VARCHAR(128)                               ,
  PROPERTY                           INTEGER                                    ,
  COUNTER                            BIGINT                                     ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( IDENTIFIER )
) IN @INSTANCE@;

ALTER TABLE @SCHEMA@.CONFIG_INFO_T VOLATILE;

CREATE TABLE @SCHEMA@.SYNC_T
(
  IDENTIFIER                         VARCHAR(254)                      NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( IDENTIFIER )
) IN @INSTANCE@;

CREATE TABLE @SCHEMA@.MV_CTR_T
(
  ID                                 INTEGER                           NOT NULL ,
  SELECT_CLAUSE                      VARCHAR(1024)                     NOT NULL ,
  WHERE_CLAUSE                       VARCHAR(1024)                              ,
  ORDER_CLAUSE                       VARCHAR(512)                               ,
  TBL_SPACE                          VARCHAR(32)                       NOT NULL ,
  UPDATED                            TIMESTAMP                         NOT NULL ,
  UPD_STARTED                        TIMESTAMP                                  ,
  AVG_UPD_TIME                       BIGINT                                     ,
  UPD_INTERVAL                       BIGINT                            NOT NULL ,
  IS_UPDATING                        SMALLINT                          NOT NULL ,
  ACTIVE_MV                          SMALLINT                          NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( ID )
) IN @INSTANCE@;

CREATE TABLE @SCHEMA@.MV_MODS_T
(
  PKID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  OID                                CHAR(16)            FOR BIT DATA  NOT NULL ,
  MODIFIED                           TIMESTAMP                         NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( PKID )
) IN @INSTANCE@;

ALTER TABLE @SCHEMA@.MV_MODS_T VOLATILE;

CREATE TABLE @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(
  PKID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  PIID                               CHAR(16)            FOR BIT DATA           ,
  CREATION_TIME                      TIMESTAMP                         NOT NULL ,
  REASON                             INTEGER                           NOT NULL ,
  ENGINE_MESSAGE_S                   VARCHAR(2000)       FOR BIT DATA           ,
  ENGINE_MESSAGE_L                   BLOB(1073741823)                           ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( PKID )
) IN @INSTANCE@;

ALTER TABLE @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T VOLATILE;

CREATE INDEX @SCHEMA@.SEM_PIID ON @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(   
  PIID
);

CREATE INDEX @SCHEMA@.SEM_REAS ON @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(   
  REASON, CREATION_TIME
);

CREATE TABLE @SCHEMA@.NAVIGATION_CLEANUP_TIMER_B_T
(
  PKID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  SCHEDULED_TIME                     TIMESTAMP                         NOT NULL ,
  SCHEDULER_ID                       VARCHAR(254)                      NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( PKID )
) IN @INSTANCE@;

ALTER TABLE @SCHEMA@.NAVIGATION_CLEANUP_TIMER_B_T VOLATILE;

CREATE TABLE @SCHEMA@.SCHEDULER_ACTION_T
(
  SCHEDULER_ID                       VARCHAR(254)                      NOT NULL ,
  OID                                CHAR(16)            FOR BIT DATA  NOT NULL ,
  ACTION_OBJECT                      BLOB(3900k)                                ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( SCHEDULER_ID )
) IN @INSTANCE@;

ALTER TABLE @SCHEMA@.SCHEDULER_ACTION_T VOLATILE;

CREATE INDEX @SCHEMA@.SCEACT_OID ON @SCHEMA@.SCHEDULER_ACTION_T
(   
  OID
);

CREATE TABLE @SCHEMA@.QUERY_TABLE_T
(
  NAME                               VARCHAR(32)                       NOT NULL ,
  KIND                               INTEGER                           NOT NULL ,
  TYPE                               INTEGER                           NOT NULL ,
  VERSION                            INTEGER                           NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                         NOT NULL ,
  PRIMARY_VIEW                       VARCHAR(32)                                ,
  DEFINITION                         BLOB(1073741823)                  NOT NULL ,
  VV_CFG                             BLOB(1073741823)                           ,
  DV_CFG                             BLOB(1073741823)                           ,
  MV_CFG                             BLOB(1073741823)                           ,
  MT_CFG                             BLOB(1073741823)                           ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( NAME )
) IN @INSTANCE@;

ALTER TABLE @SCHEMA@.QUERY_TABLE_T VOLATILE;

CREATE INDEX @SCHEMA@.QT_KI ON @SCHEMA@.QUERY_TABLE_T
(   
  KIND
);

CREATE INDEX @SCHEMA@.QT_TY ON @SCHEMA@.QUERY_TABLE_T
(   
  TYPE
);

CREATE TABLE @SCHEMA@.QUERY_TABLE_REF_T
(
  REFEREE                            VARCHAR(32)                       NOT NULL ,
  SOURCE                             VARCHAR(32)                       NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( REFEREE, SOURCE )
) IN @INSTANCE@;

ALTER TABLE @SCHEMA@.QUERY_TABLE_REF_T VOLATILE;

CREATE INDEX @SCHEMA@.QTR_SRC ON @SCHEMA@.QUERY_TABLE_REF_T
(   
  SOURCE
);

CREATE TABLE @SCHEMA@.MIGRATION_FRONT_T
(
  PIID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  MPTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  AIID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  STATE                              INTEGER                           NOT NULL ,
  SUB_STATE                          INTEGER                           NOT NULL ,
  STOP_REASON                        INTEGER                           NOT NULL ,
  SOURCE_ATID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  TARGET_ATID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  MIGRATION_TIME                     TIMESTAMP                         NOT NULL ,
  WSID_1                             CHAR(16)            FOR BIT DATA           ,
  WSID_1_HC                          INTEGER                                    ,
  WSID_2                             CHAR(16)            FOR BIT DATA           ,
  WSID_2_HC                          INTEGER                                    ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( PIID, MPTID, AIID )
) IN @INSTANCE@;

ALTER TABLE @SCHEMA@.MIGRATION_FRONT_T VOLATILE;

CREATE INDEX @SCHEMA@.MGF_MPTID ON @SCHEMA@.MIGRATION_FRONT_T
(   
  MPTID
);

CREATE TABLE @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
(
  SIID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  PIID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  COUNTER                            BIGINT                                     ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( SIID )
) IN @INSTANCE@;

CREATE INDEX @SCHEMA@.SCC_PIID ON @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
(   
  PIID
);

CREATE TABLE @SCHEMA@.RETRIEVED_GROUP_T
(
  QIID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  GROUP_NAME                         VARCHAR(128)                      NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( QIID, GROUP_NAME )
) IN @WORKITEM@;

ALTER TABLE @SCHEMA@.RETRIEVED_GROUP_T VOLATILE;

CREATE TABLE @SCHEMA@.WIS_META_DATA_T
(
  WSID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  HASH_CODE                          INTEGER                           NOT NULL ,
  OBJECT_TYPE                        INTEGER                           NOT NULL ,
  LAST_CHECK                         TIMESTAMP                         NOT NULL ,
  UNUSED                             SMALLINT                          NOT NULL ,
  AUTH_INFO_RETRIEVED_USER           SMALLINT                          NOT NULL ,
  AUTH_INFO_OWNER_ID                 SMALLINT                          NOT NULL ,
  AUTH_INFO_EVERYBODY                SMALLINT                          NOT NULL ,
  AUTH_INFO_GROUP                    SMALLINT                          NOT NULL ,
  AUTH_INFO_RETRIEVED_GROUP          SMALLINT                          NOT NULL ,
  AUTH_INFO_EMPTY                    SMALLINT                          NOT NULL ,
  SHARING_PATTERN                    INTEGER                           NOT NULL ,
  REASONS                            CHAR(32)            FOR BIT DATA  NOT NULL ,
  PARAMETER_A                        INTEGER                                    ,
  PARAMETER_B                        INTEGER                                    ,
  PARAMETER_C                        INTEGER                                    ,
  PARAMETER_D                        CHAR(16)            FOR BIT DATA           ,
  PARAMETER_E                        TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( WSID )
) IN @WORKITEM@;

ALTER TABLE @SCHEMA@.WIS_META_DATA_T VOLATILE;

CREATE TABLE @SCHEMA@.WIS_EMPTY_T
(
  WIID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  WSID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  HASH_CODE                          INTEGER                           NOT NULL ,
  WIS_HASH_CODE                      INTEGER                                    ,
  PARENT_WIID                        CHAR(16)            FOR BIT DATA           ,
  REASON                             INTEGER                           NOT NULL ,
  INHERITED                          SMALLINT                                   ,
  QIID                               CHAR(16)            FOR BIT DATA           ,
  OBJECT_TYPE                        INTEGER                           NOT NULL ,
  KIND                               INTEGER                           NOT NULL ,
  SHARING_PATTERN                    INTEGER                           NOT NULL ,
  ACCESS_KEY                         INTEGER                           NOT NULL ,
  PARAMETER_A                        INTEGER                                    ,
  PARAMETER_B                        INTEGER                                    ,
  PARAMETER_C                        INTEGER                                    ,
  PARAMETER_D                        CHAR(16)            FOR BIT DATA           ,
  PARAMETER_E                        TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( WIID )
) IN @WORKITEM@;

ALTER TABLE @SCHEMA@.WIS_EMPTY_T VOLATILE;

CREATE TABLE @SCHEMA@.SHARED_WORK_ITEM_T
(
  PKID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  WIID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  PARENT_WIID                        CHAR(16)            FOR BIT DATA           ,
  OWNER_ID                           VARCHAR(128)                               ,
  GROUP_NAME                         VARCHAR(128)                               ,
  EVERYBODY                          SMALLINT                          NOT NULL ,
  QIID                               CHAR(16)            FOR BIT DATA           ,
  OBJECT_TYPE                        INTEGER                           NOT NULL ,
  REASON                             INTEGER                           NOT NULL ,
  KIND                               INTEGER                           NOT NULL ,
  AUTH_INFO                          INTEGER                           NOT NULL ,
  SHARING_PATTERN                    INTEGER                           NOT NULL ,
  ACCESS_KEY                         INTEGER                           NOT NULL ,
  WSID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  HASH_CODE                          INTEGER                           NOT NULL ,
  WIS_HASH_CODE                      INTEGER                                    ,
  INHERITED                          SMALLINT                                   ,
  PARAMETER_A                        INTEGER                                    ,
  PARAMETER_B                        INTEGER                                    ,
  PARAMETER_C                        INTEGER                                    ,
  PARAMETER_D                        CHAR(16)            FOR BIT DATA           ,
  PARAMETER_E                        TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( PKID )
) IN @WORKITEM@;

ALTER TABLE @SCHEMA@.SHARED_WORK_ITEM_T VOLATILE;

CREATE TABLE @SCHEMA@.COMPLETION_TEMPLATE_T
(
  CMTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  ORDER_NUMBER                       INTEGER                           NOT NULL ,
  TKTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  CONTAINMENT_CONTEXT_ID             CHAR(16)            FOR BIT DATA  NOT NULL ,
  COMPL_CONDITION                    BLOB(3900K)                                ,
  CRITERION_FOR                      VARCHAR(254)                               ,
  COMPLETION_NAME                    VARCHAR(220)                               ,
  IS_DEFAULT_COMPLETION              SMALLINT                          NOT NULL ,
  PREFIX_MAP                         BLOB(3900K)                                ,
  USE_DEFAULT_RESULT_CONSTRUCT       SMALLINT                          NOT NULL ,
  PRIMARY KEY ( CMTID )
) IN @TEMPLATE@;

CREATE INDEX @SCHEMA@.CMPT_TKTID_ORDER ON @SCHEMA@.COMPLETION_TEMPLATE_T
(   
  TKTID, ORDER_NUMBER
);

CREATE INDEX @SCHEMA@.CMPT_CCID ON @SCHEMA@.COMPLETION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(
  RATID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  ORDER_NUMBER                       INTEGER                           NOT NULL ,
  CMTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  TKTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  CONTAINMENT_CONTEXT_ID             CHAR(16)            FOR BIT DATA  NOT NULL ,
  AGGR_PART                          VARCHAR(254)                               ,
  AGGR_LOCATION                      BLOB(3900K)                                ,
  AGGR_FUNCTION                      VARCHAR(254)                      NOT NULL ,
  AGGR_CONDITION                     BLOB(3900K)                                ,
  PREFIX_MAP                         BLOB(3900K)                                ,
  PRIMARY KEY ( RATID )
) IN @TEMPLATE@;

CREATE INDEX @SCHEMA@.RAGT_CMTID_ORD_TT ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(   
  CMTID, ORDER_NUMBER, TKTID
);

CREATE INDEX @SCHEMA@.RAGT_CCID ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.TASK_HISTORY_T
(
  PKID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  EVENT                              INTEGER                           NOT NULL ,
  TKIID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  CONTAINMENT_CONTEXT_ID             CHAR(16)            FOR BIT DATA  NOT NULL ,
  PARENT_TKIID                       CHAR(16)            FOR BIT DATA           ,
  ESIID                              CHAR(16)            FOR BIT DATA           ,
  REASON                             INTEGER                           NOT NULL ,
  EVENT_TIME                         TIMESTAMP                         NOT NULL ,
  NEXT_TIME                          TIMESTAMP                                  ,
  WSID_1                             CHAR(16)            FOR BIT DATA           ,
  WSID_1_HC                          INTEGER                                    ,
  WSID_2                             CHAR(16)            FOR BIT DATA           ,
  WSID_2_HC                          INTEGER                                    ,
  PRINCIPAL                          VARCHAR(128)                      NOT NULL ,
  WORK_ITEM_KIND                     INTEGER                           NOT NULL ,
  FROM_ID                            VARCHAR(128)                               ,
  TO_ID                              VARCHAR(128)                               ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( PKID )
) IN @INSTANCE@;

ALTER TABLE @SCHEMA@.TASK_HISTORY_T VOLATILE;

CREATE INDEX @SCHEMA@.TH_TKIID ON @SCHEMA@.TASK_HISTORY_T
(   
  TKIID
);

CREATE INDEX @SCHEMA@.TH_CTXID ON @SCHEMA@.TASK_HISTORY_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.COMPLETION_INSTANCE_T
(
  CMIID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  ORDER_NUMBER                       INTEGER                           NOT NULL ,
  TKIID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  CONTAINMENT_CONTEXT_ID             CHAR(16)            FOR BIT DATA  NOT NULL ,
  COMPL_CONDITION                    BLOB(3900K)                                ,
  CRITERION_FOR                      VARCHAR(254)                               ,
  CRITERION_FOR_TIME                 TIMESTAMP                                  ,
  COMPLETION_NAME                    VARCHAR(220)                               ,
  IS_DEFAULT_COMPLETION              SMALLINT                          NOT NULL ,
  PREFIX_MAP                         BLOB(3900K)                                ,
  USE_DEFAULT_RESULT_CONSTRUCT       SMALLINT                          NOT NULL ,
  SCHEDULER_ID                       VARCHAR(254)                               ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( CMIID )
) IN @INSTANCE@;

CREATE INDEX @SCHEMA@.CMPI_TKIID_ORDER ON @SCHEMA@.COMPLETION_INSTANCE_T
(   
  TKIID, ORDER_NUMBER
);

CREATE INDEX @SCHEMA@.CMPI_CCID ON @SCHEMA@.COMPLETION_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(
  RAIID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  ORDER_NUMBER                       INTEGER                           NOT NULL ,
  CMIID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  TKIID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  CONTAINMENT_CONTEXT_ID             CHAR(16)            FOR BIT DATA  NOT NULL ,
  AGGR_PART                          VARCHAR(254)                               ,
  AGGR_LOCATION                      BLOB(3900K)                                ,
  AGGR_FUNCTION                      VARCHAR(254)                      NOT NULL ,
  AGGR_CONDITION                     BLOB(3900K)                                ,
  PREFIX_MAP                         BLOB(3900K)                                ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( RAIID )
) IN @INSTANCE@;

CREATE INDEX @SCHEMA@.RAGI_CMIID_ORDER ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(   
  CMIID, ORDER_NUMBER
);

CREATE INDEX @SCHEMA@.RAGI_CCID ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.SAVED_TASK_MESSAGE_T
(
  STMID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  RELATED_OID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  CONTAINMENT_CONTEXT_ID             CHAR(16)            FOR BIT DATA  NOT NULL ,
  KIND                               INTEGER                           NOT NULL ,
  SCHEDULER_ID                       VARCHAR(254)                               ,
  CREATION_TIME                      TIMESTAMP                         NOT NULL ,
  EXPECTED_ARRIVAL_TIME              TIMESTAMP                         NOT NULL ,
  MESSAGE                            BLOB(1073741823)                           ,
  MESSAGE_IL                         VARCHAR(3000)       FOR BIT DATA           ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( STMID )
) IN @INSTANCE@;

ALTER TABLE @SCHEMA@.SAVED_TASK_MESSAGE_T VOLATILE;

CREATE INDEX @SCHEMA@.STM_ROID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  RELATED_OID
);

CREATE INDEX @SCHEMA@.STM_SID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  SCHEDULER_ID
);

CREATE INDEX @SCHEMA@.STM_CTXID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.WORK_BASKET_T
(
  WBID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  WSID_1                             CHAR(16)            FOR BIT DATA           ,
  WSID_1_HC                          INTEGER                                    ,
  WSID_2                             CHAR(16)            FOR BIT DATA           ,
  WSID_2_HC                          INTEGER                                    ,
  NAME                               VARCHAR(254)                      NOT NULL ,
  TYPE                               INTEGER                           NOT NULL ,
  OWNER                              VARCHAR(128)                               ,
  SUBSTITUTION_POLICY                INTEGER                           NOT NULL ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR(254)                      NOT NULL ,
  DEFAULT_QUERY_TABLE                VARCHAR(32)                                ,
  CUSTOM_TEXT1                       VARCHAR(254)                               ,
  CUSTOM_TEXT2                       VARCHAR(254)                               ,
  CUSTOM_TEXT3                       VARCHAR(254)                               ,
  CUSTOM_TEXT4                       VARCHAR(254)                               ,
  CUSTOM_TEXT5                       VARCHAR(254)                               ,
  CUSTOM_TEXT6                       VARCHAR(254)                               ,
  CUSTOM_TEXT7                       VARCHAR(254)                               ,
  CUSTOM_TEXT8                       VARCHAR(254)                               ,
  EXTENDED_DATA                      BLOB(3900K)                                ,
  CREATION_TIME                      TIMESTAMP                         NOT NULL ,
  LAST_MODIFICATION_TIME             TIMESTAMP                         NOT NULL ,
  CREATED_WITH_VERSION               INTEGER                           NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( WBID )
) IN @INSTANCE@;

ALTER TABLE @SCHEMA@.WORK_BASKET_T VOLATILE;

CREATE INDEX @SCHEMA@.WBK_NAME ON @SCHEMA@.WORK_BASKET_T
(   
  NAME
);

CREATE INDEX @SCHEMA@.WBK_TYPE ON @SCHEMA@.WORK_BASKET_T
(   
  TYPE
);

CREATE TABLE @SCHEMA@.WORK_BASKET_LDESC_T
(
  WBID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  LOCALE                             VARCHAR(32)                       NOT NULL ,
  WSID_1                             CHAR(16)            FOR BIT DATA           ,
  WSID_1_HC                          INTEGER                                    ,
  WSID_2                             CHAR(16)            FOR BIT DATA           ,
  WSID_2_HC                          INTEGER                                    ,
  DISPLAY_NAME                       VARCHAR(64)                                ,
  DESCRIPTION                        VARCHAR(254)                               ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( WBID, LOCALE )
) IN @INSTANCE@;

ALTER TABLE @SCHEMA@.WORK_BASKET_LDESC_T VOLATILE;

CREATE TABLE @SCHEMA@.WORK_BASKET_DIST_TARGET_T
(
  SOURCE_WBID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  TARGET_WBID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  WSID_1                             CHAR(16)            FOR BIT DATA           ,
  WSID_1_HC                          INTEGER                                    ,
  WSID_2                             CHAR(16)            FOR BIT DATA           ,
  WSID_2_HC                          INTEGER                                    ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( SOURCE_WBID, TARGET_WBID )
) IN @INSTANCE@;

ALTER TABLE @SCHEMA@.WORK_BASKET_DIST_TARGET_T VOLATILE;

CREATE INDEX @SCHEMA@.WBDT_TWB ON @SCHEMA@.WORK_BASKET_DIST_TARGET_T
(   
  TARGET_WBID
);

CREATE TABLE @SCHEMA@.BUSINESS_CATEGORY_T
(
  BCID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  PARENT_BCID                        CHAR(16)            FOR BIT DATA           ,
  WSID_1                             CHAR(16)            FOR BIT DATA           ,
  WSID_1_HC                          INTEGER                                    ,
  WSID_2                             CHAR(16)            FOR BIT DATA           ,
  WSID_2_HC                          INTEGER                                    ,
  NAME                               VARCHAR(254)                      NOT NULL ,
  PRIORITY                           INTEGER                                    ,
  SUBSTITUTION_POLICY                INTEGER                           NOT NULL ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR(254)                      NOT NULL ,
  DEFAULT_QUERY_TABLE                VARCHAR(32)                                ,
  CUSTOM_TEXT1                       VARCHAR(254)                               ,
  CUSTOM_TEXT2                       VARCHAR(254)                               ,
  CUSTOM_TEXT3                       VARCHAR(254)                               ,
  CUSTOM_TEXT4                       VARCHAR(254)                               ,
  CUSTOM_TEXT5                       VARCHAR(254)                               ,
  CUSTOM_TEXT6                       VARCHAR(254)                               ,
  CUSTOM_TEXT7                       VARCHAR(254)                               ,
  CUSTOM_TEXT8                       VARCHAR(254)                               ,
  EXTENDED_DATA                      BLOB(3900K)                                ,
  CREATION_TIME                      TIMESTAMP                         NOT NULL ,
  LAST_MODIFICATION_TIME             TIMESTAMP                         NOT NULL ,
  CREATED_WITH_VERSION               INTEGER                           NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( BCID )
) IN @INSTANCE@;

ALTER TABLE @SCHEMA@.BUSINESS_CATEGORY_T VOLATILE;

CREATE INDEX @SCHEMA@.BCG_PARENTBCID ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  PARENT_BCID
);

CREATE INDEX @SCHEMA@.BCG_NAME ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  NAME
);

CREATE TABLE @SCHEMA@.BUSINESS_CATEGORY_LDESC_T
(
  BCID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  LOCALE                             VARCHAR(32)                       NOT NULL ,
  WSID_1                             CHAR(16)            FOR BIT DATA           ,
  WSID_1_HC                          INTEGER                                    ,
  WSID_2                             CHAR(16)            FOR BIT DATA           ,
  WSID_2_HC                          INTEGER                                    ,
  DISPLAY_NAME                       VARCHAR(64)                                ,
  DESCRIPTION                        VARCHAR(254)                               ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( BCID, LOCALE )
) IN @INSTANCE@;

ALTER TABLE @SCHEMA@.BUSINESS_CATEGORY_LDESC_T VOLATILE;
ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                      ;
ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ADD 
    EXTENDED_AUTO_DELETE               INTEGER                           DEFAULT 2 NOT NULL ;
ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ADD 
    CONTINUE_ON_ERROR                  SMALLINT                          DEFAULT 1 NOT NULL ;
ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ADD 
    IGNORE_MISSING_DATA                INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ADD 
    EAR_VERSION                        INTEGER                           DEFAULT 0 NOT NULL ;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                      ;

ALTER TABLE @SCHEMA@.SCOPE_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                      ;
ALTER TABLE @SCHEMA@.SCOPE_TEMPLATE_B_T
 ADD 
    A_TKTID                            CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.SCOPE_TEMPLATE_B_T
 ADD 
    IS_IMPLICIT                        SMALLINT                          DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.SCOPE_TEMPLATE_B_T
 ADD 
    HAS_COMPENSATION_HANDLER           SMALLINT                          DEFAULT 1 NOT NULL ;

ALTER TABLE @SCHEMA@.ACTIVITY_SERVICE_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                      ;

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    EXIT_CONDITION                     INTEGER                           DEFAULT 1 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    EXIT_CONDITION_NAME                VARCHAR(254)                     ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    EXIT_CONDITION_EXECUTE_AT          INTEGER                           DEFAULT 3 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    SOURCES_TYPE                       INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    TARGETS_TYPE                       INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    PARENT_ATID                        CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    HAS_CROSSING_LINK                  SMALLINT                         ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                      ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    EXIT_EXPRESSION                    CLOB(3900K)                      ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    COMPENSATION_ATID                  CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    IS_IN_GFLOW                        SMALLINT                          DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    IS_REGION_BEGIN                    SMALLINT                          DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    CORRESPONDING_IORATID              CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    IS_GFLOW                           SMALLINT                          DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    EXPRESSION_MAP                     BLOB(3900K)                      ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    EXIT_EXPRESSION_MAP                BLOB(3900K)                      ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    GENERATED_BY                       VARCHAR(220)                     ;

ALTER TABLE @SCHEMA@.ALARM_TEMPLATE_B_T
 ADD 
    EXPRESSION_MAP                     BLOB(3900K)                      ;
ALTER TABLE @SCHEMA@.ALARM_TEMPLATE_B_T
 ADD 
    REPEAT_EXPRESSION_MAP              BLOB(3900K)                      ;
ALTER TABLE @SCHEMA@.ALARM_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                      ;

ALTER TABLE @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
 ADD 
    FAULT_LINK_SOURCE_ATID             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
 ADD 
    FAULT_LINK_TARGET_ATID             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                      ;

ALTER TABLE @SCHEMA@.LINK_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                      ;
ALTER TABLE @SCHEMA@.LINK_TEMPLATE_B_T
 ADD 
    EXPRESSION_MAP                     BLOB(3900K)                      ;
ALTER TABLE @SCHEMA@.LINK_TEMPLATE_B_T
 ADD 
    GENERATED_BY                       VARCHAR(220)                     ;
ALTER TABLE @SCHEMA@.LINK_TEMPLATE_B_T
 ADD 
    RTID                               CHAR(16)            FOR BIT DATA ;

ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                      ;
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    GENERATED_BY                       VARCHAR(220)                     ;
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    SEQUENCE_NUMBER                    INTEGER                           DEFAULT 1 NOT NULL ;
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    FROM_VARIABLE_CTID                 CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    FROM_PARAMETER2                    VARCHAR(254)                     ;
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    FROM_PARAMETER3                    BLOB(3900K)                      ;
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    FROM_PARAMETER3_LANGUAGE           INTEGER                           DEFAULT 1 NOT NULL ;
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    FROM_EXPRESSION_MAP                BLOB(3900K)                      ;

ALTER TABLE @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                      ;

ALTER TABLE @SCHEMA@.ASSIGN_TEMPLATE_B_T
 ADD 
    FROM_EXPRESSION_MAP                BLOB(3900K)                      ;
ALTER TABLE @SCHEMA@.ASSIGN_TEMPLATE_B_T
 ADD 
    TO_EXPRESSION_MAP                  BLOB(3900K)                      ;

ALTER TABLE @SCHEMA@.CORRELATION_SET_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                      ;

ALTER TABLE @SCHEMA@.EVENT_HANDLER_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                      ;

ALTER TABLE @SCHEMA@.EHALARM_TEMPLATE_B_T
 ADD 
    EXPRESSION_MAP                     BLOB(3900K)                      ;
ALTER TABLE @SCHEMA@.EHALARM_TEMPLATE_B_T
 ADD 
    REPEAT_EXPRESSION_MAP              BLOB(3900K)                      ;

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                      ;

ALTER TABLE @SCHEMA@.FOR_EACH_TEMPLATE_B_T
 ADD 
    START_COUNTER_EXPRESSION_MAP       BLOB(3900K)                      ;
ALTER TABLE @SCHEMA@.FOR_EACH_TEMPLATE_B_T
 ADD 
    FINAL_COUNTER_EXPRESSION_MAP       BLOB(3900K)                      ;
ALTER TABLE @SCHEMA@.FOR_EACH_TEMPLATE_B_T
 ADD 
    COMPLETION_COND_EXPRESSION_MAP     BLOB(3900K)                      ;

ALTER TABLE @SCHEMA@.STAFF_QUERY_TEMPLATE_T
 ADD 
    STAFF_VERB                         BLOB(3900K)                      ;

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    SHARED_PC_ID                       CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    SCHEDULER_TASK_ID                  VARCHAR(254)                     ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    RESUMES                            TIMESTAMP                        ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    PENDING_SKIP_REQUEST               SMALLINT                          DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    IS_MIGRATED                        SMALLINT                          DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    UNHANDLED_EXCEPTION                BLOB(1073741823)                 ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    CREATED_WITH_VERSION               INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.SCOPE_INSTANCE_B_T
 ADD 
    A_TKIID                            CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.SCOPE_INSTANCE_B_T
 ADD 
    HAS_COMPENSATION_WORK              SMALLINT                          DEFAULT 1 NOT NULL ;

ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    INVOKED_INSTANCE_ID                CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    INVOKED_INSTANCE_TYPE              INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    STOP_REASON                        INTEGER                           DEFAULT 1 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    PREVIOUS_STATE                     INTEGER                          ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    SKIP_REQUESTED                     SMALLINT                          DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    JUMP_TARGET_ATID                   CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    SUB_STATE                          INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    PENDING_REQUEST_DATA               BLOB(1073741823)                 ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    XTID                               CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    EXPIRATION_COUNTER                 INTEGER                          ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    PREVIOUS_EXPIRATION_DATE           TIMESTAMP                        ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    TARGET_IORAIID                     CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                      ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    MAX_COMPENSATION_NUMBER            BIGINT                           ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    HAS_WORK_ITEM                      SMALLINT                         ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_T
 ADD 
    DATA_IL                            VARCHAR(3000)       FOR BIT DATA ;

ALTER TABLE @SCHEMA@.EVENT_INSTANCE_B_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.EVENT_INSTANCE_B_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.EVENT_INSTANCE_B_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.EVENT_INSTANCE_B_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
 ADD 
    ATID                               CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
 ADD 
    COMPENSATE_AIID                    CHAR(16)            FOR BIT DATA ;

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ADD 
    DATA_TYPE                          VARCHAR(254)                     ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ADD 
    DATA                               BLOB(1073741823)                 ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.PROCESS_CONTEXT_T
 ADD 
    SHARED                             SMALLINT                         ;
ALTER TABLE @SCHEMA@.PROCESS_CONTEXT_T
 ADD 
    STARTER_EXPIRES                    TIMESTAMP                        ;

ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ADD 
    DATA_TYPE                          VARCHAR(254)                     ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ADD 
    DATA                               BLOB(1073741823)                 ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.NAVIGATION_EXCEPTION_T
 ADD 
    PIID                               CHAR(16)            FOR BIT DATA ;

ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.WORK_ITEM_T
 ADD 
    PARENT_WIID                        CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.WORK_ITEM_T
 ADD 
    AUTH_INFO                          INTEGER                           DEFAULT 0 NOT NULL ;

ALTER TABLE @SCHEMA@.WI_ASSOC_OID_T
 ADD 
    MIGRATED                           SMALLINT                          DEFAULT 0 NOT NULL ;

ALTER TABLE @SCHEMA@.STAFF_QUERY_INSTANCE_T
 ADD 
    NORMALIZED                         SMALLINT                         ;
ALTER TABLE @SCHEMA@.STAFF_QUERY_INSTANCE_T
 ADD 
    DENORMALIZED                       SMALLINT                         ;

ALTER TABLE @SCHEMA@.APPLICATION_COMPONENT_T
 ADD 
    SUBSTITUTION_POLICY                INTEGER                           DEFAULT 0 NOT NULL ;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    AUTO_DELETE_MODE                   INTEGER                           DEFAULT 2 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    AUTONOMY                           INTEGER                           DEFAULT 1 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    PRIORITY_DEFINITION                VARCHAR(254)                     ;
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    SUBSTITUTION_POLICY                INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    ASSIGNMENT_TYPE                    INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    INHERITED_AUTH                     INTEGER                           DEFAULT 2 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    PARALLEL_INHERITED_AUTH            INTEGER                           DEFAULT 2 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    EAR_VERSION                        INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    SCHEMA_VERSION                     INTEGER                           DEFAULT 0 NOT NULL ;

ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ADD 
    WSID_2_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ADD 
    ESCALATION_TIME                    TIMESTAMP                        ;

ALTER TABLE @SCHEMA@.ESC_INST_CPROP_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ESC_INST_CPROP_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.ESC_INST_CPROP_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ESC_INST_CPROP_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.ESC_INST_LDESC_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ESC_INST_LDESC_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.ESC_INST_LDESC_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ESC_INST_LDESC_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    AUTO_DELETE_MODE                   INTEGER                           DEFAULT 2 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    IS_CHILD                           SMALLINT                          DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    HAS_ESCALATIONS                    SMALLINT                         ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    RESUMES                            TIMESTAMP                        ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    SUBSTITUTION_POLICY                INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    DELETION_TIME                      TIMESTAMP                        ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    ASSIGNMENT_TYPE                    INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    INHERITED_AUTH                     INTEGER                           DEFAULT 2 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    PARALLEL_INHERITED_AUTH            INTEGER                           DEFAULT 2 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    INVOKED_INSTANCE_ID                CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    INVOKED_INSTANCE_TYPE              INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    IS_READ                            SMALLINT                          DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    IS_TRANSFERRED_TO_WORK_BASKET      SMALLINT                          DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    CREATED_WITH_VERSION               INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;

ALTER TABLE @SCHEMA@.TASK_INST_CPROP_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.TASK_INST_CPROP_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.TASK_INST_CPROP_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.TASK_INST_CPROP_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.TASK_INST_LDESC_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.TASK_INST_LDESC_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.TASK_INST_LDESC_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.TASK_INST_LDESC_T
 ADD 
    WSID_2_HC                          INTEGER                          ;


CREATE INDEX @SCHEMA@.PTB_SBLKN ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  S_BEAN60_LOOKUP_NAME
);

CREATE INDEX @SCHEMA@.AIB_PI_ATID_EH_FE ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID, ATID, EHIID, ENCLOSING_FEIID
);

CREATE INDEX @SCHEMA@.AIB_PI_DIS_EH_FE ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID, DISPLAY_ID_EXT, EHIID, ENCLOSING_FEIID
);

CREATE INDEX @SCHEMA@.AIB_ATID_STAT ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  ATID, STATE
);

CREATE INDEX @SCHEMA@.EI_PIID_PRIM ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  PIID, IS_PRIMARY_EVENT_INSTANCE, STATE
);

CREATE INDEX @SCHEMA@.EI_PIID_VTID ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  PIID, VTID, IS_PRIMARY_EVENT_INSTANCE
);

CREATE INDEX @SCHEMA@.EI_STATE_VTID ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  VTID, STATE, EIID, AIID, PIID
);

CREATE INDEX @SCHEMA@.PIA_DATY ON @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
(   
  DATA_TYPE
);

CREATE INDEX @SCHEMA@.AIA_DATY ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
  DATA_TYPE
);

CREATE INDEX @SCHEMA@.NE_PIID ON @SCHEMA@.NAVIGATION_EXCEPTION_T
(   
  PIID
);

CREATE INDEX @SCHEMA@.AWI_AIID ON @SCHEMA@.AWAITED_INVOCATION_T
(   
  AIID
);

CREATE INDEX @SCHEMA@.WI_ASSOBJ_REASON ON @SCHEMA@.WORK_ITEM_T
(   
  ASSOCIATED_OID, ASSOCIATED_OBJECT_TYPE, REASON, PARENT_WIID
);

CREATE INDEX @SCHEMA@.WI_AUTH_L ON @SCHEMA@.WORK_ITEM_T
(   
  EVERYBODY, GROUP_NAME, OWNER_ID, QIID
);

CREATE INDEX @SCHEMA@.WI_AUTH_U ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, QIID
);

CREATE INDEX @SCHEMA@.WI_AUTH_O ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, OWNER_ID DESC
);

CREATE INDEX @SCHEMA@.WI_AUTH_G ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, GROUP_NAME
);

CREATE INDEX @SCHEMA@.WI_AUTH_E ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, EVERYBODY
);

CREATE INDEX @SCHEMA@.WI_AUTH_R ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, REASON DESC
);

CREATE INDEX @SCHEMA@.WI_QI_OID_RS_OWN ON @SCHEMA@.WORK_ITEM_T
(   
  QIID, OBJECT_ID, REASON, OWNER_ID
);

CREATE INDEX @SCHEMA@.WI_QI_OID_OWN ON @SCHEMA@.WORK_ITEM_T
(   
  QIID, OBJECT_ID, OWNER_ID
);

CREATE INDEX @SCHEMA@.WI_OT_OID_RS ON @SCHEMA@.WORK_ITEM_T
(   
  OBJECT_TYPE, OBJECT_ID, REASON
);

CREATE INDEX @SCHEMA@.WI_WI_QI ON @SCHEMA@.WORK_ITEM_T
(   
  WIID, QIID
);

CREATE INDEX @SCHEMA@.WI_PWIID_OID ON @SCHEMA@.WORK_ITEM_T
(   
  PARENT_WIID, OBJECT_ID
);

CREATE INDEX @SCHEMA@.WI_PWIID_QIID ON @SCHEMA@.WORK_ITEM_T
(   
  PARENT_WIID, QIID
);

CREATE INDEX @SCHEMA@.WI_AUTH_GR_O_E ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, GROUP_NAME, OWNER_ID, EVERYBODY
);

CREATE INDEX @SCHEMA@.WIASS_WI ON @SCHEMA@.WI_ASSOC_OID_T
(   
  WIID
);

CREATE INDEX @SCHEMA@.WIASS_MIG ON @SCHEMA@.WI_ASSOC_OID_T
(   
  MIGRATED, WIID, OBJECT_ID, OBJECT_TYPE, ASSOCIATED_OID, REASON
);

CREATE INDEX @SCHEMA@.RUT_QIID ON @SCHEMA@.RETRIEVED_USER_T
(   
  QIID
);

CREATE INDEX @SCHEMA@.RUT_OWN_QIDESC ON @SCHEMA@.RETRIEVED_USER_T
(   
  OWNER_ID, QIID DESC
);

CREATE INDEX @SCHEMA@.TT_KND_INLN_VAL ON @SCHEMA@.TASK_TEMPLATE_T
(   
  KIND, IS_INLINE, VALID_FROM
);

CREATE INDEX @SCHEMA@.TTLD_TT_LOC ON @SCHEMA@.TASK_TEMPL_LDESC_T
(   
  TKTID, LOCALE DESC
);

CREATE INDEX @SCHEMA@.ESI_EST_ESI ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  ESTID, ESIID
);

CREATE INDEX @SCHEMA@.TI_TI_KND_ST ON @SCHEMA@.TASK_INSTANCE_T
(   
  TKIID, KIND, STATE
);

CREATE INDEX @SCHEMA@.TI_ST_KND_TI_NAME ON @SCHEMA@.TASK_INSTANCE_T
(   
  STATE, KIND, TKIID, NAME
);

CREATE INDEX @SCHEMA@.TI_TT_KND ON @SCHEMA@.TASK_INSTANCE_T
(   
  TKTID, KIND
);

CREATE INDEX @SCHEMA@.TI_TYPE ON @SCHEMA@.TASK_INSTANCE_T
(   
  TYPE
);

-- View: ProcessTemplate
CREATE VIEW @SCHEMA@.PROCESS_TEMPLATE(PTID, NAME, DISPLAY_NAME, VALID_FROM, TARGET_NAMESPACE, APPLICATION_NAME, VERSION, CREATED, STATE, EXECUTION_MODE, DESCRIPTION, CAN_RUN_SYNC, CAN_RUN_INTERRUP, COMP_SPHERE, CONTINUE_ON_ERROR ) AS
 SELECT @SCHEMA@.PROCESS_TEMPLATE_B_T.PTID, @SCHEMA@.PROCESS_TEMPLATE_B_T.NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.DISPLAY_NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.VALID_FROM, @SCHEMA@.PROCESS_TEMPLATE_B_T.TARGET_NAMESPACE, @SCHEMA@.PROCESS_TEMPLATE_B_T.APPLICATION_NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.VERSION, @SCHEMA@.PROCESS_TEMPLATE_B_T.CREATED, @SCHEMA@.PROCESS_TEMPLATE_B_T.STATE, @SCHEMA@.PROCESS_TEMPLATE_B_T.EXECUTION_MODE, @SCHEMA@.PROCESS_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_TEMPLATE_B_T.CAN_CALL, @SCHEMA@.PROCESS_TEMPLATE_B_T.CAN_INITIATE, @SCHEMA@.PROCESS_TEMPLATE_B_T.COMPENSATION_SPHERE, @SCHEMA@.PROCESS_TEMPLATE_B_T.CONTINUE_ON_ERROR
 FROM @SCHEMA@.PROCESS_TEMPLATE_B_T;

-- View: ProcessTemplAttr
CREATE VIEW @SCHEMA@.PROCESS_TEMPL_ATTR(PTID, NAME, VALUE ) AS
 SELECT @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.PTID, @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.ATTR_KEY, @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.VALUE
 FROM @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T;

-- View: ProcessInstance
CREATE VIEW @SCHEMA@.PROCESS_INSTANCE(PTID, PIID, NAME, STATE, CREATED, STARTED, COMPLETED, PARENT_NAME, TOP_LEVEL_NAME, PARENT_PIID, TOP_LEVEL_PIID, STARTER, DESCRIPTION, TEMPLATE_NAME, TEMPLATE_DESCR, RESUMES, CONTINUE_ON_ERROR, IS_MIGRATED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.PROCESS_INSTANCE_B_T.PTID, @SCHEMA@.PROCESS_INSTANCE_B_T.PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.STATE, @SCHEMA@.PROCESS_INSTANCE_B_T.CREATED, @SCHEMA@.PROCESS_INSTANCE_B_T.STARTED, @SCHEMA@.PROCESS_INSTANCE_B_T.COMPLETED, @SCHEMA@.PROCESS_INSTANCE_B_T.PARENT_NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.TOP_LEVEL_NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.PARENT_PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.TOP_LEVEL_PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.STARTER, @SCHEMA@.PROCESS_INSTANCE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_TEMPLATE_B_T.NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_INSTANCE_B_T.RESUMES, @SCHEMA@.PROCESS_TEMPLATE_B_T.CONTINUE_ON_ERROR, @SCHEMA@.PROCESS_INSTANCE_B_T.IS_MIGRATED, @SCHEMA@.PROCESS_INSTANCE_B_T.WSID_1, @SCHEMA@.PROCESS_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.PROCESS_INSTANCE_B_T, @SCHEMA@.PROCESS_TEMPLATE_B_T
 WHERE @SCHEMA@.PROCESS_INSTANCE_B_T.PTID = @SCHEMA@.PROCESS_TEMPLATE_B_T.PTID;

-- View: ProcessAttribute
CREATE VIEW @SCHEMA@.PROCESS_ATTRIBUTE(PIID, NAME, VALUE, DATA_TYPE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.PIID, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.ATTR_KEY, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.VALUE, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.DATA_TYPE, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.WSID_1, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.WSID_2
 FROM @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T;

-- View: Activity
CREATE VIEW @SCHEMA@.ACTIVITY(PIID, AIID, PTID, ATID, SIID, STID, EHIID, ENCLOSING_FEIID, KIND, COMPLETED, ACTIVATED, FIRST_ACTIVATED, STARTED, STATE, SUB_STATE, STOP_REASON, OWNER, DESCRIPTION, EXPIRES, TEMPLATE_NAME, TEMPLATE_DESCR, BUSINESS_RELEVANCE, SKIP_REQUESTED, CONTINUE_ON_ERROR, INVOKED_INST_ID, INVOKED_INST_TYPE, PREVIOUS_EXPIRATION_TIME, HAS_WORK_ITEM, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ACTIVITY_INSTANCE_B_T.PIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.AIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.PTID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ATID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SIID, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.PARENT_STID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.EHIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ENCLOSING_FEIID, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.KIND, @SCHEMA@.ACTIVITY_INSTANCE_B_T.FINISHED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ACTIVATED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.FIRST_ACTIVATED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STARTED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SUB_STATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STOP_REASON, @SCHEMA@.ACTIVITY_INSTANCE_B_T.OWNER, @SCHEMA@.ACTIVITY_INSTANCE_B_T.DESCRIPTION, @SCHEMA@.ACTIVITY_INSTANCE_B_T.EXPIRES, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.NAME, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.BUSINESS_RELEVANCE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SKIP_REQUESTED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.CONTINUE_ON_ERROR, @SCHEMA@.ACTIVITY_INSTANCE_B_T.INVOKED_INSTANCE_ID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.INVOKED_INSTANCE_TYPE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.PREVIOUS_EXPIRATION_DATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.HAS_WORK_ITEM, @SCHEMA@.ACTIVITY_INSTANCE_B_T.WSID_1, @SCHEMA@.ACTIVITY_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.ACTIVITY_INSTANCE_B_T, @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 WHERE @SCHEMA@.ACTIVITY_INSTANCE_B_T.ATID = @SCHEMA@.ACTIVITY_TEMPLATE_B_T.ATID;

-- View: ActivityAttribute
CREATE VIEW @SCHEMA@.ACTIVITY_ATTRIBUTE(AIID, NAME, VALUE, DATA_TYPE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.AIID, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.ATTR_KEY, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.ATTR_VALUE, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.DATA_TYPE, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.WSID_1, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.WSID_2
 FROM @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T;

-- View: Event
CREATE VIEW @SCHEMA@.EVENT(EIID, AIID, PIID, EHTID, SIID, NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.EVENT_INSTANCE_B_T.EIID, @SCHEMA@.EVENT_INSTANCE_B_T.AIID, @SCHEMA@.EVENT_INSTANCE_B_T.PIID, @SCHEMA@.EVENT_INSTANCE_B_T.EHTID, @SCHEMA@.EVENT_INSTANCE_B_T.SIID, @SCHEMA@.SERVICE_TEMPLATE_B_T.NAME, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_1, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.EVENT_INSTANCE_B_T, @SCHEMA@.SERVICE_TEMPLATE_B_T
 WHERE @SCHEMA@.EVENT_INSTANCE_B_T.STATE = 2 AND @SCHEMA@.EVENT_INSTANCE_B_T.VTID = @SCHEMA@.SERVICE_TEMPLATE_B_T.VTID;

-- View: WorkItem
CREATE VIEW @SCHEMA@.WORK_ITEM(WIID, OWNER_ID, GROUP_NAME, EVERYBODY, OBJECT_TYPE, OBJECT_ID, ASSOC_OBJECT_TYPE, ASSOC_OID, REASON, CREATION_TIME, QIID, KIND ) AS
 SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T
 WHERE @SCHEMA@.WORK_ITEM_T.QIID IS NULL OR @SCHEMA@.WORK_ITEM_T.EVERYBODY = 1
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WI_ASSOC_OID_T.OBJECT_TYPE, @SCHEMA@.WI_ASSOC_OID_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WI_ASSOC_OID_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T, @SCHEMA@.WI_ASSOC_OID_T
 WHERE @SCHEMA@.WORK_ITEM_T.WIID = @SCHEMA@.WI_ASSOC_OID_T.WIID AND (@SCHEMA@.WORK_ITEM_T.QIID IS NULL OR @SCHEMA@.WORK_ITEM_T.EVERYBODY = 1)
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.RETRIEVED_USER_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T, @SCHEMA@.RETRIEVED_USER_T
 WHERE @SCHEMA@.WORK_ITEM_T.QIID = @SCHEMA@.RETRIEVED_USER_T.QIID
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.RETRIEVED_USER_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WI_ASSOC_OID_T.OBJECT_TYPE, @SCHEMA@.WI_ASSOC_OID_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WI_ASSOC_OID_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T, @SCHEMA@.RETRIEVED_USER_T, @SCHEMA@.WI_ASSOC_OID_T
 WHERE @SCHEMA@.WORK_ITEM_T.QIID = @SCHEMA@.RETRIEVED_USER_T.QIID AND @SCHEMA@.WORK_ITEM_T.WIID = @SCHEMA@.WI_ASSOC_OID_T.WIID;

-- View: ActivityService
CREATE VIEW @SCHEMA@.ACTIVITY_SERVICE(EIID, AIID, PIID, VTID, PORT_TYPE, NAME_SPACE_URI, OPERATION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.EVENT_INSTANCE_B_T.EIID, @SCHEMA@.EVENT_INSTANCE_B_T.AIID, @SCHEMA@.EVENT_INSTANCE_B_T.PIID, @SCHEMA@.EVENT_INSTANCE_B_T.VTID, @SCHEMA@.SERVICE_TEMPLATE_B_T.PORT_TYPE_NAME,@SCHEMA@.URI_TEMPLATE_B_T.URI, @SCHEMA@.SERVICE_TEMPLATE_B_T.OPERATION_NAME, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_1, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.EVENT_INSTANCE_B_T, @SCHEMA@.SERVICE_TEMPLATE_B_T, @SCHEMA@.URI_TEMPLATE_B_T
 WHERE @SCHEMA@.EVENT_INSTANCE_B_T.STATE = 2 AND @SCHEMA@.EVENT_INSTANCE_B_T.VTID = @SCHEMA@.SERVICE_TEMPLATE_B_T.VTID AND @SCHEMA@.SERVICE_TEMPLATE_B_T.PORT_TYPE_UTID = @SCHEMA@.URI_TEMPLATE_B_T.UTID;

-- View: QueryProperty
CREATE VIEW @SCHEMA@.QUERY_PROPERTY(PIID, VARIABLE_NAME, NAME, NAMESPACE, GENERIC_VALUE, STRING_VALUE, NUMBER_VALUE, DECIMAL_VALUE, TIMESTAMP_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PIID, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.VARIABLE_NAME, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PROPERTY_NAME, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PROPERTY_NAMESPACE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.GENERIC_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.STRING_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.NUMBER_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.DECIMAL_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.TIMESTAMP_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.WSID_1, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.WSID_2
 FROM @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T;

-- View: QueryPropTempl
CREATE VIEW @SCHEMA@.QUERY_PROP_TEMPL(PTID, NAME, PROPERTY_NAME, URI, QUERY_TYPE, JAVA_TYPE ) AS
 SELECT @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.PTID, @SCHEMA@.VARIABLE_TEMPLATE_B_T.NAME, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PROPERTY_NAME, @SCHEMA@.URI_TEMPLATE_B_T.URI, @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.QUERY_TYPE, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.JAVA_TYPE
 FROM @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T, @SCHEMA@.VARIABLE_TEMPLATE_B_T, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T, @SCHEMA@.URI_TEMPLATE_B_T
 WHERE @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.CTID = @SCHEMA@.VARIABLE_TEMPLATE_B_T.CTID AND @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.PAID = @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PAID AND @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PROPERTY_UTID = @SCHEMA@.URI_TEMPLATE_B_T.UTID;

-- View: MigrationFront
CREATE VIEW @SCHEMA@.MIGRATION_FRONT(PIID, AIID, SOURCE_PTID, TARGET_PTID, STATE, SUB_STATE, STOP_REASON, SOURCE_ATID, TARGET_ATID, MIGRATION_TIME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.MIGRATION_FRONT_T.PIID, @SCHEMA@.MIGRATION_FRONT_T.AIID, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.SOURCE_PTID, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.TARGET_PTID, @SCHEMA@.MIGRATION_FRONT_T.STATE, @SCHEMA@.MIGRATION_FRONT_T.SUB_STATE, @SCHEMA@.MIGRATION_FRONT_T.STOP_REASON, @SCHEMA@.MIGRATION_FRONT_T.SOURCE_ATID, @SCHEMA@.MIGRATION_FRONT_T.TARGET_ATID, @SCHEMA@.MIGRATION_FRONT_T.MIGRATION_TIME, @SCHEMA@.MIGRATION_FRONT_T.WSID_1, @SCHEMA@.MIGRATION_FRONT_T.WSID_2
 FROM @SCHEMA@.MIGRATION_FRONT_T, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
 WHERE @SCHEMA@.MIGRATION_FRONT_T.MPTID = @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.MPTID;

-- View: AuditLog
CREATE VIEW @SCHEMA@.AUDIT_LOG(ALID, EVENT_TIME, EVENT_TIME_UTC, AUDIT_EVENT, PTID, PIID, AIID, SIID, SCOPE_NAME, PROCESS_TEMPL_NAME, PROCESS_INST_NAME, TOP_LEVEL_PI_NAME, TOP_LEVEL_PIID, PARENT_PI_NAME, PARENT_PIID, VALID_FROM, VALID_FROM_UTC, ACTIVITY_NAME, ACTIVITY_KIND, ACTIVITY_STATE, CONTROL_LINK_NAME, IMPL_NAME, PRINCIPAL, TERMINAL_NAME, VARIABLE_DATA, EXCEPTION_TEXT, DESCRIPTION, CORR_SET_INFO, USER_NAME, ATID, ADDITIONAL_INFO, OBJECT_META_TYPE ) AS
 SELECT @SCHEMA@.AUDIT_LOG_T.ALID,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME_UTC,@SCHEMA@.AUDIT_LOG_T.AUDIT_EVENT,@SCHEMA@.AUDIT_LOG_T.PTID,@SCHEMA@.AUDIT_LOG_T.PIID,@SCHEMA@.AUDIT_LOG_T.AIID,@SCHEMA@.AUDIT_LOG_T.SIID,@SCHEMA@.AUDIT_LOG_T.VARIABLE_NAME,@SCHEMA@.AUDIT_LOG_T.PROCESS_TEMPL_NAME, @SCHEMA@.AUDIT_LOG_T.PROCESS_INST_NAME,@SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PI_NAME,@SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PIID,@SCHEMA@.AUDIT_LOG_T.PARENT_PI_NAME,@SCHEMA@.AUDIT_LOG_T.PARENT_PIID,@SCHEMA@.AUDIT_LOG_T.VALID_FROM,@SCHEMA@.AUDIT_LOG_T.VALID_FROM_UTC, @SCHEMA@.AUDIT_LOG_T.ACTIVITY_NAME,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_KIND,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_STATE,@SCHEMA@.AUDIT_LOG_T.CONTROL_LINK_NAME,@SCHEMA@.AUDIT_LOG_T.IMPL_NAME,@SCHEMA@.AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.AUDIT_LOG_T.TERMINAL_NAME,@SCHEMA@.AUDIT_LOG_T.VARIABLE_DATA,@SCHEMA@.AUDIT_LOG_T.EXCEPTION_TEXT,@SCHEMA@.AUDIT_LOG_T.DESCRIPTION,@SCHEMA@.AUDIT_LOG_T.CORR_SET_INFO,@SCHEMA@.AUDIT_LOG_T.USER_NAME, @SCHEMA@.AUDIT_LOG_T.ATID, @SCHEMA@.AUDIT_LOG_T.ADDITIONAL_INFO, @SCHEMA@.AUDIT_LOG_T.OBJECT_META_TYPE
 FROM @SCHEMA@.AUDIT_LOG_T;

-- View: AuditLogB
CREATE VIEW @SCHEMA@.AUDIT_LOG_B(ALID, EVENT_TIME, EVENT_TIME_UTC, AUDIT_EVENT, PTID, PIID, AIID, SIID, VARIABLE_NAME, PROCESS_TEMPL_NAME, TOP_LEVEL_PIID, PARENT_PIID, VALID_FROM, VALID_FROM_UTC, ATID, ACTIVITY_NAME, ACTIVITY_KIND, ACTIVITY_STATE, CONTROL_LINK_NAME, PRINCIPAL, VARIABLE_DATA, EXCEPTION_TEXT, DESCRIPTION, CORR_SET_INFO, USER_NAME, ADDITIONAL_INFO ) AS
 SELECT @SCHEMA@.AUDIT_LOG_T.ALID,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME_UTC,@SCHEMA@.AUDIT_LOG_T.AUDIT_EVENT,@SCHEMA@.AUDIT_LOG_T.PTID,@SCHEMA@.AUDIT_LOG_T.PIID,@SCHEMA@.AUDIT_LOG_T.AIID,@SCHEMA@.AUDIT_LOG_T.SIID,@SCHEMA@.AUDIT_LOG_T.VARIABLE_NAME,@SCHEMA@.AUDIT_LOG_T.PROCESS_TEMPL_NAME, @SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PIID,@SCHEMA@.AUDIT_LOG_T.PARENT_PIID,@SCHEMA@.AUDIT_LOG_T.VALID_FROM,@SCHEMA@.AUDIT_LOG_T.VALID_FROM_UTC,@SCHEMA@.AUDIT_LOG_T.ATID, @SCHEMA@.AUDIT_LOG_T.ACTIVITY_NAME,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_KIND,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_STATE,@SCHEMA@.AUDIT_LOG_T.CONTROL_LINK_NAME,@SCHEMA@.AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.AUDIT_LOG_T.VARIABLE_DATA,@SCHEMA@.AUDIT_LOG_T.EXCEPTION_TEXT,@SCHEMA@.AUDIT_LOG_T.DESCRIPTION,@SCHEMA@.AUDIT_LOG_T.CORR_SET_INFO,@SCHEMA@.AUDIT_LOG_T.USER_NAME, @SCHEMA@.AUDIT_LOG_T.ADDITIONAL_INFO
 FROM @SCHEMA@.AUDIT_LOG_T
 WHERE @SCHEMA@.AUDIT_LOG_T.OBJECT_META_TYPE = 1;

-- View: ApplicationComp
CREATE VIEW @SCHEMA@.APPLICATION_COMP(ACOID, BUSINESS_RELEVANCE, NAME, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON ) AS
 SELECT @SCHEMA@.APPLICATION_COMPONENT_T.ACOID, @SCHEMA@.APPLICATION_COMPONENT_T.BUSINESS_RELEVANCE, @SCHEMA@.APPLICATION_COMPONENT_T.NAME, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_DELEGATION, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_SUB_TASK, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_FOLLOW_ON_TASK
 FROM @SCHEMA@.APPLICATION_COMPONENT_T;

-- View: Escalation
CREATE VIEW @SCHEMA@.ESCALATION(ESIID, ACTION, ACTIVATION_STATE, ACTIVATION_TIME, ESCALATION_TIME, AT_LEAST_EXP_STATE, ESTID, FIRST_ESIID, INCREASE_PRIORITY, NAME, STATE, TKIID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESCALATION_INSTANCE_T.ESIID, @SCHEMA@.ESCALATION_INSTANCE_T.ACTION, @SCHEMA@.ESCALATION_INSTANCE_T.ACTIVATION_STATE, @SCHEMA@.ESCALATION_INSTANCE_T.ACTIVATION_TIME, @SCHEMA@.ESCALATION_INSTANCE_T.ESCALATION_TIME, @SCHEMA@.ESCALATION_INSTANCE_T.AT_LEAST_EXPECTED_STATE, @SCHEMA@.ESCALATION_INSTANCE_T.ESTID, @SCHEMA@.ESCALATION_INSTANCE_T.FIRST_ESIID, @SCHEMA@.ESCALATION_INSTANCE_T.INCREASE_PRIORITY, @SCHEMA@.ESCALATION_INSTANCE_T.NAME, @SCHEMA@.ESCALATION_INSTANCE_T.STATE, @SCHEMA@.ESCALATION_INSTANCE_T.TKIID, @SCHEMA@.ESCALATION_INSTANCE_T.WSID_1, @SCHEMA@.ESCALATION_INSTANCE_T.WSID_2
 FROM @SCHEMA@.ESCALATION_INSTANCE_T;

-- View: EscTempl
CREATE VIEW @SCHEMA@.ESC_TEMPL(ESTID, FIRST_ESTID, PREVIOUS_ESTID, TKTID, CONTAINMENT_CTX_ID, NAME, ACTIVATION_STATE, AT_LEAST_EXP_STATE, INCREASE_PRIORITY, ACTION ) AS
 SELECT @SCHEMA@.ESCALATION_TEMPLATE_T.ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.FIRST_ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.PREVIOUS_ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.TKTID, @SCHEMA@.ESCALATION_TEMPLATE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.ESCALATION_TEMPLATE_T.NAME, @SCHEMA@.ESCALATION_TEMPLATE_T.ACTIVATION_STATE, @SCHEMA@.ESCALATION_TEMPLATE_T.AT_LEAST_EXPECTED_STATE, @SCHEMA@.ESCALATION_TEMPLATE_T.INCREASE_PRIORITY, @SCHEMA@.ESCALATION_TEMPLATE_T.ACTION
 FROM @SCHEMA@.ESCALATION_TEMPLATE_T;

-- View: EscTemplDesc
CREATE VIEW @SCHEMA@.ESC_TEMPL_DESC(ESTID, LOCALE, TKTID, DISPLAY_NAME, DESCRIPTION ) AS
 SELECT @SCHEMA@.ESC_TEMPL_LDESC_T.ESTID, @SCHEMA@.ESC_TEMPL_LDESC_T.LOCALE, @SCHEMA@.ESC_TEMPL_LDESC_T.TKTID, @SCHEMA@.ESC_TEMPL_LDESC_T.DISPLAY_NAME, @SCHEMA@.ESC_TEMPL_LDESC_T.DESCRIPTION
 FROM @SCHEMA@.ESC_TEMPL_LDESC_T;

-- View: TaskTemplCProp
CREATE VIEW @SCHEMA@.TASK_TEMPL_CPROP(TKTID, NAME, DATA_TYPE, STRING_VALUE ) AS
 SELECT @SCHEMA@.TASK_TEMPL_CPROP_T.TKTID, @SCHEMA@.TASK_TEMPL_CPROP_T.NAME, @SCHEMA@.TASK_TEMPL_CPROP_T.DATA_TYPE, @SCHEMA@.TASK_TEMPL_CPROP_T.STRING_VALUE
 FROM @SCHEMA@.TASK_TEMPL_CPROP_T;

-- View: EscTemplCProp
CREATE VIEW @SCHEMA@.ESC_TEMPL_CPROP(ESTID, NAME, TKTID, DATA_TYPE, VALUE ) AS
 SELECT @SCHEMA@.ESC_TEMPL_CPROP_T.ESTID, @SCHEMA@.ESC_TEMPL_CPROP_T.NAME, @SCHEMA@.ESC_TEMPL_CPROP_T.TKTID, @SCHEMA@.ESC_TEMPL_CPROP_T.DATA_TYPE, @SCHEMA@.ESC_TEMPL_CPROP_T.STRING_VALUE
 FROM @SCHEMA@.ESC_TEMPL_CPROP_T;

-- View: TaskTemplDesc
CREATE VIEW @SCHEMA@.TASK_TEMPL_DESC(TKTID, LOCALE, DESCRIPTION, DISPLAY_NAME ) AS
 SELECT @SCHEMA@.TASK_TEMPL_LDESC_T.TKTID, @SCHEMA@.TASK_TEMPL_LDESC_T.LOCALE, @SCHEMA@.TASK_TEMPL_LDESC_T.DESCRIPTION, @SCHEMA@.TASK_TEMPL_LDESC_T.DISPLAY_NAME
 FROM @SCHEMA@.TASK_TEMPL_LDESC_T;

-- View: TaskCProp
CREATE VIEW @SCHEMA@.TASK_CPROP(TKIID, NAME, DATA_TYPE, STRING_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INST_CPROP_T.TKIID, @SCHEMA@.TASK_INST_CPROP_T.NAME, @SCHEMA@.TASK_INST_CPROP_T.DATA_TYPE, @SCHEMA@.TASK_INST_CPROP_T.STRING_VALUE, @SCHEMA@.TASK_INST_CPROP_T.WSID_1, @SCHEMA@.TASK_INST_CPROP_T.WSID_2
 FROM @SCHEMA@.TASK_INST_CPROP_T;

-- View: TaskDesc
CREATE VIEW @SCHEMA@.TASK_DESC(TKIID, LOCALE, DESCRIPTION, DISPLAY_NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INST_LDESC_T.TKIID, @SCHEMA@.TASK_INST_LDESC_T.LOCALE, @SCHEMA@.TASK_INST_LDESC_T.DESCRIPTION, @SCHEMA@.TASK_INST_LDESC_T.DISPLAY_NAME, @SCHEMA@.TASK_INST_LDESC_T.WSID_1, @SCHEMA@.TASK_INST_LDESC_T.WSID_2
 FROM @SCHEMA@.TASK_INST_LDESC_T;

-- View: EscalationCProp
CREATE VIEW @SCHEMA@.ESCALATION_CPROP(ESIID, NAME, DATA_TYPE, STRING_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESC_INST_CPROP_T.ESIID, @SCHEMA@.ESC_INST_CPROP_T.NAME, @SCHEMA@.ESC_INST_CPROP_T.DATA_TYPE, @SCHEMA@.ESC_INST_CPROP_T.STRING_VALUE, @SCHEMA@.ESC_INST_CPROP_T.WSID_1, @SCHEMA@.ESC_INST_CPROP_T.WSID_2
 FROM @SCHEMA@.ESC_INST_CPROP_T;

-- View: TaskHistory
CREATE VIEW @SCHEMA@.TASK_HISTORY(TKIID, ESIID, PARENT_TKIID, EVENT, REASON, EVENT_TIME, NEXT_TIME, PRINCIPAL, WORK_ITEM_KIND, FROM_ID, TO_ID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_HISTORY_T.TKIID, @SCHEMA@.TASK_HISTORY_T.ESIID, @SCHEMA@.TASK_HISTORY_T.PARENT_TKIID, @SCHEMA@.TASK_HISTORY_T.EVENT, @SCHEMA@.TASK_HISTORY_T.REASON, @SCHEMA@.TASK_HISTORY_T.EVENT_TIME, @SCHEMA@.TASK_HISTORY_T.NEXT_TIME, @SCHEMA@.TASK_HISTORY_T.PRINCIPAL, @SCHEMA@.TASK_HISTORY_T.WORK_ITEM_KIND, @SCHEMA@.TASK_HISTORY_T.FROM_ID, @SCHEMA@.TASK_HISTORY_T.TO_ID, @SCHEMA@.TASK_HISTORY_T.WSID_1, @SCHEMA@.TASK_HISTORY_T.WSID_2
 FROM @SCHEMA@.TASK_HISTORY_T;

-- View: EscalationDesc
CREATE VIEW @SCHEMA@.ESCALATION_DESC(ESIID, LOCALE, DESCRIPTION, DISPLAY_NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESC_INST_LDESC_T.ESIID, @SCHEMA@.ESC_INST_LDESC_T.LOCALE, @SCHEMA@.ESC_INST_LDESC_T.DESCRIPTION, @SCHEMA@.ESC_INST_LDESC_T.DISPLAY_NAME, @SCHEMA@.ESC_INST_LDESC_T.WSID_1, @SCHEMA@.ESC_INST_LDESC_T.WSID_2
 FROM @SCHEMA@.ESC_INST_LDESC_T;

-- View: TaskAuditLog
CREATE VIEW @SCHEMA@.TASK_AUDIT_LOG(ALID, AUDIT_EVENT, CONTAINMENT_CTX_ID, ESIID, ESTID, EVENT_TIME, FAULT_NAME, FAULT_TYPE_NAME, FAULT_NAME_SPACE, FOLLOW_ON_TKIID, NAME, NAMESPACE, NEW_USER, OLD_USER, PARENT_CONTEXT_ID, PARENT_TASK_NAME, PARENT_TASK_NAMESP, PARENT_TKIID, PRINCIPAL, TASK_KIND, TASK_STATE, TKIID, TKTID, TOP_TKIID, VAILD_FROM, WORK_ITEM_REASON, USERS, DESCRIPTION, MESSAGE_DATA ) AS
 SELECT @SCHEMA@.TASK_AUDIT_LOG_T.ALID, @SCHEMA@.TASK_AUDIT_LOG_T.AUDIT_EVENT, @SCHEMA@.TASK_AUDIT_LOG_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_AUDIT_LOG_T.ESIID, @SCHEMA@.TASK_AUDIT_LOG_T.ESTID, @SCHEMA@.TASK_AUDIT_LOG_T.EVENT_TIME_UTC, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_TYPE_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.FOLLOW_ON_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.NAME, @SCHEMA@.TASK_AUDIT_LOG_T.NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.NEW_USER, @SCHEMA@.TASK_AUDIT_LOG_T.OLD_USER, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_CONTEXT_ID, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TASK_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TASK_NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.TASK_AUDIT_LOG_T.TASK_KIND, @SCHEMA@.TASK_AUDIT_LOG_T.TASK_STATE, @SCHEMA@.TASK_AUDIT_LOG_T.TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.TKTID, @SCHEMA@.TASK_AUDIT_LOG_T.TOP_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.VALID_FROM_UTC, @SCHEMA@.TASK_AUDIT_LOG_T.WI_REASON, @SCHEMA@.TASK_AUDIT_LOG_T.USERS, @SCHEMA@.TASK_AUDIT_LOG_T.DESCRIPTION, @SCHEMA@.TASK_AUDIT_LOG_T.MESSAGE_DATA
 FROM @SCHEMA@.TASK_AUDIT_LOG_T;

-- View: WorkBasket
CREATE VIEW @SCHEMA@.WORK_BASKET(WBID, NAME, TYPE, OWNER, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_T.WBID, @SCHEMA@.WORK_BASKET_T.NAME, @SCHEMA@.WORK_BASKET_T.TYPE, @SCHEMA@.WORK_BASKET_T.OWNER, @SCHEMA@.WORK_BASKET_T.DEFAULT_QUERY_TABLE, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT1, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT2, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT3, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT4, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT5, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT6, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT7, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT8, @SCHEMA@.WORK_BASKET_T.CREATION_TIME, @SCHEMA@.WORK_BASKET_T.LAST_MODIFICATION_TIME, @SCHEMA@.WORK_BASKET_T.WSID_1, @SCHEMA@.WORK_BASKET_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_T;

-- View: WorkBasketLDesc
CREATE VIEW @SCHEMA@.WORK_BASKET_LDESC(WBID, LOCALE, DISPLAY_NAME, DESCRIPTION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_LDESC_T.WBID, @SCHEMA@.WORK_BASKET_LDESC_T.LOCALE, @SCHEMA@.WORK_BASKET_LDESC_T.DISPLAY_NAME, @SCHEMA@.WORK_BASKET_LDESC_T.DESCRIPTION, @SCHEMA@.WORK_BASKET_LDESC_T.WSID_1, @SCHEMA@.WORK_BASKET_LDESC_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_LDESC_T;

-- View: WorkBasketDistTarget
CREATE VIEW @SCHEMA@.WORK_BASKET_DIST_TARGET(WBID, NAME, TYPE, OWNER, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, SOURCE_WBID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_DIST_TARGET_T.TARGET_WBID, @SCHEMA@.WORK_BASKET_T.NAME, @SCHEMA@.WORK_BASKET_T.TYPE, @SCHEMA@.WORK_BASKET_T.OWNER, @SCHEMA@.WORK_BASKET_T.DEFAULT_QUERY_TABLE, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT1, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT2, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT3, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT4, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT5, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT6, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT7, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT8, @SCHEMA@.WORK_BASKET_T.CREATION_TIME, @SCHEMA@.WORK_BASKET_T.LAST_MODIFICATION_TIME, @SCHEMA@.WORK_BASKET_DIST_TARGET_T.SOURCE_WBID, @SCHEMA@.WORK_BASKET_T.WSID_1, @SCHEMA@.WORK_BASKET_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_DIST_TARGET_T, @SCHEMA@.WORK_BASKET_T
 WHERE @SCHEMA@.WORK_BASKET_T.WBID = @SCHEMA@.WORK_BASKET_DIST_TARGET_T.TARGET_WBID;

-- View: BusinessCategory
CREATE VIEW @SCHEMA@.BUSINESS_CATEGORY(BCID, PARENT_BCID, NAME, PRIORITY, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.BUSINESS_CATEGORY_T.BCID, @SCHEMA@.BUSINESS_CATEGORY_T.PARENT_BCID, @SCHEMA@.BUSINESS_CATEGORY_T.NAME, @SCHEMA@.BUSINESS_CATEGORY_T.PRIORITY, @SCHEMA@.BUSINESS_CATEGORY_T.DEFAULT_QUERY_TABLE, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT1, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT2, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT3, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT4, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT5, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT6, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT7, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT8, @SCHEMA@.BUSINESS_CATEGORY_T.CREATION_TIME, @SCHEMA@.BUSINESS_CATEGORY_T.LAST_MODIFICATION_TIME, @SCHEMA@.BUSINESS_CATEGORY_T.WSID_1, @SCHEMA@.BUSINESS_CATEGORY_T.WSID_2
 FROM @SCHEMA@.BUSINESS_CATEGORY_T;

-- View: BusinessCategoryLDesc
CREATE VIEW @SCHEMA@.BUSINESS_CATEGORY_LDESC(BCID, LOCALE, DISPLAY_NAME, DESCRIPTION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.BCID, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.LOCALE, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.DISPLAY_NAME, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.DESCRIPTION, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.WSID_1, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.WSID_2
 FROM @SCHEMA@.BUSINESS_CATEGORY_LDESC_T;

-- update schema version to: 700
-- (a warning for the following statement can be ignored)
DELETE FROM @SCHEMA@.SCHEMA_VERSION WHERE SCHEMA_VERSION = 700;
INSERT INTO @SCHEMA@.SCHEMA_VERSION (SCHEMA_VERSION, DATA_MIGRATION) VALUES( 700, 1 );

