--
-- Licensed Materials - Property of IBM
-- 5655-FLW (C) Copyright IBM Corporation 2006, 2010.
-- All Rights Reserved.
-- US Government Users Restricted Rights- 
-- Use, duplication or disclosure restricted 
-- by GSA ADP Schedule Contract with IBM Corp.
--
-- Scriptfile to create schema in Informix
----------------------------------------------------------------------
-- Before running this script, you need to replace all occurences of
-- the replacement variables listed below with values appropriate for
-- your environment. Replacement variables are of the form: @VARIABLE@.
-- 
-- Note: if you do not find any replacement variables in this script 
--       this step might be already completed by a pre-processor.
-- 
-- @SCHEMA@       = schema (userId) name
-- @AUDITLOG@     = valid table space name
-- @INSTANCE@     = valid table space name
-- @STAFFQRY@     = valid table space name
-- @TEMPLATE@     = valid table space name
-- @WORKITEM@     = valid table space name
----------------------------------------------------------------------
-- 
-- The schema assumes existing dbspaces that should have been created before 
-- using the createDbspace.bat or createDbspace.sh script.
-- 
-- Process this script using the dbaccess command line processor
-- example: dbaccess <databasename> createSchema.sql
--


-------------------
-- Create tables --
-------------------

CREATE TABLE @SCHEMA@.SCHEMA_VERSION
(
  SCHEMA_VERSION                     INTEGER                       NOT NULL  PRIMARY KEY,
  DATA_MIGRATION                     SMALLINT                      NOT NULL             
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
(
  PTID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  NAME                               VARCHAR(220)                  NOT NULL             ,
  DEFINITION_NAME                    VARCHAR(220)                                       ,
  DISPLAY_NAME                       VARCHAR(64)                                        ,
  APPLICATION_NAME                   VARCHAR(220)                                       ,
  DISPLAY_ID                         INTEGER                       NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  DOCUMENTATION                      TEXT                                               ,
  EXECUTION_MODE                     INTEGER                       NOT NULL             ,
  IS_SHARED                          SMALLINT                      NOT NULL             ,
  IS_AD_HOC                          SMALLINT                      NOT NULL             ,
  STATE                              INTEGER                       NOT NULL             ,
  VALID_FROM                         DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  TARGET_NAMESPACE                   VARCHAR(250)                                       ,
  CREATED                            DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  AUTO_DELETE                        SMALLINT                      NOT NULL             ,
  EXTENDED_AUTO_DELETE               INTEGER                       NOT NULL             ,
  VERSION                            VARCHAR(32)                                        ,
  SCHEMA_VERSION                     INTEGER                       NOT NULL             ,
  ABSTRACT_BASE_NAME                 VARCHAR(254)                                       ,
  S_BEAN_LOOKUP_NAME                 VARCHAR(254)                                       ,
  S_BEAN60_LOOKUP_NAME               VARCHAR(254)                                       ,
  E_BEAN_LOOKUP_NAME                 VARCHAR(254)                                       ,
  PROCESS_BASE_NAME                  VARCHAR(254)                                       ,
  S_BEAN_HOME_NAME                   VARCHAR(254)                                       ,
  E_BEAN_HOME_NAME                   VARCHAR(254)                                       ,
  BPEWS_UTID                         CHAR(24)                                           ,
  WPC_UTID                           CHAR(24)                                           ,
  BUSINESS_RELEVANCE                 SMALLINT                      NOT NULL             ,
  ADMINISTRATOR_QTID                 CHAR(24)                                           ,
  READER_QTID                        CHAR(24)                                           ,
  A_TKTID                            CHAR(24)                                           ,
  A_TKTIDFOR_ACTS                    CHAR(24)                                           ,
  COMPENSATION_SPHERE                INTEGER                       NOT NULL             ,
  AUTONOMY                           INTEGER                       NOT NULL             ,
  CAN_CALL                           SMALLINT                      NOT NULL             ,
  CAN_INITIATE                       SMALLINT                      NOT NULL             ,
  CONTINUE_ON_ERROR                  SMALLINT                      NOT NULL             ,
  IGNORE_MISSING_DATA                INTEGER                       NOT NULL             ,
  EAR_VERSION                        INTEGER                       NOT NULL             
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE UNIQUE INDEX @SCHEMA@.PTB_NAME_VALID ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  NAME, VALID_FROM
);

CREATE INDEX @SCHEMA@.PTB_NAME_VF_STATE ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  NAME, VALID_FROM, STATE, PTID
);

CREATE INDEX @SCHEMA@.PTB_TOP_APP ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  APPLICATION_NAME
);

CREATE INDEX @SCHEMA@.PTB_STATE_PTID ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  STATE, PTID
);

CREATE INDEX @SCHEMA@.PTB_NAME ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  PTID, NAME
);

CREATE INDEX @SCHEMA@.PTB_SBLKN ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  S_BEAN60_LOOKUP_NAME
);

CREATE TABLE @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T
(
  PTID                               CHAR(24)                      NOT NULL             ,
  ATTR_KEY                           VARCHAR(220)                  NOT NULL             ,
  VALUE                              VARCHAR(254)                                       ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  PRIMARY KEY ( PTID, ATTR_KEY )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.PTAB_PTID ON @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.SCOPE_TEMPLATE_B_T
(
  STID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PARENT_STID                        CHAR(24)                                           ,
  PTID                               CHAR(24)                      NOT NULL             ,
  COMP_HANDLER_ATID                  CHAR(24)                                           ,
  IMPLEMENTS_EHTID                   CHAR(24)                                           ,
  FOR_EACH_ATID                      CHAR(24)                                           ,
  DISPLAY_ID                         INTEGER                       NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  ISOLATED                           SMALLINT                      NOT NULL             ,
  IS_COMPENSABLE                     SMALLINT                      NOT NULL             ,
  BUSINESS_RELEVANCE                 SMALLINT                      NOT NULL             ,
  A_TKTID                            CHAR(24)                                           ,
  IS_IMPLICIT                        SMALLINT                      NOT NULL             ,
  HAS_COMPENSATION_HANDLER           SMALLINT                      NOT NULL             
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.ST_PTID ON @SCHEMA@.SCOPE_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.SERVICE_TEMPLATE_B_T
(
  VTID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PORT_TYPE_NAME                     VARCHAR(254)                  NOT NULL             ,
  PORT_TYPE_UTID                     CHAR(24)                      NOT NULL             ,
  OPERATION_NAME                     VARCHAR(254)                  NOT NULL             ,
  NAME                               VARCHAR(254)                                       ,
  PTID                               CHAR(24)                      NOT NULL             ,
  TRANSACTION_BEHAVIOR               INTEGER                       NOT NULL             ,
  IS_TWO_WAY                         SMALLINT                      NOT NULL             ,
  NUMBER_OF_RECEIVE_ACTS             INTEGER                       NOT NULL             
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.VT_VTID_PTUTID ON @SCHEMA@.SERVICE_TEMPLATE_B_T
(   
  VTID, PORT_TYPE_UTID
);

CREATE INDEX @SCHEMA@.VT_PTID ON @SCHEMA@.SERVICE_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.ACTIVITY_SERVICE_TEMPLATE_B_T
(
  ATID                               CHAR(24)                      NOT NULL             ,
  VTID                               CHAR(24)                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  PARTNER_LINK_NAME                  VARCHAR(220)                                       ,
  INPUT_CTID                         CHAR(24)                                           ,
  OUTPUT_CTID                        CHAR(24)                                           ,
  LINK_ORDER_NUMBER                  INTEGER                                            ,
  POTENTIAL_OWNER_QTID               CHAR(24)                                           ,
  READER_QTID                        CHAR(24)                                           ,
  EDITOR_QTID                        CHAR(24)                                           ,
  TKTID                              CHAR(24)                                           ,
  UNDO_MSG_TEMPLATE                  BYTE                                               ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  PRIMARY KEY ( ATID, VTID, KIND )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.AST_PTID ON @SCHEMA@.ACTIVITY_SERVICE_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.SERVICE_LOCATION_TEMPLATE_B_T
(
  PTID                               CHAR(24)                      NOT NULL             ,
  VTID                               CHAR(24)                      NOT NULL             ,
  MODULE_NAME                        VARCHAR(220)                  NOT NULL             ,
  EXPORT_NAME                        TEXT                                               ,
  COMPONENT_NAME                     TEXT                          NOT NULL             ,
  PRIMARY KEY ( PTID, VTID )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.SLT_PTID ON @SCHEMA@.SERVICE_LOCATION_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.SERVICE_FAULT_TEMPLATE_B_T
(
  VTID                               CHAR(24)                      NOT NULL             ,
  FAULT_NAME                         VARCHAR(220)                  NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  MESSAGE_DEFINITION                 BYTE                          NOT NULL             ,
  PRIMARY KEY ( VTID, FAULT_NAME )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.SFT_PTID ON @SCHEMA@.SERVICE_FAULT_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
(
  ATID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PARENT_STID                        CHAR(24)                                           ,
  IMPLEMENTS_STID                    CHAR(24)                                           ,
  PTID                               CHAR(24)                      NOT NULL             ,
  IMPLEMENTS_EHTID                   CHAR(24)                                           ,
  ENCLOSING_FOR_EACH_ATID            CHAR(24)                                           ,
  IS_EVENT_HANDLER_END_ACTIVITY      SMALLINT                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  NAME                               VARCHAR(220)                                       ,
  DISPLAY_NAME                       VARCHAR(64)                                        ,
  JOIN_CONDITION                     INTEGER                       NOT NULL             ,
  JOIN_CONDITION_NAME                VARCHAR(254)                                       ,
  EXIT_CONDITION                     INTEGER                       NOT NULL             ,
  EXIT_CONDITION_NAME                VARCHAR(254)                                       ,
  EXIT_CONDITION_EXECUTE_AT          INTEGER                       NOT NULL             ,
  NUMBER_OF_LINKS                    INTEGER                       NOT NULL             ,
  SUPPRESS_JOIN_FAILURE              SMALLINT                      NOT NULL             ,
  SOURCES_TYPE                       INTEGER                       NOT NULL             ,
  TARGETS_TYPE                       INTEGER                       NOT NULL             ,
  CREATE_INSTANCE                    SMALLINT                                           ,
  IS_END_ACTIVITY                    SMALLINT                      NOT NULL             ,
  FAULT_NAME                         VARCHAR(254)                                       ,
  HAS_OWN_FAULT_HANDLER              SMALLINT                      NOT NULL             ,
  COMPLEX_BEGIN_ATID                 CHAR(24)                                           ,
  CORRESPONDING_END_ATID             CHAR(24)                                           ,
  PARENT_ATID                        CHAR(24)                                           ,
  HAS_CROSSING_LINK                  SMALLINT                                           ,
  SCRIPT_NAME                        VARCHAR(254)                                       ,
  AFFILIATION                        INTEGER                       NOT NULL             ,
  TRANSACTION_BEHAVIOR               INTEGER                       NOT NULL             ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  DOCUMENTATION                      TEXT                                               ,
  BUSINESS_RELEVANCE                 SMALLINT                      NOT NULL             ,
  FAULT_NAME_UTID                    CHAR(24)                                           ,
  FAULT_VARIABLE_CTID                CHAR(24)                                           ,
  DISPLAY_ID                         INTEGER                       NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  IS_TRANSACTIONAL                   SMALLINT                      NOT NULL             ,
  CONTINUE_ON_ERROR                  SMALLINT                      NOT NULL             ,
  ENCLOSED_FTID                      CHAR(24)                                           ,
  EXPRESSION                         TEXT                                               ,
  EXIT_EXPRESSION                    TEXT                                               ,
  HAS_INBOUND_LINK                   SMALLINT                      NOT NULL             ,
  COMPENSATION_STID                  CHAR(24)                                           ,
  COMPENSATION_ATID                  CHAR(24)                                           ,
  A_TKTID                            CHAR(24)                                           ,
  IS_IN_GFLOW                        SMALLINT                      NOT NULL             ,
  IS_REGION_BEGIN                    SMALLINT                      NOT NULL             ,
  CORRESPONDING_IORATID              CHAR(24)                                           ,
  IS_GFLOW                           SMALLINT                      NOT NULL             ,
  CUSTOM_IMPLEMENTATION              BYTE                                               ,
  EXPRESSION_MAP                     BYTE                                               ,
  EXIT_EXPRESSION_MAP                BYTE                                               ,
  GENERATED_BY                       VARCHAR(220)                                       
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.ATB_PTID ON @SCHEMA@.ACTIVITY_TEMPLATE_B_T
(   
  PTID
);

CREATE INDEX @SCHEMA@.ATB_NAME ON @SCHEMA@.ACTIVITY_TEMPLATE_B_T
(   
  NAME
);

CREATE INDEX @SCHEMA@.ATB_KIND_BR_NAME ON @SCHEMA@.ACTIVITY_TEMPLATE_B_T
(   
  KIND, BUSINESS_RELEVANCE, NAME
);

CREATE TABLE @SCHEMA@.ALARM_TEMPLATE_B_T
(
  XTID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  ATID                               CHAR(24)                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  EXPRESSION                         BYTE                                               ,
  EXPRESSION_NAME                    VARCHAR(254)                                       ,
  DURATION                           VARCHAR(254)                                       ,
  CALENDAR                           VARCHAR(254)                                       ,
  CALENDAR_JNDI_NAME                 VARCHAR(254)                                       ,
  REPEAT_KIND                        INTEGER                       NOT NULL             ,
  REPEAT_EXPRESSION                  BYTE                                               ,
  REPEAT_EXP_NAME                    VARCHAR(254)                                       ,
  ON_ALARM_ORDER_NUMBER              INTEGER                                            ,
  EXPRESSION_MAP                     BYTE                                               ,
  REPEAT_EXPRESSION_MAP              BYTE                                               ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.XT_PTID ON @SCHEMA@.ALARM_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
(
  FTID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  FAULT_NAME                         VARCHAR(254)                                       ,
  CTID                               CHAR(24)                                           ,
  STID                               CHAR(24)                                           ,
  ATID                               CHAR(24)                                           ,
  FAULT_LINK_SOURCE_ATID             CHAR(24)                                           ,
  FAULT_LINK_TARGET_ATID             CHAR(24)                                           ,
  IMPLEMENTATION_ATID                CHAR(24)                      NOT NULL             ,
  FAULT_NAME_UTID                    CHAR(24)                                           ,
  ORDER_NUMBER                       INTEGER                       NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.FT_PTID ON @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.LINK_TEMPLATE_B_T
(
  SOURCE_ATID                        CHAR(24)                      NOT NULL             ,
  TARGET_ATID                        CHAR(24)                      NOT NULL             ,
  FLOW_BEGIN_ATID                    CHAR(24)                                           ,
  ENCLOSING_FOR_EACH_ATID            CHAR(24)                                           ,
  DISPLAY_ID                         INTEGER                       NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  NAME                               VARCHAR(254)                                       ,
  PTID                               CHAR(24)                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  LIFETIME                           INTEGER                       NOT NULL             ,
  TRANSITION_CONDITION               INTEGER                       NOT NULL             ,
  TRANSITION_CONDITION_NAME          VARCHAR(254)                                       ,
  ORDER_NUMBER                       INTEGER                       NOT NULL             ,
  SEQUENCE_NUMBER                    INTEGER                       NOT NULL             ,
  BUSINESS_RELEVANCE                 SMALLINT                      NOT NULL             ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  DOCUMENTATION                      TEXT                                               ,
  EXPRESSION                         TEXT                                               ,
  IS_INBOUND_LINK                    SMALLINT                      NOT NULL             ,
  OUTBOUND_ATID                      CHAR(24)                                           ,
  EXPRESSION_MAP                     BYTE                                               ,
  GENERATED_BY                       VARCHAR(220)                                       ,
  RTID                               CHAR(24)                                           ,
  PRIMARY KEY ( SOURCE_ATID, TARGET_ATID )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.LNK_PTID ON @SCHEMA@.LINK_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.LINK_BOUNDARY_TEMPLATE_B_T
(
  SOURCE_ATID                        CHAR(24)                      NOT NULL             ,
  TARGET_ATID                        CHAR(24)                      NOT NULL             ,
  BOUNDARY_STID                      CHAR(24)                      NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  IS_OUTMOST_BOUNDARY                SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( SOURCE_ATID, TARGET_ATID, BOUNDARY_STID )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.BND_PTID ON @SCHEMA@.LINK_BOUNDARY_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.RESET_TEMPLATE_B_T
(
  LOOP_ENTRY_ATID                    CHAR(24)                      NOT NULL             ,
  LOOP_BODY_ATID                     CHAR(24)                      NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  PRIMARY KEY ( LOOP_ENTRY_ATID, LOOP_BODY_ATID )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.RST_PTID ON @SCHEMA@.RESET_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.VARIABLE_MAPPING_TEMPLATE_B_T
(
  PTID                               CHAR(24)                      NOT NULL             ,
  ATID                               CHAR(24)                      NOT NULL             ,
  VTID                               CHAR(24)                      NOT NULL             ,
  SOURCE_CTID                        CHAR(24)                      NOT NULL             ,
  TARGET_CTID                        CHAR(24)                      NOT NULL             ,
  PARAMETER                          VARCHAR(254)                  NOT NULL             ,
  PRIMARY KEY ( PTID, ATID, VTID, SOURCE_CTID, TARGET_CTID )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.VMT_TCTID ON @SCHEMA@.VARIABLE_MAPPING_TEMPLATE_B_T
(   
  PTID, ATID, VTID, TARGET_CTID
);

CREATE TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
(
  CTID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  EHTID                              CHAR(24)                                           ,
  STID                               CHAR(24)                                           ,
  FTID                               CHAR(24)                                           ,
  DERIVED                            SMALLINT                      NOT NULL             ,
  DISPLAY_ID                         INTEGER                       NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  FROM_SPEC                          INTEGER                       NOT NULL             ,
  NAME                               VARCHAR(254)                  NOT NULL             ,
  MESSAGE_TEMPLATE                   BYTE                                               ,
  IS_QUERYABLE                       SMALLINT                      NOT NULL             ,
  BUSINESS_RELEVANCE                 SMALLINT                      NOT NULL             ,
  GENERATED_BY                       VARCHAR(220)                                       ,
  SEQUENCE_NUMBER                    INTEGER                       NOT NULL             ,
  FROM_VARIABLE_CTID                 CHAR(24)                                           ,
  FROM_PARAMETER2                    VARCHAR(254)                                       ,
  FROM_PARAMETER3                    BYTE                                               ,
  FROM_PARAMETER3_LANGUAGE           INTEGER                       NOT NULL             ,
  FROM_EXPRESSION_MAP                BYTE                                               
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.CT_PTID ON @SCHEMA@.VARIABLE_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.VARIABLE_STACK_TEMPLATE_B_T
(
  VSID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  CTID                               CHAR(24)                      NOT NULL             ,
  STID                               CHAR(24)                      NOT NULL             ,
  FTID                               CHAR(24)                                           ,
  EHTID                              CHAR(24)                                           ,
  NAME                               LVARCHAR                      NOT NULL             
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.VS_PTID ON @SCHEMA@.VARIABLE_STACK_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.ACTIVITY_FAULT_TEMPLATE_B_T
(
  AFID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  ATID                               CHAR(24)                      NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  FAULT_NAME                         VARCHAR(254)                  NOT NULL             ,
  FAULT_UTID                         CHAR(24)                                           ,
  MESSAGE                            BYTE                          NOT NULL             
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.AF_PTID ON @SCHEMA@.ACTIVITY_FAULT_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T
(
  PTID                               CHAR(24)                      NOT NULL             ,
  PARTNER_LINK_NAME                  VARCHAR(220)                  NOT NULL             ,
  PROCESS_NAME                       VARCHAR(220)                                       ,
  TARGET_NAMESPACE                   VARCHAR(250)                                       ,
  RESOLUTION_SCOPE                   INTEGER                       NOT NULL             ,
  MY_ROLE                            SMALLINT                      NOT NULL             ,
  MY_ROLE_IMPL                       BYTE                                               ,
  MY_ROLE_LOCALNAME                  VARCHAR(220)                                       ,
  MY_ROLE_NAMESPACE                  VARCHAR(220)                                       ,
  THEIR_ROLE                         SMALLINT                      NOT NULL             ,
  THEIR_ROLE_IMPL                    BYTE                                               ,
  THEIR_ROLE_LOCALNAME               VARCHAR(220)                                       ,
  THEIR_ROLE_NAMESPACE               VARCHAR(220)                                       ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  PRIMARY KEY ( PTID, PARTNER_LINK_NAME )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.URI_TEMPLATE_B_T
(
  UTID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  URI                                VARCHAR(220)                  NOT NULL             
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE UNIQUE INDEX @SCHEMA@.UT_PTID_URI ON @SCHEMA@.URI_TEMPLATE_B_T
(   
  PTID, URI
);

CREATE INDEX @SCHEMA@.UT_UTID_URI ON @SCHEMA@.URI_TEMPLATE_B_T
(   
  UTID, URI
);

CREATE TABLE @SCHEMA@.CLIENT_SETTING_TEMPLATE_B_T
(
  CSID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  ATID                               CHAR(24)                                           ,
  PTID                               CHAR(24)                      NOT NULL             ,
  VTID                               CHAR(24)                                           ,
  SETTINGS                           BYTE                                               
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.CS_PTID ON @SCHEMA@.CLIENT_SETTING_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.ASSIGN_TEMPLATE_B_T
(
  ATID                               CHAR(24)                      NOT NULL             ,
  ORDER_NUMBER                       INTEGER                       NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  FROM_SPEC                          INTEGER                       NOT NULL             ,
  FROM_VARIABLE_CTID                 CHAR(24)                                           ,
  FROM_PARAMETER2                    VARCHAR(254)                                       ,
  FROM_PARAMETER3                    BYTE                                               ,
  FROM_PARAMETER3_LANGUAGE           INTEGER                       NOT NULL             ,
  TO_SPEC                            INTEGER                       NOT NULL             ,
  TO_VARIABLE_CTID                   CHAR(24)                                           ,
  TO_PARAMETER2                      VARCHAR(254)                                       ,
  TO_PARAMETER3                      BYTE                                               ,
  TO_PARAMETER3_LANGUAGE             INTEGER                       NOT NULL             ,
  FROM_EXPRESSION_MAP                BYTE                                               ,
  TO_EXPRESSION_MAP                  BYTE                                               ,
  PRIMARY KEY ( ATID, ORDER_NUMBER )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.ASTB_PTID ON @SCHEMA@.ASSIGN_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.CORRELATION_SET_TEMPLATE_B_T
(
  COID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  STID                               CHAR(24)                      NOT NULL             ,
  NAME                               LVARCHAR                      NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.CSTB_PTID ON @SCHEMA@.CORRELATION_SET_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.CORRELATION_TEMPLATE_B_T
(
  ATID                               CHAR(24)                      NOT NULL             ,
  VTID                               CHAR(24)                      NOT NULL             ,
  COID                               CHAR(24)                      NOT NULL             ,
  IS_FOR_EVENT_HANDLER               SMALLINT                      NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  INITIATE                           INTEGER                       NOT NULL             ,
  PATTERN                            INTEGER                       NOT NULL             ,
  PRIMARY KEY ( ATID, VTID, COID, IS_FOR_EVENT_HANDLER )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.COID_PTID ON @SCHEMA@.CORRELATION_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
(
  PAID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  COID                               CHAR(24)                      NOT NULL             ,
  SEQUENCE_NUMBER                    INTEGER                       NOT NULL             ,
  PROPERTY_UTID                      CHAR(24)                      NOT NULL             ,
  PROPERTY_NAME                      LVARCHAR                      NOT NULL             ,
  JAVA_TYPE                          LVARCHAR                      NOT NULL             ,
  MSG_TYPE_UTID                      CHAR(24)                      NOT NULL             ,
  MSG_TYPE_NAME                      LVARCHAR                      NOT NULL             ,
  MSG_TYPE_KIND                      INTEGER                       NOT NULL             ,
  PROPERTY_TYPE_UTID                 CHAR(24)                                           ,
  PROPERTY_TYPE_NAME                 LVARCHAR                                           ,
  PART                               LVARCHAR                                           ,
  QUERY                              LVARCHAR                                           ,
  QUERY_LANGUAGE                     INTEGER                       NOT NULL             ,
  IS_DEFINED_INLINE                  SMALLINT                      NOT NULL             
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.PATB_COID_UTID ON @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
(   
  COID, MSG_TYPE_UTID
);

CREATE INDEX @SCHEMA@.PATB_PTID_UTIDS ON @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
(   
  PTID, MSG_TYPE_UTID, PROPERTY_UTID
);

CREATE TABLE @SCHEMA@.EVENT_HANDLER_TEMPLATE_B_T
(
  EHTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  STID                               CHAR(24)                      NOT NULL             ,
  IMPL_ATID                          CHAR(24)                      NOT NULL             ,
  VTID                               CHAR(24)                                           ,
  INPUT_CTID                         CHAR(24)                                           ,
  TKTID                              CHAR(24)                                           ,
  KIND                               INTEGER                       NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.EHT_PTID ON @SCHEMA@.EVENT_HANDLER_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.EHALARM_TEMPLATE_B_T
(
  EHTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  EXPRESSION                         BYTE                                               ,
  EXPRESSION_NAME                    VARCHAR(254)                                       ,
  DURATION                           VARCHAR(254)                                       ,
  CALENDAR                           VARCHAR(254)                                       ,
  CALENDAR_JNDI_NAME                 VARCHAR(254)                                       ,
  REPEAT_KIND                        INTEGER                       NOT NULL             ,
  REPEAT_EXPRESSION                  BYTE                                               ,
  REPEAT_EXP_NAME                    VARCHAR(254)                                       ,
  REPEAT_DURATION                    VARCHAR(254)                                       ,
  REPEAT_CALENDAR                    VARCHAR(254)                                       ,
  REPEAT_CALENDAR_JNDI_NAME          VARCHAR(254)                                       ,
  EXPRESSION_MAP                     BYTE                                               ,
  REPEAT_EXPRESSION_MAP              BYTE                                               
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.EXT_PTID ON @SCHEMA@.EHALARM_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.CUSTOM_EXT_TEMPLATE_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  NAMESPACE                          VARCHAR(220)                  NOT NULL             ,
  LOCALNAME                          VARCHAR(220)                  NOT NULL             ,
  TEMPLATE_INFO                      BYTE                                               ,
  INSTANCE_INFO                      BYTE                                               
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.CETB_PTID ON @SCHEMA@.CUSTOM_EXT_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.CUSTOM_STMT_TEMPLATE_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  NAMESPACE                          VARCHAR(220)                  NOT NULL             ,
  LOCALNAME                          VARCHAR(220)                  NOT NULL             ,
  PURPOSE                            VARCHAR(220)                  NOT NULL             ,
  STATEMENT                          BYTE                                               
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.CST_PTID ON @SCHEMA@.CUSTOM_STMT_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.PROCESS_CELL_MAP_T
(
  PTID                               CHAR(24)                      NOT NULL             ,
  CELL                               VARCHAR(220)                  NOT NULL             ,
  PRIMARY KEY ( PTID, CELL )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
(
  ATID                               CHAR(24)                      NOT NULL             ,
  ATTR_KEY                           VARCHAR(192)                  NOT NULL             ,
  ATTR_VALUE                         VARCHAR(254)                                       ,
  PTID                               CHAR(24)                      NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  PRIMARY KEY ( ATID, ATTR_KEY )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.ATAB_PTID ON @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
(   
  PTID
);

CREATE INDEX @SCHEMA@.ATAB_VALUE ON @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
(   
  ATTR_VALUE
);

CREATE TABLE @SCHEMA@.FOR_EACH_TEMPLATE_B_T
(
  ATID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  COUNTER_CTID                       CHAR(24)                      NOT NULL             ,
  SUCCESSFUL_BRANCHES_ONLY           SMALLINT                      NOT NULL             ,
  START_COUNTER_LANGUAGE             INTEGER                       NOT NULL             ,
  FINAL_COUNTER_LANGUAGE             INTEGER                       NOT NULL             ,
  COMPLETION_CONDITION_LANGUAGE      INTEGER                       NOT NULL             ,
  START_COUNTER_EXPRESSION           BYTE                                               ,
  FINAL_COUNTER_EXPRESSION           BYTE                                               ,
  COMPLETION_COND_EXPRESSION         BYTE                                               ,
  FOR_EACH_METHOD                    VARCHAR(254)                                       ,
  START_COUNTER_EXPRESSION_MAP       BYTE                                               ,
  FINAL_COUNTER_EXPRESSION_MAP       BYTE                                               ,
  COMPLETION_COND_EXPRESSION_MAP     BYTE                                               
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.FET_PTID ON @SCHEMA@.FOR_EACH_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.GRAPHICAL_PROCESS_MODEL_T
(
  PTID                               CHAR(24)                      NOT NULL             ,
  SOURCE                             VARCHAR(100)                  NOT NULL             ,
  KIND                               VARCHAR(100)                  NOT NULL             ,
  GRAPHICAL_DATA                     BYTE                                               ,
  ID_MAPPING                         BYTE                                               ,
  PRIMARY KEY ( PTID, SOURCE, KIND )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  CTID                               CHAR(24)                      NOT NULL             ,
  PAID                               CHAR(24)                      NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  QUERY_TYPE                         INTEGER                       NOT NULL             
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.QVT_PTID ON @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(
  MPTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  SOURCE_PTID                        CHAR(24)                      NOT NULL             ,
  TARGET_PTID                        CHAR(24)                      NOT NULL             
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE UNIQUE INDEX @SCHEMA@.MPT_PTIDS ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(   
  SOURCE_PTID, TARGET_PTID
);

CREATE INDEX @SCHEMA@.MPT_TPTID ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(   
  TARGET_PTID
);

CREATE TABLE @SCHEMA@.IDMAPPING_TEMPLATE_T
(
  MPTID                              CHAR(24)                      NOT NULL             ,
  SOURCE_OID                         CHAR(24)                      NOT NULL             ,
  TARGET_OID                         CHAR(24)                      NOT NULL             ,
  SOURCE_PTID                        CHAR(24)                      NOT NULL             ,
  PRIMARY KEY ( MPTID, SOURCE_OID )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.IDMT_PTID ON @SCHEMA@.IDMAPPING_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(
  CGTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  MPTID                              CHAR(24)                      NOT NULL             ,
  SOURCE_PTID                        CHAR(24)                      NOT NULL             ,
  MANDATORY                          SMALLINT                      NOT NULL             ,
  CHANGES                            TEXT                          NOT NULL             
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.CGT_MT ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(   
  MPTID
);

CREATE INDEX @SCHEMA@.CGT_PT ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(
  CGTID                              CHAR(24)                      NOT NULL             ,
  SOURCE_ATID                        CHAR(24)                      NOT NULL             ,
  MPTID                              CHAR(24)                      NOT NULL             ,
  SOURCE_PTID                        CHAR(24)                      NOT NULL             ,
  RELATIONSHIP                       INTEGER                       NOT NULL             ,
  PRIMARY KEY ( CGTID, SOURCE_ATID )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.CGIT_MT ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
  MPTID
);

CREATE INDEX @SCHEMA@.CGIT_PT ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
(
  MPTID                              CHAR(24)                      NOT NULL             ,
  TARGET_CTID                        CHAR(24)                      NOT NULL             ,
  TARGET_STID                        CHAR(24)                      NOT NULL             ,
  SOURCE_PTID                        CHAR(24)                      NOT NULL             ,
  PRIMARY KEY ( MPTID, TARGET_CTID )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.MPVT_PT ON @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE @SCHEMA@.REGION_TEMPLATE_T
(
  RTID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  BEGIN_ATID                         CHAR(24)                                           ,
  END_ATID                           CHAR(24)                                           ,
  REGION_TYPE                        INTEGER                       NOT NULL             ,
  BEGIN_ORDER_NUMBER                 INTEGER                       NOT NULL             ,
  PARENT_RTID                        CHAR(24)                                           
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.RGT_PTID ON @SCHEMA@.REGION_TEMPLATE_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.REGION_CONTENT_TEMPLATE_T
(
  RTID                               CHAR(24)                      NOT NULL             ,
  CONTAINED_ATID                     CHAR(24)                      NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  PRIMARY KEY ( RTID, CONTAINED_ATID )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.RCT_PTID ON @SCHEMA@.REGION_CONTENT_TEMPLATE_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.CHANGE_TEMPLATE_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  MPTID                              CHAR(24)                      NOT NULL             ,
  PROPERTY                           INTEGER                       NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                   NOT NULL             ,
  CHANGE_TYPE                        INTEGER                       NOT NULL             ,
  SOURCE_PTID                        CHAR(24)                      NOT NULL             
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE UNIQUE INDEX @SCHEMA@.CT_MTPDIS ON @SCHEMA@.CHANGE_TEMPLATE_T
(   
  MPTID, PROPERTY, DISPLAY_ID_EXT
);

CREATE INDEX @SCHEMA@.CGT_PTID ON @SCHEMA@.CHANGE_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE @SCHEMA@.STAFF_QUERY_TEMPLATE_T
(
  QTID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  ASSOCIATED_OBJECT_TYPE             INTEGER                       NOT NULL             ,
  ASSOCIATED_OID                     CHAR(24)                      NOT NULL             ,
  T_QUERY                            VARCHAR(32)                   NOT NULL             ,
  QUERY                              BYTE                          NOT NULL             ,
  HASH_CODE                          INTEGER                       NOT NULL             ,
  SUBSTITUTION_POLICY                INTEGER                       NOT NULL             ,
  STAFF_VERB                         BYTE                                               
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.SQT_HASH ON @SCHEMA@.STAFF_QUERY_TEMPLATE_T
(   
  ASSOCIATED_OID, HASH_CODE, T_QUERY, ASSOCIATED_OBJECT_TYPE
);

CREATE TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
(
  PIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  SHARED_PC_ID                       CHAR(24)                                           ,
  STATE                              INTEGER                       NOT NULL             ,
  PENDING_REQUEST                    INTEGER                       NOT NULL             ,
  CREATED                            DATETIME YEAR TO FRACTION(3)                       ,
  STARTED                            DATETIME YEAR TO FRACTION(3)                       ,
  COMPLETED                          DATETIME YEAR TO FRACTION(3)                       ,
  LAST_STATE_CHANGE                  DATETIME YEAR TO FRACTION(3)                       ,
  LAST_MODIFIED                      DATETIME YEAR TO FRACTION(3)                       ,
  NAME                               VARCHAR(220)                  NOT NULL             ,
  PARENT_NAME                        VARCHAR(220)                                       ,
  TOP_LEVEL_NAME                     VARCHAR(220)                  NOT NULL             ,
  COMPENSATION_SPHERE_NAME           VARCHAR(100)                                       ,
  STARTER                            VARCHAR(128)                                       ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  INPUT_SNID                         CHAR(24)                                           ,
  INPUT_ATID                         CHAR(24)                                           ,
  INPUT_VTID                         CHAR(24)                                           ,
  OUTPUT_SNID                        CHAR(24)                                           ,
  OUTPUT_ATID                        CHAR(24)                                           ,
  OUTPUT_VTID                        CHAR(24)                                           ,
  FAULT_NAME                         VARCHAR(254)                                       ,
  TOP_LEVEL_PIID                     CHAR(24)                      NOT NULL             ,
  PARENT_PIID                        CHAR(24)                                           ,
  PARENT_AIID                        CHAR(24)                                           ,
  TKIID                              CHAR(24)                                           ,
  TERMIN_ON_REC                      SMALLINT                      NOT NULL             ,
  AWAITED_SUB_PROC                   SMALLINT                      NOT NULL             ,
  IS_CREATING                        SMALLINT                      NOT NULL             ,
  PREVIOUS_STATE                     INTEGER                                            ,
  EXECUTING_ISOLATED_SCOPE           SMALLINT                      NOT NULL             ,
  SCHEDULER_TASK_ID                  VARCHAR(254)                                       ,
  RESUMES                            DATETIME YEAR TO FRACTION(3)                       ,
  PENDING_SKIP_REQUEST               SMALLINT                      NOT NULL             ,
  IS_MIGRATED                        SMALLINT                      NOT NULL             ,
  UNHANDLED_EXCEPTION                BYTE                                               ,
  CREATED_WITH_VERSION               INTEGER                       NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE UNIQUE INDEX @SCHEMA@.PIB_NAME ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  NAME
);

CREATE INDEX @SCHEMA@.PIB_TOP ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  TOP_LEVEL_PIID
);

CREATE INDEX @SCHEMA@.PIB_PAP ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  PARENT_PIID
);

CREATE INDEX @SCHEMA@.PIB_PAR ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  PARENT_AIID
);

CREATE INDEX @SCHEMA@.PIB_PTID ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  PTID
);

CREATE INDEX @SCHEMA@.PIB_PIID_STATE ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  PIID, STATE
);

CREATE INDEX @SCHEMA@.PIB_STATE ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  STATE
);

CREATE INDEX @SCHEMA@.PIB_PIID_PTID_STAT ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  PIID, PTID, STATE, STARTER, STARTED
);

CREATE INDEX @SCHEMA@.PIB_WSID1 ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  WSID_1, STATE
);

CREATE INDEX @SCHEMA@.PIB_WSID2 ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  WSID_2, STATE
);

CREATE INDEX @SCHEMA@.PIB_SWI1 ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  PIID, NAME, PTID
);

CREATE TABLE @SCHEMA@.SCOPE_INSTANCE_B_T
(
  SIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PARENT_SIID                        CHAR(24)                                           ,
  STID                               CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  EHIID                              CHAR(24)                                           ,
  ENCLOSING_FEIID                    CHAR(24)                                           ,
  ENCLOSING_FOR_EACH_END_AIID        CHAR(24)                                           ,
  COMPENSATE_AIID                    CHAR(24)                                           ,
  PARENT_COMP_SIID                   CHAR(24)                                           ,
  LAST_COMP_SIID                     CHAR(24)                                           ,
  RUNNING_EVENT_HANDLERS             INTEGER                       NOT NULL             ,
  STATE                              INTEGER                       NOT NULL             ,
  NOTIFY_PARENT                      SMALLINT                      NOT NULL             ,
  AWAITED_SCOPES                     INTEGER                       NOT NULL             ,
  AWAITED_SUB_PROCESSES              INTEGER                       NOT NULL             ,
  BPEL_EXCEPTION                     BYTE                                               ,
  IS_ACTIVE                          SMALLINT                      NOT NULL             ,
  INITIATED_COMP                     SMALLINT                      NOT NULL             ,
  IS_TERMINATION_FROM_FOR_EACH       SMALLINT                      NOT NULL             ,
  TOTAL_COMPL_NUMBER                 INT8                          NOT NULL             ,
  SCOPE_COMPL_NUMBER                 INT8                          NOT NULL             ,
  A_TKIID                            CHAR(24)                                           ,
  HAS_COMPENSATION_WORK              SMALLINT                      NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.SI_PI_ST_EH_STA_FE ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  PIID, STID, STATE, EHIID, ENCLOSING_FEIID
);

CREATE INDEX @SCHEMA@.SI_PI_ST_EH_ACT_FE ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  PIID, STID, IS_ACTIVE, EHIID, ENCLOSING_FEIID
);

CREATE INDEX @SCHEMA@.SI_PIID_PARSI ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  PIID, PARENT_SIID, IS_ACTIVE
);

CREATE INDEX @SCHEMA@.SI_PARCOMP_STA_ST ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  PARENT_COMP_SIID, STATE, STID
);

CREATE INDEX @SCHEMA@.SI_PIID_STATE ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  PIID, STATE
);

CREATE INDEX @SCHEMA@.SI_LAST_COMPSIID ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  LAST_COMP_SIID
);

CREATE TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
(
  AIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  ATID                               CHAR(24)                      NOT NULL             ,
  SIID                               CHAR(24)                                           ,
  PIID                               CHAR(24)                      NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  EHIID                              CHAR(24)                                           ,
  ENCLOSING_FEIID                    CHAR(24)                                           ,
  P_TKIID                            CHAR(24)                                           ,
  A_TKIID                            CHAR(24)                                           ,
  INVOKED_INSTANCE_ID                CHAR(24)                                           ,
  INVOKED_INSTANCE_TYPE              INTEGER                       NOT NULL             ,
  STATE                              INTEGER                       NOT NULL             ,
  TRANS_COND_VALUES                  CHAR(88)                      NOT NULL             ,
  NUMBER_LINKS_EVALUATED             INTEGER                       NOT NULL             ,
  FINISHED                           DATETIME YEAR TO FRACTION(3)                       ,
  ACTIVATED                          DATETIME YEAR TO FRACTION(3)                       ,
  FIRST_ACTIVATED                    DATETIME YEAR TO FRACTION(3)                       ,
  STARTED                            DATETIME YEAR TO FRACTION(3)                       ,
  LAST_MODIFIED                      DATETIME YEAR TO FRACTION(3)                       ,
  LAST_STATE_CHANGE                  DATETIME YEAR TO FRACTION(3)                       ,
  OWNER                              VARCHAR(128)                                       ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  LINK_ORDER_NUMBER                  INTEGER                                            ,
  SCHEDULER_TASK_ID                  VARCHAR(254)                                       ,
  EXPIRES                            DATETIME YEAR TO FRACTION(3)                       ,
  CONTINUE_ON_ERROR                  SMALLINT                      NOT NULL             ,
  UNHANDLED_EXCEPTION                BYTE                                               ,
  STOP_REASON                        INTEGER                       NOT NULL             ,
  PREVIOUS_STATE                     INTEGER                                            ,
  INVOCATION_COUNTER                 INTEGER                       NOT NULL             ,
  FOR_EACH_START_COUNTER_VALUE       INT8                                               ,
  FOR_EACH_FINAL_COUNTER_VALUE       INT8                                               ,
  FOR_EACH_CURRENT_COUNTER_VALUE     INT8                                               ,
  FOR_EACH_COMPLETED_BRANCHES        INT8                                               ,
  FOR_EACH_FAILED_BRANCHES           INT8                                               ,
  FOR_EACH_MAX_COMPL_BRANCHES        INT8                                               ,
  FOR_EACH_AWAITED_BRANCHES          INT8                                               ,
  IS51_ACTIVITY                      SMALLINT                      NOT NULL             ,
  MAY_HAVE_SUBPROCESS                SMALLINT                                           ,
  SKIP_REQUESTED                     SMALLINT                      NOT NULL             ,
  JUMP_TARGET_ATID                   CHAR(24)                                           ,
  SUB_STATE                          INTEGER                       NOT NULL             ,
  PENDING_REQUEST_DATA               BYTE                                               ,
  XTID                               CHAR(24)                                           ,
  EXPIRATION_COUNTER                 INTEGER                                            ,
  PREVIOUS_EXPIRATION_DATE           DATETIME YEAR TO FRACTION(3)                       ,
  TARGET_IORAIID                     CHAR(24)                                           ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  MAX_COMPENSATION_NUMBER            INT8                                               ,
  HAS_WORK_ITEM                      SMALLINT                                           ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.AIB_PI_ATID_EH_FE ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID, ATID, EHIID, ENCLOSING_FEIID
);

CREATE INDEX @SCHEMA@.AIB_PI_EH_FE_AT ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID, EHIID, ENCLOSING_FEIID, ATID
);

CREATE INDEX @SCHEMA@.AIB_PI_DIS_EH_FE ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID, DISPLAY_ID_EXT, EHIID, ENCLOSING_FEIID
);

CREATE INDEX @SCHEMA@.AIB_PTID ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PTID
);

CREATE INDEX @SCHEMA@.AIB_PIID_STAT_AIID ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID, STATE, AIID, ACTIVATED
);

CREATE INDEX @SCHEMA@.AIB_AI_AT_STAT_PI ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  AIID, ATID, STATE, PIID, OWNER, ACTIVATED
);

CREATE INDEX @SCHEMA@.AIB_SIID ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  SIID
);

CREATE INDEX @SCHEMA@.AIB_ATID_STAT ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  ATID, STATE
);

CREATE INDEX @SCHEMA@.AIB_WSID1 ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  WSID_1, STATE
);

CREATE INDEX @SCHEMA@.AIB_WSID2 ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  WSID_2, STATE
);

CREATE INDEX @SCHEMA@.AIB_PIID ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID
);

CREATE TABLE @SCHEMA@.VARIABLE_INSTANCE_B_T
(
  CTID                               CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  DATA                               BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( CTID, PIID )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.CI_PIID ON @SCHEMA@.VARIABLE_INSTANCE_B_T
(   
  PIID
);

CREATE TABLE @SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_T
(
  SVIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  CTID                               CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  SIID                               CHAR(24)                      NOT NULL             ,
  EHIID                              CHAR(24)                                           ,
  FEIID                              CHAR(24)                                           ,
  DATA                               BYTE                                               ,
  IS_ACTIVE                          SMALLINT                      NOT NULL             ,
  IS_INITIALIZED                     SMALLINT                      NOT NULL             ,
  IS_QUERYABLE                       SMALLINT                      NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.SVI_PI_CT_EH_FE ON @SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_T
(   
  PIID, CTID, IS_ACTIVE, EHIID, FEIID
);

CREATE INDEX @SCHEMA@.SVI_CT_SI_EH_AC ON @SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_T
(   
  SIID, CTID, IS_ACTIVE, EHIID
);

CREATE TABLE @SCHEMA@.STAFF_MESSAGE_INSTANCE_B_T
(
  AIID                               CHAR(24)                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  DATA                               BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( AIID, KIND )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.SMI_PIID ON @SCHEMA@.STAFF_MESSAGE_INSTANCE_B_T
(   
  PIID
);

CREATE TABLE @SCHEMA@.EVENT_INSTANCE_B_T
(
  EIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PIID                               CHAR(24)                      NOT NULL             ,
  VTID                               CHAR(24)                      NOT NULL             ,
  IS_TWO_WAY                         SMALLINT                      NOT NULL             ,
  IS_PRIMARY_EVENT_INSTANCE          SMALLINT                      NOT NULL             ,
  STATE                              INTEGER                       NOT NULL             ,
  AIID                               CHAR(24)                                           ,
  EHTID                              CHAR(24)                                           ,
  SIID                               CHAR(24)                                           ,
  TKIID                              CHAR(24)                                           ,
  NEXT_POSTED_EVENT                  CHAR(24)                                           ,
  LAST_POSTED_EVENT                  CHAR(24)                                           ,
  POST_COUNT                         INTEGER                       NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  MESSAGE                            BYTE                                               ,
  REPLY_CONTEXT                      BYTE                                               ,
  POST_TIME                          DATETIME YEAR TO FRACTION(3)                       ,
  MAX_NUMBER_OF_POSTS                INTEGER                       NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.EI_PIID_PRIM ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  PIID, IS_PRIMARY_EVENT_INSTANCE, STATE
);

CREATE INDEX @SCHEMA@.EI_PIID_VTID ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  PIID, VTID, IS_PRIMARY_EVENT_INSTANCE
);

CREATE INDEX @SCHEMA@.EI_AIID ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  AIID
);

CREATE INDEX @SCHEMA@.EI_STATE_VTID ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  VTID, STATE, EIID, AIID, PIID
);

CREATE INDEX @SCHEMA@.EI_WSID1 ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  WSID_1
);

CREATE INDEX @SCHEMA@.EI_WSID2 ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  WSID_2
);

CREATE TABLE @SCHEMA@.REQUEST_INSTANCE_B_T
(
  RIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PIID                               CHAR(24)                      NOT NULL             ,
  VTID                               CHAR(24)                      NOT NULL             ,
  ATID                               CHAR(24)                      NOT NULL             ,
  EHIID                              CHAR(24)                                           ,
  TKIID                              CHAR(24)                                           ,
  FEIID                              CHAR(24)                                           ,
  INSTANTIATING                      SMALLINT                      NOT NULL             ,
  REPLY_CONTEXT                      BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.RI_PIID_VTID_EHIID ON @SCHEMA@.REQUEST_INSTANCE_B_T
(   
  PIID, VTID
);

CREATE TABLE @SCHEMA@.PARTNER_LINK_INSTANCE_B_T
(
  PIID                               CHAR(24)                      NOT NULL             ,
  NAME                               VARCHAR(220)                  NOT NULL             ,
  ENDPOINT_REFERENCE                 BYTE                                               ,
  SERVICE_DEFINITION                 BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( PIID, NAME )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.PA_PIID ON @SCHEMA@.PARTNER_LINK_INSTANCE_B_T
(   
  PIID
);

CREATE TABLE @SCHEMA@.VARIABLE_SNAPSHOT_B_T
(
  SNID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  CTID                               CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  DATA                               BYTE                                               ,
  COPY_VERSION                       SMALLINT                      NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.SN_PIID_CTID ON @SCHEMA@.VARIABLE_SNAPSHOT_B_T
(   
  PIID, CTID
);

CREATE TABLE @SCHEMA@.SUSPENDED_MESSAGE_INSTANCE_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PIID                               CHAR(24)                      NOT NULL             ,
  ENGINE_MESSAGE                     BYTE                          NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.PIID ON @SCHEMA@.SUSPENDED_MESSAGE_INSTANCE_B_T
(   
  PIID
);

CREATE TABLE @SCHEMA@.CROSSING_LINK_INSTANCE_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PIID                               CHAR(24)                      NOT NULL             ,
  SOURCE_ATID                        CHAR(24)                      NOT NULL             ,
  TARGET_ATID                        CHAR(24)                      NOT NULL             ,
  EHIID                              CHAR(24)                                           ,
  FEIID                              CHAR(24)                                           ,
  CONDITION_VALUE                    INTEGER                       NOT NULL             ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.CL_PI_TAT_EH_FE_SA ON @SCHEMA@.CROSSING_LINK_INSTANCE_B_T
(   
  PIID, TARGET_ATID, EHIID, FEIID, SOURCE_ATID
);

CREATE TABLE @SCHEMA@.INVOKE_RESULT_B_T
(
  PIID                               CHAR(24)                      NOT NULL             ,
  ATID                               CHAR(24)                      NOT NULL             ,
  STATE                              INTEGER                       NOT NULL             ,
  INVOKE_RESULT                      BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( PIID, ATID )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.INVOKE_RESULT2_B_T
(
  IRID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PIID                               CHAR(24)                      NOT NULL             ,
  ATID                               CHAR(24)                      NOT NULL             ,
  EHIID                              CHAR(24)                                           ,
  FEIID                              CHAR(24)                                           ,
  STATE                              INTEGER                       NOT NULL             ,
  INVOKE_RESULT                      BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.IR2_PI_AT_EH_FE ON @SCHEMA@.INVOKE_RESULT2_B_T
(   
  PIID, ATID, EHIID, FEIID
);

CREATE TABLE @SCHEMA@.EVENT_HANDLER_INSTANCE_B_T
(
  EHIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  EHTID                              CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  SIID                               CHAR(24)                      NOT NULL             ,
  PARENT_EHIID                       CHAR(24)                                           ,
  FEIID                              CHAR(24)                                           ,
  SCHEDULER_TASK_ID                  VARCHAR(254)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.EHI_PIID_EHTID ON @SCHEMA@.EVENT_HANDLER_INSTANCE_B_T
(   
  PIID, EHTID
);

CREATE INDEX @SCHEMA@.EHI_SIID_EHTID ON @SCHEMA@.EVENT_HANDLER_INSTANCE_B_T
(   
  SIID, EHTID
);

CREATE TABLE @SCHEMA@.CORRELATION_SET_INSTANCE_B_T
(
  PIID                               CHAR(24)                      NOT NULL             ,
  COID                               CHAR(24)                      NOT NULL             ,
  SIID                               CHAR(24)                      NOT NULL             ,
  PROCESS_NAME                       VARCHAR(220)                  NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  STATUS                             INTEGER                       NOT NULL             ,
  HASH_CODE                          CHAR(24)                      NOT NULL             ,
  DATA                               TEXT                                               ,
  DATA_LONG                          TEXT                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( PIID, COID, SIID )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE UNIQUE INDEX @SCHEMA@.CSIB_HASH_PN ON @SCHEMA@.CORRELATION_SET_INSTANCE_B_T
(   
  HASH_CODE, PROCESS_NAME
);

CREATE INDEX @SCHEMA@.CSIB_PIID ON @SCHEMA@.CORRELATION_SET_INSTANCE_B_T
(   
  PIID
);

CREATE TABLE @SCHEMA@.CORRELATION_SET_PROPERTIES_B_T
(
  PIID                               CHAR(24)                      NOT NULL             ,
  COID                               CHAR(24)                      NOT NULL             ,
  SIID                               CHAR(24)                      NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  DATA                               BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( PIID, COID, SIID )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.UNDO_ACTION_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  ATID                               CHAR(24)                      NOT NULL             ,
  PARENT_ATID                        CHAR(24)                                           ,
  PARENT_PIID                        CHAR(24)                                           ,
  PARENT_AIID                        CHAR(24)                                           ,
  PARENT_EHIID                       CHAR(24)                                           ,
  PARENT_FEIID                       CHAR(24)                                           ,
  PROCESS_NAME                       VARCHAR(220)                  NOT NULL             ,
  CSCOPE_ID                          VARCHAR(100)                  NOT NULL             ,
  UUID                               VARCHAR(100)                  NOT NULL             ,
  COMP_CREATION_TIME                 DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  DO_OP_WAS_TXNAL                    SMALLINT                      NOT NULL             ,
  STATE                              INTEGER                       NOT NULL             ,
  INPUT_DATA                         BYTE                          NOT NULL             ,
  FAULT_DATA                         BYTE                                               ,
  CREATED                            INTEGER                       NOT NULL             ,
  PROCESS_ADMIN                      VARCHAR(128)                  NOT NULL             ,
  IS_VISIBLE                         SMALLINT                      NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.UA_CSID_DOOP_UUID ON @SCHEMA@.UNDO_ACTION_B_T
(   
  CSCOPE_ID, DO_OP_WAS_TXNAL, UUID
);

CREATE INDEX @SCHEMA@.UA_CSID_STATE_CCT ON @SCHEMA@.UNDO_ACTION_B_T
(   
  CSCOPE_ID, STATE, UUID
);

CREATE INDEX @SCHEMA@.UA_STATE_ISV ON @SCHEMA@.UNDO_ACTION_B_T
(   
  STATE, IS_VISIBLE
);

CREATE INDEX @SCHEMA@.UA_AIID_STATE_UUID ON @SCHEMA@.UNDO_ACTION_B_T
(   
  PARENT_AIID, STATE, UUID
);

CREATE INDEX @SCHEMA@.UA_PIID ON @SCHEMA@.UNDO_ACTION_B_T
(   
  PARENT_PIID
);

CREATE INDEX @SCHEMA@.UA_PT_AT_CS_UU_CCT ON @SCHEMA@.UNDO_ACTION_B_T
(   
  PTID, ATID, CSCOPE_ID, UUID, COMP_CREATION_TIME
);

CREATE TABLE @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  SVIID                              CHAR(24)                                           ,
  NAMESPACE                          VARCHAR(220)                  NOT NULL             ,
  LOCALNAME                          VARCHAR(220)                  NOT NULL             ,
  PURPOSE                            VARCHAR(220)                  NOT NULL             ,
  STATEMENT                          BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.CSI_PIID_NS ON @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T
(   
  PIID, NAMESPACE
);

CREATE INDEX @SCHEMA@.CSI_SVIID_NS ON @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T
(   
  SVIID, NAMESPACE
);

CREATE TABLE @SCHEMA@.COMP_WORK_PENDING_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PARENT_PIID                        CHAR(24)                      NOT NULL             ,
  PARENT_ATID                        CHAR(24)                      NOT NULL             ,
  PARENT_EHIID                       CHAR(24)                                           ,
  PARENT_FEIID                       CHAR(24)                                           ,
  STATE                              INTEGER                       NOT NULL             ,
  CSCOPE_ID                          VARCHAR(100)                  NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.CWP_PI_AT_CS_EH_FE ON @SCHEMA@.COMP_WORK_PENDING_B_T
(   
  PARENT_PIID, PARENT_ATID, CSCOPE_ID, PARENT_EHIID, PARENT_FEIID
);

CREATE INDEX @SCHEMA@.CWP_PI_AT_EHI ON @SCHEMA@.COMP_WORK_PENDING_B_T
(   
  PARENT_PIID, PARENT_ATID, PARENT_EHIID
);

CREATE TABLE @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
(
  AIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  SIID                               CHAR(24)                      NOT NULL             ,
  ATID                               CHAR(24)                                           ,
  PIID                               CHAR(24)                      NOT NULL             ,
  COMPLETION_NUMBER                  INT8                          NOT NULL             ,
  STATE                              INTEGER                       NOT NULL             ,
  COMPENSATE_AIID                    CHAR(24)                                           ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.CPAI_SI_S_CN_AI_PI ON @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
(   
  SIID, STATE, COMPLETION_NUMBER, AIID, PIID
);

CREATE INDEX @SCHEMA@.CPAI_PIID ON @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
(   
  PIID
);

CREATE TABLE @SCHEMA@.RESTART_EVENT_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PIID                               CHAR(24)                      NOT NULL             ,
  PORT_TYPE                          VARCHAR(254)                  NOT NULL             ,
  OPERATION                          VARCHAR(254)                  NOT NULL             ,
  NAMESPACE                          VARCHAR(254)                  NOT NULL             ,
  INPUT_MESSAGE                      BYTE                                               ,
  REPLY_CTX                          BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.REB_PIID ON @SCHEMA@.RESTART_EVENT_B_T
(   
  PIID
);

CREATE TABLE @SCHEMA@.PROGRESS_COUNTER_T
(
  PIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  COUNTER                            INT8                          NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.RELEVANT_SCOPE_ATASK_T
(
  SIID                               CHAR(24)                      NOT NULL             ,
  TKIID                              CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( SIID, TKIID )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.RSAT_PIID ON @SCHEMA@.RELEVANT_SCOPE_ATASK_T
(   
  PIID
);

CREATE TABLE @SCHEMA@.CONFIG_INFO_T
(
  IDENTIFIER                         VARCHAR(64)                   NOT NULL  PRIMARY KEY,
  DESCRIPTION                        VARCHAR(128)                                       ,
  PROPERTY                           INTEGER                                            ,
  COUNTER                            INT8                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
(
  PIID                               CHAR(24)                      NOT NULL             ,
  ATTR_KEY                           VARCHAR(220)                  NOT NULL             ,
  VALUE                              VARCHAR(254)                                       ,
  DATA_TYPE                          VARCHAR(254)                                       ,
  DATA                               BYTE                                               ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( PIID, ATTR_KEY )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.PIA_VALUE ON @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
(   
  VALUE
);

CREATE INDEX @SCHEMA@.PIA_DATY ON @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
(   
  DATA_TYPE
);

CREATE TABLE @SCHEMA@.PROCESS_CONTEXT_T
(
  PIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  SHARED                             SMALLINT                                           ,
  REPLY_CONTEXT                      BYTE                                               ,
  SERVICE_CONTEXT                    BYTE                                               ,
  STARTER_EXPIRES                    DATETIME YEAR TO FRACTION(3)                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PIID                               CHAR(24)                      NOT NULL             ,
  ATID                               CHAR(24)                      NOT NULL             ,
  EHIID                              CHAR(24)                                           ,
  FEIID                              CHAR(24)                                           ,
  AIID                               CHAR(24)                                           ,
  ATTR_KEY                           VARCHAR(189)                  NOT NULL             ,
  ATTR_VALUE                         VARCHAR(254)                                       ,
  DATA_TYPE                          VARCHAR(254)                                       ,
  DATA                               BYTE                                               ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE UNIQUE INDEX @SCHEMA@.AIA_UNIQUE ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
  PIID, ATID, EHIID, FEIID, ATTR_KEY
);

CREATE INDEX @SCHEMA@.AIA_AIID ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
  AIID
);

CREATE INDEX @SCHEMA@.AIA_VALUE ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
  ATTR_VALUE
);

CREATE INDEX @SCHEMA@.AIA_DATY ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
  DATA_TYPE
);

CREATE TABLE @SCHEMA@.NAVIGATION_EXCEPTION_T
(
  CORRELATION_ID                     CHAR(296)                     NOT NULL             ,
  EXCEPTION_TYPE                     INTEGER                       NOT NULL             ,
  PIID                               CHAR(24)                                           ,
  OUTPUT_MESSAGE                     BYTE                                               ,
  TYPE_SYSTEM                        VARCHAR(32)                                        ,
  PROCESS_EXCEPTION                  BYTE                          NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( CORRELATION_ID, EXCEPTION_TYPE )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.NE_PIID ON @SCHEMA@.NAVIGATION_EXCEPTION_T
(   
  PIID
);

CREATE TABLE @SCHEMA@.AWAITED_INVOCATION_T
(
  CORRELATION_ID                     CHAR(340)                     NOT NULL  PRIMARY KEY,
  CORRELATION_INFO                   BYTE                          NOT NULL             ,
  AIID                               CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.AWI_PIID ON @SCHEMA@.AWAITED_INVOCATION_T
(   
  PIID
);

CREATE INDEX @SCHEMA@.AWI_AIID ON @SCHEMA@.AWAITED_INVOCATION_T
(   
  AIID
);

CREATE TABLE @SCHEMA@.STORED_QUERY_T
(
  SQID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  KIND                               INTEGER                       NOT NULL             ,
  NAME                               VARCHAR(64)                   NOT NULL             ,
  OWNER_ID                           VARCHAR(128)                  NOT NULL             ,
  SELECT_CLAUSE                      TEXT                          NOT NULL             ,
  WHERE_CLAUSE                       TEXT                                               ,
  ORDER_CLAUSE                       VARCHAR(254)                                       ,
  THRESHOLD                          INTEGER                                            ,
  TIMEZONE                           VARCHAR(63)                                        ,
  CREATOR                            VARCHAR(128)                                       ,
  TYPE                               VARCHAR(128)                                       ,
  PROPERTY                           BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE UNIQUE INDEX @SCHEMA@.SQ_NAME ON @SCHEMA@.STORED_QUERY_T
(   
  KIND, OWNER_ID, NAME
);

CREATE TABLE @SCHEMA@.FOR_EACH_INSTANCE_B_T
(
  FEIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  PARENT_FEIID                       CHAR(24)                                           ,
  PIID                               CHAR(24)                      NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.FEI_PIID ON @SCHEMA@.FOR_EACH_INSTANCE_B_T
(   
  PIID
);

CREATE TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  CTID                               CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  PAID                               CHAR(24)                      NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  VARIABLE_NAME                      VARCHAR(254)                  NOT NULL             ,
  PROPERTY_NAME                      LVARCHAR                      NOT NULL             ,
  PROPERTY_NAMESPACE                 VARCHAR(254)                  NOT NULL             ,
  TYPE                               INTEGER                       NOT NULL             ,
  GENERIC_VALUE                      LVARCHAR                                           ,
  STRING_VALUE                       LVARCHAR                                           ,
  NUMBER_VALUE                       INT8                                               ,
  DECIMAL_VALUE                      DOUBLE PRECISION                                   ,
  TIMESTAMP_VALUE                    DATETIME YEAR TO FRACTION(3)                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.QVI_PI_CT_PA ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, CTID, PAID
);

CREATE INDEX @SCHEMA@.QVI_PI_NUM ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, NUMBER_VALUE
);

CREATE INDEX @SCHEMA@.QVI_PI_DEC ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, DECIMAL_VALUE
);

CREATE INDEX @SCHEMA@.QVI_PI_TIME ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, TIMESTAMP_VALUE
);

CREATE TABLE @SCHEMA@.SYNC_T
(
  IDENTIFIER                         VARCHAR(254)                  NOT NULL  PRIMARY KEY,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.MV_CTR_T
(
  ID                                 INTEGER                       NOT NULL  PRIMARY KEY,
  SELECT_CLAUSE                      LVARCHAR                      NOT NULL             ,
  WHERE_CLAUSE                       LVARCHAR                                           ,
  ORDER_CLAUSE                       LVARCHAR                                           ,
  TBL_SPACE                          VARCHAR(32)                   NOT NULL             ,
  UPDATED                            DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  UPD_STARTED                        DATETIME YEAR TO FRACTION(3)                       ,
  AVG_UPD_TIME                       INT8                                               ,
  UPD_INTERVAL                       INT8                          NOT NULL             ,
  IS_UPDATING                        SMALLINT                      NOT NULL             ,
  ACTIVE_MV                          SMALLINT                      NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.MV_MODS_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  OID                                CHAR(24)                      NOT NULL             ,
  MODIFIED                           DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PIID                               CHAR(24)                                           ,
  CREATION_TIME                      DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  REASON                             INTEGER                       NOT NULL             ,
  ENGINE_MESSAGE_S                   CHAR(2668)                                         ,
  ENGINE_MESSAGE_L                   BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.SEM_PIID ON @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(   
  PIID
);

CREATE INDEX @SCHEMA@.SEM_REAS ON @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(   
  REASON, CREATION_TIME
);

CREATE TABLE @SCHEMA@.NAVIGATION_CLEANUP_TIMER_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  SCHEDULED_TIME                     DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  SCHEDULER_ID                       VARCHAR(254)                  NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.SCHEDULER_ACTION_T
(
  SCHEDULER_ID                       VARCHAR(254)                  NOT NULL  PRIMARY KEY,
  OID                                CHAR(24)                      NOT NULL             ,
  ACTION_OBJECT                      BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.SCEACT_OID ON @SCHEMA@.SCHEDULER_ACTION_T
(   
  OID
);

CREATE TABLE @SCHEMA@.QUERY_TABLE_T
(
  NAME                               VARCHAR(32)                   NOT NULL  PRIMARY KEY,
  KIND                               INTEGER                       NOT NULL             ,
  TYPE                               INTEGER                       NOT NULL             ,
  VERSION                            INTEGER                       NOT NULL             ,
  LAST_UPDATED                       DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  PRIMARY_VIEW                       VARCHAR(32)                                        ,
  DEFINITION                         BYTE                          NOT NULL             ,
  VV_CFG                             BYTE                                               ,
  DV_CFG                             BYTE                                               ,
  MV_CFG                             BYTE                                               ,
  MT_CFG                             BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.QT_KI ON @SCHEMA@.QUERY_TABLE_T
(   
  KIND
);

CREATE INDEX @SCHEMA@.QT_TY ON @SCHEMA@.QUERY_TABLE_T
(   
  TYPE
);

CREATE TABLE @SCHEMA@.QUERY_TABLE_REF_T
(
  REFEREE                            VARCHAR(32)                   NOT NULL             ,
  SOURCE                             VARCHAR(32)                   NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( REFEREE, SOURCE )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.QTR_SRC ON @SCHEMA@.QUERY_TABLE_REF_T
(   
  SOURCE
);

CREATE TABLE @SCHEMA@.MIGRATION_FRONT_T
(
  PIID                               CHAR(24)                      NOT NULL             ,
  MPTID                              CHAR(24)                      NOT NULL             ,
  AIID                               CHAR(24)                      NOT NULL             ,
  STATE                              INTEGER                       NOT NULL             ,
  SUB_STATE                          INTEGER                       NOT NULL             ,
  STOP_REASON                        INTEGER                       NOT NULL             ,
  SOURCE_ATID                        CHAR(24)                      NOT NULL             ,
  TARGET_ATID                        CHAR(24)                      NOT NULL             ,
  MIGRATION_TIME                     DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( PIID, MPTID, AIID )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.MGF_MPTID ON @SCHEMA@.MIGRATION_FRONT_T
(   
  MPTID
);

CREATE TABLE @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
(
  SIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PIID                               CHAR(24)                      NOT NULL             ,
  COUNTER                            INT8                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.SCC_PIID ON @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
(   
  PIID
);

CREATE TABLE @SCHEMA@.AUDIT_LOG_T
(
  ALID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  EVENT_TIME                         DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  EVENT_TIME_UTC                     DATETIME YEAR TO FRACTION(3)                       ,
  AUDIT_EVENT                        INTEGER                       NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                                           ,
  AIID                               CHAR(24)                                           ,
  SIID                               CHAR(24)                                           ,
  VARIABLE_NAME                      VARCHAR(254)                                       ,
  PROCESS_TEMPL_NAME                 VARCHAR(254)                  NOT NULL             ,
  PROCESS_INST_NAME                  VARCHAR(254)                                       ,
  TOP_LEVEL_PI_NAME                  VARCHAR(254)                                       ,
  TOP_LEVEL_PIID                     CHAR(24)                                           ,
  PARENT_PI_NAME                     VARCHAR(254)                                       ,
  PARENT_PIID                        CHAR(24)                                           ,
  VALID_FROM                         DATETIME YEAR TO FRACTION(3)                       ,
  VALID_FROM_UTC                     DATETIME YEAR TO FRACTION(3)                       ,
  ATID                               CHAR(24)                                           ,
  ACTIVITY_NAME                      VARCHAR(254)                                       ,
  ACTIVITY_KIND                      INTEGER                                            ,
  ACTIVITY_STATE                     INTEGER                                            ,
  CONTROL_LINK_NAME                  VARCHAR(254)                                       ,
  IMPL_NAME                          VARCHAR(254)                                       ,
  PRINCIPAL                          VARCHAR(128)                                       ,
  TERMINAL_NAME                      VARCHAR(254)                                       ,
  VARIABLE_DATA                      BYTE                                               ,
  EXCEPTION_TEXT                     TEXT                                               ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  CORR_SET_INFO                      TEXT                                               ,
  USER_NAME                          VARCHAR(128)                                       ,
  ADDITIONAL_INFO                    TEXT                                               ,
  OBJECT_META_TYPE                   INTEGER                                            ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @AUDITLOG@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.WORK_ITEM_T
(
  WIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PARENT_WIID                        CHAR(24)                                           ,
  OWNER_ID                           VARCHAR(128)                                       ,
  GROUP_NAME                         VARCHAR(128)                                       ,
  EVERYBODY                          SMALLINT                      NOT NULL             ,
  EXCLUDE                            SMALLINT                      NOT NULL             ,
  QIID                               CHAR(24)                                           ,
  OBJECT_TYPE                        INTEGER                       NOT NULL             ,
  OBJECT_ID                          CHAR(24)                      NOT NULL             ,
  ASSOCIATED_OBJECT_TYPE             INTEGER                       NOT NULL             ,
  ASSOCIATED_OID                     CHAR(24)                                           ,
  REASON                             INTEGER                       NOT NULL             ,
  CREATION_TIME                      DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  AUTH_INFO                          INTEGER                       NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @WORKITEM@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.WI_ASSOBJ_REASON ON @SCHEMA@.WORK_ITEM_T
(   
  ASSOCIATED_OID, ASSOCIATED_OBJECT_TYPE, REASON, PARENT_WIID
);

CREATE INDEX @SCHEMA@.WI_OBJID_TYPE_QIID ON @SCHEMA@.WORK_ITEM_T
(   
  OBJECT_ID, OBJECT_TYPE, QIID
);

CREATE INDEX @SCHEMA@.WI_OBJID_TYPE_REAS ON @SCHEMA@.WORK_ITEM_T
(   
  OBJECT_ID, OBJECT_TYPE, REASON
);

CREATE INDEX @SCHEMA@.WI_GROUP_NAME ON @SCHEMA@.WORK_ITEM_T
(   
  GROUP_NAME
);

CREATE INDEX @SCHEMA@.WI_AUTH_U ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, QIID
);

CREATE INDEX @SCHEMA@.WI_AUTH_O ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, OWNER_ID DESC
);

CREATE INDEX @SCHEMA@.WI_AUTH_G ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, GROUP_NAME
);

CREATE INDEX @SCHEMA@.WI_AUTH_E ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, EVERYBODY
);

CREATE INDEX @SCHEMA@.WI_AUTH_R ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, REASON DESC
);

CREATE INDEX @SCHEMA@.WI_REASON ON @SCHEMA@.WORK_ITEM_T
(   
  REASON
);

CREATE INDEX @SCHEMA@.WI_OWNER ON @SCHEMA@.WORK_ITEM_T
(   
  OWNER_ID, OBJECT_ID, REASON, OBJECT_TYPE
);

CREATE INDEX @SCHEMA@.WI_QIID ON @SCHEMA@.WORK_ITEM_T
(   
  QIID
);

CREATE INDEX @SCHEMA@.WI_QRY ON @SCHEMA@.WORK_ITEM_T
(   
  OBJECT_ID, REASON, EVERYBODY, OWNER_ID
);

CREATE INDEX @SCHEMA@.WI_QI_OID_RS_OWN ON @SCHEMA@.WORK_ITEM_T
(   
  QIID, OBJECT_ID, REASON, OWNER_ID
);

CREATE INDEX @SCHEMA@.WI_QI_OID_OWN ON @SCHEMA@.WORK_ITEM_T
(   
  QIID, OBJECT_ID, OWNER_ID
);

CREATE INDEX @SCHEMA@.WI_OT_OID_RS ON @SCHEMA@.WORK_ITEM_T
(   
  OBJECT_TYPE, OBJECT_ID, REASON
);

CREATE INDEX @SCHEMA@.WI_WI_QI ON @SCHEMA@.WORK_ITEM_T
(   
  WIID, QIID
);

CREATE INDEX @SCHEMA@.WI_PWIID_OID ON @SCHEMA@.WORK_ITEM_T
(   
  PARENT_WIID, OBJECT_ID
);

CREATE INDEX @SCHEMA@.WI_PWIID_QIID ON @SCHEMA@.WORK_ITEM_T
(   
  PARENT_WIID, QIID
);

CREATE INDEX @SCHEMA@.WI_PD1 ON @SCHEMA@.WORK_ITEM_T
(   
  OWNER_ID, AUTH_INFO, OBJECT_TYPE, REASON, OBJECT_ID
);

CREATE INDEX @SCHEMA@.WI_PD2 ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, OBJECT_TYPE, REASON, OBJECT_ID, QIID
);

CREATE TABLE @SCHEMA@.RETRIEVED_USER_T
(
  QIID                               CHAR(24)                      NOT NULL             ,
  OWNER_ID                           VARCHAR(128)                  NOT NULL             ,
  REASON                             INTEGER                       NOT NULL             ,
  ASSOCIATED_OID                     CHAR(24)                                           ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( QIID, OWNER_ID )
) IN @WORKITEM@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.RUT_OWN_QIID ON @SCHEMA@.RETRIEVED_USER_T
(   
  OWNER_ID, QIID
);

CREATE INDEX @SCHEMA@.RUT_ASSOC ON @SCHEMA@.RETRIEVED_USER_T
(   
  ASSOCIATED_OID
);

CREATE INDEX @SCHEMA@.RUT_QIID ON @SCHEMA@.RETRIEVED_USER_T
(   
  QIID
);

CREATE INDEX @SCHEMA@.RUT_OWN_QIDESC ON @SCHEMA@.RETRIEVED_USER_T
(   
  OWNER_ID, QIID DESC
);

CREATE TABLE @SCHEMA@.RETRIEVED_GROUP_T
(
  QIID                               CHAR(24)                      NOT NULL             ,
  GROUP_NAME                         VARCHAR(128)                  NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( QIID, GROUP_NAME )
) IN @WORKITEM@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.WIS_META_DATA_T
(
  WSID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  HASH_CODE                          INTEGER                       NOT NULL             ,
  OBJECT_TYPE                        INTEGER                       NOT NULL             ,
  LAST_CHECK                         DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  UNUSED                             SMALLINT                      NOT NULL             ,
  AUTH_INFO_RETRIEVED_USER           SMALLINT                      NOT NULL             ,
  AUTH_INFO_OWNER_ID                 SMALLINT                      NOT NULL             ,
  AUTH_INFO_EVERYBODY                SMALLINT                      NOT NULL             ,
  AUTH_INFO_GROUP                    SMALLINT                      NOT NULL             ,
  AUTH_INFO_RETRIEVED_GROUP          SMALLINT                      NOT NULL             ,
  AUTH_INFO_EMPTY                    SMALLINT                      NOT NULL             ,
  SHARING_PATTERN                    INTEGER                       NOT NULL             ,
  REASONS                            CHAR(44)                      NOT NULL             ,
  PARAMETER_A                        INTEGER                                            ,
  PARAMETER_B                        INTEGER                                            ,
  PARAMETER_C                        INTEGER                                            ,
  PARAMETER_D                        CHAR(24)                                           ,
  PARAMETER_E                        DATETIME YEAR TO FRACTION(3)                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @WORKITEM@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.WMD_HCUNU ON @SCHEMA@.WIS_META_DATA_T
(   
  HASH_CODE, UNUSED
);

CREATE TABLE @SCHEMA@.E_SWI_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  WIID                               CHAR(24)                      NOT NULL             ,
  WSID                               CHAR(24)                      NOT NULL             ,
  HASH_CODE                          INTEGER                       NOT NULL             ,
  WIS_HASH_CODE                      INTEGER                                            ,
  PARENT_WIID                        CHAR(24)                                           ,
  REASON                             INTEGER                       NOT NULL             ,
  INHERITED                          SMALLINT                                           ,
  QIID                               CHAR(24)                                           ,
  OBJECT_TYPE                        INTEGER                       NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  SHARING_PATTERN                    INTEGER                       NOT NULL             ,
  ACCESS_KEY                         INTEGER                       NOT NULL             ,
  TEMPLATE_ID                        CHAR(24)                                           ,
  PARAMETER_A                        INTEGER                                            ,
  PARAMETER_B                        INTEGER                                            ,
  PARAMETER_C                        INTEGER                                            ,
  PARAMETER_D                        CHAR(24)                                           ,
  PARAMETER_E                        DATETIME YEAR TO FRACTION(3)                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @WORKITEM@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.WE_WSID ON @SCHEMA@.E_SWI_T
(   
  WSID
);

CREATE INDEX @SCHEMA@.WE_HASHCODE ON @SCHEMA@.E_SWI_T
(   
  HASH_CODE
);

CREATE INDEX @SCHEMA@.WE_WIID ON @SCHEMA@.E_SWI_T
(   
  WIID
);

CREATE INDEX @SCHEMA@.WE_QIID ON @SCHEMA@.E_SWI_T
(   
  QIID
);

CREATE TABLE @SCHEMA@.SWI_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  WIID                               CHAR(24)                      NOT NULL             ,
  PARENT_WIID                        CHAR(24)                                           ,
  OWNER_ID                           VARCHAR(128)                                       ,
  GROUP_NAME                         VARCHAR(128)                                       ,
  EVERYBODY                          SMALLINT                      NOT NULL             ,
  QIID                               CHAR(24)                                           ,
  OBJECT_TYPE                        INTEGER                       NOT NULL             ,
  REASON                             INTEGER                       NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  AUTH_INFO                          INTEGER                       NOT NULL             ,
  SHARING_PATTERN                    INTEGER                       NOT NULL             ,
  ACCESS_KEY                         INTEGER                       NOT NULL             ,
  WSID                               CHAR(24)                      NOT NULL             ,
  HASH_CODE                          INTEGER                       NOT NULL             ,
  WIS_HASH_CODE                      INTEGER                                            ,
  INHERITED                          SMALLINT                                           ,
  TEMPLATE_ID                        CHAR(24)                                           ,
  PARAMETER_A                        INTEGER                                            ,
  PARAMETER_B                        INTEGER                                            ,
  PARAMETER_C                        INTEGER                                            ,
  PARAMETER_D                        CHAR(24)                                           ,
  PARAMETER_E                        DATETIME YEAR TO FRACTION(3)                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @WORKITEM@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.SWI_WSID ON @SCHEMA@.SWI_T
(   
  WSID
);

CREATE INDEX @SCHEMA@.SWI_HASHCODE ON @SCHEMA@.SWI_T
(   
  HASH_CODE
);

CREATE INDEX @SCHEMA@.SWI_OTRPD ON @SCHEMA@.SWI_T
(   
  OBJECT_TYPE, REASON, TEMPLATE_ID
);

CREATE INDEX @SCHEMA@.SWI_WIID ON @SCHEMA@.SWI_T
(   
  WIID
);

CREATE INDEX @SCHEMA@.SWI_QIID ON @SCHEMA@.SWI_T
(   
  QIID
);

CREATE INDEX @SCHEMA@.SWI_OWN ON @SCHEMA@.SWI_T
(   
  OWNER_ID, ACCESS_KEY, WSID, REASON
);

CREATE INDEX @SCHEMA@.SWI_GRP ON @SCHEMA@.SWI_T
(   
  GROUP_NAME, ACCESS_KEY, WSID, REASON
);

CREATE INDEX @SCHEMA@.SWI_ACCK1 ON @SCHEMA@.SWI_T
(   
  ACCESS_KEY, REASON, WSID, QIID
);

CREATE INDEX @SCHEMA@.SWI_ACCK2 ON @SCHEMA@.SWI_T
(   
  ACCESS_KEY, REASON, QIID, WSID
);

CREATE INDEX @SCHEMA@.SWI_ACCK3 ON @SCHEMA@.SWI_T
(   
  ACCESS_KEY, REASON, OWNER_ID, WSID
);

CREATE INDEX @SCHEMA@.SWI_ACCK4 ON @SCHEMA@.SWI_T
(   
  ACCESS_KEY, REASON, WSID
);

CREATE INDEX @SCHEMA@.SWI_ACCK5 ON @SCHEMA@.SWI_T
(   
  ACCESS_KEY, OWNER_ID, REASON, WSID
);

CREATE INDEX @SCHEMA@.SWI_ACCK6 ON @SCHEMA@.SWI_T
(   
  ACCESS_KEY, GROUP_NAME, REASON, WSID
);

CREATE TABLE @SCHEMA@.STAFF_QUERY_INSTANCE_T
(
  QIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  QTID                               CHAR(24)                      NOT NULL             ,
  EVERYBODY                          SMALLINT                      NOT NULL             ,
  NOBODY                             SMALLINT                      NOT NULL             ,
  IS_SHAREABLE                       SMALLINT                      NOT NULL             ,
  IS_TRANSFERRED                     SMALLINT                      NOT NULL             ,
  SR_HASH_CODE                       INTEGER                                            ,
  GROUP_NAME                         VARCHAR(128)                                       ,
  CONTEXT_VALUES                     TEXT                                               ,
  CONTEXT_VALUES_LONG                TEXT                                               ,
  HASH_CODE                          INTEGER                                            ,
  EXPIRES                            DATETIME YEAR TO FRACTION(3)                       ,
  ASSOCIATED_OBJECT_TYPE             INTEGER                       NOT NULL             ,
  ASSOCIATED_OID                     CHAR(24)                      NOT NULL             ,
  NORMALIZED                         SMALLINT                                           ,
  DENORMALIZED                       SMALLINT                                           ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @STAFFQRY@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.SQI_QTID ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
  QTID, HASH_CODE
);

CREATE INDEX @SCHEMA@.SQI_ASSOCID ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
  ASSOCIATED_OID, ASSOCIATED_OBJECT_TYPE
);

CREATE INDEX @SCHEMA@.SQI_QIIDGN ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
  QIID, GROUP_NAME
);

CREATE INDEX @SCHEMA@.SQI_QIIDTREX ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
  QIID, IS_TRANSFERRED, EXPIRES
);

CREATE TABLE @SCHEMA@.STAFF_LOCK_T
(
  QTID                               CHAR(24)                      NOT NULL             ,
  HASH_CODE                          INTEGER                       NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( QTID, HASH_CODE )
) IN @STAFFQRY@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.APPLICATION_COMPONENT_T
(
  ACOID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  NAME                               VARCHAR(64)                   NOT NULL             ,
  CALENDAR_NAME                      VARCHAR(254)                                       ,
  JNDI_NAME_CALENDAR                 VARCHAR(254)                                       ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR(254)                  NOT NULL             ,
  DURATION_UNTIL_DELETED             VARCHAR(254)                                       ,
  EVENT_HANDLER_NAME                 VARCHAR(64)                                        ,
  INSTANCE_CREATOR_QTID              CHAR(24)                                           ,
  SUPPORTS_AUTO_CLAIM                SMALLINT                      NOT NULL             ,
  SUPPORTS_FOLLOW_ON_TASK            SMALLINT                      NOT NULL             ,
  SUPPORTS_CLAIM_SUSPENDED           SMALLINT                      NOT NULL             ,
  SUPPORTS_DELEGATION                SMALLINT                      NOT NULL             ,
  SUPPORTS_SUB_TASK                  SMALLINT                      NOT NULL             ,
  BUSINESS_RELEVANCE                 SMALLINT                      NOT NULL             ,
  SUBSTITUTION_POLICY                INTEGER                       NOT NULL             
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE UNIQUE INDEX @SCHEMA@.ACO_NAME ON @SCHEMA@.APPLICATION_COMPONENT_T
(   
  NAME
);

CREATE TABLE @SCHEMA@.ESCALATION_TEMPLATE_T
(
  ESTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  FIRST_ESTID                        CHAR(24)                                           ,
  PREVIOUS_ESTID                     CHAR(24)                                           ,
  TKTID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  MNTID                              CHAR(24)                                           ,
  NAME                               VARCHAR(220)                                       ,
  ACTIVATION_STATE                   INTEGER                       NOT NULL             ,
  AT_LEAST_EXPECTED_STATE            INTEGER                       NOT NULL             ,
  DURATION_UNTIL_ESCALATION          VARCHAR(254)                                       ,
  DURATION_UNTIL_REPEATS             VARCHAR(254)                                       ,
  INCREASE_PRIORITY                  INTEGER                       NOT NULL             ,
  ACTION                             INTEGER                       NOT NULL             ,
  ESCALATION_RECEIVER_QTID           CHAR(24)                                           ,
  RECEIVER_EMAIL_QTID                CHAR(24)                                           
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.ET_TKTID ON @SCHEMA@.ESCALATION_TEMPLATE_T
(   
  TKTID
);

CREATE INDEX @SCHEMA@.ET_CCID ON @SCHEMA@.ESCALATION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.ESC_TEMPL_CPROP_T
(
  ESTID                              CHAR(24)                      NOT NULL             ,
  NAME                               VARCHAR(220)                  NOT NULL             ,
  TKTID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  STRING_VALUE                       VARCHAR(254)                                       ,
  DATA_TYPE                          VARCHAR(254)                                       ,
  DATA                               BYTE                                               ,
  PRIMARY KEY ( ESTID, NAME )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.ETCP_TKTID ON @SCHEMA@.ESC_TEMPL_CPROP_T
(   
  TKTID
);

CREATE INDEX @SCHEMA@.ETCP_CCID ON @SCHEMA@.ESC_TEMPL_CPROP_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.ESC_TEMPL_LDESC_T
(
  ESTID                              CHAR(24)                      NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  TKTID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  DISPLAY_NAME                       VARCHAR(64)                                        ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  DOCUMENTATION                      TEXT                                               ,
  PRIMARY KEY ( ESTID, LOCALE )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.ETLD_TKTID ON @SCHEMA@.ESC_TEMPL_LDESC_T
(   
  TKTID
);

CREATE INDEX @SCHEMA@.ETLD_CCID ON @SCHEMA@.ESC_TEMPL_LDESC_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.TTASK_MESSAGE_DEFINITION_T
(
  TMTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  TKTID                              CHAR(24)                                           ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  FAULT_NAME                         VARCHAR(254)                                       ,
  MESSAGE_TYPE_NS                    VARCHAR(220)                  NOT NULL             ,
  MESSAGE_TYPE_NAME                  VARCHAR(220)                  NOT NULL             ,
  MESSAGE_DEFINITION                 BYTE                                               
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.TTMD_TKTID ON @SCHEMA@.TTASK_MESSAGE_DEFINITION_T
(   
  TKTID
);

CREATE INDEX @SCHEMA@.TTMD_CCID ON @SCHEMA@.TTASK_MESSAGE_DEFINITION_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.TASK_TEMPLATE_T
(
  TKTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  NAME                               VARCHAR(220)                  NOT NULL             ,
  DEFINITION_NAME                    VARCHAR(220)                  NOT NULL             ,
  NAMESPACE                          VARCHAR(254)                  NOT NULL             ,
  TARGET_NAMESPACE                   VARCHAR(254)                  NOT NULL             ,
  VALID_FROM                         DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  APPLICATION_NAME                   VARCHAR(220)                                       ,
  APPLICATION_DEFAULTS_ID            CHAR(24)                                           ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                                           ,
  SVTID                              CHAR(24)                                           ,
  KIND                               INTEGER                       NOT NULL             ,
  STATE                              INTEGER                       NOT NULL             ,
  AUTO_DELETE_MODE                   INTEGER                       NOT NULL             ,
  IS_AD_HOC                          SMALLINT                      NOT NULL             ,
  IS_INLINE                          SMALLINT                      NOT NULL             ,
  IS_SHARED                          SMALLINT                      NOT NULL             ,
  SUPPORTS_CLAIM_SUSPENDED           SMALLINT                      NOT NULL             ,
  SUPPORTS_AUTO_CLAIM                SMALLINT                      NOT NULL             ,
  SUPPORTS_FOLLOW_ON_TASK            SMALLINT                      NOT NULL             ,
  SUPPORTS_DELEGATION                SMALLINT                      NOT NULL             ,
  SUPPORTS_SUB_TASK                  SMALLINT                      NOT NULL             ,
  CONTEXT_AUTHORIZATION              INTEGER                       NOT NULL             ,
  AUTONOMY                           INTEGER                       NOT NULL             ,
  ADMIN_QTID                         CHAR(24)                                           ,
  EDITOR_QTID                        CHAR(24)                                           ,
  INSTANCE_CREATOR_QTID              CHAR(24)                                           ,
  POTENTIAL_STARTER_QTID             CHAR(24)                                           ,
  POTENTIAL_OWNER_QTID               CHAR(24)                                           ,
  READER_QTID                        CHAR(24)                                           ,
  DEFAULT_LOCALE                     VARCHAR(32)                                        ,
  CALENDAR_NAME                      VARCHAR(254)                                       ,
  DURATION_UNTIL_DELETED             VARCHAR(254)                                       ,
  DURATION_UNTIL_DUE                 VARCHAR(254)                                       ,
  DURATION_UNTIL_EXPIRES             VARCHAR(254)                                       ,
  JNDI_NAME_CALENDAR                 VARCHAR(254)                                       ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR(254)                  NOT NULL             ,
  TYPE                               VARCHAR(254)                                       ,
  EVENT_HANDLER_NAME                 VARCHAR(64)                                        ,
  PRIORITY                           INTEGER                                            ,
  PRIORITY_DEFINITION                VARCHAR(254)                                       ,
  BUSINESS_RELEVANCE                 SMALLINT                      NOT NULL             ,
  SUBSTITUTION_POLICY                INTEGER                       NOT NULL             ,
  CONTACTS_QTIDS                     BYTE                                               ,
  UI_SETTINGS                        BYTE                                               ,
  ASSIGNMENT_TYPE                    INTEGER                       NOT NULL             ,
  INHERITED_AUTH                     INTEGER                       NOT NULL             ,
  PARALLEL_INHERITED_AUTH            INTEGER                       NOT NULL             ,
  NATIVE_LOOKUP_NAME                 VARCHAR(254)                                       ,
  WORK_BASKET                        VARCHAR(254)                                       ,
  EAR_VERSION                        INTEGER                       NOT NULL             ,
  SCHEMA_VERSION                     INTEGER                       NOT NULL             
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.TT_NAME_VF ON @SCHEMA@.TASK_TEMPLATE_T
(   
  NAME, VALID_FROM
);

CREATE INDEX @SCHEMA@.TT_CCID_STATE ON @SCHEMA@.TASK_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID, STATE
);

CREATE INDEX @SCHEMA@.TT_KND_INLN_VAL ON @SCHEMA@.TASK_TEMPLATE_T
(   
  KIND, IS_INLINE, VALID_FROM
);

CREATE INDEX @SCHEMA@.TT_NATLOOK ON @SCHEMA@.TASK_TEMPLATE_T
(   
  NATIVE_LOOKUP_NAME
);

CREATE TABLE @SCHEMA@.TASK_TEMPL_CPROP_T
(
  TKTID                              CHAR(24)                      NOT NULL             ,
  NAME                               VARCHAR(220)                  NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  DATA_TYPE                          VARCHAR(254)                                       ,
  STRING_VALUE                       VARCHAR(254)                                       ,
  DATA                               BYTE                                               ,
  PRIMARY KEY ( TKTID, NAME )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.TTCP_TKTID ON @SCHEMA@.TASK_TEMPL_CPROP_T
(   
  TKTID
);

CREATE INDEX @SCHEMA@.TTCP_CCID ON @SCHEMA@.TASK_TEMPL_CPROP_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.TASK_TEMPL_LDESC_T
(
  TKTID                              CHAR(24)                      NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  DISPLAY_NAME                       VARCHAR(64)                                        ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  DOCUMENTATION                      TEXT                                               ,
  PRIMARY KEY ( TKTID, LOCALE )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.TTLD_TKTID ON @SCHEMA@.TASK_TEMPL_LDESC_T
(   
  TKTID
);

CREATE INDEX @SCHEMA@.TTLD_CCID ON @SCHEMA@.TASK_TEMPL_LDESC_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE INDEX @SCHEMA@.TTLD_TT_LOC ON @SCHEMA@.TASK_TEMPL_LDESC_T
(   
  TKTID, LOCALE DESC
);

CREATE TABLE @SCHEMA@.TSERVICE_DESCRIPTION_T
(
  SVTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  TKTID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  IS_ONE_WAY                         SMALLINT                      NOT NULL             ,
  SERVICE_REF_NAME                   VARCHAR(254)                                       ,
  OPERATION                          VARCHAR(254)                  NOT NULL             ,
  PORT                               VARCHAR(254)                                       ,
  PORT_TYPE_NS                       VARCHAR(254)                  NOT NULL             ,
  PORT_TYPE_NAME                     VARCHAR(254)                  NOT NULL             ,
  S_BEAN_JNDI_NAME                   VARCHAR(254)                                       ,
  SERVICE                            VARCHAR(254)                                       
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.TSD_TKTID ON @SCHEMA@.TSERVICE_DESCRIPTION_T
(   
  TKTID
);

CREATE INDEX @SCHEMA@.TSD_CCID ON @SCHEMA@.TSERVICE_DESCRIPTION_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.TASK_CELL_MAP_T
(
  TKTID                              CHAR(24)                      NOT NULL             ,
  CELL                               VARCHAR(220)                  NOT NULL             ,
  PRIMARY KEY ( TKTID, CELL )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.TMAIL_T
(
  MNTID                              CHAR(24)                      NOT NULL             ,
  FROM_STATE                         INTEGER                       NOT NULL             ,
  TO_STATE                           INTEGER                       NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  HASH_CODE                          INTEGER                       NOT NULL             ,
  SUBJECT                            VARCHAR(254)                  NOT NULL             ,
  BODY_TEXT                          TEXT                                               ,
  PRIMARY KEY ( MNTID, FROM_STATE, TO_STATE, LOCALE )
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.EMT_HC ON @SCHEMA@.TMAIL_T
(   
  HASH_CODE
);

CREATE TABLE @SCHEMA@.COMPLETION_TEMPLATE_T
(
  CMTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  ORDER_NUMBER                       INTEGER                       NOT NULL             ,
  TKTID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  COMPL_CONDITION                    BYTE                                               ,
  CRITERION_FOR                      VARCHAR(254)                                       ,
  COMPLETION_NAME                    VARCHAR(220)                                       ,
  IS_DEFAULT_COMPLETION              SMALLINT                      NOT NULL             ,
  PREFIX_MAP                         BYTE                                               ,
  USE_DEFAULT_RESULT_CONSTRUCT       SMALLINT                      NOT NULL             
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.CMPT_TKTID_ORDER ON @SCHEMA@.COMPLETION_TEMPLATE_T
(   
  TKTID, ORDER_NUMBER
);

CREATE INDEX @SCHEMA@.CMPT_CCID ON @SCHEMA@.COMPLETION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(
  RATID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  ORDER_NUMBER                       INTEGER                       NOT NULL             ,
  CMTID                              CHAR(24)                      NOT NULL             ,
  TKTID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  AGGR_PART                          VARCHAR(254)                                       ,
  AGGR_LOCATION                      BYTE                                               ,
  AGGR_FUNCTION                      VARCHAR(254)                  NOT NULL             ,
  AGGR_CONDITION                     BYTE                                               ,
  PREFIX_MAP                         BYTE                                               
) IN @TEMPLATE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.RAGT_CMTID_ORD_TT ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(   
  CMTID, ORDER_NUMBER, TKTID
);

CREATE INDEX @SCHEMA@.RAGT_CCID ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.ESCALATION_INSTANCE_T
(
  ESIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  ESTID                              CHAR(24)                                           ,
  FIRST_ESIID                        CHAR(24)                                           ,
  PREVIOUS_ESIID                     CHAR(24)                                           ,
  TKIID                              CHAR(24)                      NOT NULL             ,
  MNTID                              CHAR(24)                                           ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  NAME                               VARCHAR(220)                                       ,
  STATE                              INTEGER                       NOT NULL             ,
  ACTIVATION_STATE                   INTEGER                       NOT NULL             ,
  AT_LEAST_EXPECTED_STATE            INTEGER                       NOT NULL             ,
  ACTIVATION_TIME                    DATETIME YEAR TO FRACTION(3)                       ,
  ESCALATION_TIME                    DATETIME YEAR TO FRACTION(3)                       ,
  DURATION_UNTIL_ESCALATION          VARCHAR(254)                                       ,
  DURATION_UNTIL_REPEATS             VARCHAR(254)                                       ,
  INCREASE_PRIORITY                  INTEGER                       NOT NULL             ,
  ACTION                             INTEGER                       NOT NULL             ,
  ESCALATION_RECEIVER_QTID           CHAR(24)                                           ,
  RECEIVER_EMAIL_QTID                CHAR(24)                                           ,
  SCHEDULER_ID                       VARCHAR(254)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.ESI_FIRST ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  FIRST_ESIID
);

CREATE INDEX @SCHEMA@.ESI_TKIID_ASTATE ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  TKIID, ACTIVATION_STATE, STATE
);

CREATE INDEX @SCHEMA@.ESI_TKIID_STATE ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  TKIID, STATE
);

CREATE INDEX @SCHEMA@.ESI_PREV ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  PREVIOUS_ESIID
);

CREATE INDEX @SCHEMA@.ESI_ESTID ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  ESTID
);

CREATE INDEX @SCHEMA@.ESI_CCID ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE INDEX @SCHEMA@.ESI_EST_ESI ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  ESTID, ESIID
);

CREATE INDEX @SCHEMA@.ESI_WSID1 ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  WSID_1
);

CREATE INDEX @SCHEMA@.ESI_WSID2 ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  WSID_2
);

CREATE TABLE @SCHEMA@.ESC_INST_CPROP_T
(
  ESIID                              CHAR(24)                      NOT NULL             ,
  NAME                               VARCHAR(220)                  NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  STRING_VALUE                       VARCHAR(254)                                       ,
  DATA_TYPE                          VARCHAR(254)                                       ,
  DATA                               BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( ESIID, NAME )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.EICP_CCID ON @SCHEMA@.ESC_INST_CPROP_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.ESC_INST_LDESC_T
(
  ESIID                              CHAR(24)                      NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  DISPLAY_NAME                       VARCHAR(64)                                        ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( ESIID, LOCALE )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.EILD_CCID ON @SCHEMA@.ESC_INST_LDESC_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.EIDOCUMENTATION_T
(
  ESIID                              CHAR(24)                      NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  TKIID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  DOCUMENTATION                      TEXT                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( ESIID, LOCALE )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.EIDOC_CCID ON @SCHEMA@.EIDOCUMENTATION_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.ISERVICE_DESCRIPTION_T
(
  SVTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  TKIID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  IS_ONE_WAY                         SMALLINT                      NOT NULL             ,
  SERVICE_REF_NAME                   VARCHAR(254)                                       ,
  OPERATION                          VARCHAR(254)                  NOT NULL             ,
  PORT                               VARCHAR(254)                                       ,
  PORT_TYPE_NS                       VARCHAR(254)                  NOT NULL             ,
  PORT_TYPE_NAME                     VARCHAR(254)                  NOT NULL             ,
  S_BEAN_JNDI_NAME                   VARCHAR(254)                                       ,
  SERVICE                            VARCHAR(254)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.ISD_TKIID ON @SCHEMA@.ISERVICE_DESCRIPTION_T
(   
  TKIID
);

CREATE INDEX @SCHEMA@.ISD_CCID ON @SCHEMA@.ISERVICE_DESCRIPTION_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.TASK_INSTANCE_T
(
  TKIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  NAME                               VARCHAR(220)                  NOT NULL             ,
  NAMESPACE                          VARCHAR(254)                  NOT NULL             ,
  TKTID                              CHAR(24)                                           ,
  TOP_TKIID                          CHAR(24)                      NOT NULL             ,
  FOLLOW_ON_TKIID                    CHAR(24)                                           ,
  APPLICATION_NAME                   VARCHAR(220)                                       ,
  APPLICATION_DEFAULTS_ID            CHAR(24)                                           ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                                           ,
  PARENT_CONTEXT_ID                  CHAR(24)                                           ,
  STATE                              INTEGER                       NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  AUTO_DELETE_MODE                   INTEGER                       NOT NULL             ,
  HIERARCHY_POSITION                 INTEGER                       NOT NULL             ,
  TYPE                               VARCHAR(254)                                       ,
  SVTID                              CHAR(24)                                           ,
  SUPPORTS_CLAIM_SUSPENDED           SMALLINT                      NOT NULL             ,
  SUPPORTS_AUTO_CLAIM                SMALLINT                      NOT NULL             ,
  SUPPORTS_FOLLOW_ON_TASK            SMALLINT                      NOT NULL             ,
  IS_AD_HOC                          SMALLINT                      NOT NULL             ,
  IS_ESCALATED                       SMALLINT                      NOT NULL             ,
  IS_INLINE                          SMALLINT                      NOT NULL             ,
  IS_SUSPENDED                       SMALLINT                      NOT NULL             ,
  IS_WAITING_FOR_SUBTASK             SMALLINT                      NOT NULL             ,
  SUPPORTS_DELEGATION                SMALLINT                      NOT NULL             ,
  SUPPORTS_SUB_TASK                  SMALLINT                      NOT NULL             ,
  IS_CHILD                           SMALLINT                      NOT NULL             ,
  HAS_ESCALATIONS                    SMALLINT                                           ,
  START_TIME                         DATETIME YEAR TO FRACTION(3)                       ,
  ACTIVATION_TIME                    DATETIME YEAR TO FRACTION(3)                       ,
  LAST_MODIFICATION_TIME             DATETIME YEAR TO FRACTION(3)                       ,
  LAST_STATE_CHANGE_TIME             DATETIME YEAR TO FRACTION(3)                       ,
  COMPLETION_TIME                    DATETIME YEAR TO FRACTION(3)                       ,
  DUE_TIME                           DATETIME YEAR TO FRACTION(3)                       ,
  EXPIRATION_TIME                    DATETIME YEAR TO FRACTION(3)                       ,
  FIRST_ACTIVATION_TIME              DATETIME YEAR TO FRACTION(3)                       ,
  DEFAULT_LOCALE                     VARCHAR(32)                                        ,
  DURATION_UNTIL_DELETED             VARCHAR(254)                                       ,
  DURATION_UNTIL_DUE                 VARCHAR(254)                                       ,
  DURATION_UNTIL_EXPIRES             VARCHAR(254)                                       ,
  CALENDAR_NAME                      VARCHAR(254)                                       ,
  JNDI_NAME_CALENDAR                 VARCHAR(254)                                       ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR(254)                                       ,
  CONTEXT_AUTHORIZATION              INTEGER                       NOT NULL             ,
  ORIGINATOR                         VARCHAR(128)                                       ,
  STARTER                            VARCHAR(128)                                       ,
  OWNER                              VARCHAR(128)                                       ,
  ADMIN_QTID                         CHAR(24)                                           ,
  EDITOR_QTID                        CHAR(24)                                           ,
  POTENTIAL_OWNER_QTID               CHAR(24)                                           ,
  POTENTIAL_STARTER_QTID             CHAR(24)                                           ,
  READER_QTID                        CHAR(24)                                           ,
  PRIORITY                           INTEGER                                            ,
  SCHEDULER_ID                       VARCHAR(254)                                       ,
  SERVICE_TICKET                     VARCHAR(254)                                       ,
  EVENT_HANDLER_NAME                 VARCHAR(64)                                        ,
  BUSINESS_RELEVANCE                 SMALLINT                      NOT NULL             ,
  RESUMES                            DATETIME YEAR TO FRACTION(3)                       ,
  SUBSTITUTION_POLICY                INTEGER                       NOT NULL             ,
  DELETION_TIME                      DATETIME YEAR TO FRACTION(3)                       ,
  ASSIGNMENT_TYPE                    INTEGER                       NOT NULL             ,
  INHERITED_AUTH                     INTEGER                       NOT NULL             ,
  PARALLEL_INHERITED_AUTH            INTEGER                       NOT NULL             ,
  INVOKED_INSTANCE_ID                CHAR(24)                                           ,
  INVOKED_INSTANCE_TYPE              INTEGER                       NOT NULL             ,
  WORK_BASKET                        VARCHAR(254)                                       ,
  IS_READ                            SMALLINT                      NOT NULL             ,
  IS_TRANSFERRED_TO_WORK_BASKET      SMALLINT                      NOT NULL             ,
  CREATED_WITH_VERSION               INTEGER                       NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.TI_PARENT ON @SCHEMA@.TASK_INSTANCE_T
(   
  PARENT_CONTEXT_ID
);

CREATE INDEX @SCHEMA@.TI_ACOID ON @SCHEMA@.TASK_INSTANCE_T
(   
  APPLICATION_DEFAULTS_ID
);

CREATE INDEX @SCHEMA@.TI_NAME ON @SCHEMA@.TASK_INSTANCE_T
(   
  NAME
);

CREATE INDEX @SCHEMA@.TI_STATE ON @SCHEMA@.TASK_INSTANCE_T
(   
  STATE
);

CREATE INDEX @SCHEMA@.TI_SERVICET ON @SCHEMA@.TASK_INSTANCE_T
(   
  SERVICE_TICKET
);

CREATE INDEX @SCHEMA@.TI_CCID ON @SCHEMA@.TASK_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE INDEX @SCHEMA@.TI_TK_TOPTK ON @SCHEMA@.TASK_INSTANCE_T
(   
  TKTID, TKIID, TOP_TKIID
);

CREATE INDEX @SCHEMA@.TI_TOPTKIID ON @SCHEMA@.TASK_INSTANCE_T
(   
  TOP_TKIID
);

CREATE INDEX @SCHEMA@.TI_TI_KND_ST ON @SCHEMA@.TASK_INSTANCE_T
(   
  TKIID, KIND, STATE
);

CREATE INDEX @SCHEMA@.TI_ST_KND_TI_NAME ON @SCHEMA@.TASK_INSTANCE_T
(   
  STATE, KIND, TKIID, NAME
);

CREATE INDEX @SCHEMA@.TI_TT_KND ON @SCHEMA@.TASK_INSTANCE_T
(   
  TKTID, KIND
);

CREATE INDEX @SCHEMA@.TI_WOBA ON @SCHEMA@.TASK_INSTANCE_T
(   
  WORK_BASKET
);

CREATE INDEX @SCHEMA@.TI_TYPE ON @SCHEMA@.TASK_INSTANCE_T
(   
  TYPE
);

CREATE INDEX @SCHEMA@.TI_WSID1 ON @SCHEMA@.TASK_INSTANCE_T
(   
  WSID_1, KIND
);

CREATE INDEX @SCHEMA@.TI_WSID2 ON @SCHEMA@.TASK_INSTANCE_T
(   
  WSID_2, KIND
);

CREATE INDEX @SCHEMA@.TI_WSID1S ON @SCHEMA@.TASK_INSTANCE_T
(   
  WSID_1, KIND, STATE
);

CREATE INDEX @SCHEMA@.TI_WSID2S ON @SCHEMA@.TASK_INSTANCE_T
(   
  WSID_2, KIND, STATE
);

CREATE INDEX @SCHEMA@.TI_Q1IF ON @SCHEMA@.TASK_INSTANCE_T
(   
  KIND, PRIORITY, OWNER
);

CREATE TABLE @SCHEMA@.TASK_CONTEXT_T
(
  TKIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  SERVICE_CONTEXT                    BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.TC_CCID ON @SCHEMA@.TASK_CONTEXT_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.CONTACT_QUERIES_T
(
  TKIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  CONTACTS_QTIDS                     BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.CQ_CCID ON @SCHEMA@.CONTACT_QUERIES_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.UISETTINGS_T
(
  TKIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  UI_SETTINGS                        BYTE                          NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.UIS_CCID ON @SCHEMA@.UISETTINGS_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.REPLY_HANDLER_T
(
  TKIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  REPLY_HANDLER                      BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.RH_CCID ON @SCHEMA@.REPLY_HANDLER_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.TASK_TIMER_T
(
  OID                                CHAR(24)                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  SCHEDULER_ID                       VARCHAR(254)                  NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( OID, KIND )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.TASK_INST_CPROP_T
(
  TKIID                              CHAR(24)                      NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  NAME                               VARCHAR(220)                  NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  DATA_TYPE                          VARCHAR(254)                                       ,
  STRING_VALUE                       VARCHAR(254)                                       ,
  DATA                               BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( TKIID, NAME )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.TICP_CCID ON @SCHEMA@.TASK_INST_CPROP_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.TASK_INST_LDESC_T
(
  TKIID                              CHAR(24)                      NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  DISPLAY_NAME                       VARCHAR(64)                                        ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( TKIID, LOCALE )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.TILD_CCID ON @SCHEMA@.TASK_INST_LDESC_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE INDEX @SCHEMA@.TILD_PD2 ON @SCHEMA@.TASK_INST_LDESC_T
(   
  LOCALE, TKIID, DISPLAY_NAME
);

CREATE TABLE @SCHEMA@.TIDOCUMENTATION_T
(
  TKIID                              CHAR(24)                      NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  DOCUMENTATION                      TEXT                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( TKIID, LOCALE )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.TIDOC_CCID ON @SCHEMA@.TIDOCUMENTATION_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
(
  TMTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  TKIID                              CHAR(24)                                           ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  FAULT_NAME                         VARCHAR(254)                                       ,
  KIND                               INTEGER                       NOT NULL             ,
  MESSAGE_TYPE_NS                    VARCHAR(220)                  NOT NULL             ,
  MESSAGE_TYPE_NAME                  VARCHAR(220)                  NOT NULL             ,
  MESSAGE_DEFINITION                 BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.ITMD_IDKITYPE ON @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
(   
  TKIID, MESSAGE_TYPE_NAME, KIND
);

CREATE INDEX @SCHEMA@.ITMD_TKIIDKIND ON @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
(   
  TKIID, KIND
);

CREATE INDEX @SCHEMA@.ITMD_CCID ON @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.TASK_MESSAGE_INSTANCE_T
(
  TMIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  TMTID                              CHAR(24)                                           ,
  TKIID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  FAULT_NAME                         VARCHAR(254)                                       ,
  KIND                               INTEGER                       NOT NULL             ,
  MESSAGE_TYPE_NS                    VARCHAR(220)                  NOT NULL             ,
  MESSAGE_TYPE_NAME                  VARCHAR(220)                  NOT NULL             ,
  DATA                               BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.TMI_TI_K ON @SCHEMA@.TASK_MESSAGE_INSTANCE_T
(   
  TKIID, KIND
);

CREATE INDEX @SCHEMA@.TMI_TMTID ON @SCHEMA@.TASK_MESSAGE_INSTANCE_T
(   
  TMTID
);

CREATE INDEX @SCHEMA@.TMI_CCID ON @SCHEMA@.TASK_MESSAGE_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.TASK_AUDIT_LOG_T
(
  ALID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  AUDIT_EVENT                        INTEGER                       NOT NULL             ,
  TKIID                              CHAR(24)                                           ,
  TKTID                              CHAR(24)                                           ,
  ESIID                              CHAR(24)                                           ,
  ESTID                              CHAR(24)                                           ,
  TOP_TKIID                          CHAR(24)                                           ,
  FOLLOW_ON_TKIID                    CHAR(24)                                           ,
  PARENT_TKIID                       CHAR(24)                                           ,
  PARENT_CONTEXT_ID                  CHAR(24)                                           ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                                           ,
  WI_REASON                          INTEGER                                            ,
  NAME                               VARCHAR(254)                                       ,
  NAMESPACE                          VARCHAR(254)                                       ,
  VALID_FROM_UTC                     DATETIME YEAR TO FRACTION(3)                       ,
  EVENT_TIME_UTC                     DATETIME YEAR TO FRACTION(3)                       ,
  PARENT_TASK_NAME                   VARCHAR(254)                                       ,
  PARENT_TASK_NAMESPACE              VARCHAR(254)                                       ,
  TASK_KIND                          INTEGER                                            ,
  TASK_STATE                         INTEGER                                            ,
  FAULT_TYPE_NAME                    VARCHAR(220)                                       ,
  FAULT_NAMESPACE                    VARCHAR(220)                                       ,
  FAULT_NAME                         VARCHAR(220)                                       ,
  NEW_USER                           VARCHAR(128)                                       ,
  OLD_USER                           VARCHAR(128)                                       ,
  PRINCIPAL                          VARCHAR(128)                                       ,
  USERS                              TEXT                                               ,
  DESCRIPTION                        TEXT                                               ,
  MESSAGE_DATA                       BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @AUDITLOG@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.IMAIL_T
(
  OBJECT_ID                          CHAR(24)                      NOT NULL             ,
  FROM_STATE                         INTEGER                       NOT NULL             ,
  TO_STATE                           INTEGER                       NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  SUBJECT                            VARCHAR(254)                  NOT NULL             ,
  URI                                VARCHAR(254)                                       ,
  BODY_TEXT                          TEXT                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( OBJECT_ID, FROM_STATE, TO_STATE, LOCALE )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.IMN_CTX ON @SCHEMA@.IMAIL_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.TASK_HISTORY_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  EVENT                              INTEGER                       NOT NULL             ,
  TKIID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  PARENT_TKIID                       CHAR(24)                                           ,
  ESIID                              CHAR(24)                                           ,
  REASON                             INTEGER                       NOT NULL             ,
  EVENT_TIME                         DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  NEXT_TIME                          DATETIME YEAR TO FRACTION(3)                       ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  PRINCIPAL                          VARCHAR(128)                  NOT NULL             ,
  WORK_ITEM_KIND                     INTEGER                       NOT NULL             ,
  FROM_ID                            VARCHAR(128)                                       ,
  TO_ID                              VARCHAR(128)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.TH_TKIID ON @SCHEMA@.TASK_HISTORY_T
(   
  TKIID
);

CREATE INDEX @SCHEMA@.TH_CTXID ON @SCHEMA@.TASK_HISTORY_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.COMPLETION_INSTANCE_T
(
  CMIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  ORDER_NUMBER                       INTEGER                       NOT NULL             ,
  TKIID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  COMPL_CONDITION                    BYTE                                               ,
  CRITERION_FOR                      VARCHAR(254)                                       ,
  CRITERION_FOR_TIME                 DATETIME YEAR TO FRACTION(3)                       ,
  COMPLETION_NAME                    VARCHAR(220)                                       ,
  IS_DEFAULT_COMPLETION              SMALLINT                      NOT NULL             ,
  PREFIX_MAP                         BYTE                                               ,
  USE_DEFAULT_RESULT_CONSTRUCT       SMALLINT                      NOT NULL             ,
  SCHEDULER_ID                       VARCHAR(254)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.CMPI_TKIID_ORDER ON @SCHEMA@.COMPLETION_INSTANCE_T
(   
  TKIID, ORDER_NUMBER
);

CREATE INDEX @SCHEMA@.CMPI_CCID ON @SCHEMA@.COMPLETION_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(
  RAIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  ORDER_NUMBER                       INTEGER                       NOT NULL             ,
  CMIID                              CHAR(24)                      NOT NULL             ,
  TKIID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  AGGR_PART                          VARCHAR(254)                                       ,
  AGGR_LOCATION                      BYTE                                               ,
  AGGR_FUNCTION                      VARCHAR(254)                  NOT NULL             ,
  AGGR_CONDITION                     BYTE                                               ,
  PREFIX_MAP                         BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.RAGI_CMIID_ORDER ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(   
  CMIID, ORDER_NUMBER
);

CREATE INDEX @SCHEMA@.RAGI_CCID ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.SAVED_TASK_MESSAGE_T
(
  STMID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  RELATED_OID                        CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  SCHEDULER_ID                       VARCHAR(254)                                       ,
  CREATION_TIME                      DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  EXPECTED_ARRIVAL_TIME              DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  MESSAGE                            BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.STM_ROID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  RELATED_OID
);

CREATE INDEX @SCHEMA@.STM_SID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  SCHEDULER_ID
);

CREATE INDEX @SCHEMA@.STM_CTXID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.WORK_BASKET_T
(
  WBID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  NAME                               VARCHAR(254)                  NOT NULL             ,
  TYPE                               INTEGER                       NOT NULL             ,
  OWNER                              VARCHAR(128)                                       ,
  SUBSTITUTION_POLICY                INTEGER                       NOT NULL             ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR(254)                  NOT NULL             ,
  DEFAULT_QUERY_TABLE                VARCHAR(32)                                        ,
  CUSTOM_TEXT1                       VARCHAR(254)                                       ,
  CUSTOM_TEXT2                       VARCHAR(254)                                       ,
  CUSTOM_TEXT3                       VARCHAR(254)                                       ,
  CUSTOM_TEXT4                       VARCHAR(254)                                       ,
  CUSTOM_TEXT5                       VARCHAR(254)                                       ,
  CUSTOM_TEXT6                       VARCHAR(254)                                       ,
  CUSTOM_TEXT7                       VARCHAR(254)                                       ,
  CUSTOM_TEXT8                       VARCHAR(254)                                       ,
  EXTENDED_DATA                      BYTE                                               ,
  CREATION_TIME                      DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  LAST_MODIFICATION_TIME             DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  CREATED_WITH_VERSION               INTEGER                       NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.WBK_NAME ON @SCHEMA@.WORK_BASKET_T
(   
  NAME
);

CREATE INDEX @SCHEMA@.WBK_TYPE ON @SCHEMA@.WORK_BASKET_T
(   
  TYPE
);

CREATE INDEX @SCHEMA@.WBK_WSID1 ON @SCHEMA@.WORK_BASKET_T
(   
  WSID_1
);

CREATE INDEX @SCHEMA@.WBK_WSID2 ON @SCHEMA@.WORK_BASKET_T
(   
  WSID_2
);

CREATE TABLE @SCHEMA@.WORK_BASKET_LDESC_T
(
  WBID                               CHAR(24)                      NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  DISPLAY_NAME                       VARCHAR(64)                                        ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( WBID, LOCALE )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE TABLE @SCHEMA@.WORK_BASKET_DIST_TARGET_T
(
  SOURCE_WBID                        CHAR(24)                      NOT NULL             ,
  TARGET_WBID                        CHAR(24)                      NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( SOURCE_WBID, TARGET_WBID )
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.WBDT_TWB ON @SCHEMA@.WORK_BASKET_DIST_TARGET_T
(   
  TARGET_WBID
);

CREATE TABLE @SCHEMA@.BUSINESS_CATEGORY_T
(
  BCID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PARENT_BCID                        CHAR(24)                                           ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  NAME                               VARCHAR(254)                  NOT NULL             ,
  PRIORITY                           INTEGER                                            ,
  SUBSTITUTION_POLICY                INTEGER                       NOT NULL             ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR(254)                  NOT NULL             ,
  DEFAULT_QUERY_TABLE                VARCHAR(32)                                        ,
  CUSTOM_TEXT1                       VARCHAR(254)                                       ,
  CUSTOM_TEXT2                       VARCHAR(254)                                       ,
  CUSTOM_TEXT3                       VARCHAR(254)                                       ,
  CUSTOM_TEXT4                       VARCHAR(254)                                       ,
  CUSTOM_TEXT5                       VARCHAR(254)                                       ,
  CUSTOM_TEXT6                       VARCHAR(254)                                       ,
  CUSTOM_TEXT7                       VARCHAR(254)                                       ,
  CUSTOM_TEXT8                       VARCHAR(254)                                       ,
  EXTENDED_DATA                      BYTE                                               ,
  CREATION_TIME                      DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  LAST_MODIFICATION_TIME             DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  CREATED_WITH_VERSION               INTEGER                       NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) IN @INSTANCE@
  LOCK MODE ROW;

CREATE INDEX @SCHEMA@.BCG_PARENTBCID ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  PARENT_BCID
);

CREATE INDEX @SCHEMA@.BCG_NAME ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  NAME
);

CREATE INDEX @SCHEMA@.BCG_WSID1 ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  WSID_1
);

CREATE INDEX @SCHEMA@.BCG_WSID2 ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  WSID_2
);

CREATE TABLE @SCHEMA@.BUSINESS_CATEGORY_LDESC_T
(
  BCID                               CHAR(24)                      NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  DISPLAY_NAME                       VARCHAR(64)                                        ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( BCID, LOCALE )
) IN @INSTANCE@
  LOCK MODE ROW;
-- set schema version to: 700
INSERT INTO @SCHEMA@.SCHEMA_VERSION (SCHEMA_VERSION, DATA_MIGRATION) VALUES( 700, 0 );


-- View: ProcessTemplate
CREATE VIEW @SCHEMA@.PROCESS_TEMPLATE(PTID, NAME, DISPLAY_NAME, VALID_FROM, TARGET_NAMESPACE, APPLICATION_NAME, VERSION, CREATED, STATE, EXECUTION_MODE, DESCRIPTION, CAN_RUN_SYNC, CAN_RUN_INTERRUP, COMP_SPHERE, CONTINUE_ON_ERROR ) AS
 SELECT @SCHEMA@.PROCESS_TEMPLATE_B_T.PTID, @SCHEMA@.PROCESS_TEMPLATE_B_T.NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.DISPLAY_NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.VALID_FROM, @SCHEMA@.PROCESS_TEMPLATE_B_T.TARGET_NAMESPACE, @SCHEMA@.PROCESS_TEMPLATE_B_T.APPLICATION_NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.VERSION, @SCHEMA@.PROCESS_TEMPLATE_B_T.CREATED, @SCHEMA@.PROCESS_TEMPLATE_B_T.STATE, @SCHEMA@.PROCESS_TEMPLATE_B_T.EXECUTION_MODE, @SCHEMA@.PROCESS_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_TEMPLATE_B_T.CAN_CALL, @SCHEMA@.PROCESS_TEMPLATE_B_T.CAN_INITIATE, @SCHEMA@.PROCESS_TEMPLATE_B_T.COMPENSATION_SPHERE, @SCHEMA@.PROCESS_TEMPLATE_B_T.CONTINUE_ON_ERROR
 FROM @SCHEMA@.PROCESS_TEMPLATE_B_T;

-- View: ProcessTemplAttr
CREATE VIEW @SCHEMA@.PROCESS_TEMPL_ATTR(PTID, NAME, VALUE ) AS
 SELECT @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.PTID, @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.ATTR_KEY, @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.VALUE
 FROM @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T;

-- View: ProcessInstance
CREATE VIEW @SCHEMA@.PROCESS_INSTANCE(PTID, PIID, NAME, STATE, CREATED, STARTED, COMPLETED, PARENT_NAME, TOP_LEVEL_NAME, PARENT_PIID, TOP_LEVEL_PIID, STARTER, DESCRIPTION, TEMPLATE_NAME, TEMPLATE_DESCR, RESUMES, CONTINUE_ON_ERROR, IS_MIGRATED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.PROCESS_INSTANCE_B_T.PTID, @SCHEMA@.PROCESS_INSTANCE_B_T.PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.STATE, @SCHEMA@.PROCESS_INSTANCE_B_T.CREATED, @SCHEMA@.PROCESS_INSTANCE_B_T.STARTED, @SCHEMA@.PROCESS_INSTANCE_B_T.COMPLETED, @SCHEMA@.PROCESS_INSTANCE_B_T.PARENT_NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.TOP_LEVEL_NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.PARENT_PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.TOP_LEVEL_PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.STARTER, @SCHEMA@.PROCESS_INSTANCE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_TEMPLATE_B_T.NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_INSTANCE_B_T.RESUMES, @SCHEMA@.PROCESS_TEMPLATE_B_T.CONTINUE_ON_ERROR, @SCHEMA@.PROCESS_INSTANCE_B_T.IS_MIGRATED, @SCHEMA@.PROCESS_INSTANCE_B_T.WSID_1, @SCHEMA@.PROCESS_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.PROCESS_INSTANCE_B_T, @SCHEMA@.PROCESS_TEMPLATE_B_T
 WHERE @SCHEMA@.PROCESS_INSTANCE_B_T.PTID = @SCHEMA@.PROCESS_TEMPLATE_B_T.PTID;

-- View: ProcessAttribute
CREATE VIEW @SCHEMA@.PROCESS_ATTRIBUTE(PIID, NAME, VALUE, DATA_TYPE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.PIID, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.ATTR_KEY, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.VALUE, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.DATA_TYPE, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.WSID_1, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.WSID_2
 FROM @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T;

-- View: Activity
CREATE VIEW @SCHEMA@.ACTIVITY(PIID, AIID, PTID, ATID, SIID, STID, EHIID, ENCLOSING_FEIID, KIND, COMPLETED, ACTIVATED, FIRST_ACTIVATED, STARTED, STATE, SUB_STATE, STOP_REASON, OWNER, DESCRIPTION, EXPIRES, TEMPLATE_NAME, TEMPLATE_DESCR, BUSINESS_RELEVANCE, SKIP_REQUESTED, CONTINUE_ON_ERROR, INVOKED_INST_ID, INVOKED_INST_TYPE, PREVIOUS_EXPIRATION_TIME, HAS_WORK_ITEM, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ACTIVITY_INSTANCE_B_T.PIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.AIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.PTID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ATID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SIID, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.PARENT_STID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.EHIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ENCLOSING_FEIID, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.KIND, @SCHEMA@.ACTIVITY_INSTANCE_B_T.FINISHED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ACTIVATED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.FIRST_ACTIVATED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STARTED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SUB_STATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STOP_REASON, @SCHEMA@.ACTIVITY_INSTANCE_B_T.OWNER, @SCHEMA@.ACTIVITY_INSTANCE_B_T.DESCRIPTION, @SCHEMA@.ACTIVITY_INSTANCE_B_T.EXPIRES, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.NAME, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.BUSINESS_RELEVANCE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SKIP_REQUESTED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.CONTINUE_ON_ERROR, @SCHEMA@.ACTIVITY_INSTANCE_B_T.INVOKED_INSTANCE_ID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.INVOKED_INSTANCE_TYPE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.PREVIOUS_EXPIRATION_DATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.HAS_WORK_ITEM, @SCHEMA@.ACTIVITY_INSTANCE_B_T.WSID_1, @SCHEMA@.ACTIVITY_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.ACTIVITY_INSTANCE_B_T, @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 WHERE @SCHEMA@.ACTIVITY_INSTANCE_B_T.ATID = @SCHEMA@.ACTIVITY_TEMPLATE_B_T.ATID;

-- View: ActivityAttribute
CREATE VIEW @SCHEMA@.ACTIVITY_ATTRIBUTE(AIID, NAME, VALUE, DATA_TYPE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.AIID, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.ATTR_KEY, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.ATTR_VALUE, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.DATA_TYPE, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.WSID_1, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.WSID_2
 FROM @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T;

-- View: Event
CREATE VIEW @SCHEMA@.EVENT(EIID, AIID, PIID, EHTID, SIID, NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.EVENT_INSTANCE_B_T.EIID, @SCHEMA@.EVENT_INSTANCE_B_T.AIID, @SCHEMA@.EVENT_INSTANCE_B_T.PIID, @SCHEMA@.EVENT_INSTANCE_B_T.EHTID, @SCHEMA@.EVENT_INSTANCE_B_T.SIID, @SCHEMA@.SERVICE_TEMPLATE_B_T.NAME, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_1, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.EVENT_INSTANCE_B_T, @SCHEMA@.SERVICE_TEMPLATE_B_T
 WHERE @SCHEMA@.EVENT_INSTANCE_B_T.STATE = 2 AND @SCHEMA@.EVENT_INSTANCE_B_T.VTID = @SCHEMA@.SERVICE_TEMPLATE_B_T.VTID;

-- View: WorkItem
CREATE VIEW @SCHEMA@.WORK_ITEM(WIID, OWNER_ID, GROUP_NAME, EVERYBODY, OBJECT_TYPE, OBJECT_ID, ASSOC_OBJECT_TYPE, ASSOC_OID, REASON, CREATION_TIME, QIID, KIND ) AS
 SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO = 1
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO = 2
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO = 3
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.RETRIEVED_USER_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T, @SCHEMA@.RETRIEVED_USER_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO = 0 AND @SCHEMA@.WORK_ITEM_T.QIID = @SCHEMA@.RETRIEVED_USER_T.QIID;

-- View: SharedWorkItem
CREATE VIEW @SCHEMA@.SHARED_WORK_ITEM(WSID, OWNER_ID, GROUP_NAME, EVERYBODY, REASON ) AS
 SELECT @SCHEMA@.SWI_T.WSID, @SCHEMA@.SWI_T.OWNER_ID, @SCHEMA@.SWI_T.GROUP_NAME, @SCHEMA@.SWI_T.EVERYBODY, @SCHEMA@.SWI_T.REASON
 FROM @SCHEMA@.SWI_T
 WHERE @SCHEMA@.SWI_T.AUTH_INFO IN ( 1,2,3 )
 UNION ALL SELECT @SCHEMA@.SWI_T.WSID, @SCHEMA@.RETRIEVED_USER_T.OWNER_ID, @SCHEMA@.SWI_T.GROUP_NAME, @SCHEMA@.SWI_T.EVERYBODY, @SCHEMA@.SWI_T.REASON
 FROM @SCHEMA@.SWI_T, @SCHEMA@.RETRIEVED_USER_T
 WHERE @SCHEMA@.SWI_T.QIID = @SCHEMA@.RETRIEVED_USER_T.QIID AND @SCHEMA@.SWI_T.AUTH_INFO = 0;

-- View: ActivityService
CREATE VIEW @SCHEMA@.ACTIVITY_SERVICE(EIID, AIID, PIID, VTID, PORT_TYPE, NAME_SPACE_URI, OPERATION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.EVENT_INSTANCE_B_T.EIID, @SCHEMA@.EVENT_INSTANCE_B_T.AIID, @SCHEMA@.EVENT_INSTANCE_B_T.PIID, @SCHEMA@.EVENT_INSTANCE_B_T.VTID, @SCHEMA@.SERVICE_TEMPLATE_B_T.PORT_TYPE_NAME,@SCHEMA@.URI_TEMPLATE_B_T.URI, @SCHEMA@.SERVICE_TEMPLATE_B_T.OPERATION_NAME, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_1, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.EVENT_INSTANCE_B_T, @SCHEMA@.SERVICE_TEMPLATE_B_T, @SCHEMA@.URI_TEMPLATE_B_T
 WHERE @SCHEMA@.EVENT_INSTANCE_B_T.STATE = 2 AND @SCHEMA@.EVENT_INSTANCE_B_T.VTID = @SCHEMA@.SERVICE_TEMPLATE_B_T.VTID AND @SCHEMA@.SERVICE_TEMPLATE_B_T.PORT_TYPE_UTID = @SCHEMA@.URI_TEMPLATE_B_T.UTID;

-- View: QueryProperty
CREATE VIEW @SCHEMA@.QUERY_PROPERTY(PIID, VARIABLE_NAME, NAME, NAMESPACE, GENERIC_VALUE, STRING_VALUE, NUMBER_VALUE, DECIMAL_VALUE, TIMESTAMP_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PIID, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.VARIABLE_NAME, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PROPERTY_NAME, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PROPERTY_NAMESPACE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.GENERIC_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.STRING_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.NUMBER_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.DECIMAL_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.TIMESTAMP_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.WSID_1, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.WSID_2
 FROM @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T;

-- View: QueryPropTempl
CREATE VIEW @SCHEMA@.QUERY_PROP_TEMPL(PTID, NAME, PROPERTY_NAME, URI, QUERY_TYPE, JAVA_TYPE ) AS
 SELECT @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.PTID, @SCHEMA@.VARIABLE_TEMPLATE_B_T.NAME, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PROPERTY_NAME, @SCHEMA@.URI_TEMPLATE_B_T.URI, @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.QUERY_TYPE, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.JAVA_TYPE
 FROM @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T, @SCHEMA@.VARIABLE_TEMPLATE_B_T, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T, @SCHEMA@.URI_TEMPLATE_B_T
 WHERE @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.CTID = @SCHEMA@.VARIABLE_TEMPLATE_B_T.CTID AND @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.PAID = @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PAID AND @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PROPERTY_UTID = @SCHEMA@.URI_TEMPLATE_B_T.UTID;

-- View: MigrationFront
CREATE VIEW @SCHEMA@.MIGRATION_FRONT(PIID, AIID, SOURCE_PTID, TARGET_PTID, STATE, SUB_STATE, STOP_REASON, SOURCE_ATID, TARGET_ATID, MIGRATION_TIME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.MIGRATION_FRONT_T.PIID, @SCHEMA@.MIGRATION_FRONT_T.AIID, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.SOURCE_PTID, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.TARGET_PTID, @SCHEMA@.MIGRATION_FRONT_T.STATE, @SCHEMA@.MIGRATION_FRONT_T.SUB_STATE, @SCHEMA@.MIGRATION_FRONT_T.STOP_REASON, @SCHEMA@.MIGRATION_FRONT_T.SOURCE_ATID, @SCHEMA@.MIGRATION_FRONT_T.TARGET_ATID, @SCHEMA@.MIGRATION_FRONT_T.MIGRATION_TIME, @SCHEMA@.MIGRATION_FRONT_T.WSID_1, @SCHEMA@.MIGRATION_FRONT_T.WSID_2
 FROM @SCHEMA@.MIGRATION_FRONT_T, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
 WHERE @SCHEMA@.MIGRATION_FRONT_T.MPTID = @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.MPTID;

-- View: AuditLog
CREATE VIEW @SCHEMA@.AUDIT_LOG(ALID, EVENT_TIME, EVENT_TIME_UTC, AUDIT_EVENT, PTID, PIID, AIID, SIID, SCOPE_NAME, PROCESS_TEMPL_NAME, PROCESS_INST_NAME, TOP_LEVEL_PI_NAME, TOP_LEVEL_PIID, PARENT_PI_NAME, PARENT_PIID, VALID_FROM, VALID_FROM_UTC, ACTIVITY_NAME, ACTIVITY_KIND, ACTIVITY_STATE, CONTROL_LINK_NAME, IMPL_NAME, PRINCIPAL, TERMINAL_NAME, VARIABLE_DATA, EXCEPTION_TEXT, DESCRIPTION, CORR_SET_INFO, USER_NAME, ATID, ADDITIONAL_INFO, OBJECT_META_TYPE ) AS
 SELECT @SCHEMA@.AUDIT_LOG_T.ALID,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME_UTC,@SCHEMA@.AUDIT_LOG_T.AUDIT_EVENT,@SCHEMA@.AUDIT_LOG_T.PTID,@SCHEMA@.AUDIT_LOG_T.PIID,@SCHEMA@.AUDIT_LOG_T.AIID,@SCHEMA@.AUDIT_LOG_T.SIID,@SCHEMA@.AUDIT_LOG_T.VARIABLE_NAME,@SCHEMA@.AUDIT_LOG_T.PROCESS_TEMPL_NAME, @SCHEMA@.AUDIT_LOG_T.PROCESS_INST_NAME,@SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PI_NAME,@SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PIID,@SCHEMA@.AUDIT_LOG_T.PARENT_PI_NAME,@SCHEMA@.AUDIT_LOG_T.PARENT_PIID,@SCHEMA@.AUDIT_LOG_T.VALID_FROM,@SCHEMA@.AUDIT_LOG_T.VALID_FROM_UTC, @SCHEMA@.AUDIT_LOG_T.ACTIVITY_NAME,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_KIND,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_STATE,@SCHEMA@.AUDIT_LOG_T.CONTROL_LINK_NAME,@SCHEMA@.AUDIT_LOG_T.IMPL_NAME,@SCHEMA@.AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.AUDIT_LOG_T.TERMINAL_NAME,@SCHEMA@.AUDIT_LOG_T.VARIABLE_DATA,@SCHEMA@.AUDIT_LOG_T.EXCEPTION_TEXT,@SCHEMA@.AUDIT_LOG_T.DESCRIPTION,@SCHEMA@.AUDIT_LOG_T.CORR_SET_INFO,@SCHEMA@.AUDIT_LOG_T.USER_NAME, @SCHEMA@.AUDIT_LOG_T.ATID, @SCHEMA@.AUDIT_LOG_T.ADDITIONAL_INFO, @SCHEMA@.AUDIT_LOG_T.OBJECT_META_TYPE
 FROM @SCHEMA@.AUDIT_LOG_T;

-- View: AuditLogB
CREATE VIEW @SCHEMA@.AUDIT_LOG_B(ALID, EVENT_TIME, EVENT_TIME_UTC, AUDIT_EVENT, PTID, PIID, AIID, SIID, VARIABLE_NAME, PROCESS_TEMPL_NAME, TOP_LEVEL_PIID, PARENT_PIID, VALID_FROM, VALID_FROM_UTC, ATID, ACTIVITY_NAME, ACTIVITY_KIND, ACTIVITY_STATE, CONTROL_LINK_NAME, PRINCIPAL, VARIABLE_DATA, EXCEPTION_TEXT, DESCRIPTION, CORR_SET_INFO, USER_NAME, ADDITIONAL_INFO ) AS
 SELECT @SCHEMA@.AUDIT_LOG_T.ALID,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME_UTC,@SCHEMA@.AUDIT_LOG_T.AUDIT_EVENT,@SCHEMA@.AUDIT_LOG_T.PTID,@SCHEMA@.AUDIT_LOG_T.PIID,@SCHEMA@.AUDIT_LOG_T.AIID,@SCHEMA@.AUDIT_LOG_T.SIID,@SCHEMA@.AUDIT_LOG_T.VARIABLE_NAME,@SCHEMA@.AUDIT_LOG_T.PROCESS_TEMPL_NAME, @SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PIID,@SCHEMA@.AUDIT_LOG_T.PARENT_PIID,@SCHEMA@.AUDIT_LOG_T.VALID_FROM,@SCHEMA@.AUDIT_LOG_T.VALID_FROM_UTC,@SCHEMA@.AUDIT_LOG_T.ATID, @SCHEMA@.AUDIT_LOG_T.ACTIVITY_NAME,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_KIND,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_STATE,@SCHEMA@.AUDIT_LOG_T.CONTROL_LINK_NAME,@SCHEMA@.AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.AUDIT_LOG_T.VARIABLE_DATA,@SCHEMA@.AUDIT_LOG_T.EXCEPTION_TEXT,@SCHEMA@.AUDIT_LOG_T.DESCRIPTION,@SCHEMA@.AUDIT_LOG_T.CORR_SET_INFO,@SCHEMA@.AUDIT_LOG_T.USER_NAME, @SCHEMA@.AUDIT_LOG_T.ADDITIONAL_INFO
 FROM @SCHEMA@.AUDIT_LOG_T
 WHERE @SCHEMA@.AUDIT_LOG_T.OBJECT_META_TYPE = 1;

-- View: ApplicationComp
CREATE VIEW @SCHEMA@.APPLICATION_COMP(ACOID, BUSINESS_RELEVANCE, NAME, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON ) AS
 SELECT @SCHEMA@.APPLICATION_COMPONENT_T.ACOID, @SCHEMA@.APPLICATION_COMPONENT_T.BUSINESS_RELEVANCE, @SCHEMA@.APPLICATION_COMPONENT_T.NAME, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_DELEGATION, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_SUB_TASK, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_FOLLOW_ON_TASK
 FROM @SCHEMA@.APPLICATION_COMPONENT_T;

-- View: Task
CREATE VIEW @SCHEMA@.TASK(TKIID, ACTIVATED, APPLIC_DEFAULTS_ID, APPLIC_NAME, BUSINESS_RELEVANCE, COMPLETED, CONTAINMENT_CTX_ID, CTX_AUTHORIZATION, DUE, EXPIRES, FIRST_ACTIVATED, FOLLOW_ON_TKIID, IS_AD_HOC, IS_ESCALATED, IS_INLINE, IS_WAIT_FOR_SUB_TK, KIND, LAST_MODIFIED, LAST_STATE_CHANGE, NAME, NAME_SPACE, ORIGINATOR, OWNER, PARENT_CONTEXT_ID, PRIORITY, STARTED, STARTER, STATE, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON, HIERARCHY_POSITION, IS_CHILD, SUSPENDED, TKTID, TOP_TKIID, TYPE, RESUMES, ASSIGNMENT_TYPE, INHERITED_AUTH, INVOKED_INSTANCE_ID, INVOKED_INSTANCE_TYPE, WORK_BASKET, IS_READ, IS_TRANSFERRED_TO_WORK_BASKET, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INSTANCE_T.TKIID, @SCHEMA@.TASK_INSTANCE_T.ACTIVATION_TIME, @SCHEMA@.TASK_INSTANCE_T.APPLICATION_DEFAULTS_ID, @SCHEMA@.TASK_INSTANCE_T.APPLICATION_NAME, @SCHEMA@.TASK_INSTANCE_T.BUSINESS_RELEVANCE, @SCHEMA@.TASK_INSTANCE_T.COMPLETION_TIME, @SCHEMA@.TASK_INSTANCE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_INSTANCE_T.CONTEXT_AUTHORIZATION, @SCHEMA@.TASK_INSTANCE_T.DUE_TIME, @SCHEMA@.TASK_INSTANCE_T.EXPIRATION_TIME, @SCHEMA@.TASK_INSTANCE_T.FIRST_ACTIVATION_TIME, @SCHEMA@.TASK_INSTANCE_T.FOLLOW_ON_TKIID, @SCHEMA@.TASK_INSTANCE_T.IS_AD_HOC, @SCHEMA@.TASK_INSTANCE_T.IS_ESCALATED, @SCHEMA@.TASK_INSTANCE_T.IS_INLINE, @SCHEMA@.TASK_INSTANCE_T.IS_WAITING_FOR_SUBTASK, @SCHEMA@.TASK_INSTANCE_T.KIND, @SCHEMA@.TASK_INSTANCE_T.LAST_MODIFICATION_TIME, @SCHEMA@.TASK_INSTANCE_T.LAST_STATE_CHANGE_TIME, @SCHEMA@.TASK_INSTANCE_T.NAME, @SCHEMA@.TASK_INSTANCE_T.NAMESPACE, @SCHEMA@.TASK_INSTANCE_T.ORIGINATOR, @SCHEMA@.TASK_INSTANCE_T.OWNER, @SCHEMA@.TASK_INSTANCE_T.PARENT_CONTEXT_ID, @SCHEMA@.TASK_INSTANCE_T.PRIORITY, @SCHEMA@.TASK_INSTANCE_T.START_TIME, @SCHEMA@.TASK_INSTANCE_T.STARTER, @SCHEMA@.TASK_INSTANCE_T.STATE, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_DELEGATION, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_SUB_TASK, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_FOLLOW_ON_TASK, @SCHEMA@.TASK_INSTANCE_T.HIERARCHY_POSITION, @SCHEMA@.TASK_INSTANCE_T.IS_CHILD, @SCHEMA@.TASK_INSTANCE_T.IS_SUSPENDED, @SCHEMA@.TASK_INSTANCE_T.TKTID, @SCHEMA@.TASK_INSTANCE_T.TOP_TKIID, @SCHEMA@.TASK_INSTANCE_T.TYPE, @SCHEMA@.TASK_INSTANCE_T.RESUMES, @SCHEMA@.TASK_INSTANCE_T.ASSIGNMENT_TYPE, @SCHEMA@.TASK_INSTANCE_T.INHERITED_AUTH, @SCHEMA@.TASK_INSTANCE_T.INVOKED_INSTANCE_ID, @SCHEMA@.TASK_INSTANCE_T.INVOKED_INSTANCE_TYPE, @SCHEMA@.TASK_INSTANCE_T.WORK_BASKET, @SCHEMA@.TASK_INSTANCE_T.IS_READ, @SCHEMA@.TASK_INSTANCE_T.IS_TRANSFERRED_TO_WORK_BASKET, @SCHEMA@.TASK_INSTANCE_T.WSID_1, @SCHEMA@.TASK_INSTANCE_T.WSID_2
 FROM @SCHEMA@.TASK_INSTANCE_T;

-- View: TaskTempl
CREATE VIEW @SCHEMA@.TASK_TEMPL(TKTID, APPLIC_DEFAULTS_ID, APPLIC_NAME, BUSINESS_RELEVANCE, CONTAINMENT_CTX_ID, CTX_AUTHORIZATION, DEFINITION_NAME, DEFINITION_NS, IS_AD_HOC, IS_INLINE, KIND, NAME, NAMESPACE, PRIORITY, STATE, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON, TYPE, VALID_FROM, AUTONOMY, ASSIGNMENT_TYPE, INHERITED_AUTH, WORK_BASKET ) AS
 SELECT @SCHEMA@.TASK_TEMPLATE_T.TKTID, @SCHEMA@.TASK_TEMPLATE_T.APPLICATION_DEFAULTS_ID, @SCHEMA@.TASK_TEMPLATE_T.APPLICATION_NAME, @SCHEMA@.TASK_TEMPLATE_T.BUSINESS_RELEVANCE, @SCHEMA@.TASK_TEMPLATE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_TEMPLATE_T.CONTEXT_AUTHORIZATION, @SCHEMA@.TASK_TEMPLATE_T.DEFINITION_NAME, @SCHEMA@.TASK_TEMPLATE_T.TARGET_NAMESPACE, @SCHEMA@.TASK_TEMPLATE_T.IS_AD_HOC, @SCHEMA@.TASK_TEMPLATE_T.IS_INLINE, @SCHEMA@.TASK_TEMPLATE_T.KIND, @SCHEMA@.TASK_TEMPLATE_T.NAME, @SCHEMA@.TASK_TEMPLATE_T.NAMESPACE, @SCHEMA@.TASK_TEMPLATE_T.PRIORITY, @SCHEMA@.TASK_TEMPLATE_T.STATE, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_DELEGATION, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_SUB_TASK, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_FOLLOW_ON_TASK, @SCHEMA@.TASK_TEMPLATE_T.TYPE, @SCHEMA@.TASK_TEMPLATE_T.VALID_FROM, @SCHEMA@.TASK_TEMPLATE_T.AUTONOMY, @SCHEMA@.TASK_TEMPLATE_T.ASSIGNMENT_TYPE, @SCHEMA@.TASK_TEMPLATE_T.INHERITED_AUTH, @SCHEMA@.TASK_TEMPLATE_T.WORK_BASKET
 FROM @SCHEMA@.TASK_TEMPLATE_T;

-- View: Escalation
CREATE VIEW @SCHEMA@.ESCALATION(ESIID, ACTION, ACTIVATION_STATE, ACTIVATION_TIME, ESCALATION_TIME, AT_LEAST_EXP_STATE, ESTID, FIRST_ESIID, INCREASE_PRIORITY, NAME, STATE, TKIID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESCALATION_INSTANCE_T.ESIID, @SCHEMA@.ESCALATION_INSTANCE_T.ACTION, @SCHEMA@.ESCALATION_INSTANCE_T.ACTIVATION_STATE, @SCHEMA@.ESCALATION_INSTANCE_T.ACTIVATION_TIME, @SCHEMA@.ESCALATION_INSTANCE_T.ESCALATION_TIME, @SCHEMA@.ESCALATION_INSTANCE_T.AT_LEAST_EXPECTED_STATE, @SCHEMA@.ESCALATION_INSTANCE_T.ESTID, @SCHEMA@.ESCALATION_INSTANCE_T.FIRST_ESIID, @SCHEMA@.ESCALATION_INSTANCE_T.INCREASE_PRIORITY, @SCHEMA@.ESCALATION_INSTANCE_T.NAME, @SCHEMA@.ESCALATION_INSTANCE_T.STATE, @SCHEMA@.ESCALATION_INSTANCE_T.TKIID, @SCHEMA@.ESCALATION_INSTANCE_T.WSID_1, @SCHEMA@.ESCALATION_INSTANCE_T.WSID_2
 FROM @SCHEMA@.ESCALATION_INSTANCE_T;

-- View: EscTempl
CREATE VIEW @SCHEMA@.ESC_TEMPL(ESTID, FIRST_ESTID, PREVIOUS_ESTID, TKTID, CONTAINMENT_CTX_ID, NAME, ACTIVATION_STATE, AT_LEAST_EXP_STATE, INCREASE_PRIORITY, ACTION ) AS
 SELECT @SCHEMA@.ESCALATION_TEMPLATE_T.ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.FIRST_ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.PREVIOUS_ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.TKTID, @SCHEMA@.ESCALATION_TEMPLATE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.ESCALATION_TEMPLATE_T.NAME, @SCHEMA@.ESCALATION_TEMPLATE_T.ACTIVATION_STATE, @SCHEMA@.ESCALATION_TEMPLATE_T.AT_LEAST_EXPECTED_STATE, @SCHEMA@.ESCALATION_TEMPLATE_T.INCREASE_PRIORITY, @SCHEMA@.ESCALATION_TEMPLATE_T.ACTION
 FROM @SCHEMA@.ESCALATION_TEMPLATE_T;

-- View: EscTemplDesc
CREATE VIEW @SCHEMA@.ESC_TEMPL_DESC(ESTID, LOCALE, TKTID, DISPLAY_NAME, DESCRIPTION ) AS
 SELECT @SCHEMA@.ESC_TEMPL_LDESC_T.ESTID, @SCHEMA@.ESC_TEMPL_LDESC_T.LOCALE, @SCHEMA@.ESC_TEMPL_LDESC_T.TKTID, @SCHEMA@.ESC_TEMPL_LDESC_T.DISPLAY_NAME, @SCHEMA@.ESC_TEMPL_LDESC_T.DESCRIPTION
 FROM @SCHEMA@.ESC_TEMPL_LDESC_T;

-- View: TaskTemplCProp
CREATE VIEW @SCHEMA@.TASK_TEMPL_CPROP(TKTID, NAME, DATA_TYPE, STRING_VALUE ) AS
 SELECT @SCHEMA@.TASK_TEMPL_CPROP_T.TKTID, @SCHEMA@.TASK_TEMPL_CPROP_T.NAME, @SCHEMA@.TASK_TEMPL_CPROP_T.DATA_TYPE, @SCHEMA@.TASK_TEMPL_CPROP_T.STRING_VALUE
 FROM @SCHEMA@.TASK_TEMPL_CPROP_T;

-- View: EscTemplCProp
CREATE VIEW @SCHEMA@.ESC_TEMPL_CPROP(ESTID, NAME, TKTID, DATA_TYPE, VALUE ) AS
 SELECT @SCHEMA@.ESC_TEMPL_CPROP_T.ESTID, @SCHEMA@.ESC_TEMPL_CPROP_T.NAME, @SCHEMA@.ESC_TEMPL_CPROP_T.TKTID, @SCHEMA@.ESC_TEMPL_CPROP_T.DATA_TYPE, @SCHEMA@.ESC_TEMPL_CPROP_T.STRING_VALUE
 FROM @SCHEMA@.ESC_TEMPL_CPROP_T;

-- View: TaskTemplDesc
CREATE VIEW @SCHEMA@.TASK_TEMPL_DESC(TKTID, LOCALE, DESCRIPTION, DISPLAY_NAME ) AS
 SELECT @SCHEMA@.TASK_TEMPL_LDESC_T.TKTID, @SCHEMA@.TASK_TEMPL_LDESC_T.LOCALE, @SCHEMA@.TASK_TEMPL_LDESC_T.DESCRIPTION, @SCHEMA@.TASK_TEMPL_LDESC_T.DISPLAY_NAME
 FROM @SCHEMA@.TASK_TEMPL_LDESC_T;

-- View: TaskCProp
CREATE VIEW @SCHEMA@.TASK_CPROP(TKIID, NAME, DATA_TYPE, STRING_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INST_CPROP_T.TKIID, @SCHEMA@.TASK_INST_CPROP_T.NAME, @SCHEMA@.TASK_INST_CPROP_T.DATA_TYPE, @SCHEMA@.TASK_INST_CPROP_T.STRING_VALUE, @SCHEMA@.TASK_INST_CPROP_T.WSID_1, @SCHEMA@.TASK_INST_CPROP_T.WSID_2
 FROM @SCHEMA@.TASK_INST_CPROP_T;

-- View: TaskDesc
CREATE VIEW @SCHEMA@.TASK_DESC(TKIID, LOCALE, DESCRIPTION, DISPLAY_NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INST_LDESC_T.TKIID, @SCHEMA@.TASK_INST_LDESC_T.LOCALE, @SCHEMA@.TASK_INST_LDESC_T.DESCRIPTION, @SCHEMA@.TASK_INST_LDESC_T.DISPLAY_NAME, @SCHEMA@.TASK_INST_LDESC_T.WSID_1, @SCHEMA@.TASK_INST_LDESC_T.WSID_2
 FROM @SCHEMA@.TASK_INST_LDESC_T;

-- View: EscalationCProp
CREATE VIEW @SCHEMA@.ESCALATION_CPROP(ESIID, NAME, DATA_TYPE, STRING_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESC_INST_CPROP_T.ESIID, @SCHEMA@.ESC_INST_CPROP_T.NAME, @SCHEMA@.ESC_INST_CPROP_T.DATA_TYPE, @SCHEMA@.ESC_INST_CPROP_T.STRING_VALUE, @SCHEMA@.ESC_INST_CPROP_T.WSID_1, @SCHEMA@.ESC_INST_CPROP_T.WSID_2
 FROM @SCHEMA@.ESC_INST_CPROP_T;

-- View: TaskHistory
CREATE VIEW @SCHEMA@.TASK_HISTORY(TKIID, ESIID, PARENT_TKIID, EVENT, REASON, EVENT_TIME, NEXT_TIME, PRINCIPAL, WORK_ITEM_KIND, FROM_ID, TO_ID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_HISTORY_T.TKIID, @SCHEMA@.TASK_HISTORY_T.ESIID, @SCHEMA@.TASK_HISTORY_T.PARENT_TKIID, @SCHEMA@.TASK_HISTORY_T.EVENT, @SCHEMA@.TASK_HISTORY_T.REASON, @SCHEMA@.TASK_HISTORY_T.EVENT_TIME, @SCHEMA@.TASK_HISTORY_T.NEXT_TIME, @SCHEMA@.TASK_HISTORY_T.PRINCIPAL, @SCHEMA@.TASK_HISTORY_T.WORK_ITEM_KIND, @SCHEMA@.TASK_HISTORY_T.FROM_ID, @SCHEMA@.TASK_HISTORY_T.TO_ID, @SCHEMA@.TASK_HISTORY_T.WSID_1, @SCHEMA@.TASK_HISTORY_T.WSID_2
 FROM @SCHEMA@.TASK_HISTORY_T;

-- View: EscalationDesc
CREATE VIEW @SCHEMA@.ESCALATION_DESC(ESIID, LOCALE, DESCRIPTION, DISPLAY_NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESC_INST_LDESC_T.ESIID, @SCHEMA@.ESC_INST_LDESC_T.LOCALE, @SCHEMA@.ESC_INST_LDESC_T.DESCRIPTION, @SCHEMA@.ESC_INST_LDESC_T.DISPLAY_NAME, @SCHEMA@.ESC_INST_LDESC_T.WSID_1, @SCHEMA@.ESC_INST_LDESC_T.WSID_2
 FROM @SCHEMA@.ESC_INST_LDESC_T;

-- View: TaskAuditLog
CREATE VIEW @SCHEMA@.TASK_AUDIT_LOG(ALID, AUDIT_EVENT, CONTAINMENT_CTX_ID, ESIID, ESTID, EVENT_TIME, FAULT_NAME, FAULT_TYPE_NAME, FAULT_NAME_SPACE, FOLLOW_ON_TKIID, NAME, NAMESPACE, NEW_USER, OLD_USER, PARENT_CONTEXT_ID, PARENT_TASK_NAME, PARENT_TASK_NAMESP, PARENT_TKIID, PRINCIPAL, TASK_KIND, TASK_STATE, TKIID, TKTID, TOP_TKIID, VAILD_FROM, WORK_ITEM_REASON, USERS, DESCRIPTION, MESSAGE_DATA ) AS
 SELECT @SCHEMA@.TASK_AUDIT_LOG_T.ALID, @SCHEMA@.TASK_AUDIT_LOG_T.AUDIT_EVENT, @SCHEMA@.TASK_AUDIT_LOG_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_AUDIT_LOG_T.ESIID, @SCHEMA@.TASK_AUDIT_LOG_T.ESTID, @SCHEMA@.TASK_AUDIT_LOG_T.EVENT_TIME_UTC, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_TYPE_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.FOLLOW_ON_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.NAME, @SCHEMA@.TASK_AUDIT_LOG_T.NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.NEW_USER, @SCHEMA@.TASK_AUDIT_LOG_T.OLD_USER, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_CONTEXT_ID, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TASK_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TASK_NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.TASK_AUDIT_LOG_T.TASK_KIND, @SCHEMA@.TASK_AUDIT_LOG_T.TASK_STATE, @SCHEMA@.TASK_AUDIT_LOG_T.TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.TKTID, @SCHEMA@.TASK_AUDIT_LOG_T.TOP_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.VALID_FROM_UTC, @SCHEMA@.TASK_AUDIT_LOG_T.WI_REASON, @SCHEMA@.TASK_AUDIT_LOG_T.USERS, @SCHEMA@.TASK_AUDIT_LOG_T.DESCRIPTION, @SCHEMA@.TASK_AUDIT_LOG_T.MESSAGE_DATA
 FROM @SCHEMA@.TASK_AUDIT_LOG_T;

-- View: WorkBasket
CREATE VIEW @SCHEMA@.WORK_BASKET(WBID, NAME, TYPE, OWNER, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_T.WBID, @SCHEMA@.WORK_BASKET_T.NAME, @SCHEMA@.WORK_BASKET_T.TYPE, @SCHEMA@.WORK_BASKET_T.OWNER, @SCHEMA@.WORK_BASKET_T.DEFAULT_QUERY_TABLE, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT1, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT2, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT3, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT4, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT5, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT6, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT7, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT8, @SCHEMA@.WORK_BASKET_T.CREATION_TIME, @SCHEMA@.WORK_BASKET_T.LAST_MODIFICATION_TIME, @SCHEMA@.WORK_BASKET_T.WSID_1, @SCHEMA@.WORK_BASKET_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_T;

-- View: WorkBasketLDesc
CREATE VIEW @SCHEMA@.WORK_BASKET_LDESC(WBID, LOCALE, DISPLAY_NAME, DESCRIPTION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_LDESC_T.WBID, @SCHEMA@.WORK_BASKET_LDESC_T.LOCALE, @SCHEMA@.WORK_BASKET_LDESC_T.DISPLAY_NAME, @SCHEMA@.WORK_BASKET_LDESC_T.DESCRIPTION, @SCHEMA@.WORK_BASKET_LDESC_T.WSID_1, @SCHEMA@.WORK_BASKET_LDESC_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_LDESC_T;

-- View: WorkBasketDistTarget
CREATE VIEW @SCHEMA@.WORK_BASKET_DIST_TARGET(WBID, NAME, TYPE, OWNER, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, SOURCE_WBID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_DIST_TARGET_T.TARGET_WBID, @SCHEMA@.WORK_BASKET_T.NAME, @SCHEMA@.WORK_BASKET_T.TYPE, @SCHEMA@.WORK_BASKET_T.OWNER, @SCHEMA@.WORK_BASKET_T.DEFAULT_QUERY_TABLE, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT1, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT2, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT3, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT4, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT5, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT6, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT7, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT8, @SCHEMA@.WORK_BASKET_T.CREATION_TIME, @SCHEMA@.WORK_BASKET_T.LAST_MODIFICATION_TIME, @SCHEMA@.WORK_BASKET_DIST_TARGET_T.SOURCE_WBID, @SCHEMA@.WORK_BASKET_T.WSID_1, @SCHEMA@.WORK_BASKET_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_DIST_TARGET_T, @SCHEMA@.WORK_BASKET_T
 WHERE @SCHEMA@.WORK_BASKET_T.WBID = @SCHEMA@.WORK_BASKET_DIST_TARGET_T.TARGET_WBID;

-- View: BusinessCategory
CREATE VIEW @SCHEMA@.BUSINESS_CATEGORY(BCID, PARENT_BCID, NAME, PRIORITY, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.BUSINESS_CATEGORY_T.BCID, @SCHEMA@.BUSINESS_CATEGORY_T.PARENT_BCID, @SCHEMA@.BUSINESS_CATEGORY_T.NAME, @SCHEMA@.BUSINESS_CATEGORY_T.PRIORITY, @SCHEMA@.BUSINESS_CATEGORY_T.DEFAULT_QUERY_TABLE, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT1, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT2, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT3, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT4, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT5, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT6, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT7, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT8, @SCHEMA@.BUSINESS_CATEGORY_T.CREATION_TIME, @SCHEMA@.BUSINESS_CATEGORY_T.LAST_MODIFICATION_TIME, @SCHEMA@.BUSINESS_CATEGORY_T.WSID_1, @SCHEMA@.BUSINESS_CATEGORY_T.WSID_2
 FROM @SCHEMA@.BUSINESS_CATEGORY_T;

-- View: BusinessCategoryLDesc
CREATE VIEW @SCHEMA@.BUSINESS_CATEGORY_LDESC(BCID, LOCALE, DISPLAY_NAME, DESCRIPTION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.BCID, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.LOCALE, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.DISPLAY_NAME, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.DESCRIPTION, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.WSID_1, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.WSID_2
 FROM @SCHEMA@.BUSINESS_CATEGORY_LDESC_T;


-- start import scheduler DDL: createSchemaInformix.sql



CREATE TABLE @SCHEMA@.SCHED_TASK ( TASKID DECIMAL(19,
               0) NOT NULL PRIMARY KEY ,
               VERSION VARCHAR(5) NOT NULL ,
               ROW_VERSION INTEGER NOT NULL ,
               TASKTYPE INTEGER NOT NULL ,
               TASKSUSPENDED SMALLINT NOT NULL ,
               CANCELLED SMALLINT NOT NULL ,
               NEXTFIRETIME DECIMAL(19,
               0) NOT NULL ,
               STARTBYINTERVAL VARCHAR(254) ,
               STARTBYTIME DECIMAL(19,
               0) ,
               VALIDFROMTIME DECIMAL(19,
               0) ,
               VALIDTOTIME DECIMAL(19,
               0) ,
               REPEATINTERVAL VARCHAR(254) ,
               MAXREPEATS INTEGER NOT NULL ,
               REPEATSLEFT INTEGER NOT NULL ,
               TASKINFO BYTE ,
               NAME VARCHAR(254) NOT NULL ,
               AUTOPURGE INTEGER NOT NULL ,
               FAILUREACTION INTEGER ,
               MAXATTEMPTS INTEGER ,
               QOS INTEGER  ,
               PARTITIONID INTEGER ,
               OWNERTOKEN VARCHAR(200) NOT NULL ,
               CREATETIME DECIMAL(19,
               0) NOT NULL ) LOCK MODE ROW;

CREATE INDEX @SCHEMA@.SCHED_TASK_IDX1 ON @SCHEMA@.SCHED_TASK ( TASKID,
               OWNERTOKEN ) ;

CREATE CLUSTER INDEX @SCHEMA@.SCHED_TASK_IDX2 ON @SCHEMA@.SCHED_TASK ( NEXTFIRETIME ASC,
               REPEATSLEFT,
               PARTITIONID );

CREATE TABLE @SCHEMA@.SCHED_TREG ( REGKEY VARCHAR(254) NOT NULL PRIMARY KEY,
               REGVALUE VARCHAR(254) ) LOCK MODE ROW;

CREATE TABLE @SCHEMA@.SCHED_LMGR ( LEASENAME VARCHAR(254) NOT NULL PRIMARY KEY,
               LEASEOWNER VARCHAR(254) NOT NULL,
               LEASE_EXPIRE_TIME NUMERIC(19,
               0),
               DISABLED VARCHAR(5) ) LOCK MODE ROW;

CREATE TABLE @SCHEMA@.SCHED_LMPR ( LEASENAME VARCHAR(254) NOT NULL,
               NAME VARCHAR(254) NOT NULL,
               VALUE VARCHAR(254) NOT NULL ) LOCK MODE ROW;

CREATE INDEX @SCHEMA@.SCHED_LMPR_IDX1 ON @SCHEMA@.SCHED_LMPR ( LEASENAME );

-- end import scheduler DDL: createSchemaInformix.sql

