#
# Licensed Materials - Property of IBM
# 5655-FLW (C) Copyright IBM Corporation 2010. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
import os.path, sys
import jarray

from java.lang import System
from java.lang import String
from javax.management import ObjectName

execfile(os.path.join(System.getProperty("was.install.root"), "ProcessChoreographer/config/bpclib.py"))
__file__ = "archive.py"

#*******************************************************************************************************
# globals
#*******************************************************************************************************
MIN_SLICE = 1
MAX_SLICE = sys.maxint
DEFAULT_SLICE = 1

MIN_LIMIT = 0
MAX_LIMIT = sys.maxint
DEFAULT_LIMIT = 1

#*******************************************************************************************************
# print usage and error message, if any
#*******************************************************************************************************
def usage(errmsg = None):
  if errmsg:
    print
    print "ERROR: " + errmsg
  #endif
  print
  print "Usage: wsadmin -f " + __file__
  print "       ( ( -fromNode <fromNodeName> -fromServer <fromServerName> ) | ( -fromCluster <fromClusterName> ) )"
  print "       ( ( -toNode <toNodeName> -toServer <toServerName> ) | ( -toCluster <toClusterName> ) )"
  print "       ( -tasks | -processes )"
  print "       ( -all | [ -finished ] [ -terminated ] [ -failed ] [ -expired ] )"
  print "       [ ( -templateName <templateName> [ -nameSpace <namespace> ] [ -validFromUTC <timestamp> ] ) ]"
  print "       [ -kind ( todo | invocation | collaboration ) ]"
  print "       [ -completedAfterUTC <timestamp> | -completedAfterLocal <timestamp> ]"
  print "       [ -completedBeforeUTC <timestamp> | -completedBeforeLocal <timestamp> ]"
  print "       [ -startedBy <userID> | -createdBy <userID> ]"
  print "       [ -slice <numberOfEntities> ]"
  print "       [ -limit <numberOfEntities> ]"
  print
  print "Transfer task or process instances and related data to the archive."
  print
  print "With option '-processes' archive completed process instances. Process templates and"
  print "  sub-processes are managed as dependent objects based on related process instance data."
  print "With option '-tasks' archive completed task instances. Task templates are managed as"
  print "  dependent objects based on related task instance data."
  print
  print "With option '-all', all instances in state finished, terminated, failed or expired are archived."
  print "With option '-finished', only instances in state finished are archived."
  print "With option '-terminated', only instances in state terminated are archived."
  print "With option '-failed', only instances in state failed are archived."
  print "With option '-expired', only instances in state expired are archived."
  print
  print "The '-expired' option is valid for the '-tasks' option only"
  print
  print "The set of to be archived instances may be further restricted: "
  print
  print "With parameter '-templateName', only instances that belong to the process or task template with"
  print "  the specified template name are archived. In case there are multiple process/task templates"
  print "  sharing the same name but with different validFrom dates the instances for all process/task"
  print "  templates with that name are archived. This may be further restricted by additionally"
  print "  specifying the option '-validFromUTC' and in case of the '-tasks' option by specifying"
  print "  the '-namespace' and '-kind' options."
  print
  print "With parameter '-startedBy', only instances started by the specified user are archived."
  print "  This option is valid for the '-process' option only"
  print "With parameter '-createdBy', only instances created by the specified user are archived."
  print "  This option is valid for the '-taks' option only"
  print "With parameter '-completedAfterUTC' or '-completedAfterLocal', only instances completed"
  print "  after the specified timestamp are archived."
  print "With parameter '-completedBeforeUTC' or '-completedBeforeLocal', only instances completed"
  print "  before the specified timestamp are archived."
  print
  print "<timestamp> format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]."
  print "If you specify only the year, month, and day, the hour, minutes, and seconds are set to 00:00:00."
  print "You must not omit the hour, minutes, and seconds for parameter '-validFromUTC'."
  print "Example timestamp: 2006-11-04T21:57:22"
  print
  print "The optional '-slice' parameter can be used to overwrite the default transaction slice size (" + str(DEFAULT_SLICE) + ")."
  print "Its value must be between " + str(MIN_SLICE) + " and " + str(MAX_SLICE) + "."
  print
  print "The optional '-limit' parameter can be used to overwrite the default limit size (" + str(DEFAULT_LIMIT) + ")."
  print "Its value must be between " + str(MIN_LIMIT) + " and " + str(MAX_LIMIT) + "."
  print "If a limit value of '0' is provided, recovery is run only. For more information on"
  print "recovery, see the Info Center and related documentation."
  print
#enddef

#*******************************************************************************************************
# main
#*******************************************************************************************************

# ----------------------------------------------------
# make sure the script is running in connected mode
if wsadmin.getConnectionStatus() != WsAdmin.CONNECTED:
  usage(__file__ + " must run in connected mode, make sure that you run the script without the '-conntype NONE' option and verify that user and password are correct.")
  sys.exit(1)
#endif

# ----------------------
# parse the command line
props = {}
props.update({ "fromServer": "", "fromNode": "", "fromCluster": "", "toServer": "", "toNode": "", "toCluster": "" })
props.update({ "processes": None, "tasks": None })
props.update({ "all": None, "finished": None, "terminated": None, "failed": None, "expired": None })
props.update({ "templateName": "", "nameSpace": "", "validFromUTC": "", "kind": "", "startedBy": "", "createdBy": "" })
props.update({ "completedAfterLocal": "", "completedAfterUTC": "", "completedBeforeLocal": "", "completedBeforeUTC": "" })
props.update({ "slice": DEFAULT_SLICE, "limit": DEFAULT_LIMIT, "verbose": None })
try:
  props = wsadmin.parse(sys.argv, props)
except ValueError, error:
  usage(str(error))
  sys.exit(1)
#endtry

states = [key for key in props.keys() if props[key] and key in ["all", "finished", "terminated", "failed", "expired"]]
operationMode = [key for key in props.keys() if props[key] and key in ["tasks", "processes"]]

# -----------------------------
# check command line parameters
if not props["fromServer"] and not props["fromCluster"]:
  usage("One of the '-fromServer' and '-fromCluster' parameters must be specified.")
  sys.exit(1)
#endif

if props["fromServer"] and props["fromCluster"]:
  usage("Only one of the '-fromServer' and '-fromCluster' parameters can be specified.")
  sys.exit(1)
#endif

if props["fromServer"] and not props["fromNode"]:
  usage("The '-fromNode' parameter must be specified if '-fromServer' is specified.")
  sys.exit(1)
#endif

# -----------------------------------------------
# check if the scope is a valid deployment target
scope = Scope(nodeName = props["fromNode"], serverName = props["fromServer"], clusterName = props["fromCluster"])
if scope.convertToCluster():
  print "Warning: '" + props["fromServer"] + "' is a member of cluster '" + scope.clusterName + "', adjusting scope to cluster."
#endif

if not scope.isDeploymentTarget():
  usage(str(scope) + " is not a valid deployment target.")
  sys.exit(1)
#endif

if not scope.isBPCDeploymentTarget("RUNTIME"):
  usage("Process Choreographer is not configured on " + scope.displayName() +"." )
  sys.exit(1)
#endif

if not props["toServer"] and not props["toCluster"]:
  usage("One of the '-toServer' and '-toCluster' parameters must be specified.")
  sys.exit(1)
#endif

if props["toServer"] and props["toCluster"]:
  usage("Only one of the '-toServer' and '-toCluster' parameters can be specified.")
  sys.exit(1)
#endif

if props["toServer"] and not props["toNode"]:
  usage("The '-toNode' parameter must be specified if '-toServer' is specified.")
  sys.exit(1)
#endif

# -----------------------------------------------
# check if the toScope is a valid deployment target
toScope = Scope(nodeName = props["toNode"], serverName = props["toServer"], clusterName = props["toCluster"])
if toScope.convertToCluster():
  print "Warning: '" + props["toServer"] + "' is a member of cluster '" + toScope.clusterName + "', adjusting scope to cluster."
#endif

if not toScope.isDeploymentTarget():
  usage(str(toScope) + " is not a valid deployment target.")
  sys.exit(1)
#endif

if not toScope.isBPCDeploymentTarget("ARCHIVE"):
  usage("Archive Manager is not configured on " + toScope.displayName() + "." )
  sys.exit(1)
#endif

# ------------------------------------------------------------
# validate the 'slice' value
sliceError = validateIntValue(props, "slice", MIN_SLICE, MAX_SLICE)
if sliceError:
  usage(sliceError)
  sys.exit(1)
#endif

# ------------------------------------------------------------
# validate the 'limit' value
limitError = validateIntValue(props, "limit", MIN_LIMIT, MAX_LIMIT)
if limitError:
  usage(limitError)
  sys.exit(1)
#endif

validFrom = None

if props["validFromUTC"]:
  validFrom = normalizeTimeStamp(props["validFromUTC"], 0, 0)
  if not validFrom:
    usage("Invalid timestamp '" + props["validFromUTC"] + "', format must be <yyyy>-<MM>-<dd>T<HH>:<mm>:<ss>.")
    sys.exit(1)
  #endif
#endif

if props["completedAfterLocal"] and props["completedAfterUTC"]:
  usage("Only one of the '-completedAfterLocal' and '-completedAfterUTC' parameters can be specified.")
  sys.exit(1)
#endif

completedAfter = None
if props["completedAfterLocal"]:
  completedAfter = normalizeTimeStamp(props["completedAfterLocal"], 1, 1)
  if not completedAfter:
    usage("Invalid timestamp '" + props["completedAfterLocal"] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>].")
    sys.exit(1)
  #endif
#endif

if props["completedAfterUTC"]:
  completedAfter = normalizeTimeStamp(props["completedAfterUTC"], 0, 1)
  if not completedAfter:
    usage("Invalid timestamp '" + props["completedAfterUTC"] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>].")
    sys.exit(1)
  #endif
#endif

completedBefore = None
if props["completedBeforeLocal"] and props["completedBeforeUTC"]:
  usage("Only one of the '-completedBeforeLocal' and '-completedBeforeUTC' parameters can be specified.")
  sys.exit(1)
#endif

if props["completedBeforeLocal"]:
  completedBefore = normalizeTimeStamp(props["completedBeforeLocal"], 1, 1)
  if not completedBefore:
    usage("Invalid timestamp '" + props["completedBeforeLocal"] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>].")
    sys.exit(1)
  #endif
#endif

if props["completedBeforeUTC"]:
  completedBefore = normalizeTimeStamp(props["completedBeforeUTC"], 0, 1)
  if not completedBefore:
    usage("Invalid timestamp '" + props["completedBeforeUTC"] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>].")
    sys.exit(1)
  #endif
#endif

if (not states) or ("all" in states and len(states) > 1):
  if "processes" in operationMode:
    usage("Either '-all'; or at least one of '-finished', '-terminated' or '-failed' must be specified.")
  else:
    usage("Either '-all'; or at least one of '-finished', '-terminated', '-failed' or '-expired' must be specified.")
  #endElse
  sys.exit(1)
#endif

if (not operationMode) or (len(operationMode) > 1):
  usage("Exactly one of the '-tasks' or '-processes' command line options must be specified.")
  sys.exit(1)
#endif

if (validFrom and not props["templateName"]):
  usage("The '-templateName' command line option must be specified if '-validFromUTC' is specified.")
  sys.exit(1)
#endif

if props["nameSpace"] and not isValidNameSpace(props["nameSpace"]):
  usage("Value '" + str(props["nameSpace"]) + "' specfied for command line option '-nameSpace' is not a valid namespace identifier.")
  sys.exit(1)
#endif

if (props["nameSpace"] and not props["templateName"]):
  usage("The '-templateName' command line option must be specified if '-nameSpace' is specified.")
  sys.exit(1)
#endif

if (props["kind"] and props["kind"] != "todo" and props["kind"] != "invocation" and props["kind"] != "collaboration"):
  usage("Invalid kind '" + props["kind"] + "', value must be either 'todo', 'invocation' or 'collaboration'.")
  sys.exit(1)
#endif

if "processes" in operationMode:
  if props["nameSpace"]:
    usage("The '-nameSpace' command line option is only valid if '-tasks' is specified.")
    sys.exit(1)
  #endif
  if props["createdBy"]:
    usage("The '-createdBy' command line option is only valid if '-tasks' is specified.")
    sys.exit(1)
  #endif
  if props["kind"]:
    usage("The '-kind' command line option is only valid if '-tasks' is specified.")
    sys.exit(1)
  #endif
  if ("expired" in states):
    usage("The '-expired' command line option is only valid if '-tasks' is specified.")
    sys.exit(1)
  #endif
#endif
if "tasks" in operationMode:
  if props["startedBy"]:
    usage("The '-startedBy' command line option is only valid if '-processes' is specified.")
    sys.exit(1)
  #endif
#endif
#TODO: validate htm/bfm only parameters

archiveMBean = scope.lookupMBean("InternalArchiveManager")
invokeParams=""

toArchiveMBean = toScope.lookupMBean("InternalArchiveManager")
if not toArchiveMBean:
  print str(toScope) + " is not available -- make sure the server or at least one cluster member is running."
  sys.exit(1)
#endif

if not archiveMBean:
  print str(scope) + " is not available -- make sure the server or at least one cluster member is running."
else:
  print
  print "*********************************************************************"
  print "* Note: If there are many instances to be archived, you may         *"
  print "*       experience a timeout because the server does not finish its *"
  print "*       work before the scripting client expires.                   *"
  print "*       In case of a timeout the archiving operation continues      *"
  print "*       to run on the server and you need to check the server logs  *"
  print "*       to get information about the progress and results of the    *"
  print "        archiving operation.                                        *"
  print "*       Either choose the script parameters such that the timeout   *"
  print "*       is avoided or increase the scripting client's timeout value *"
  print "*       (see the WebSphere InfoCenter for details).                 *"
  print "*********************************************************************"
  if (props["verbose"]):
    print
    if "all" in states:
      if "processes" in operationMode:
        print "Archiving instances in states finished, terminated, failed."
      else:
        print "Archiving instances in states finished, terminated, failed, expired."
      #endElse
    else:
      print "Archiving instances in states " + ", ".join(states) + "."
    #endElse
    if props["templateName"]:
      print "Only archiving instances with template name: '" + props["templateName"] + "'."
    if props["nameSpace"]:
      print "Only archiving instances with nameSpace: '" + props["nameSpace"] + "'."
    if validFrom:
      print "Only archiving instances with validFrom: '" + validFrom + "'."
    if props["startedBy"]:
      print "Only archiving instances created by user: '" + props["startedBy"] + "'."
    if props["createdBy"]:
      print "Only archiving instances created by user: '" + props["createdBy"] + "'."
    if completedAfter:
      print "Only archiving instances completed after: '" + completedAfter + "'."
    if completedBefore:
      print "Only archiving instances completed before: '" + completedBefore + "'."
    print
  #endIf
  server =  ObjectName(archiveMBean).getKeyProperty("process")
  node = ObjectName(archiveMBean).getKeyProperty("node")
  print ""
  print "*********************************************************************"
  print "The archive operation is running on server '"+ server +"'"
  print "on node  '" + node +"'. Check the log files of the server"
  print "to get information about the progress and results of the archiving"
  print "operation."
  print "*********************************************************************"
  print ""
  if "all" in states:
    states = []; # must not pass 'None' to MBean invocation
  #endIf

  result = 0

  if "processes" in operationMode:
    params = [ props["toServer"], props["toNode"], props["toCluster"], jarray.array(states,String), props["templateName"], validFrom, completedAfter, completedBefore, props["startedBy"],props["limit"],props["slice"] ]
    signature = ['java.lang.String','java.lang.String','java.lang.String','[Ljava.lang.String;','java.lang.String','java.lang.String','java.lang.String','java.lang.String','java.lang.String','java.lang.Integer','java.lang.Integer']
    method = "archiveProcessInstances"
  else:
    params = [ props["toServer"], props["toNode"], props["toCluster"], jarray.array(states,String), props["templateName"], props["nameSpace"], validFrom, props["kind"], completedAfter, completedBefore, props["createdBy"],props["limit"],props["slice"] ]
    signature = ['java.lang.String','java.lang.String','java.lang.String','[Ljava.lang.String;','java.lang.String','java.lang.String','java.lang.String','java.lang.String','java.lang.String','java.lang.String','java.lang.String','java.lang.Integer','java.lang.Integer']
    method = "archiveTaskInstances"
  #endElse
  if (props["verbose"]):
    print "invoking MBean method " + method + " using parameters: "  + str(params) + "."
  #endIf
  try:
    result = AdminControl.invoke_jmx(ObjectName(archiveMBean), method, params, signature)
  except:
    printException()
  else:
   if result > 0:
     print "Top-level instances archived:", result
   else:
     if props["limit"] == 0:
       print "Recovery completed successfully."
     else:
       print "WARNING: The selection criterion returned no results. No instances were archived."
   #endif
   print __file__ + " finished."
#endIf

