#
# Licensed Materials - Property of IBM
# 5655-FLW (C) Copyright IBM Corporation 2011. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#

import os.path, sys
import jarray
import AdminUtilities

from java.lang import Integer, System
from java.util import HashMap
# only classes from plugins/*runtime*.jar and plugins/*admin*.jar are visible to Jython in WAS 7
from com.ibm.bpe.database.migration import DbUtility
from com.ibm.bpe.database import DbUtilityResource
from com.ibm.bpe.database import DbUtilityResult

execfile(os.path.join(System.getProperty("was.install.root"), "ProcessChoreographer/config/bpclib.py"))
__file__ = "dbUtility.py"

#*******************************************************************************************************
# globals
#*******************************************************************************************************
MIN_SLICE = 10
MAX_SLICE = 50000
DEFAULT_SLICE = 50
AVAILABLE_RESOURCES = [str(resource) for resource in DbUtilityResource.values()]

#*******************************************************************************************************
# print usage and error message, if any
#*******************************************************************************************************
def usage(errmsg = None):
  if errmsg:
    print
    print "ERROR: " + errmsg
  #endif
  print
  print "Usage: wsadmin -conntype NONE -f " + __file__
  print "       (-server <serverName> | -cluster <clusterName>)"
  print "       [-dbUser <userID>] -dbPassword <password> [-dbSchema <schema> | -dbDesign <file>]"
  print "       [-slice <slice>] "
  print "       (-testConnection)"
  print
  print "Usage: wsadmin -conntype NONE -f " + __file__
  print "       (-server <serverName> | -cluster <clusterName>)"
  print "       [-dbUser <userID>] -dbPassword <password> [-dbSchema <schema> | -dbDesign <file>]"
  print "       [-slice <slice>] "
  print "       (-check all | " + ' | '.join(AVAILABLE_RESOURCES) +" )"
  print
  print "Usage: wsadmin -conntype NONE -f " + __file__
  print "       (-server <serverName> | -cluster <clusterName>)"
  print "       [-dbUser <userID>] -dbPassword <password> [-dbSchema <schema> | -dbDesign <file>]"
  print "       [-slice <slice>] "
  print "       (-repair all | " + ' | '.join(AVAILABLE_RESOURCES) +" )"
  print
  print "Checks the Business Process Choreographer database for errors and repairs them. This script must"
  print "be run in disconnected mode and the application server or cluster members must not be running."
  print
  print "Note that this script must be run on the node of the server (when '-server' was specified) or"
  print "on the node of a cluster member (when '-cluster' was specified). That is, it cannot be run on"
  print "the deployment manager node in a network deployment (ND) environment."
  print 
  print "This script currently checks the following resources: 'all','" + "','".join(AVAILABLE_RESOURCES) + "'. "
  print "Note that this script is  extensible and further checks might be added in the future."
  print
  print "The script has three modes, only one of them must be specified:"
  print "The '-testConnection' parameter can be used to test the connection settings to the database."
  print "The '-check' parameters searches for elements that need to be repaired and to display the "
  print " number of elements that need to be repaired. Either all or only specific checks can be executed."
  print "The '-repair' parameters repairs the element display the number of repaired elements. "
  print " Either all or only specific resources can be repaired."
  print
  print "The '-server' and '-cluster' parameters denote the Business Process Choreographer"
  print "  configuration for which to check the database."
  print "The '-dbUser' and '-dbPassword' parameters are used to authenticate with the database."
  print "The optional '-dbSchema' parameter can be used to overwrite an implicit schema qualifier."
  print "  Do not use this parameter if an explicit schema qualifier has been configured."
  print "The optional '-dbDesign' parameter can be use to specify a database design file. Settings"
  print "  like the schema qualifier will be read from this file."
  print "The optional '-slice' parameter can be used to overwrite the default transaction slice size (" + str(DEFAULT_SLICE) + ")."
  print "  Its value must be between " + str(MIN_SLICE) + " and " + str(MAX_SLICE) + "."
#enddef

def printDetails (mode, resources, results):
  keys = [str(key) for key in resources]
  keywidth = reduce(lambda maxlen, len: max(maxlen, len), map(lambda key: len(key), keys), 0) # get length of longest key
  if mode == "check":
    for resource in resources:
      print "%s: %*s %7d elements need to be repaired." % (str(resource), keywidth - len(str(resource)),"",str(results.get(resource)))
    #endfor
    print
    print "************************************************************************************"
    print "NOTE: If the utility has found elements that need to be repaired, run the the script" 
    print "again with the '-repair' option."
    print "************************************************************************************"
  elif mode == "repair":
    for resource in resources:
      print "%s: %*s %7d elements were repaired." % (str(resource), keywidth - len(str(resource)),"",str(results.get(resource)))
    #endfor
    print
    print "************************************************************************************"
    print "NOTE: The number of repaired elements can be higher than the number of elements " 
    print "found using the '-check' option if dependant elements were also repaired."
    print "************************************************************************************"
  else:
    if len(results) == 0:
      print "Connection tested successfully."
    else:
      print "Connection failed with the following exception:"
      for exception in results:
       print exception
    #endif
  #endif
#endef

#*******************************************************************************************************
# main
#*******************************************************************************************************

# ----------------------------------------------------
# make sure the script is running in disconnected mode
if wsadmin.getConnectionStatus() == WsAdmin.CONNECTED:
  usage(__file__ + " cannot be run in connected mode, re-run using the '-conntype NONE' option.")

if wsadmin.getConnectionStatus() != WsAdmin.DISCONNECTED: # connected or error -> exit
  sys.exit(1)

# ----------------------
# parse the command line
props = {}
props.update({ "server": "", "cluster": "", "dbUser": "", "dbPassword": "", "dbSchema": "", "dbDesign": "" })
props.update({ "slice": DEFAULT_SLICE})
props.update({ "testConnection": None, "check": "", "repair":""})
try:
  props = wsadmin.parse(sys.argv, props)
  props["node"] = System.getProperty("local.node")
except ValueError, error:
  usage(str(error))
  sys.exit(1)
#endtry

# -----------------------------
# check command line parameters
if not props["server"] and not props["cluster"]:
  usage("One of the '-server' and '-cluster' parameters must be specified.")
  sys.exit(1)
#endif

if props["server"] and props["cluster"]:
  usage("Only one of the '-server' and '-cluster' parameters must be specified.")
  sys.exit(1)
#endif

if props["dbSchema"] and props["dbDesign"]:
  usage("Only one of the '-dbSchema' and '-dbDesign' parameters must be specified.")
  sys.exit(1)
#endif

if props["dbDesign"]:
  props["dbDesign"] = os.path.normpath(props["dbDesign"])
  if not os.path.isfile(props["dbDesign"]):
    usage("Database design file '" + props["dbDesign"] + "' does not exist.")
    sys.exit(1)
  #endif
#endif

# ------------------------------------------------------------
# validate the 'slice' value
intError = validateIntValue(props, "slice", MIN_SLICE, MAX_SLICE)
if intError:
  usage(intError)
  sys.exit(0)
#endif

# -----------------------------------------------
# check if the scope is a valid deployment target
scope = Scope(nodeName = props["node"], serverName = props["server"], clusterName = props["cluster"])
if scope.convertToCluster():
  print "Warning: '" + props["server"] + "' is a member of cluster '" + scope.clusterName + "', adjusting scope to cluster."
#endif

if not scope.isDeploymentTarget():
  usage(str(scope) + " is not a valid deployment target.")
  sys.exit(1)
#endif

if not scope.isBPCDeploymentTarget("RUNTIME"):
  usage("Process Choreographer is not configured on " + scope.displayName() +"." )
  sys.exit(1)
#endif

if scope.getCluster():
  foundMemberOnLocalNode = 0
  for member in AdminUtilities.convertToList(scope.list("ClusterMember")):
    if AdminConfig.showAttribute(member, "nodeName") == props["node"]:
      foundMemberOnLocalNode = 1
      break
    #endif
  #endfor
  if not foundMemberOnLocalNode:
    usage("No member of cluster " + props["cluster"] + " is defined on local node " + props["node"] + ".")
    sys.exit(1)
  #endif
#endif

# ------------------------------------------------------------
# validate 'Mode' 
if ((props["check"] and props["repair"]) or (props["check"] and props["testConnection"]) or (props["repair"] and props["testConnection"])):
  usage("Only one of the '-check' '-repair' and '-testConnection' parameters must be specified.")
  sys.exit(1)
#endif

#Initialize and validate ressources and mode
mode = None
resources = []
if props["check"]:
  mode = "check"
elif props["repair"]:
  mode = "repair"
#endif
if mode and props[mode] == "all":
  resources = DbUtilityResource.values()
elif mode:
  if props[mode] in AVAILABLE_RESOURCES:
    resource = DbUtilityResource.valueOf(props[mode])
    resources = jarray.array([resource],DbUtilityResource)
  else:
    usage("'" + props[mode] + "' is not a valid argument for the  '-check' and '-repair' parameters. Valid arguments are: 'all','" + "','".join(AVAILABLE_RESOURCES) + "'.")
    sys.exit(1) 
  #endif
#endif

# ---------------------------------------------------------------
# set options for data migration and invoke the DB migration tool
properties = addJDBCDriverForBPEDBToClasspath(scope, props)
options= HashMap()
options.put(DbUtility.SLICE_SIZE, str(props["slice"]))
results = None

try:
  if props["testConnection"]:
    results = DbUtility.testConnection(props["dbUser"], props["dbPassword"], props["dbSchema"], props["className"], properties)
  elif props["check"]:
    results = DbUtility.check(props["dbUser"], props["dbPassword"], props["dbSchema"], props["className"], properties, resources, options)
  elif props["repair"]:
    results = DbUtility.repair(props["dbUser"], props["dbPassword"], props["dbSchema"], props["className"], properties, resources, options)
  #endif
  print 
  print __file__ + " finished with the following results:"
  print "------------------------------------------------------------------------------------"
  print
  if results != None: 
    printDetails(mode,resources,results)
   #endif
except:
  print
  print __file__ + " finished with an exception:"
  print "------------------------------------------------------------------------------------"
  printException()

