#
# Licensed Materials - Property of IBM
# 5655-FLW (C) Copyright IBM Corporation 2006, 2010. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#

import os.path, sys

from java.lang import System

execfile(os.path.join(System.getProperty("was.install.root"), "ProcessChoreographer/config/bpclib.py"))
__file__ = "deleteAuditLog.py"

#*******************************************************************************************************
# print usage and error message, if any
#*******************************************************************************************************
def usage(errmsg = None):
  if errmsg:
    print
    print "ERROR: " + errmsg
  #endif
  print
  print "Usage: wsadmin -f " + __file__
  print "       ( ( [-node <nodeName>] -server <serverName> ) | ( -cluster <clusterName> ) )"
  print "       (-all | -timeUTC <timestamp> | -timeLocal <timestamp> |"
  print "        -processtimeUTC <timestamp> | -processtimeLocal <timestamp>)"
  print "       [-slice <slice size>]"
  print
  print "Delete entries in the audit log table."
  print "With operation 'all', all entries are deleted using 'slices' avoid log overflow."
  print "With operation 'time', only entries before the given time are deleted."
  print "With operation 'processtime', only entries belonging to a process are deleted,"
  print "if this process has finished before the given time."
  print
  print "<timestamp> format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]."
  print "If you specify only the year, month, and day, the hour, minutes, and seconds are set to 00:00:00."
  print "Example timestamp: 2006-11-04T21:57:22"
  print
  print "The default values for the optional parameters are:"
  print "  node:               <local node> (" + localNode + ")"
  print "  slice:              250"
#enddef

#*******************************************************************************************************
# main
#*******************************************************************************************************
localNode = java.lang.System.getProperty ( "local.node" )

if wsadmin.getConnectionStatus() != WsAdmin.CONNECTED:
  usage(__file__ + " must run in connected mode, cannot use the '-conntype NONE' option.")
  sys.exit(1)
#endif

argerr = ""
slice = "250"
operation = None
clusterName = None
serverName = None
nodeName = localNode
time = ""
rows = "0"

argc = len(sys.argv)

i = 0
while ( i < argc ):
  arg = sys.argv[i]
  if (arg == "-node"):
    i = i+1;
    if (i < argc):
      nodeName = sys.argv[i]
    else:
       argerr = "Missing argument for '-node' parameter"
    #endElse
  elif (arg == "-server"):
    i = i+1;
    if (i < argc):
      serverName = sys.argv[i]
    else:
      argerr = "Missing argument for '-server' parameter"
    #endElse
  elif (arg == "-cluster"):
    i = i+1;
    if (i < argc):
      clusterName = sys.argv[i]
    else:
      argerr = "Missing argument for '-cluster' parameter"
    #endElse
  elif (arg == "-all"):
    operation = "all"
  elif (arg == "-time" or arg == "-timeUTC"):
    if (arg == "-time"):
      print "WARNING: As of WPS 7.0, parameter '-time' has been deprecated and replaced by '-timeUTC'."
    i = i+1;
    if (i < argc):
      operation = "time"
      time = normalizeTimeStamp(sys.argv[i], 0, 1)
      if not time:
        argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]."
    else:
      argerr = "Missing argument for '-timeUTC' parameter"
    #endElse
  elif (arg == "-timeLocal"):
    i = i+1;
    if (i < argc):
      operation = "time"
      time = normalizeTimeStamp(sys.argv[i], 1, 1)
      if not time:
        argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]."
    else:
      argerr = "Missing argument for '-timeLocal' parameter"
    #endElse
  elif (arg == "-processtime" or arg == "-processtimeUTC"):
    if (arg == "-processtime"):
      print "WARNING: As of WPS 7.0, parameter '-processtime' has been deprecated and replaced by '-processtimeUTC'."
    i = i+1;
    if (i < argc):
      operation = "processtime"
      processtime = normalizeTimeStamp(sys.argv[i], 0, 1)
      if not processtime:
        argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]."
    else:
      argerr = "Missing argument for '-processtimeUTC' parameter"
    #endElse
  elif (arg == "-processtimeLocal"):
    i = i+1;
    if (i < argc):
      operation = "processtime"
      processtime = normalizeTimeStamp(sys.argv[i], 1, 1)
      if not processtime:
        argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]."
    else:
      argerr = "Missing argument for '-processtimeLocal' parameter"
    #endElse
  elif (arg == "-slice"):
    i = i+1;
    if (i < argc):
      slice = sys.argv[i]
    else:
      argerr = "Missing argument for '-slice' parameter"
    #endElse
  else:
    argerr = "Invalid command line argument: "+arg
    break
  #endElse
  i += 1
#endWhile

if (argerr == ""):
  if ( (serverName != None) + (clusterName != None) != 1 ):
     argerr = "Exactly one of the '-server' and '-cluster' command line options must be specified"
  elif (not operation):
    argerr = "Either 'all', 'time' or 'processtime' must be specified for the 'operation' command line parameter"
  #endif
#endIf

if ( (argerr != "") or (argc==0)  ):
  usage(argerr)
  sys.exit(1)
#endIf

scope = Scope(nodeName = nodeName, serverName = serverName, clusterName = clusterName)

if not scope.isDeploymentTarget():
  usage(str(scope) + " is not a valid deployment target.")
  sys.exit(1)
#endif

if not scope.isBPCDeploymentTarget("RUNTIME|ARCHIVE"):
  usage("Process Choreographer or Archive Manager is not configured on " + str(scope) + ".")
  sys.exit(1)
#endif

bfmMBean = scope.lookupMBean("ProcessContainer")

if not bfmMBean:
  print str(scope) + " is not available -- make sure the server or at least one cluster member is running."
else:
  print
  print "*********************************************************************"
  print "* Note: If there are many audit log entries to be deleted, you may  *"
  print "*       experience a timeout because the server does not finish its *"
  print "*       work before the scripting client expires.                   *"
  print "*       Either choose the script parameters such that the timeout   *"
  print "*       is avoided or increase the scripting client's timeout value *"
  print "*       (see the WebSphere InfoCenter for details).                 *"
  print "*********************************************************************"
  print
  if (operation == "all"):
    print "Deleting all audit log entries using slice: " + slice + "..."
    params = [ operation, "0", slice ]
  elif (operation == "time"):
    print "Deleting audit log entries written before: " + time + "..."
    params = [ operation, time, slice ]
  elif (operation == "processtime"):
    print "Deleting audit log entries of processes finished before: " + processtime + "..."
    params = [ operation, processtime, slice ]
  #endif
  try:
    rows = AdminControl.invoke(bfmMBean, "deleteAuditLog", params )
    # @TODO: That's the only exception type for "catch" that worked. Needs more work to figure out the exception details.
    # except java.lang.Throwable, xcpt:
    #  print xcpt
  except Dummy, xcpt:
    print xcpt
  else:
    print
    print rows + " entries deleted."
#endIf
