#
# Licensed Materials - Property of IBM
# 5655-FLW (C) Copyright IBM Corporation 2009, 2010. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#

import os.path, sys

from java.lang import System

execfile(os.path.join(System.getProperty("was.install.root"), "ProcessChoreographer/config/bpclib.py"))
__file__ = "deleteCompletedTaskInstances.py"

#*******************************************************************************************************
# print usage and error message, if any
#*******************************************************************************************************
def usage(errmsg = None):
  if errmsg:
    print
    print "ERROR: " + errmsg
  #endif
  print
  print "Usage: wsadmin -f " + __file__
  print "       ( ( [-node <nodeName>] -server <serverName> ) | ( -cluster <clusterName> ) )"
  print "       ( -all | [-finished] [-terminated] [-failed] [-expired] )"
  print "       [ ( -templateName <templateName> -nameSpace <nameSpace> [ -validFromUTC <timestamp> ] ) ]"
  print "       [ -completedAfterUTC <timestamp> | -completedAfterLocal <timestamp> ]"
  print "       [ -completedBeforeUTC <timestamp> | -completedBeforeLocal <timestamp> ]"
  print "       [ -createdBy <userID> ]"
  print
  print "Delete completed task instances."
  print
  print "With option '-all', instances in states finished, terminated, failed, or expired are deleted."
  print "With option '-finished', instances in states finished are deleted."
  print "With option '-terminated', instances in state terminated are deleted."
  print "With option '-expired', instances in state expired are deleted."
  print "With option '-failed', instances in state failed are deleted."
  print
  print "The set of to be deleted task instances may be further restricted: "
  print
  print "With parameters '-templateName' and '-nameSpace', only instances that belong to the task template with"
  print "  the specified template name and name space are deleted. In case there are multiple task templates"
  print "  sharing the same name and name space but with different validFrom dates the instances for all"
  print "  task templates with that name are deleted. This may be further restricted by additionally specifying"
  print "  the option '-validFromUTC'."
  print
  print "With parameter '-createdBy', only instances created by the specified user are deleted."
  print "With parameter '-completedAfterUTC' or '-completedAfterLocal', only instances completed after"
  print "the specified timestamp are deleted."
  print "With parameter '-completedBeforeUTC' or '-completedBeforeLocal', only instances completed before"
  print "the specified timestamp are deleted."
  print
  print "<timestamp> format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]."
  print "If you specify only the year, month, and day, the hour, minutes, and seconds are set to 00:00:00. "
  print "You must not omit the hour, minutes, and seconds for parameter '-validFromUTC'."
  print "Example timestamp: 2006-11-04T21:57:22"
  print
  print "The default values for the optional parameters are:"
  print "  node:               <local node> (" + localNode + ")"
#enddef

#*******************************************************************************************************
# main
#*******************************************************************************************************
localNode = System.getProperty ( "local.node" )

if wsadmin.getConnectionStatus() != WsAdmin.CONNECTED:
  usage(__file__ + " must run in connected mode, cannot use the '-conntype NONE' option.")
  sys.exit(1)
#endif

argerr = ""
operation = ""
nodeName  = localNode
serverName = None
clusterName = None
rows = 0
templateName = ""
nameSpace = ""
validFrom = ""
completedAfter = ""
completedBefore = ""
createdBy = ""
states = []
verbose = 0

argc = len(sys.argv)

i = 0
while ( i < argc ):
  arg = sys.argv[i]
  if (arg == "-node"):
    i = i+1;
    if (i < argc):
      nodeName = sys.argv[i]
    else:
      argerr = "Missing argument for '-node' parameter"
    #endElse
  elif (arg == "-server"):
    i = i+1;
    if (i < argc):
      serverName = sys.argv[i]
    else:
      argerr = "Missing argument for '-server' parameter"
    #endElse
  elif (arg == "-cluster"):
    i = i+1;
    if (i < argc):
      clusterName = sys.argv[i]
    else:
      argerr = "Missing argument for '-cluster' parameter"
    #endElse
  elif (arg == "-all" and not "all" in states):
    states .append("all")
  elif (arg == "-finished" and not "finished" in states):
    states.append("finished")
  elif (arg == "-terminated" and not "terminated" in states):
    states.append("terminated")
  elif (arg == "-failed" and not "failed" in states):
    states.append("failed")
  elif (arg == "-expired" and not "expired" in states):
    states.append("expired")
  elif (arg == "-templateName"):
    i = i+1;
    if (i < argc):
      templateName = sys.argv[i]
    else:
       argerr = "Missing argument for '-templateName' parameter"
    #endElse
  elif (arg == "-validFromUTC"):
    i = i+1;
    if (i < argc):
      validFrom = normalizeTimeStamp(sys.argv[i], 0, 0)
      if not validFrom:
        argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>T<HH>:<mm>:<ss>."
    else:
       argerr = "Missing argument for '-validFromUTC' parameter"
    #endElse
  elif (arg == "-nameSpace"):
    i = i+1;
    if (i < argc):
      nameSpace = sys.argv[i]
    else:
      argerr = "Missing argument for '-nameSpace' parameter"
    #endElse
  elif (arg == "-createdBy"):
    i = i+1;
    if (i < argc):
      createdBy = sys.argv[i]
    else:
       argerr = "Missing argument for '-createdBy' parameter"
    #endElse
  elif (arg == "-completedAfterUTC"):
    i = i+1;
    if (i < argc):
      completedAfter = normalizeTimeStamp(sys.argv[i], 0, 1)
      if not completedAfter:
        argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]."
    else:
       argerr = "Missing argument for '-completedAfterUTC' parameter"
    #endElse
  elif (arg == "-completedAfterLocal"):
    i = i+1;
    if (i < argc):
      completedAfter = normalizeTimeStamp(sys.argv[i], 1, 1)
      if not completedAfter:
        argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]."
    else:
       argerr = "Missing argument for '-completedAfterLocal' parameter"
    #endElse
  elif (arg == "-completedBeforeUTC"):
    i = i+1;
    if (i < argc):
      completedBefore = normalizeTimeStamp(sys.argv[i], 0, 1)
      if not completedBefore:
        argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]."
    else:
       argerr = "Missing argument for '-completedBeforeUTC' parameter"
    #endElse
  elif (arg == "-completedBeforeLocal"):
    i = i+1;
    if (i < argc):
      completedBefore = normalizeTimeStamp(sys.argv[i], 1, 1)
      if not completedBefore:
        argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]."
    else:
       argerr = "Missing argument for '-completedBeforeLocal' parameter"
    #endElse
  elif (arg == "-verbose"):
    verbose = 1
  else:
    argerr = "Invalid command line argument: "+arg
    break
  #endElse
  i += 1
#endWhile

if (argerr == ""):
  if ( (serverName != None) + (clusterName != None) != 1 ):
     argerr = "Exactly one of the '-server' and '-cluster' command line options must be specified"
  elif ( (len(templateName)>0) + (len(nameSpace)>0) == 1 ):
     argerr = "Either both or none of the '-templateName' and '-nameSpace' command line options must be specified"
  elif ( len(validFrom) > 0 and len(templateName) == 0 ):
     argerr = "The '-templateName' command line option must be specified if '-validFromUTC' is specified"
  elif (not states) or ("all" in states and len(states) > 1):
    argerr = "Either '-all'; or at least one of '-finished', '-terminated', 'expired', or '-failed' must be specified"
  #endIf
#endIf

if ( (argerr != "") or (argc==0)  ):
  usage(argerr)
  sys.exit(1)
#endIf

if nameSpace and not isValidNameSpace(nameSpace):
  usage("Value '" + str(nameSpace) + "' specfied for command line option '-nameSpace' is not a valid namespace identifier.")
  sys.exit(1)
#endif

scope = Scope(nodeName = nodeName, serverName = serverName, clusterName = clusterName)

if not scope.isDeploymentTarget():
  usage(str(scope) + " is not a valid deployment target.")
  sys.exit(1)
#endif

if not scope.isBPCDeploymentTarget("RUNTIME|ARCHIVE"):
  usage("Process Choreographer or Archive Manager is not configured on " + str(scope) + ".")
  sys.exit(1)
#endif

htmMBean = scope.lookupMBean("TaskManager")

if not htmMBean:
  print str(scope) + " is not available -- make sure the server or at least one cluster member is running."
else:
  print
  print "*********************************************************************"
  print "* Note: If there are many task instances to be deleted, you may     *"
  print "*       experience a timeout because the server does not finish its *"
  print "*       work before the scripting client expires.                   *"
  print "*       Either choose the script parameters such that the timeout   *"
  print "*       is avoided or increase the scripting client's timeout value *"
  print "*       (see the WebSphere InfoCenter for details).                 *"
  print "*********************************************************************"
  if (verbose):
    print
    if "all" in states:
      print "Deleting instances in states finished, terminated, expired, failed."
    else:
      print "Deleting instances in states " + ", ".join(states) + "."
    #endElse
    if (templateName != ""):
      print "Only deleting instances with template name: '" + templateName + "'."
    if (validFrom != ""):
      print "Only deleting instances with validFrom: '" + validFrom + "'."
    if (createdBy != ""):
      print "Only deleting instances created by user: '" + createdBy + "'."
    if (completedAfter != ""):
      print "Only deleting instances completed after: '" + completedAfter + "'."
    if (completedBefore != ""):
      print "Only deleting instances completed before: '" + completedBefore + "'."
    print
  #endIf

  if "all" in states:
    states = []; # must not pass 'None' to MBean invocation
  #endIf
  params = [ states, templateName, nameSpace, validFrom, completedAfter, completedBefore, createdBy ]
  if (verbose):
    print "Invoking MBean method 'deleteCompletedTaskInstances' using parameters: " + str(params) + "."
  try:
    rows = AdminControl.invoke(htmMBean, "deleteCompletedTaskInstances", params)
    # @TODO: That's the only exception type for "catch" that worked. Needs more work to figure out the exception details.
    # except java.lang.Throwable, xcpt:
    #  print xcpt
  except Dummy, xcpt:
    print xcpt
  else:
    print
    print "Instances deleted:", rows
#endIf
