#
# Licensed Materials - Property of IBM
# 5655-FLW (C) Copyright IBM Corporation 2006, 2010. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#

import os.path, sys

from java.lang import System

execfile(os.path.join(System.getProperty("was.install.root"), "ProcessChoreographer/config/bpclib.py"))
__file__ = "deleteInvalidTaskTemplate.py"

#*******************************************************************************************************
# print usage and error message, if any
#*******************************************************************************************************
def usage(errmsg = None):
  if errmsg:
    print
    print "ERROR: " + errmsg
  #endif
  print
  print "Usage: wsadmin -f " + __file__
  print "       ( ( [-node <nodeName>] -server <serverName> ) | ( -cluster <clusterName> ) )"
  print "       -templateName <templateName> -nameSpace <nameSpace> -validFromUTC <timestamp>"
  print
  print "Delete task template without corresponding enterprise application"
  print "on server <serverName> on node <nodeName> or of cluster <clusterName>. "
  print
  print "<timestamp> format must be <yyyy>-<MM>-<dd>T<HH>:<mm>:<ss>."
  print "Example timestamp: 2006-11-04T21:57:22"
  print
  print "The default values for the optional parameters are:"
  print "  node:               <local node> (" + localNode + ")"
#enddef

#*******************************************************************************************************
# main
#*******************************************************************************************************
localNode = java.lang.System.getProperty ( "local.node" )

if wsadmin.getConnectionStatus() != WsAdmin.CONNECTED:
  usage(__file__ + " must run in connected mode, cannot use the '-conntype NONE' option.")
  sys.exit(1)
#endif

argerr      = ""
templateName = ""
validFrom   = ""
nameSpace   = ""
nodeName = localNode
clusterName = None
serverName  = None

argc = len(sys.argv)

i = 0
while ( i < argc ):  #forTest
  arg = sys.argv[i]
  if (arg == "-node"):
    i = i+1;
    if (i < argc):
      nodeName = sys.argv[i]
    else:
      argerr = "Missing argument for '-node' parameter"
    #endElse
  elif (arg == "-server"):
    i = i+1;
    if (i < argc):
      serverName = sys.argv[i]
    else:
       argerr = "Missing argument for '-server' parameter"
    #endElse
  elif (arg == "-cluster"):
    i = i+1;
    if (i < argc):
      clusterName = sys.argv[i]
    else:
       argerr = "Missing argument for '-cluster' parameter"
    #endElse
  elif (arg == "-templateName"):
    i = i+1;
    if (i < argc):
      templateName = sys.argv[i]
    else:
      argerr = "Missing argument for '-templateName' parameter"
    #endElse
  elif (arg == "-validFrom" or arg == "-validFromUTC"):
    if (arg == "-validFrom"):
      print "WARNING: As of WPS 7.0, parameter '-validFrom' has been deprecated and replaced by '-validFromUTC'."
    i = i+1;
    if (i < argc):
      validFrom = normalizeTimeStamp(sys.argv[i], 0, 0)
      if not validFrom:
        argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>T<HH>:<mm>:<ss>."
    else:
       argerr = "Missing argument for '-validFromUTC' parameter"
    #endElse
  elif (arg == "-nameSpace"):
    i = i+1;
    if (i < argc):
      nameSpace = sys.argv[i]
    else:
      argerr = "Missing argument for '-nameSpace' parameter"
    #endElse
  else:
    argerr = "Invalid command line argument: "+arg
    break
  #endElse
  i += 1
#endWhile

if (argerr == ""):
  if ( (serverName != None) + (clusterName != None) != 1 ):
     argerr = "Exactly one of the '-server' and '-cluster' command line options must be specified"
  elif (templateName=="" or validFrom=="" or nameSpace==""):
    argerr="All of the '-templateName', '-validFromUTC', and '-nameSpace' command line options must be specified"
  #endif
#endIf

if ( (argerr != "") or (argc==0)  ):
  usage(argerr)
  sys.exit(1)
#endIf

if nameSpace and not isValidNameSpace(nameSpace):
  usage("Value '" + str(nameSpace) + "' specfied for command line option '-nameSpace' is not a valid namespace identifier.")
  sys.exit(1)
#endif

scope = Scope(nodeName = nodeName, serverName = serverName, clusterName = clusterName)

if not scope.isDeploymentTarget():
  usage( str(scope) + " is not a valid deployment target.")
  sys.exit(1)
#endif

if not scope.isBPCDeploymentTarget():
  usage("Process Choreographer is not configured on " + str(scope) + ".")
  sys.exit(1)
#endif

htmMBeans = scope.lookupMBean("TaskManager", 1)

if not htmMBeans:
  print str(scope) + " is not available -- make sure the server or at least one cluster member is running."
else:
  print "Removing invalid task template " + templateName + ", valid from " + validFrom + ", namespace " + nameSpace + "..."
  for htmMBean in htmMBeans:
    AdminControl.invoke(htmMBean, "deleteInvalidTaskTemplate", [ templateName, validFrom, nameSpace ] )
  print "Done."
#endElse
