#
# Licensed Materials - Property of IBM
# 5655-FLW (C) Copyright IBM Corporation 2008, 2010. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#

import os.path, sys
import traceback
import exceptions
import jarray
import java.io.File as File;
from java.lang import *;
from java.io import *
import javax.management as mgmt

execfile(os.path.join(System.getProperty("was.install.root"), "ProcessChoreographer/config/bpclib.py"))
__file__ = "manageQueryTable.py"

#*******************************************************************************************************
# print usage and error message, if any
#*******************************************************************************************************
def usage(errmsg = None):
  if errmsg:
    print
    print "ERROR: " + errmsg
  #endif
  print "Usage: wsadmin -f " + __file__
  print "       [ ([-node <nodeName>] -server <serverName>) | (-cluster <clusterName>) ]"
  print "       ( ( -deploy <qtd file>|<jar file>) |"
  print "         ( -undeploy <query table name>)  |"
  print "         ( -update definition <qtd file>|<jar file>) |"
  print "         ( -query names -kind composite|predefined|supplemental) |"
  print "         ( -query definition -name <query table name>))"
  print
  print "Manage query tables. This script must be run in connected mode, that is, "
  print "the application server or at least one cluster member and the deployment"
  print "manager must be running."
  print
  print "The '-deploy' and '-update' parameters denote the fully qualified path "
  print "to the query table definfition file or a jar file which contains the definitions. "
  print "On Windows either '/' or '\\\\' must be used (e.g. c:/temp/myQueryTable.qtd' "
  print "or 'c:\\\\temp\\\\myQueryTable.qtd') as path separator."
  print
  print "The '-node', '-server', and '-cluster' parameters denote the Business Process "
  print "Choreographer configuration to work with."
  print
  print "The default values for the optional parameters are:"
  print "  node:               <local node> ("+localNode+")"
  print
#enddef

#*******************************************************************************************************
# @EF remove need for this: make a string in double qoutes
#*******************************************************************************************************
def enquote(_inStr):
  inStr = _inStr
  if not inStr:
    inStr = '"null"'
  elif inStr == "":
    inStr = '""'
  else:
    if inStr[0] != '"': inStr = '"' + inStr
    if inStr[-1] != '"': inStr = inStr + '"'
  return inStr
#enddef

#*******************************************************************************************************
# main
#*******************************************************************************************************
localNode = java.lang.System.getProperty ( "local.node" )
localCell = java.lang.System.getProperty ( "local.cell" )
nodeName  = localNode

# ----------------------------------------------------
# make sure the script is running in disconnected mode
if wsadmin.getConnectionStatus() == WsAdmin.DISCONNECTED:
  usage( __file__ + " cannot be run in disconnected mode, re-run without using the '-conntype NONE' option.")

if wsadmin.getConnectionStatus() != WsAdmin.CONNECTED: # disconnected or error -> exit
  sys.exit(1)

# Parse command line

argerr          = ""
clusterName     = ""
serverName      = ""
operation       = ""
updateType      = ""
queryType       = ""
queryTableFile  = None
queryTableDepDesc = None
queryTableType  = None
queryTableTablespace = None
queryTableUpdateInterval = None
queryTableManageArtifacts = None
queryTableName = None
queryTableParam = None
queryKind = None

argc = len(sys.argv)

i = 0
while ( i < argc ):
  arg = sys.argv[i]
  if (arg == "-node"):
    i = i+1;
    if (i < argc):
      nodeName = sys.argv[i]
    else:
      argerr = "Error: Missing argument for '-node' parameter"
    #endElse
  elif (arg == "-server"):
    i = i+1;
    if (i < argc):
      serverName = sys.argv[i]
    else:
      argerr = "Error: Missing argument for '-server' parameter"
    #endElse
  elif (arg == "-cluster"):
    i = i+1;
    if (i < argc):
      clusterName = sys.argv[i]
    else:
      argerr = "Error: Missing argument for '-cluster' parameter"
    #endElse
  elif (arg == "-deploy"):
    i = i+1;
    operation = "deploy"
    if (i < argc):
      queryTableFile = sys.argv[i]
    else:
      argerr = "Error: Missing argument for '-deploy' parameter"
    #endElse
  elif (arg == "-undeploy"):
    i = i+1;
    operation = "undeploy"
    if (i < argc):
      queryTableName = sys.argv[i]
    else:
      argerr = "Error: Missing argument for '-undeploy' parameter"
    #endElse
  elif (arg == "-update"):
    i = i+1;
    operation = "update"
    if (i < argc):
      updateType = sys.argv[i]
    else:
      argerr = "Error: Missing argument for '-update' parameter"
    #endElse
    i = i+1;
    if (i < argc):
      queryTableFile = sys.argv[i]
    else:
      argerr = "Error: Missing argument for '-update' parameter"
    #endElse
  elif (arg == "-query"):
    i = i+1;
    operation = "query"
    if (i < argc):
      queryType = sys.argv[i]
    else:
      argerr = "Error: Missing argument for '-query' parameter"
    #endElse
  elif (arg == "-kind"):
    i = i+1;
    if (i < argc):
      queryKind = sys.argv[i]
    else:
      argerr = "Error: Missing argument for '-kind' parameter"
    #endElse
  elif (arg == "-name"):
    i = i+1;
    if (i < argc):
      queryTableName = sys.argv[i]
    else:
      argerr = "Error: Missing argument for '-name' parameter"
    #endElse
  elif (arg.find(__file__)>-1) or arg=="ARGO":   # when debugging, we get also the filename as arg or somehow the word ARGO
    pass;
  else:
    argerr = "Error: Invalid command line argument: "+arg
    ## leave loop, otherwise arg value will be read ....
    break
  #endElse
  i += 1  #forNext
#endWhile  (#endFor)

if(operation == ""):
  argerr="Error: Exactly one of the '-deploy', -'undeploy', '-update' and '-query' command line options must be specified"

if (operation == "query" and queryType == "names" and queryKind == None):
  argerr="Error: The '-kind' command line option must be specified"

if (operation == "query" and queryType == "definition" and queryTableName == None):
  argerr="Error: The '-name' command line option must be specified"

if (argerr == ""):

  if ( (len(serverName)>0) + (len(clusterName)>0) != 1 ):
    argerr="Error: Exactly one of the '-server' and '-cluster' command line options must be specified"
  #endIf
#endIf

if ( argerr != "" ):
  usage(argerr)
  sys.exit(1)
#endIf

scope = Scope(nodeName = nodeName, serverName = serverName, clusterName = clusterName)

if not scope.isDeploymentTarget():
  usage( str(scope) + " is not a valid deployment target.")
  sys.exit(1)
#endif

if not scope.isBPCDeploymentTarget("RUNTIME|ARCHIVE"):
  usage("Process Choreographer or Archive Manager is not configured on " + str(scope) + ".")
  sys.exit(1)
#endif

mbean = scope.lookupMBean("InternalProcessContainer")

if not mbean:
  print str(scope) + " is not available -- make sure the server or at least one cluster member is running."
else:
  print
  try:
    if (operation == "deploy"):
      print "Deploying query table "+ queryTableFile + "."
      if (queryTableFile.endswith(".qtd")):
        file = open(queryTableFile, "r")
        qtd = file.read()
        file.close()
        params = [qtd, queryTableDepDesc, queryTableType, queryTableTablespace, queryTableUpdateInterval, queryTableManageArtifacts]
        signature = ['java.lang.String','java.lang.String','java.lang.String','java.lang.String','java.lang.String','java.lang.Boolean']
        AdminControl.invoke_jmx(mgmt.ObjectName(mbean), "deployQueryTable", params, signature)
      elif (queryTableFile.endswith(".jar")):
        jar=java.io.File(queryTableFile)
        jarFis=java.io.FileInputStream(jar)
        fileAsBlob=jarray.zeros(jar.length(),'b')
        # to create a BLOB, we need a java array
        jarFis.read(fileAsBlob)
        jarFis.close()
        params = jarray.array([fileAsBlob],java.lang.Object)
        signature = ['[B']
        AdminControl.invoke_jmx(mgmt.ObjectName(mbean), "deployQueryTable", params, signature)
      else:
        usage("Error: File extension must be either '.xml' or '.jar'")
        sys.exit(1)
      #endIf
      print "Query table " + queryTableFile + " deployed successfully."
    elif (operation == "undeploy"):
      print "Undeploying query table " + queryTableName + "."
      params = "["+enquote(queryTableName) + " " + enquote(queryTableManageArtifacts) + "]"
      AdminControl.invoke(mbean, "undeployQueryTable", params)
      print "Query table " + queryTableName + " undeployed successfully."
    elif (operation == "update"):
      print "Updating query table " + queryTableFile + "."
      if (queryTableFile.endswith(".qtd")):
        file = open(queryTableFile, "r")
        qtd = file.read()
        file.close()
        params = [queryTableParam, qtd, queryTableDepDesc, queryTableName, queryTableType, queryTableTablespace, queryTableUpdateInterval, queryTableManageArtifacts]
        signature = ['java.lang.String', 'java.lang.String','java.lang.String','java.lang.String','java.lang.String','java.lang.String','java.lang.String','java.lang.Boolean']
        AdminControl.invoke_jmx(mgmt.ObjectName(mbean), "updateQueryTable", params, signature)
      elif (queryTableFile.endswith(".jar")):
        jar=java.io.File(queryTableFile)
        jarFis=java.io.FileInputStream(jar)
        fileAsBlob=jarray.zeros(jar.length(),'b')
        # to create a BLOB, we need a java array
        jarFis.read(fileAsBlob)
        jarFis.close()
        params = jarray.array([fileAsBlob],java.lang.Object)
        signature = ['[B']
        AdminControl.invoke_jmx(mgmt.ObjectName(mbean), "updateQueryTable", params, signature)
      else:
        usage("Error: File extension must be either '.xml' or '.jar'")
        sys.exit(1)
      #endIf
      print "Query table " + queryTableFile + " updated successfully."
    elif (operation == "query" and queryType == "names"):
      print "Listing all query tables with kind " + queryKind + "."
      params = "["+enquote(queryKind) + "]"
      result = AdminControl.invoke(mbean, "queryQueryTableNames", params)
      if (len(result) == 0):
        result = "<none>"
      print "Result: " + result
    elif (operation == "query" and queryType == "definition"):
      print "Definition for query table "+ queryTableName +" ."
      params = "["+enquote(queryTableName) + "]"
      result = AdminControl.invoke(mbean, "queryQueryTableDefinition", params)
      if (len(result) == 0):
          result = "<none>"
      print "Result:"
      print result
  except:
    print
    print "***** An error occured during " + operation + " *******"
    print
    raise
 #endIf

