#
# Licensed Materials - Property of IBM
# 5655-FLW (C) Copyright IBM Corporation 2009, 2010. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#

import os.path, sys
import traceback
import exceptions
import jarray
import java.io.File as File;
from java.lang import *;
from java.io import *
import javax.management as mgmt

execfile(os.path.join(System.getProperty("was.install.root"), "ProcessChoreographer/config/bpclib.py"))
__file__ = "migrateProcessInstances.py"

#*******************************************************************************************************
# globals
#*******************************************************************************************************
MIN_SLICE = 1
MAX_SLICE = 500
DEFAULT_SLICE = 10

localNode = System.getProperty("local.node")
sourceValidFrom = None
targetValidFrom = None

#*******************************************************************************************************
# print usage and error message, if any
#*******************************************************************************************************
def usage(errmsg = None):
  if errmsg:
    print
    print errmsg
    print
  #endif
  print "Usage: wsadmin -f migrateProcessInstances.py "
  print "       [ ([-node <nodeName>] -server <serverName>) | (-cluster <clusterName>) ]"
  print "       -templateName <templateName>"
  print "       -sourceValidFromUTC <timestamp>"
  print "       [ -targetValidFromUTC <timestamp> ]"
  print "       [ -slice <slice size> ]"
  print " "
  print "All process instances of the specified process template which are not in one of the states "
  print "finished, terminated or failed are migrated to the new version. The results are logged to the"
  print "SystemOut.log. Instances that cannot be migrated because they are in a wrong state or where"
  print "problems occured during migration are logged as well. "
  print " "
  print "The '-node', '-server', and '-cluster' parameters denote the Business Process "
  print "Choreographer configuration to work with. Specify the deployment target where Business Process "
  print "Choreographer is configured. The server or at least one cluster member must be running."
  print " "
  print "The '-templateName' parameter specifies the name of the process template to be migrated.  "
  print " "
  print "The '-sourceValidFromUTC' parameter specifies which version of the named template will have its "
  print "instances migrated. "
  print " "
  print "The '-targetValidFromUTC' parameter optionally specifies which version of the named process template "
  print "the instances will be migrated to. If this parameter is not specified, the latest available version "
  print "of the template will be used "
  print " "
  print "<timestamp> format must be <yyyy>-<MM>-<dd>T<HH>:<mm>:<ss>."
  print "Example timestamp: 2009-11-04T21:57:22"
  print " "
  print "The optional -slice parameter can be used to overwrite the default transaction slice size (" + str(DEFAULT_SLICE) + "). "
  print "The -slice parameter must be in the range from " + str(MIN_SLICE) + " to " + str(MAX_SLICE) + "."
  print " "
  print "The default values for the optional parameters are:"
  print "  node:               <local node> (" + localNode + ")"
  print "  slice:             " + str(DEFAULT_SLICE)
  print " "
#enddef

#*******************************************************************************************************
# main
#*******************************************************************************************************

# ----------------------------------------------------
# make sure the script is running in connected mode
if wsadmin.getConnectionStatus() == WsAdmin.DISCONNECTED:
  usage(__file__ + " cannot be run in disconnected mode, re-run without using the '-conntype NONE' option.")

if wsadmin.getConnectionStatus() != WsAdmin.CONNECTED: # disconnected or error -> exit
  sys.exit(1)

# ----------------------
# parse the command line
props = {}
props.update({ "node": localNode, "server": "", "cluster": "" })
props.update({ "slice": str(DEFAULT_SLICE), "templateName": "", "sourceValidFromUTC": "", "targetValidFromUTC": "" })
try:
  props = wsadmin.parse(sys.argv, props)
except ValueError, error:
  usage(str(error))
  sys.exit(1)
#endtry

# -----------------------------
# check command line parameters
if not props["server"] and not props["cluster"]:
  usage("One of the '-server' and '-cluster' parameters must be specified.")
  sys.exit(1)
#endif

# ------------------------------------------------------------
# validate the 'slice' value
sliceError = validateIntValue(props, "slice", MIN_SLICE, MAX_SLICE)
if sliceError:
  usage(sliceError)
  sys.exit(0)
#endif

if not props["templateName"]:
  usage("The '-templateName' parameter must be specified.")
  sys.exit(1)
#endif

if not props["sourceValidFromUTC"]:
  usage("The '-sourceValidFromUTC' parameter must be specified.")
  sys.exit(1)
else:
  sourceValidFrom = normalizeTimeStamp(props["sourceValidFromUTC"], 0, 0)
  if not sourceValidFrom:
    usage("Invalid timestamp '" + props["sourceValidFromUTC"] + "', format must be <yyyy>-<MM>-<dd>T<HH>:<mm>:<ss>.")
    sys.exit(1)
  #endif
#endif

if props["targetValidFromUTC"]:
  targetValidFrom = normalizeTimeStamp(props["targetValidFromUTC"], 0, 0)
  if not targetValidFrom:
    usage("Invalid timestamp '" + props["targetValidFromUTC"] + "', format must be <yyyy>-<MM>-<dd>T<HH>:<mm>:<ss>.")
    sys.exit(1)
  #endif
#endif

# -----------------------------------------------
# check if the scope is a valid deployment target
scope = Scope(nodeName = props["node"], serverName = props["server"], clusterName = props["cluster"])
if scope.convertToCluster():
  print "Warning: '" + props["server"] + "' is a member of cluster '" + scope.clusterName + "', adjusting scope to cluster."
#endif

if not scope.isDeploymentTarget():
  usage(str(scope) + " is not a valid deployment target.")
  sys.exit(1)
#endif

if not scope.isBPCDeploymentTarget():
  usage("Process Choreographer is not configured on " + str(scope) + ".")
  sys.exit(1)
#endif

mbean = scope.lookupMBean("ProcessContainer")

if not mbean:
  print str(scope) + " is not available -- make sure the server or at least one cluster member is running."
else:
  server =  mgmt.ObjectName(mbean).getKeyProperty("process")
  node = mgmt.ObjectName(mbean).getKeyProperty("node")
  print ""
  try:
    params = [props["templateName"],sourceValidFrom,targetValidFrom, props["slice"]]
    signature = ['java.lang.String','java.lang.String','java.lang.String','java.lang.Integer']
    AdminControl.invoke_jmx(mgmt.ObjectName(mbean), "migrateProcessInstances", params, signature)
    print ""
    print "The process instance migration is running on server '"+ server +"' on node '" + node +"'."
    print "Please check the log files of the server to get information about the progress "
    print "and results of the migration."
    print ""
  except:
    print ""
    print "***** An error occured during instance migration *******"
    print ""
    raise
 #endIf

