#
# Licensed Materials - Property of IBM
# 5655-FLW (C) Copyright IBM Corporation 2010. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#

import os.path, sys

from java.lang import Integer, Long, System
# only classes from plugins/*runtime*.jar and plugins/*admin*.jar are visible to Jython in WAS 7
from com.ibm.bpe.database.migration import WIMigrationTool, WIMigrationOptions
from com.ibm.bpe.database import SharedWorkItemMode

execfile(os.path.join(System.getProperty("was.install.root"), "ProcessChoreographer/config/bpclib.py"))
__file__ = "migrateWI.py"

#*******************************************************************************************************
# globals
#*******************************************************************************************************
MIN_SLICE = 10
MAX_SLICE = 50000
DEFAULT_SLICE = 50

MIN_DURATION = 0
MAX_DURATION = 34560 # limit to 24 days because of: OverflowError: integer multiplication: 60000 * 35792
DEFAULT_DURATION = 1

#*******************************************************************************************************
# print usage and error message, if any
#*******************************************************************************************************
def usage(errmsg = None):
  if errmsg:
    print
    print "ERROR: " + errmsg
  #endif
  print
  print "Usage: wsadmin -conntype NONE -f " + __file__
  print "       (-server <serverName> | -cluster <clusterName>)"
  print "       [-dbUser <userID>] -dbPassword <password> [-dbSchema <schema>]"
  print "       -migrateToWISharing [-slice <slice>] [-duration <minutes>]"
  print
  print "Usage: wsadmin -conntype NONE -f " + __file__
  print "       (-server <serverName> | -cluster <clusterName>)"
  print "       [-dbUser <userID>] -dbPassword <password> [-dbSchema <schema>]"
  print "       -setMode WS_SHARING_ACTIVE_MODE [-suppressWarning]"
  print
  print "Usage: wsadmin -conntype NONE -f " + __file__
  print "       (-server <serverName> | -cluster <clusterName>)"
  print "       [-dbUser <userID>] -dbPassword <password> [-dbSchema <schema>]"
  print "       -getMode"
  print
  print "Migrates the work items in a Business Process Choreographer database to shared work items."
  print "This script must be run in disconnected mode. When setting the mode the application server or"
  print "cluster members must not be running."
  print
  print "Note that this script must be run on the node of the server (when '-server' was specified) or"
  print "on the node of a cluster member (when '-cluster' was specified). That is, it cannot be run on"
  print "the deployment manager node in a network deployment (ND) environment."
  print
  print "The '-server' and '-cluster' parameters denote the Business Process Choreographer"
  print "  configuration for which to migrate the database or the work items."
  print "The '-dbUser' and '-dbPassword' parameters are used to authenticate with the database."
  print "The optional '-dbSchema' parameter can be used to overwrite an implicit schema qualifier."
  print "  Do not use this parameter if an explicit schema qualifier has been configured."
  print "The optional '-slice' parameter can be used to overwrite the default transaction slice size (" + str(DEFAULT_SLICE) + ")."
  print "  Its value must be between " + str(MIN_SLICE) + " and " + str(MAX_SLICE) + "."
  print "The '-migrateToWISharing' parameter indicates that work items are to be migrated."
  print "The optional '-duration' parameter allows to specify after which time to stop migrating work items."
  print "  It defaults to " + str(DEFAULT_DURATION) + " minute. To run the script without limiting the duration"
  print "  set this parameter to 0. Its value must be between " + str(MIN_DURATION) + " and " + str(MAX_DURATION) + " minutes."
  print "The '-setMode WS_SHARING_ACTIVE_MODE' parameter indicates that work item migration has finished"
  print "  and work item sharing mode should be entered now."
  print "The optional '-suppressWarning' parameter suppresses the prompt warning you that the server or all"
  print "  cluster members must be stopped when calling '-setMode'."
  print "The '-getMode' parameter can be used to query the currently active work item mode."
#enddef

#*******************************************************************************************************
# format the WI migration results
#*******************************************************************************************************
def printDetails(result):
  SUM_KEY = "Total"
  itemsUnprocessed = { SUM_KEY: 0 }
  itemsProcessed = { SUM_KEY: 0 }
  itemsTotal = { SUM_KEY: 0 }
  percentageCompleted = { }
  resultTweaked = 0
  keys = [key for key in result.getCountTotalAtEnd().keySet()]
  keywidth = reduce(lambda maxlen, len: max(maxlen, len), map(lambda key: len(key), keys), 0) # get length of longest key
  print
  print "Work item migration ran for %ds:" % ((result.getEndMillis() - result.getStartMillis()) / 1000)
  print
  print "%*s Entities  Migrated Not migrated  Completed" % (keywidth, "")
  for key in keys + [SUM_KEY]:
    if key.endswith("B"): dkey = key[:-1] # strip trailing "B" for some keys like "EventInstanceB"
    else: dkey = key
    if key != SUM_KEY:
      itemsUnprocessed[dkey] = result.getCountNonMigratedAtEnd().get(key) # The number of entities with non-shared work items that still have to be processed
      itemsUnprocessed[SUM_KEY] += itemsUnprocessed[dkey]
      itemsTotal[dkey] = result.getCountTotalAtEnd().get(key) # The total number of entities in the system.
      if itemsTotal[dkey] < itemsUnprocessed[dkey]:
        itemsTotal[dkey] = itemsUnprocessed[dkey]
        resultTweaked = 1
      #endif
      itemsTotal[SUM_KEY] += itemsTotal[dkey]
    #endif
    itemsProcessed[dkey] = itemsTotal[dkey] - itemsUnprocessed[dkey]
    if itemsTotal[dkey] == 0: percentageCompleted[dkey] = 100
    else: percentageCompleted[dkey] = (itemsTotal[dkey] - itemsUnprocessed[dkey]) / float(itemsTotal[dkey]) * 100 # divide first to help avoid overflows
    if key == SUM_KEY:
      print "-------------------------------------------------------------"
    print "%s %*s %7d %9d %12d %9d%%" % (dkey, keywidth - len(dkey), "", itemsTotal[dkey], itemsProcessed[dkey], itemsUnprocessed[dkey], percentageCompleted[dkey])
  #endfor
  print
  if resultTweaked:
    print "Note: Work item migration has detected that entities were created, or deleted while it was running."
    print "      To get more precise figures re-run the migration script with the '-getMode' parameter."
    print
  #endif
#enddef

#*******************************************************************************************************
# main
#*******************************************************************************************************

# ----------------------------------------------------
# make sure the script is running in disconnected mode
if wsadmin.getConnectionStatus() == WsAdmin.CONNECTED:
  usage(__file__ + " cannot be run in connected mode, re-run using the '-conntype NONE' option.")

if wsadmin.getConnectionStatus() != WsAdmin.DISCONNECTED: # connected or error -> exit
  sys.exit(1)

# ----------------------
# parse the command line
props = {}
props.update({ "server": "", "cluster": "", "dbUser": "", "dbPassword": "", "dbSchema": "", "dbDesign": "" })
props.update({ "slice": DEFAULT_SLICE, "duration": DEFAULT_DURATION })
props.update({ "migrateToWISharing": None, "setMode": "", "getMode": None, "suppressWarning": None })
try:
  props = wsadmin.parse(sys.argv, props)
  props["node"] = System.getProperty("local.node")
except ValueError, error:
  usage(str(error))
  sys.exit(1)
#endtry

# -----------------------------
# check command line parameters
if not props["server"] and not props["cluster"]:
  usage("One of the '-server' and '-cluster' parameters must be specified.")
  sys.exit(1)
#endif

if props["server"] and props["cluster"]:
  usage("Only one of the '-server' and '-cluster' parameters must be specified.")
  sys.exit(1)
#endif

# ------------------------------------------------------------
# validate the 'slice' value
intError = validateIntValue(props, "slice", MIN_SLICE, MAX_SLICE)
if intError:
  usage(intError)
  sys.exit(0)
#endif

# ------------------------------------------------------------
# validate the 'duration' value
intError = validateIntValue(props, "duration", MIN_DURATION, MAX_DURATION)
if intError:
  usage(intError)
  sys.exit(0)
#endif

# ------------------------------------------------------------
# validate the 'setMode' value
if props["setMode"] and props["setMode"] != "WS_SHARING_ACTIVE_MODE" and props["setMode"] != SharedWorkItemMode.MigrationMode.getDisplayName() :
  usage("Value '" + props["setMode"] + "' is not valid for parameter '-setMode'")
  sys.exit(0)
#endif

if props["setMode"] and props["migrateToWISharing"]:
  usage("Only one of the '-migrateToWISharing' and '-setMode' parameters must be specified.")
  sys.exit(1)
#endif

if props["setMode"] and props["getMode"]:
  usage("Only one of the '-getMode' and '-setMode' parameters must be specified.")
  sys.exit(1)
#endif

# ------------------------------------------------------------
# validate the 'getMode' value
if props["getMode"] and props["migrateToWISharing"]:
  usage("Only one of the '-migrateToWISharing' and '-getMode' parameters must be specified.")
  sys.exit(1)
#endif

if props["dbSchema"] and props["dbDesign"]:
  usage("Only one of the '-dbSchema' and '-dbDesign' parameters must be specified.")
  sys.exit(1)
#endif

if props["dbDesign"]:
  props["dbDesign"] = os.path.normpath(props["dbDesign"])
  if not os.path.isfile(props["dbDesign"]):
    usage("Database design file '" + props["dbDesign"] + "' does not exist.")
    sys.exit(1)
  #endif
#endif

# -----------------------------------------------
# check if the scope is a valid deployment target
scope = Scope(nodeName = props["node"], serverName = props["server"], clusterName = props["cluster"])
if scope.convertToCluster():
  print "Warning: '" + props["server"] + "' is a member of cluster '" + scope.clusterName + "', adjusting scope to cluster."
#endif

if not scope.isDeploymentTarget():
  usage(str(scope) + " is not a valid deployment target.")
  sys.exit(1)
#endif

if not scope.isBPCDeploymentTarget("RUNTIME"):
  usage("Process Choreographer is not configured on " + scope.displayName() +"." )
  sys.exit(1)
#endif

if scope.getCluster():
  foundMemberOnLocalNode = 0
  for member in wsadminToList(scope.list("ClusterMember")):
    if AdminConfig.showAttribute(member, "nodeName") == props["node"]:
      foundMemberOnLocalNode = 1
      break
    #endif
  #endfor
  if not foundMemberOnLocalNode:
    usage("No member of cluster " + props["cluster"] + " is defined on local node " + props["node"] + ".")
    sys.exit(1)
  #endif
#endif

if props["setMode"] and not props["suppressWarning"]:
  if scope.getCluster():
    print "Caution: All members of " + scope.displayName() + " must be stopped when switching to " + props["setMode"] + " to avoid database inconsistencies."
  else:
    print "Caution: " + scope.displayName() + " must be stopped when switching to " + props["setMode"] + " to avoid database inconsistencies."
  answer = raw_input("Continue [No/yes]? ")
  print "==> " + answer
  if answer.lower() != "yes":
    print "Aborting..."
    sys.exit(1)
  #endif
#endif

# ---------------------------------------------------------------
# set options for work item migration and invoke the migration tool
properties = addJDBCDriverForBPEDBToClasspath(scope, props)
options = WIMigrationOptions()
options.setSliceSize(Integer(props["slice"]))
options.setLimit(Integer(sys.maxint)) # hard-coded for the time being, not (yet) exposed externally
options.setTimeout(Long(props["duration"] * 60000)) # convert min to ms
if props["getMode"]:
  options.setMigrationMode(WIMigrationOptions.WIMigrationMode.GET_MODE)
elif props["setMode"] == "WS_SHARING_ACTIVE_MODE":
  options.setMigrationMode(WIMigrationOptions.WIMigrationMode.SWITCH_TO_SHARING_MODE)
elif props["setMode"] == SharedWorkItemMode.MigrationMode.getDisplayName():
  options.setMigrationMode(WIMigrationOptions.WIMigrationMode.SWITCH_TO_MIGRATION_MODE)
try:
  resultState = "UNKNOWN"
  result = WIMigrationTool.start(props["dbUser"], props["dbPassword"], props["dbSchema"], props["className"], properties, options)
  resultState = result.getResultStateAsString()
  if result.getException():
    raise result.getException()
  printDetails(result)
  if props["getMode"]:
    print "Currently active work item mode: %s" % (result.getMode().getDisplayName())
  if props["setMode"]:
    print "Changed active work item mode to: %s" % (result.getMode().getDisplayName())
except:
  printException()

displayState = {"SUCCESS": "successfully", "WARNING": "with warnings", "ERROR": "with an error", "UNKNOWN": "with an unknown result"}
print "%s finished %s." % (__file__, displayState[resultState])
