#
# Licensed Materials - Property of IBM
# 5655-FLW (C) Copyright IBM Corporation 2006, 2010. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#

import os.path, sys

from java.lang import System

execfile(os.path.join(System.getProperty("was.install.root"), "ProcessChoreographer/config/bpclib.py"))
__file__ = "observerDeleteProcessInstanceData.py"

#*******************************************************************************************************
# print usage and error message, if any
#*******************************************************************************************************
def usage(errmsg = None):
  if errmsg:
    print
    print "ERROR: " + errmsg
  #endif
  print
  print
  print "ObserverDeleteProcessInstanceData"
  print "================================="
  print
  print "Delete process instance data from the reporting database."
  print
  print "Usage: wsadmin -f " + __file__
  print "       ( ( [-node <nodeName>] -server <serverName> ) | ( -cluster <clusterName> ) )"
  print "       [ -dataSource <dataSourceJNDIName> ]"
  print "       [ -dbSchemaName <dbSchemaName> ]"
  print "       ( "
  print "         -deletedBeforeUTC <timestamp> "
  print "         | (-templateName <templateName> -validFromUTC <timestamp>) "
  print "         | (-force [-templateName <templateName> -validFromUTC <timestamp>]"
  print "             -state <state> -reachedBeforeUTC <timestamp>)"
  print "       ) "
  print
  print "Where "
  print
  print "  -node <nodeName>        is the nodename of the server where the datasource"
  print "                          is defined. If not specified, '"+localNode+"' is used."
  print
  print "  -server <serverName>    is the name of the server where the datasource"
  print "                          is defined."
  print
  print "  -cluster <clusterName>  is the name of the cluster when the datasource"
  print "                          is defined on a cluster. Used instead of -server then."
  print
  print "  -dataSource <dataSourceJNDIName>"
  print "                          is the JNDI name of the datasource used to access the"
  print "                          reporting database. If omitted, '"+dataSource+"' is "
  print "                          used."
  print
  print "  -dbSchemaName <dbSchemaName>"
  print "                          is the name of the schema used for the reporting "
  print "                          database. If you didn't specify a schema when "
  print "                          creating the database you can omit this parameter."
  print
  print "  -deletedBeforeUTC <timestamp>"
  print "                          Deletes all observer data for process instances"
  print "                          in state deleted before the specified timestamp."
  print
  print "  -templateName <templateName> -validFromUTC <timestamp>"
  print "                          Deletes all observer data for instances that belong"
  print "                          to the specified template version."
  print
  print "  -force [-templateName <templateName> -validFromUTC <timestamp>]"
  print "     -state <state> -reachedBeforeUTC <timestamp>"
  print "                          Forces the deletion of all observer data for process"
  print "                          instances of the specified template version that "
  print "                          reached the specified state before the specified "
  print "                          time."
  print "                          Possible states are:"
  print "                          running | terminated | suspended | failed | finished "
  print "                          | compensated."
  print
  print "  <timestamp>             format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]."
  print "                          If you specify only the year, month, and day, the hour,"
  print "                          minutes, and seconds are set to 00:00:00."
  print "                          You must not omit the hour, minutes, and seconds for"
  print "                          parameter '-validFromUTC'."
  print "                          Example timestamp: 2006-11-04T21:57:22"
#enddef

#*******************************************************************************************************
# main
#*******************************************************************************************************
localNode = java.lang.System.getProperty ( "local.node" )
dataSource = "jdbc/BPEDB"

if wsadmin.getConnectionStatus() != WsAdmin.CONNECTED:
  usage(__file__ + " must run in connected mode, cannot use the '-conntype NONE' option.")
  sys.exit(1)
#endif

nodeName  = localNode
serverName = None
clusterName = None

argerr = ""
operation = ""
rows = 0
templateName = ""
validFrom = ""
deletedBefore = ""
reachedBefore=""
verbose = 0
dbSchema = ""
forceMode = 0
validStates=["running","terminated","suspended","failed","finished","compensated"]
state=""

argc = len(sys.argv)

i = 0
while ( i < argc ):
  arg = sys.argv[i]
  if (arg == "-dataSource"):
          i=i+1;
          if (i < argc):
                  dataSource = sys.argv[i]
          else:
                  argerr = "Missing argument for '-dataSource' parameter"
          #endElse
  elif (arg == "-dbSchemaName"):
          i=i+1;
          if (i < argc):
                  dbSchema = sys.argv[i]
          else:
                  argerr = "Missing argument for '-dbSchemaName' parameter"
          #endElse
  elif (arg == "-node"):
          i = i+1;
          if (i < argc):
                  nodeName = sys.argv[i]
          else:
                  argerr = "Missing argument for '-node' parameter"
          #endElse
  elif (arg == "-server"):
          i = i+1;
          if (i < argc):
                  serverName = sys.argv[i]
          else:
                  argerr = "Missing argument for '-server' parameter"
          #endElse
  elif (arg == "-cluster"):
          i = i+1;
          if (i < argc):
                  clusterName = sys.argv[i]
          else:
                  argerr = "Missing argument for '-cluster' parameter"
          #endElse
  elif (arg == "-state"):
          i = i+1;
          if (i < argc):

                  state = sys.argv[i]
                  try:
                    #check if state is valid
                    validStates.index(state)
                  except:
                    argerr = "Invalid state '" + state + "' specifed for -state parameter\n"
                    argerr += "Valid states are " + str(validStates)[1:-1]
          else:
                  argerr = "Missing argument for '-state' parameter"
  elif (arg == "-templateName"):
          i = i+1;
          if (i < argc):
                  templateName = sys.argv[i]
          else:
                  argerr = "Missing argument for '-templateName' parameter"
          #endElse
  elif (arg == "-validFrom" or arg == "-validFromUTC"):
          if (arg == "-validFrom"):
            print "WARNING: As of WPS 7.0, parameter '-validFrom' has been deprecated and replaced by '-validFromUTC'."
          i = i+1;
          if (i < argc):
                  validFrom = normalizeTimeStamp(sys.argv[i], 0, 0)
                  if not validFrom:
                    argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>T<HH>:<mm>:<ss>"
          else:
                  argerr = "Missing argument for '-validFrom' parameter"
          #endElse
  elif (arg == "-deletedBefore" or arg == "-deletedBeforeUTC"):
          if (arg == "-deletedBefore"):
            print "WARNING: As of WPS 7.0, parameter '-deletedBefore' has been deprecated and replaced by '-deletedBeforeUTC'."
          i = i+1;
          if (i < argc):
                  deletedBefore = normalizeTimeStamp(sys.argv[i], 0, 1)
                  if not deletedBefore:
                    argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]"
          else:
                  argerr = "Missing argument for '-deletedBeforeUTC' parameter"
          #endElse
  elif (arg == "-deletedBeforeLocal"):
          i = i+1;
          if (i < argc):
                  deletedBefore = normalizeTimeStamp(sys.argv[i], 1, 1)
                  if not deletedBefore:
                    argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]"
          else:
                  argerr = "Missing argument for '-deletedBeforeLocal' parameter"
          #endElse
  elif (arg == "-reachedBefore" or arg == "-reachedBeforeUTC"):
          if (arg == "-reachedBefore"):
            print "WARNING: As of WPS 7.0, parameter '-reachedBefore' has been deprecated and replaced by '-reachedBeforeUTC'."
          i = i+1;
          if (i < argc):
                  reachedBefore = normalizeTimeStamp(sys.argv[i], 0, 1)
                  if not reachedBefore:
                    argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]"
          else:
                  argerr = "Missing argument for '-reachedBeforeUTC' parameter"
          #endElse
  elif (arg == "-reachedBeforeLocal"):
          i = i+1;
          if (i < argc):
                  reachedBefore = normalizeTimeStamp(sys.argv[i], 1, 1)
                  if not reachedBefore:
                    argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>[T<HH>:<mm>:<ss>]"
          else:
                  argerr = "Missing argument for '-reachedBeforeLocal' parameter"
          #endElse
  elif (arg == "-verbose"):
          verbose = 1
  elif (arg == "-force"):
          forceMode = 1
  elif (arg == "-?" or arg == "-h"):
          argc=0
          break
  else:
          argerr = "Invalid command line argument: " + arg
          break
  #endElse
  i += 1  #forNext
#endWhile  (#endFor)

if (argerr == ""):

  if ( (serverName != None) + (clusterName != None) != 1 ):
    argerr = "Exactly one of the '-server' and '-cluster' command line options must be specified"

  elif ( deletedBefore=="" and templateName=="" and forceMode!=1):
    argerr="You have to specify either -deletedBeforeUTC, -force or -templateName."

  elif (deletedBefore!="" and templateName!="") :
    argerr="Only one of -deletedBeforeUTC or -templateName command line options can be specified."

  elif (templateName!="" and validFrom=="") :
    argerr="When using -templateName, also -validFromUTC must be specified."

  elif (forceMode==1 and reachedBefore=="") :
    argerr="When using -force, also -reachedBeforeUTC must be specified."

  elif (forceMode==1 and state=="") :
    argerr="When using -force, also -state must be specified."

  elif (forceMode==0):
    if state!="" :
        argerr="Parameters -state and -reachedBeforeUTC have to be used when using option -force."
    elif reachedBefore!="" :
        argerr="Parameters -state and -reachedBeforeUTC have to be used when using option -force."

#endIf

if ( (argerr != "") or (argc==0)  ):
  usage(argerr)
  sys.exit(1)
#endIf


scope = Scope(nodeName = nodeName, serverName = serverName, clusterName = clusterName)

if not scope.isDeploymentTarget():
  usage( str(scope) + " is not a valid deployment target.")
  sys.exit(1)
#endif

if not scope.isBPCEventCollectorDeploymentTarget():
  usage("Process Choreographer Event Collector is not configured on " + str(scope) + ".")
  sys.exit(1)
#endif

obsMBean = scope.lookupMBean("InternalBPCObserver")

if not obsMBean:
  print str(scope) + " is not available -- make sure the server or at least one cluster member is running."
else:
  if (verbose):
    print
    if (templateName != ""):
        print "Only deleting instances with template name: '" + templateName + "'."
    if (validFrom != ""):
        print "Only deleting instances with validFrom: '" + validFrom + "'."
    if (deletedBefore != ""):
        print "Only deleting instances completed before: '" + deletedBefore + "'."
    if (reachedBefore != ""):
        print "Only deleting instances that reached state " + state + " before: '" + reachedBefore + "'."
    print
  #endIf

  if (deletedBefore != ""):
    # delete observer data for process instances that have reached the end state
    # "deleted" before a specified time
    params = [ dataSource, dbSchema, deletedBefore ]
    if (verbose):
      print "invoking MBean method" + " using parameters: " + params
    rows = AdminControl.invoke(obsMBean, "observerRemoveDeletedInstancesData", params )

  elif (forceMode == 1):
    # delete observer data for process instances that reached a specified state
    # before a specified time; regardless of their current state
    params = [ dataSource, dbSchema, state, templateName, validFrom, reachedBefore ]
    if (verbose):
      print "invoking MBean method" + " using parameters: " + params
    rows = AdminControl.invoke(obsMBean, "observerForceRemoveInstanceData", params )

  elif (templateName != "" and validFrom != ""):
    # delete observer data for process instances of a specific template version
    # regardless of its current state
    params = [ dataSource, dbSchema, templateName, validFrom ]
    if (verbose):
      print "invoking MBean method" + " using parameters: " + params
    rows = AdminControl.invoke(obsMBean, "observerRemoveInstanceDataOfTemplate", params )
  #endIf

  print
  if (rows[0] == 'E'):
    print rows
  else:
    print "Instances deleted:", rows
#endIf
