#
# Licensed Materials - Property of IBM
# 5655-FLW (C) Copyright IBM Corporation 2006, 2010. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#

import os.path, sys

from java.lang import System

execfile(os.path.join(System.getProperty("was.install.root"), "ProcessChoreographer/config/bpclib.py"))
__file__ = "queryNumberOfFailedMessages.py"

#*******************************************************************************************************
# print usage and error message, if any
#*******************************************************************************************************
def usage(errmsg = None):
  if errmsg:
    print
    print "ERROR: " + errmsg
  #endif
  print
  print "Usage: wsadmin -f " + __file__
  print "       ( ( [-node <nodeName>] -server <serverName> ) | ( -cluster <clusterName> ) )"
  print "       [ ( -bfm | -htm ) ]"
  print
  print "Query the number of messages that are in the retention queue and in the hold queues"
  print "of server <serverName> on node <nodeName> or of cluster <clusterName>."
  print
  print "The default values for the optional parameters are:"
  print "  node:               <local node> (" + localNode + ")"
  print
#enddef

#*******************************************************************************************************
# main
#*******************************************************************************************************
localNode = java.lang.System.getProperty ( "local.node" )

if wsadmin.getConnectionStatus() != WsAdmin.CONNECTED:
  usage(__file__ + " must run in connected mode, cannot use the '-conntype NONE' option.")
  sys.exit(1)
#endif

argerr      = ""
mode = "bfm_and_htm"
nodeName = localNode
clusterName = None
serverName  = None

argc = len(sys.argv)

i = 0
while ( i < argc ):
  arg = sys.argv[i]
  if (arg == "-node"):
    i = i+1;
    if (i < argc):
      nodeName = sys.argv[i]
    else:
      argerr = "Missing argument for '-node' parameter"
    #endElse
  elif (arg == "-server"):
    i = i+1;
    if (i < argc):
      serverName = sys.argv[i]
    else:
      argerr = "Missing argument for '-server' parameter"
    #endElse
  elif (arg == "-cluster"):
    i = i+1;
    if (i < argc):
      clusterName = sys.argv[i]
    else:
      argerr = "Missing argument for '-cluster' parameter"
    #endElse
  elif (arg == "-bfm"):
    mode = "bfm_only"
  elif (arg == "-htm"):
    mode = "htm_only"
  else:
    argerr = "Invalid command line argument: "+arg
    break
  #endElse
  i += 1
#endWhile

if (argerr == ""):
  if ( (serverName != None) + (clusterName != None) != 1 ):
     argerr = "Exactly one of the '-server' and '-cluster' command line options must be specified"
#endIf

if ( (argerr != "") or (argc==0)  ):
  usage(argerr)
  sys.exit(1)
#endIf

scope = Scope(nodeName = nodeName, serverName = serverName, clusterName = clusterName)

if not scope.isDeploymentTarget():
  usage( str(scope) + " is not a valid deployment target.")
  sys.exit(1)
#endif

if not scope.isBPCDeploymentTarget("RUNTIME|ARCHIVE"):
  usage("Process Choreographer or Archive Manager is not configured on " + str(scope) + ".")
  sys.exit(1)
#endif

if mode == "htm_only":
  bfmMBean = None
else:
  bfmMBean = scope.lookupMBean("ProcessContainer")

if mode == "bfm_only":
  htmMBean = None
else:
  htmMBean = scope.lookupMBean("TaskManager")

if not bfmMBean:
  if (mode != "htm_only"):
    print str(scope) + " is not available -- make sure the server or at least one cluster member is running."
  #endIf
else:
  numMsgs = AdminControl.getAttribute(bfmMBean, "numberOfMessagesInRetentionQueue" )
  print "The process container retention queue for " + scope.displayName() + " contains " + numMsgs + " messages."
  numMsgs = AdminControl.getAttribute(bfmMBean, "numberOfMessagesInHoldQueue" )
  print "The process container hold queue for " + scope.displayName() + " contains " + numMsgs + " messages."
#endElse

if not htmMBean:
  if (mode != "bfm_only"):
    print str(scope) + " is not available -- make sure the server or at least one cluster member is running."
  #endIf
else:
  numMsgs = AdminControl.getAttribute(htmMBean, "numberOfMessagesInHoldQueue" )
  print "The task container hold queue for " + scope.displayName() + " contains " + numMsgs + " messages."
#endElse
