#
# Licensed Materials - Property of IBM
# 5655-FLW (C) Copyright IBM Corporation 2006, 2010. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#

import os.path, sys

from java.lang import System

execfile(os.path.join(System.getProperty("was.install.root"), "ProcessChoreographer/config/bpclib.py"))
__file__ = "refreshStaffQuery.py"

#*******************************************************************************************************
# print usage and error message, if any
#*******************************************************************************************************
def usage(errmsg = None):
  if errmsg:
    print
    print "ERROR: " + errmsg
  #endif
  print
  print "Usage: wsadmin -f " + __file__
  print "       ( ( [-node <nodeName>] -server <serverName> ) | ( -cluster <clusterName> ) )"
  print "       [ -processTemplate <name> | ( -taskTemplate <name> [ -nameSpace <nameSpace> ] ) | -userlist <username>{,<username>} ] "
  print
  print "Refresh staff query entries after the underlying staff directory has been changed."
  print "If no arguments are specified, the staff queries for all processes are refreshed."
  print "Apply changes on server <serverName> on node <nodeName> or of cluster <clusterName>. "
  print
  print "The default values for the optional parameters are:"
  print "  node:               <local node> (" + localNode + ")"
  print
#enddef

#*******************************************************************************************************
# main
#*******************************************************************************************************
localNode = java.lang.System.getProperty ( "local.node" )

if wsadmin.getConnectionStatus() != WsAdmin.CONNECTED:
  usage(__file__ + " must run in connected mode, cannot use the '-conntype NONE' option.")
  sys.exit(1)
#endif

argerr      = ""
nodeName  = localNode
clusterName = None
serverName  = None
userList    = ""
taskTemplate= ""
nameSpace   = ""
processTemplate= ""

argc = len(sys.argv)

i = 0
while ( i < argc ):
  arg = sys.argv[i]
  if (arg == "-node"):
    i = i+1;
    if (i < argc):
      nodeName = sys.argv[i]
    else:
      argerr = "Missing argument for '-node' parameter"
    #endElse
  elif (arg == "-server"):
    i = i+1;
    if (i < argc):
      serverName = sys.argv[i]
    else:
      argerr = "Missing argument for '-server' parameter"
    #endElse
  elif (arg == "-cluster"):
    i = i+1;
    if (i < argc):
      clusterName = sys.argv[i]
    else:
      argerr = "Missing argument for '-cluster' parameter"
    #endElse
  elif (arg == "-processTemplate"):
    i = i+1;
    if (i < argc):
      processTemplate = sys.argv[i]
    else:
      argerr = "Missing argument for '-processTemplate' parameter"
    #endElse
  elif (arg == "-taskTemplate"):
    i = i+1;
    if (i < argc):
      taskTemplate = sys.argv[i]
    else:
      argerr = "Missing argument for '-taskTemplate' parameter"
    #endElse
  elif (arg == "-nameSpace"):
    i = i+1;
    if (i < argc):
      nameSpace = sys.argv[i]
    else:
      argerr = "Missing argument for '-nameSpace' parameter"
    #endElse
  elif (arg == "-userlist"):
    i = i+1;
    if (i < argc):
      userList = sys.argv[i]
    else:
      argerr = "Missing argument for '-userlist' parameter"
    #endElse
  elif (arg.find(__file__)>-1) or arg=="ARGO":   # when debugging, we get also the filename as arg or somehow the word ARGO
    pass;
  else:
    argerr = "Invalid command line argument: "+arg
    ## leave loop, otherwise arg value will be read ....
    break
  #endElse
  i += 1  #forNext
#endWhile  (#endFor)

if (argerr == ""):
  if ( (serverName != None) + (clusterName != None) != 1 ):
     argerr = "Exactly one of the '-server' and '-cluster' command line options must be specified"
  elif ((userList!="") + (processTemplate!="") + (taskTemplate!="")) > 1 :
    argerr = "Only one of the '-taskTemplate', '-processTemplate', and '-userlist' command line options can be specified"
  #endif
#endIf

if ( (argerr != "") or (argc==0)  ):
  usage(argerr)
  sys.exit(1)
#endIf

if nameSpace and not isValidNameSpace(nameSpace):
  usage("Value '" + str(nameSpace) + "' specfied for command line option '-nameSpace' is not a valid namespace identifier.")
  sys.exit(1)
#endif

scope = Scope(nodeName = nodeName, serverName = serverName, clusterName = clusterName)

if not scope.isDeploymentTarget():
  usage(str(scope) + " is not a valid deployment target.")
  sys.exit(1)
#endif

if not scope.isBPCDeploymentTarget():
  usage("Process Choreographer is not configured on " + str(scope) + ".")
  sys.exit(1)
#endif

if ( processTemplate ):
  appType = "InternalProcessContainer"
else:
  appType = "TaskManager"
#endElse

mbean = scope.lookupMBean(appType)

if not mbean:
  print str(scope) + " is not available -- make sure the server or at least one cluster member is running."
else:
  try:
    if ( processTemplate ):
      print "Refreshing staff queries for process template " + processTemplate + "..."
      AdminControl.invoke(mbean, "refreshStaffQuery", [ processTemplate ])
    elif ( taskTemplate ):
      print "Refreshing staff queries for task template " + taskTemplate + "..."
      AdminControl.invoke(mbean, "refreshStaffQuery", [taskTemplate, nameSpace])
    elif ( userList ):
      userList=userList.split(",")
      print "Refreshing staff queries containing following users: " + ", ".join(userList) + "..."
      AdminControl.invoke(mbean,"refreshStaffQuery", [ userList ])
    else:
      print "Refreshing all staff queries..."
      AdminControl.invoke(mbean, "refreshStaffQuery")
    print "Done."
  except:
    # BP602 format the exception
    # tb=traceback.format_exception(sys.exc_info()[0], sys.exc_info()[1], sys.exc_info()[2])
    print sys.exc_info()[0]
    print sys.exc_info()[1]
    if sys.exc_info()[2]:
      tb=sys.exc_info()[2]
      print tb.dumpStack()
#endIf
