--
-- Licensed Materials - Property of IBM
-- 5655-FLW (C) Copyright IBM Corporation 2006, 2010.
-- All Rights Reserved.
-- US Government Users Restricted Rights- 
-- Use, duplication or disclosure restricted 
-- by GSA ADP Schedule Contract with IBM Corp.
--
-- Scriptfile to create schema for Oracle 9i, 10g, 11g
----------------------------------------------------------------------
-- Before running this script, you need to replace all occurences of
-- the replacement variables listed below with values appropriate for
-- your environment. Replacement variables are of the form: @VARIABLE@.
-- 
-- Note: if you do not find any replacement variables in this script 
--       this step might be already completed by a pre-processor.
-- 
-- @SCHEMA@       = schema name (user )
-- @AUDITLOG@     = valid table space name
-- @INSTANCE@     = valid table space name
-- @STAFFQRY@     = valid table space name
-- @TEMPLATE@     = valid table space name
-- @WORKITEM@     = valid table space name
-- @LOBTS@        = valid table space name
-- @INDEXTS@      = valid table space name
-- @SCHEDTS@      = valid table space name
----------------------------------------------------------------------
-- Process this script using SQL*Plus
-- Example: sqlplus scott/tiger@mydb @createSchema.sql
-- or, at the sqlplus prompt, enter
-- SQL> @createSchema.sql


-------------------
-- Create tables --
-------------------

CREATE TABLE @SCHEMA@.SCHEMA_VERSION
(
  SCHEMA_VERSION                     NUMBER(10,0)         NOT NULL ,
  DATA_MIGRATION                     NUMBER(5,0)          NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.SCHEMA_VERSION ADD(
  PRIMARY KEY ( SCHEMA_VERSION )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
(
  PTID                               RAW(16)              NOT NULL ,
  NAME                               VARCHAR2(220)        NOT NULL ,
  DEFINITION_NAME                    VARCHAR2(220)                 ,
  DISPLAY_NAME                       VARCHAR2(64)                  ,
  APPLICATION_NAME                   VARCHAR2(220)                 ,
  DISPLAY_ID                         NUMBER(10,0)         NOT NULL ,
  DISPLAY_ID_EXT                     VARCHAR2(32)                  ,
  DESCRIPTION                        VARCHAR2(254)                 ,
  DOCUMENTATION                      CLOB                          ,
  EXECUTION_MODE                     NUMBER(10,0)         NOT NULL ,
  IS_SHARED                          NUMBER(5,0)          NOT NULL ,
  IS_AD_HOC                          NUMBER(5,0)          NOT NULL ,
  STATE                              NUMBER(10,0)         NOT NULL ,
  VALID_FROM                         TIMESTAMP            NOT NULL ,
  TARGET_NAMESPACE                   VARCHAR2(250)                 ,
  CREATED                            TIMESTAMP            NOT NULL ,
  AUTO_DELETE                        NUMBER(5,0)          NOT NULL ,
  EXTENDED_AUTO_DELETE               NUMBER(10,0)         NOT NULL ,
  VERSION                            VARCHAR2(32)                  ,
  SCHEMA_VERSION                     NUMBER(10,0)         NOT NULL ,
  ABSTRACT_BASE_NAME                 VARCHAR2(254)                 ,
  S_BEAN_LOOKUP_NAME                 VARCHAR2(254)                 ,
  S_BEAN60_LOOKUP_NAME               VARCHAR2(254)                 ,
  E_BEAN_LOOKUP_NAME                 VARCHAR2(254)                 ,
  PROCESS_BASE_NAME                  VARCHAR2(254)                 ,
  S_BEAN_HOME_NAME                   VARCHAR2(254)                 ,
  E_BEAN_HOME_NAME                   VARCHAR2(254)                 ,
  BPEWS_UTID                         RAW(16)                       ,
  WPC_UTID                           RAW(16)                       ,
  BUSINESS_RELEVANCE                 NUMBER(5,0)          NOT NULL ,
  ADMINISTRATOR_QTID                 RAW(16)                       ,
  READER_QTID                        RAW(16)                       ,
  A_TKTID                            RAW(16)                       ,
  A_TKTIDFOR_ACTS                    RAW(16)                       ,
  COMPENSATION_SPHERE                NUMBER(10,0)         NOT NULL ,
  AUTONOMY                           NUMBER(10,0)         NOT NULL ,
  CAN_CALL                           NUMBER(5,0)          NOT NULL ,
  CAN_INITIATE                       NUMBER(5,0)          NOT NULL ,
  CONTINUE_ON_ERROR                  NUMBER(5,0)          NOT NULL ,
  IGNORE_MISSING_DATA                NUMBER(10,0)         NOT NULL ,
  EAR_VERSION                        NUMBER(10,0)         NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING
  LOB (DOCUMENTATION) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  );

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T ADD(
  PRIMARY KEY ( PTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE UNIQUE INDEX @SCHEMA@.PTB_NAME_VALID ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  NAME, VALID_FROM
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.PTB_NAME_VF_STATE ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  NAME, VALID_FROM, STATE, PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.PTB_TOP_APP ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  APPLICATION_NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.PTB_STATE_PTID ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  STATE, PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.PTB_NAME ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  PTID, NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.PTB_SBLKN ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  S_BEAN60_LOOKUP_NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T
(
  PTID                               RAW(16)              NOT NULL ,
  ATTR_KEY                           VARCHAR2(220)        NOT NULL ,
  VALUE                              VARCHAR2(254)                 ,
  DISPLAY_ID_EXT                     VARCHAR2(32)                  
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T ADD(
  PRIMARY KEY ( PTID, ATTR_KEY )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.PTAB_PTID ON @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.SCOPE_TEMPLATE_B_T
(
  STID                               RAW(16)              NOT NULL ,
  PARENT_STID                        RAW(16)                       ,
  PTID                               RAW(16)              NOT NULL ,
  COMP_HANDLER_ATID                  RAW(16)                       ,
  IMPLEMENTS_EHTID                   RAW(16)                       ,
  FOR_EACH_ATID                      RAW(16)                       ,
  DISPLAY_ID                         NUMBER(10,0)         NOT NULL ,
  DISPLAY_ID_EXT                     VARCHAR2(32)                  ,
  ISOLATED                           NUMBER(5,0)          NOT NULL ,
  IS_COMPENSABLE                     NUMBER(5,0)          NOT NULL ,
  BUSINESS_RELEVANCE                 NUMBER(5,0)          NOT NULL ,
  A_TKTID                            RAW(16)                       ,
  IS_IMPLICIT                        NUMBER(5,0)          NOT NULL ,
  HAS_COMPENSATION_HANDLER           NUMBER(5,0)          NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.SCOPE_TEMPLATE_B_T ADD(
  PRIMARY KEY ( STID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.ST_PTID ON @SCHEMA@.SCOPE_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.SERVICE_TEMPLATE_B_T
(
  VTID                               RAW(16)              NOT NULL ,
  PORT_TYPE_NAME                     VARCHAR2(254)        NOT NULL ,
  PORT_TYPE_UTID                     RAW(16)              NOT NULL ,
  OPERATION_NAME                     VARCHAR2(254)        NOT NULL ,
  NAME                               VARCHAR2(254)                 ,
  PTID                               RAW(16)              NOT NULL ,
  TRANSACTION_BEHAVIOR               NUMBER(10,0)         NOT NULL ,
  IS_TWO_WAY                         NUMBER(5,0)          NOT NULL ,
  NUMBER_OF_RECEIVE_ACTS             NUMBER(10,0)         NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.SERVICE_TEMPLATE_B_T ADD(
  PRIMARY KEY ( VTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.VT_VTID_PTUTID ON @SCHEMA@.SERVICE_TEMPLATE_B_T
(   
  VTID, PORT_TYPE_UTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.VT_PTID ON @SCHEMA@.SERVICE_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.ACTIVITY_SERVICE_TEMPLATE_B_T
(
  ATID                               RAW(16)              NOT NULL ,
  VTID                               RAW(16)              NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  PARTNER_LINK_NAME                  VARCHAR2(220)                 ,
  INPUT_CTID                         RAW(16)                       ,
  OUTPUT_CTID                        RAW(16)                       ,
  LINK_ORDER_NUMBER                  NUMBER(10,0)                  ,
  POTENTIAL_OWNER_QTID               RAW(16)                       ,
  READER_QTID                        RAW(16)                       ,
  EDITOR_QTID                        RAW(16)                       ,
  TKTID                              RAW(16)                       ,
  UNDO_MSG_TEMPLATE                  BLOB                          ,
  DISPLAY_ID_EXT                     VARCHAR2(32)                  
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.ACTIVITY_SERVICE_TEMPLATE_B_T ADD(
  PRIMARY KEY ( ATID, VTID, KIND )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.AST_PTID ON @SCHEMA@.ACTIVITY_SERVICE_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.SERVICE_LOCATION_TEMPLATE_B_T
(
  PTID                               RAW(16)              NOT NULL ,
  VTID                               RAW(16)              NOT NULL ,
  MODULE_NAME                        VARCHAR2(220)        NOT NULL ,
  EXPORT_NAME                        CLOB                          ,
  COMPONENT_NAME                     CLOB                 NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING
  LOB (EXPORT_NAME) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  )
  LOB (COMPONENT_NAME) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  );

ALTER TABLE @SCHEMA@.SERVICE_LOCATION_TEMPLATE_B_T ADD(
  PRIMARY KEY ( PTID, VTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.SLT_PTID ON @SCHEMA@.SERVICE_LOCATION_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.SERVICE_FAULT_TEMPLATE_B_T
(
  VTID                               RAW(16)              NOT NULL ,
  FAULT_NAME                         VARCHAR2(220)        NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  MESSAGE_DEFINITION                 BLOB                 NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.SERVICE_FAULT_TEMPLATE_B_T ADD(
  PRIMARY KEY ( VTID, FAULT_NAME )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.SFT_PTID ON @SCHEMA@.SERVICE_FAULT_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
(
  ATID                               RAW(16)              NOT NULL ,
  PARENT_STID                        RAW(16)                       ,
  IMPLEMENTS_STID                    RAW(16)                       ,
  PTID                               RAW(16)              NOT NULL ,
  IMPLEMENTS_EHTID                   RAW(16)                       ,
  ENCLOSING_FOR_EACH_ATID            RAW(16)                       ,
  IS_EVENT_HANDLER_END_ACTIVITY      NUMBER(5,0)          NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  NAME                               VARCHAR2(220)                 ,
  DISPLAY_NAME                       VARCHAR2(64)                  ,
  JOIN_CONDITION                     NUMBER(10,0)         NOT NULL ,
  JOIN_CONDITION_NAME                VARCHAR2(254)                 ,
  EXIT_CONDITION                     NUMBER(10,0)         NOT NULL ,
  EXIT_CONDITION_NAME                VARCHAR2(254)                 ,
  EXIT_CONDITION_EXECUTE_AT          NUMBER(10,0)         NOT NULL ,
  NUMBER_OF_LINKS                    NUMBER(10,0)         NOT NULL ,
  SUPPRESS_JOIN_FAILURE              NUMBER(5,0)          NOT NULL ,
  SOURCES_TYPE                       NUMBER(10,0)         NOT NULL ,
  TARGETS_TYPE                       NUMBER(10,0)         NOT NULL ,
  CREATE_INSTANCE                    NUMBER(5,0)                   ,
  IS_END_ACTIVITY                    NUMBER(5,0)          NOT NULL ,
  FAULT_NAME                         VARCHAR2(254)                 ,
  HAS_OWN_FAULT_HANDLER              NUMBER(5,0)          NOT NULL ,
  COMPLEX_BEGIN_ATID                 RAW(16)                       ,
  CORRESPONDING_END_ATID             RAW(16)                       ,
  PARENT_ATID                        RAW(16)                       ,
  HAS_CROSSING_LINK                  NUMBER(5,0)                   ,
  SCRIPT_NAME                        VARCHAR2(254)                 ,
  AFFILIATION                        NUMBER(10,0)         NOT NULL ,
  TRANSACTION_BEHAVIOR               NUMBER(10,0)         NOT NULL ,
  DESCRIPTION                        VARCHAR2(254)                 ,
  DOCUMENTATION                      CLOB                          ,
  BUSINESS_RELEVANCE                 NUMBER(5,0)          NOT NULL ,
  FAULT_NAME_UTID                    RAW(16)                       ,
  FAULT_VARIABLE_CTID                RAW(16)                       ,
  DISPLAY_ID                         NUMBER(10,0)         NOT NULL ,
  DISPLAY_ID_EXT                     VARCHAR2(32)                  ,
  IS_TRANSACTIONAL                   NUMBER(5,0)          NOT NULL ,
  CONTINUE_ON_ERROR                  NUMBER(5,0)          NOT NULL ,
  ENCLOSED_FTID                      RAW(16)                       ,
  EXPRESSION                         CLOB                          ,
  EXIT_EXPRESSION                    CLOB                          ,
  HAS_INBOUND_LINK                   NUMBER(5,0)          NOT NULL ,
  COMPENSATION_STID                  RAW(16)                       ,
  COMPENSATION_ATID                  RAW(16)                       ,
  A_TKTID                            RAW(16)                       ,
  IS_IN_GFLOW                        NUMBER(5,0)          NOT NULL ,
  IS_REGION_BEGIN                    NUMBER(5,0)          NOT NULL ,
  CORRESPONDING_IORATID              RAW(16)                       ,
  IS_GFLOW                           NUMBER(5,0)          NOT NULL ,
  CUSTOM_IMPLEMENTATION              BLOB                          ,
  EXPRESSION_MAP                     BLOB                          ,
  EXIT_EXPRESSION_MAP                BLOB                          ,
  GENERATED_BY                       VARCHAR2(220)                 
) TABLESPACE @TEMPLATE@
  LOGGING
  LOB (DOCUMENTATION) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  )
  LOB (EXPRESSION) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  )
  LOB (EXIT_EXPRESSION) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  );

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T ADD(
  PRIMARY KEY ( ATID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.ATB_PTID ON @SCHEMA@.ACTIVITY_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.ATB_NAME ON @SCHEMA@.ACTIVITY_TEMPLATE_B_T
(   
  NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.ATB_KIND_BR_NAME ON @SCHEMA@.ACTIVITY_TEMPLATE_B_T
(   
  KIND, BUSINESS_RELEVANCE, NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.ALARM_TEMPLATE_B_T
(
  XTID                               RAW(16)              NOT NULL ,
  ATID                               RAW(16)              NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  EXPRESSION                         BLOB                          ,
  EXPRESSION_NAME                    VARCHAR2(254)                 ,
  DURATION                           VARCHAR2(254)                 ,
  CALENDAR                           VARCHAR2(254)                 ,
  CALENDAR_JNDI_NAME                 VARCHAR2(254)                 ,
  REPEAT_KIND                        NUMBER(10,0)         NOT NULL ,
  REPEAT_EXPRESSION                  BLOB                          ,
  REPEAT_EXP_NAME                    VARCHAR2(254)                 ,
  ON_ALARM_ORDER_NUMBER              NUMBER(10,0)                  ,
  EXPRESSION_MAP                     BLOB                          ,
  REPEAT_EXPRESSION_MAP              BLOB                          ,
  DISPLAY_ID_EXT                     VARCHAR2(32)                  
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.ALARM_TEMPLATE_B_T ADD(
  PRIMARY KEY ( XTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.XT_PTID ON @SCHEMA@.ALARM_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
(
  FTID                               RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  FAULT_NAME                         VARCHAR2(254)                 ,
  CTID                               RAW(16)                       ,
  STID                               RAW(16)                       ,
  ATID                               RAW(16)                       ,
  FAULT_LINK_SOURCE_ATID             RAW(16)                       ,
  FAULT_LINK_TARGET_ATID             RAW(16)                       ,
  IMPLEMENTATION_ATID                RAW(16)              NOT NULL ,
  FAULT_NAME_UTID                    RAW(16)                       ,
  ORDER_NUMBER                       NUMBER(10,0)         NOT NULL ,
  DISPLAY_ID_EXT                     VARCHAR2(32)                  
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T ADD(
  PRIMARY KEY ( FTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.FT_PTID ON @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.LINK_TEMPLATE_B_T
(
  SOURCE_ATID                        RAW(16)              NOT NULL ,
  TARGET_ATID                        RAW(16)              NOT NULL ,
  FLOW_BEGIN_ATID                    RAW(16)                       ,
  ENCLOSING_FOR_EACH_ATID            RAW(16)                       ,
  DISPLAY_ID                         NUMBER(10,0)         NOT NULL ,
  DISPLAY_ID_EXT                     VARCHAR2(32)                  ,
  NAME                               VARCHAR2(254)                 ,
  PTID                               RAW(16)              NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  LIFETIME                           NUMBER(10,0)         NOT NULL ,
  TRANSITION_CONDITION               NUMBER(10,0)         NOT NULL ,
  TRANSITION_CONDITION_NAME          VARCHAR2(254)                 ,
  ORDER_NUMBER                       NUMBER(10,0)         NOT NULL ,
  SEQUENCE_NUMBER                    NUMBER(10,0)         NOT NULL ,
  BUSINESS_RELEVANCE                 NUMBER(5,0)          NOT NULL ,
  DESCRIPTION                        VARCHAR2(254)                 ,
  DOCUMENTATION                      CLOB                          ,
  EXPRESSION                         CLOB                          ,
  IS_INBOUND_LINK                    NUMBER(5,0)          NOT NULL ,
  OUTBOUND_ATID                      RAW(16)                       ,
  EXPRESSION_MAP                     BLOB                          ,
  GENERATED_BY                       VARCHAR2(220)                 ,
  RTID                               RAW(16)                       
) TABLESPACE @TEMPLATE@
  LOGGING
  LOB (DOCUMENTATION) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  )
  LOB (EXPRESSION) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  );

ALTER TABLE @SCHEMA@.LINK_TEMPLATE_B_T ADD(
  PRIMARY KEY ( SOURCE_ATID, TARGET_ATID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.LNK_PTID ON @SCHEMA@.LINK_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.LINK_BOUNDARY_TEMPLATE_B_T
(
  SOURCE_ATID                        RAW(16)              NOT NULL ,
  TARGET_ATID                        RAW(16)              NOT NULL ,
  BOUNDARY_STID                      RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  IS_OUTMOST_BOUNDARY                NUMBER(5,0)          NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.LINK_BOUNDARY_TEMPLATE_B_T ADD(
  PRIMARY KEY ( SOURCE_ATID, TARGET_ATID, BOUNDARY_STID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.BND_PTID ON @SCHEMA@.LINK_BOUNDARY_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.RESET_TEMPLATE_B_T
(
  LOOP_ENTRY_ATID                    RAW(16)              NOT NULL ,
  LOOP_BODY_ATID                     RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.RESET_TEMPLATE_B_T ADD(
  PRIMARY KEY ( LOOP_ENTRY_ATID, LOOP_BODY_ATID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.RST_PTID ON @SCHEMA@.RESET_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.VARIABLE_MAPPING_TEMPLATE_B_T
(
  PTID                               RAW(16)              NOT NULL ,
  ATID                               RAW(16)              NOT NULL ,
  VTID                               RAW(16)              NOT NULL ,
  SOURCE_CTID                        RAW(16)              NOT NULL ,
  TARGET_CTID                        RAW(16)              NOT NULL ,
  PARAMETER                          VARCHAR2(254)        NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.VARIABLE_MAPPING_TEMPLATE_B_T ADD(
  PRIMARY KEY ( PTID, ATID, VTID, SOURCE_CTID, TARGET_CTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.VMT_TCTID ON @SCHEMA@.VARIABLE_MAPPING_TEMPLATE_B_T
(   
  PTID, ATID, VTID, TARGET_CTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
(
  CTID                               RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  EHTID                              RAW(16)                       ,
  STID                               RAW(16)                       ,
  FTID                               RAW(16)                       ,
  DERIVED                            NUMBER(5,0)          NOT NULL ,
  DISPLAY_ID                         NUMBER(10,0)         NOT NULL ,
  DISPLAY_ID_EXT                     VARCHAR2(32)                  ,
  FROM_SPEC                          NUMBER(10,0)         NOT NULL ,
  NAME                               VARCHAR2(254)        NOT NULL ,
  MESSAGE_TEMPLATE                   BLOB                          ,
  IS_QUERYABLE                       NUMBER(5,0)          NOT NULL ,
  BUSINESS_RELEVANCE                 NUMBER(5,0)          NOT NULL ,
  GENERATED_BY                       VARCHAR2(220)                 ,
  SEQUENCE_NUMBER                    NUMBER(10,0)         NOT NULL ,
  FROM_VARIABLE_CTID                 RAW(16)                       ,
  FROM_PARAMETER2                    VARCHAR2(254)                 ,
  FROM_PARAMETER3                    BLOB                          ,
  FROM_PARAMETER3_LANGUAGE           NUMBER(10,0)         NOT NULL ,
  FROM_EXPRESSION_MAP                BLOB                          
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T ADD(
  PRIMARY KEY ( CTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.CT_PTID ON @SCHEMA@.VARIABLE_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.VARIABLE_STACK_TEMPLATE_B_T
(
  VSID                               RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  CTID                               RAW(16)              NOT NULL ,
  STID                               RAW(16)              NOT NULL ,
  FTID                               RAW(16)                       ,
  EHTID                              RAW(16)                       ,
  NAME                               VARCHAR2(255)        NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.VARIABLE_STACK_TEMPLATE_B_T ADD(
  PRIMARY KEY ( VSID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.VS_PTID ON @SCHEMA@.VARIABLE_STACK_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.ACTIVITY_FAULT_TEMPLATE_B_T
(
  AFID                               RAW(16)              NOT NULL ,
  ATID                               RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  FAULT_NAME                         VARCHAR2(254)        NOT NULL ,
  FAULT_UTID                         RAW(16)                       ,
  MESSAGE                            BLOB                 NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.ACTIVITY_FAULT_TEMPLATE_B_T ADD(
  PRIMARY KEY ( AFID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.AF_PTID ON @SCHEMA@.ACTIVITY_FAULT_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T
(
  PTID                               RAW(16)              NOT NULL ,
  PARTNER_LINK_NAME                  VARCHAR2(220)        NOT NULL ,
  PROCESS_NAME                       VARCHAR2(220)                 ,
  TARGET_NAMESPACE                   VARCHAR2(250)                 ,
  RESOLUTION_SCOPE                   NUMBER(10,0)         NOT NULL ,
  MY_ROLE                            NUMBER(5,0)          NOT NULL ,
  MY_ROLE_IMPL                       BLOB                          ,
  MY_ROLE_LOCALNAME                  VARCHAR2(220)                 ,
  MY_ROLE_NAMESPACE                  VARCHAR2(220)                 ,
  THEIR_ROLE                         NUMBER(5,0)          NOT NULL ,
  THEIR_ROLE_IMPL                    BLOB                          ,
  THEIR_ROLE_LOCALNAME               VARCHAR2(220)                 ,
  THEIR_ROLE_NAMESPACE               VARCHAR2(220)                 ,
  DISPLAY_ID_EXT                     VARCHAR2(32)                  
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T ADD(
  PRIMARY KEY ( PTID, PARTNER_LINK_NAME )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.URI_TEMPLATE_B_T
(
  UTID                               RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  URI                                VARCHAR2(220)                 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.URI_TEMPLATE_B_T ADD(
  PRIMARY KEY ( UTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE UNIQUE INDEX @SCHEMA@.UT_PTID_URI ON @SCHEMA@.URI_TEMPLATE_B_T
(   
  PTID, URI
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.UT_UTID_URI ON @SCHEMA@.URI_TEMPLATE_B_T
(   
  UTID, URI
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.CLIENT_SETTING_TEMPLATE_B_T
(
  CSID                               RAW(16)              NOT NULL ,
  ATID                               RAW(16)                       ,
  PTID                               RAW(16)              NOT NULL ,
  VTID                               RAW(16)                       ,
  SETTINGS                           BLOB                          
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.CLIENT_SETTING_TEMPLATE_B_T ADD(
  PRIMARY KEY ( CSID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.CS_PTID ON @SCHEMA@.CLIENT_SETTING_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.ASSIGN_TEMPLATE_B_T
(
  ATID                               RAW(16)              NOT NULL ,
  ORDER_NUMBER                       NUMBER(10,0)         NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  FROM_SPEC                          NUMBER(10,0)         NOT NULL ,
  FROM_VARIABLE_CTID                 RAW(16)                       ,
  FROM_PARAMETER2                    VARCHAR2(254)                 ,
  FROM_PARAMETER3                    BLOB                          ,
  FROM_PARAMETER3_LANGUAGE           NUMBER(10,0)         NOT NULL ,
  TO_SPEC                            NUMBER(10,0)         NOT NULL ,
  TO_VARIABLE_CTID                   RAW(16)                       ,
  TO_PARAMETER2                      VARCHAR2(254)                 ,
  TO_PARAMETER3                      BLOB                          ,
  TO_PARAMETER3_LANGUAGE             NUMBER(10,0)         NOT NULL ,
  FROM_EXPRESSION_MAP                BLOB                          ,
  TO_EXPRESSION_MAP                  BLOB                          
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.ASSIGN_TEMPLATE_B_T ADD(
  PRIMARY KEY ( ATID, ORDER_NUMBER )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.ASTB_PTID ON @SCHEMA@.ASSIGN_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.CORRELATION_SET_TEMPLATE_B_T
(
  COID                               RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  STID                               RAW(16)              NOT NULL ,
  NAME                               VARCHAR2(255)        NOT NULL ,
  DISPLAY_ID_EXT                     VARCHAR2(32)                  
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.CORRELATION_SET_TEMPLATE_B_T ADD(
  PRIMARY KEY ( COID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.CSTB_PTID ON @SCHEMA@.CORRELATION_SET_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.CORRELATION_TEMPLATE_B_T
(
  ATID                               RAW(16)              NOT NULL ,
  VTID                               RAW(16)              NOT NULL ,
  COID                               RAW(16)              NOT NULL ,
  IS_FOR_EVENT_HANDLER               NUMBER(5,0)          NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  INITIATE                           NUMBER(10,0)         NOT NULL ,
  PATTERN                            NUMBER(10,0)         NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.CORRELATION_TEMPLATE_B_T ADD(
  PRIMARY KEY ( ATID, VTID, COID, IS_FOR_EVENT_HANDLER )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.COID_PTID ON @SCHEMA@.CORRELATION_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
(
  PAID                               RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  COID                               RAW(16)              NOT NULL ,
  SEQUENCE_NUMBER                    NUMBER(10,0)         NOT NULL ,
  PROPERTY_UTID                      RAW(16)              NOT NULL ,
  PROPERTY_NAME                      VARCHAR2(255)        NOT NULL ,
  JAVA_TYPE                          VARCHAR2(255)        NOT NULL ,
  MSG_TYPE_UTID                      RAW(16)              NOT NULL ,
  MSG_TYPE_NAME                      VARCHAR2(255)        NOT NULL ,
  MSG_TYPE_KIND                      NUMBER(10,0)         NOT NULL ,
  PROPERTY_TYPE_UTID                 RAW(16)                       ,
  PROPERTY_TYPE_NAME                 VARCHAR2(255)                 ,
  PART                               VARCHAR2(255)                 ,
  QUERY                              VARCHAR2(255)                 ,
  QUERY_LANGUAGE                     NUMBER(10,0)         NOT NULL ,
  IS_DEFINED_INLINE                  NUMBER(5,0)          NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T ADD(
  PRIMARY KEY ( PAID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.PATB_COID_UTID ON @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
(   
  COID, MSG_TYPE_UTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.PATB_PTID_UTIDS ON @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
(   
  PTID, MSG_TYPE_UTID, PROPERTY_UTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.EVENT_HANDLER_TEMPLATE_B_T
(
  EHTID                              RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  STID                               RAW(16)              NOT NULL ,
  IMPL_ATID                          RAW(16)              NOT NULL ,
  VTID                               RAW(16)                       ,
  INPUT_CTID                         RAW(16)                       ,
  TKTID                              RAW(16)                       ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  DISPLAY_ID_EXT                     VARCHAR2(32)                  
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.EVENT_HANDLER_TEMPLATE_B_T ADD(
  PRIMARY KEY ( EHTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.EHT_PTID ON @SCHEMA@.EVENT_HANDLER_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.EHALARM_TEMPLATE_B_T
(
  EHTID                              RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  EXPRESSION                         BLOB                          ,
  EXPRESSION_NAME                    VARCHAR2(254)                 ,
  DURATION                           VARCHAR2(254)                 ,
  CALENDAR                           VARCHAR2(254)                 ,
  CALENDAR_JNDI_NAME                 VARCHAR2(254)                 ,
  REPEAT_KIND                        NUMBER(10,0)         NOT NULL ,
  REPEAT_EXPRESSION                  BLOB                          ,
  REPEAT_EXP_NAME                    VARCHAR2(254)                 ,
  REPEAT_DURATION                    VARCHAR2(254)                 ,
  REPEAT_CALENDAR                    VARCHAR2(254)                 ,
  REPEAT_CALENDAR_JNDI_NAME          VARCHAR2(254)                 ,
  EXPRESSION_MAP                     BLOB                          ,
  REPEAT_EXPRESSION_MAP              BLOB                          
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.EHALARM_TEMPLATE_B_T ADD(
  PRIMARY KEY ( EHTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.EXT_PTID ON @SCHEMA@.EHALARM_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.CUSTOM_EXT_TEMPLATE_B_T
(
  PKID                               RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  NAMESPACE                          VARCHAR2(220)        NOT NULL ,
  LOCALNAME                          VARCHAR2(220)        NOT NULL ,
  TEMPLATE_INFO                      BLOB                          ,
  INSTANCE_INFO                      BLOB                          
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.CUSTOM_EXT_TEMPLATE_B_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.CETB_PTID ON @SCHEMA@.CUSTOM_EXT_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.CUSTOM_STMT_TEMPLATE_B_T
(
  PKID                               RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  NAMESPACE                          VARCHAR2(220)        NOT NULL ,
  LOCALNAME                          VARCHAR2(220)        NOT NULL ,
  PURPOSE                            VARCHAR2(220)        NOT NULL ,
  STATEMENT                          BLOB                          
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.CUSTOM_STMT_TEMPLATE_B_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.CST_PTID_NS_LN_P ON @SCHEMA@.CUSTOM_STMT_TEMPLATE_B_T
(   
  PTID, NAMESPACE, LOCALNAME, PURPOSE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.PROCESS_CELL_MAP_T
(
  PTID                               RAW(16)              NOT NULL ,
  CELL                               VARCHAR2(220)        NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.PROCESS_CELL_MAP_T ADD(
  PRIMARY KEY ( PTID, CELL )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
(
  ATID                               RAW(16)              NOT NULL ,
  ATTR_KEY                           VARCHAR2(192)        NOT NULL ,
  ATTR_VALUE                         VARCHAR2(254)                 ,
  PTID                               RAW(16)              NOT NULL ,
  DISPLAY_ID_EXT                     VARCHAR2(32)                  
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T ADD(
  PRIMARY KEY ( ATID, ATTR_KEY )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.ATAB_PTID ON @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.ATAB_VALUE ON @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
(   
  ATTR_VALUE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.FOR_EACH_TEMPLATE_B_T
(
  ATID                               RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  COUNTER_CTID                       RAW(16)              NOT NULL ,
  SUCCESSFUL_BRANCHES_ONLY           NUMBER(5,0)          NOT NULL ,
  START_COUNTER_LANGUAGE             NUMBER(10,0)         NOT NULL ,
  FINAL_COUNTER_LANGUAGE             NUMBER(10,0)         NOT NULL ,
  COMPLETION_CONDITION_LANGUAGE      NUMBER(10,0)         NOT NULL ,
  START_COUNTER_EXPRESSION           BLOB                          ,
  FINAL_COUNTER_EXPRESSION           BLOB                          ,
  COMPLETION_COND_EXPRESSION         BLOB                          ,
  FOR_EACH_METHOD                    VARCHAR2(254)                 ,
  START_COUNTER_EXPRESSION_MAP       BLOB                          ,
  FINAL_COUNTER_EXPRESSION_MAP       BLOB                          ,
  COMPLETION_COND_EXPRESSION_MAP     BLOB                          
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.FOR_EACH_TEMPLATE_B_T ADD(
  PRIMARY KEY ( ATID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.FET_PTID ON @SCHEMA@.FOR_EACH_TEMPLATE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.GRAPHICAL_PROCESS_MODEL_T
(
  PTID                               RAW(16)              NOT NULL ,
  SOURCE                             VARCHAR2(100)        NOT NULL ,
  KIND                               VARCHAR2(100)        NOT NULL ,
  GRAPHICAL_DATA                     BLOB                          ,
  ID_MAPPING                         BLOB                          
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.GRAPHICAL_PROCESS_MODEL_T ADD(
  PRIMARY KEY ( PTID, SOURCE, KIND )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T
(
  PKID                               RAW(16)              NOT NULL ,
  CTID                               RAW(16)              NOT NULL ,
  PAID                               RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  QUERY_TYPE                         NUMBER(10,0)         NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.QVT_PTID ON @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(
  MPTID                              RAW(16)              NOT NULL ,
  SOURCE_PTID                        RAW(16)              NOT NULL ,
  TARGET_PTID                        RAW(16)              NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T ADD(
  PRIMARY KEY ( MPTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE UNIQUE INDEX @SCHEMA@.MPT_PTIDS ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(   
  SOURCE_PTID, TARGET_PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.MPT_TPTID ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(   
  TARGET_PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.IDMAPPING_TEMPLATE_T
(
  MPTID                              RAW(16)              NOT NULL ,
  SOURCE_OID                         RAW(16)              NOT NULL ,
  TARGET_OID                         RAW(16)              NOT NULL ,
  SOURCE_PTID                        RAW(16)              NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.IDMAPPING_TEMPLATE_T ADD(
  PRIMARY KEY ( MPTID, SOURCE_OID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.IDMT_PTID ON @SCHEMA@.IDMAPPING_TEMPLATE_T
(   
  SOURCE_PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(
  CGTID                              RAW(16)              NOT NULL ,
  MPTID                              RAW(16)              NOT NULL ,
  SOURCE_PTID                        RAW(16)              NOT NULL ,
  MANDATORY                          NUMBER(5,0)          NOT NULL ,
  CHANGES                            CLOB                 NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING
  LOB (CHANGES) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  );

ALTER TABLE @SCHEMA@.CHANGE_GROUP_TEMPLATE_T ADD(
  PRIMARY KEY ( CGTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.CGT_MT ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(   
  MPTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.CGT_PT ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(   
  SOURCE_PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(
  CGTID                              RAW(16)              NOT NULL ,
  SOURCE_ATID                        RAW(16)              NOT NULL ,
  MPTID                              RAW(16)              NOT NULL ,
  SOURCE_PTID                        RAW(16)              NOT NULL ,
  RELATIONSHIP                       NUMBER(10,0)         NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T ADD(
  PRIMARY KEY ( CGTID, SOURCE_ATID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.CGIT_MT ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
  MPTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.CGIT_PT ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
  SOURCE_PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
(
  MPTID                              RAW(16)              NOT NULL ,
  TARGET_CTID                        RAW(16)              NOT NULL ,
  TARGET_STID                        RAW(16)              NOT NULL ,
  SOURCE_PTID                        RAW(16)              NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T ADD(
  PRIMARY KEY ( MPTID, TARGET_CTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.MPVT_PT ON @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
(   
  SOURCE_PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.REGION_TEMPLATE_T
(
  RTID                               RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  BEGIN_ATID                         RAW(16)                       ,
  END_ATID                           RAW(16)                       ,
  REGION_TYPE                        NUMBER(10,0)         NOT NULL ,
  BEGIN_ORDER_NUMBER                 NUMBER(10,0)         NOT NULL ,
  PARENT_RTID                        RAW(16)                       
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.REGION_TEMPLATE_T ADD(
  PRIMARY KEY ( RTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.RGT_PTID ON @SCHEMA@.REGION_TEMPLATE_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.REGION_CONTENT_TEMPLATE_T
(
  RTID                               RAW(16)              NOT NULL ,
  CONTAINED_ATID                     RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.REGION_CONTENT_TEMPLATE_T ADD(
  PRIMARY KEY ( RTID, CONTAINED_ATID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.RCT_PTID ON @SCHEMA@.REGION_CONTENT_TEMPLATE_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.CHANGE_TEMPLATE_T
(
  PKID                               RAW(16)              NOT NULL ,
  MPTID                              RAW(16)              NOT NULL ,
  PROPERTY                           NUMBER(10,0)         NOT NULL ,
  DISPLAY_ID_EXT                     VARCHAR2(32)         NOT NULL ,
  CHANGE_TYPE                        NUMBER(10,0)         NOT NULL ,
  SOURCE_PTID                        RAW(16)              NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.CHANGE_TEMPLATE_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE UNIQUE INDEX @SCHEMA@.CT_MTPDIS ON @SCHEMA@.CHANGE_TEMPLATE_T
(   
  MPTID, PROPERTY, DISPLAY_ID_EXT
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.CGT_PTID ON @SCHEMA@.CHANGE_TEMPLATE_T
(   
  SOURCE_PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.STAFF_QUERY_TEMPLATE_T
(
  QTID                               RAW(16)              NOT NULL ,
  ASSOCIATED_OBJECT_TYPE             NUMBER(10,0)         NOT NULL ,
  ASSOCIATED_OID                     RAW(16)              NOT NULL ,
  T_QUERY                            VARCHAR2(32)         NOT NULL ,
  QUERY                              BLOB                 NOT NULL ,
  HASH_CODE                          NUMBER(10,0)         NOT NULL ,
  SUBSTITUTION_POLICY                NUMBER(10,0)         NOT NULL ,
  STAFF_VERB                         BLOB                          
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.STAFF_QUERY_TEMPLATE_T ADD(
  PRIMARY KEY ( QTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.SQT_HASH ON @SCHEMA@.STAFF_QUERY_TEMPLATE_T
(   
  ASSOCIATED_OID, HASH_CODE, T_QUERY, ASSOCIATED_OBJECT_TYPE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
(
  PIID                               RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  SHARED_PC_ID                       RAW(16)                       ,
  STATE                              NUMBER(10,0)         NOT NULL ,
  PENDING_REQUEST                    NUMBER(10,0)         NOT NULL ,
  CREATED                            TIMESTAMP                     ,
  STARTED                            TIMESTAMP                     ,
  COMPLETED                          TIMESTAMP                     ,
  LAST_STATE_CHANGE                  TIMESTAMP                     ,
  LAST_MODIFIED                      TIMESTAMP                     ,
  NAME                               VARCHAR2(220)        NOT NULL ,
  PARENT_NAME                        VARCHAR2(220)                 ,
  TOP_LEVEL_NAME                     VARCHAR2(220)        NOT NULL ,
  COMPENSATION_SPHERE_NAME           VARCHAR2(100)                 ,
  STARTER                            VARCHAR2(128)                 ,
  DESCRIPTION                        VARCHAR2(254)                 ,
  INPUT_SNID                         RAW(16)                       ,
  INPUT_ATID                         RAW(16)                       ,
  INPUT_VTID                         RAW(16)                       ,
  OUTPUT_SNID                        RAW(16)                       ,
  OUTPUT_ATID                        RAW(16)                       ,
  OUTPUT_VTID                        RAW(16)                       ,
  FAULT_NAME                         VARCHAR2(254)                 ,
  TOP_LEVEL_PIID                     RAW(16)              NOT NULL ,
  PARENT_PIID                        RAW(16)                       ,
  PARENT_AIID                        RAW(16)                       ,
  TKIID                              RAW(16)                       ,
  TERMIN_ON_REC                      NUMBER(5,0)          NOT NULL ,
  AWAITED_SUB_PROC                   NUMBER(5,0)          NOT NULL ,
  IS_CREATING                        NUMBER(5,0)          NOT NULL ,
  PREVIOUS_STATE                     NUMBER(10,0)                  ,
  EXECUTING_ISOLATED_SCOPE           NUMBER(5,0)          NOT NULL ,
  SCHEDULER_TASK_ID                  VARCHAR2(254)                 ,
  RESUMES                            TIMESTAMP                     ,
  PENDING_SKIP_REQUEST               NUMBER(5,0)          NOT NULL ,
  IS_MIGRATED                        NUMBER(5,0)          NOT NULL ,
  UNHANDLED_EXCEPTION                BLOB                          ,
  CREATED_WITH_VERSION               NUMBER(10,0)         NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T ADD(
  PRIMARY KEY ( PIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE UNIQUE INDEX @SCHEMA@.PIB_NAME ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.PIB_TOP ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  TOP_LEVEL_PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.PIB_PAP ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  PARENT_PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.PIB_PAR ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  PARENT_AIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.PIB_PTID ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.PIB_PIID_STATE ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  PIID, STATE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.PIB_STATE ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  STATE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.PIB_PIID_PTID_STAT ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  PIID, PTID, STATE, STARTER, STARTED
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.PIB_WSID1 ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  WSID_1, STATE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.PIB_WSID2 ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  WSID_2, STATE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.PIB_SWI1 ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
  PIID, NAME, PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.SCOPE_INSTANCE_B_T
(
  SIID                               RAW(16)              NOT NULL ,
  PARENT_SIID                        RAW(16)                       ,
  STID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  EHIID                              RAW(16)                       ,
  ENCLOSING_FEIID                    RAW(16)                       ,
  ENCLOSING_FOR_EACH_END_AIID        RAW(16)                       ,
  COMPENSATE_AIID                    RAW(16)                       ,
  PARENT_COMP_SIID                   RAW(16)                       ,
  LAST_COMP_SIID                     RAW(16)                       ,
  RUNNING_EVENT_HANDLERS             NUMBER(10,0)         NOT NULL ,
  STATE                              NUMBER(10,0)         NOT NULL ,
  NOTIFY_PARENT                      NUMBER(5,0)          NOT NULL ,
  AWAITED_SCOPES                     NUMBER(10,0)         NOT NULL ,
  AWAITED_SUB_PROCESSES              NUMBER(10,0)         NOT NULL ,
  BPEL_EXCEPTION                     BLOB                          ,
  IS_ACTIVE                          NUMBER(5,0)          NOT NULL ,
  INITIATED_COMP                     NUMBER(5,0)          NOT NULL ,
  IS_TERMINATION_FROM_FOR_EACH       NUMBER(5,0)          NOT NULL ,
  TOTAL_COMPL_NUMBER                 NUMBER(20,0)         NOT NULL ,
  SCOPE_COMPL_NUMBER                 NUMBER(20,0)         NOT NULL ,
  A_TKIID                            RAW(16)                       ,
  HAS_COMPENSATION_WORK              NUMBER(5,0)          NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.SCOPE_INSTANCE_B_T ADD(
  PRIMARY KEY ( SIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.SI_PI_ST_EH_STA_FE ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  PIID, STID, STATE, EHIID, ENCLOSING_FEIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SI_PI_ST_EH_ACT_FE ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  PIID, STID, IS_ACTIVE, EHIID, ENCLOSING_FEIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SI_PIID_PARSI ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  PIID, PARENT_SIID, IS_ACTIVE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SI_PARCOMP_STA_ST ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  PARENT_COMP_SIID, STATE, STID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SI_PIID_STATE ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  PIID, STATE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SI_LAST_COMPSIID ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
  LAST_COMP_SIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
(
  AIID                               RAW(16)              NOT NULL ,
  ATID                               RAW(16)              NOT NULL ,
  SIID                               RAW(16)                       ,
  PIID                               RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  EHIID                              RAW(16)                       ,
  ENCLOSING_FEIID                    RAW(16)                       ,
  P_TKIID                            RAW(16)                       ,
  A_TKIID                            RAW(16)                       ,
  INVOKED_INSTANCE_ID                RAW(16)                       ,
  INVOKED_INSTANCE_TYPE              NUMBER(10,0)         NOT NULL ,
  STATE                              NUMBER(10,0)         NOT NULL ,
  TRANS_COND_VALUES                  RAW(66)              NOT NULL ,
  NUMBER_LINKS_EVALUATED             NUMBER(10,0)         NOT NULL ,
  FINISHED                           TIMESTAMP                     ,
  ACTIVATED                          TIMESTAMP                     ,
  FIRST_ACTIVATED                    TIMESTAMP                     ,
  STARTED                            TIMESTAMP                     ,
  LAST_MODIFIED                      TIMESTAMP                     ,
  LAST_STATE_CHANGE                  TIMESTAMP                     ,
  OWNER                              VARCHAR2(128)                 ,
  DESCRIPTION                        VARCHAR2(254)                 ,
  LINK_ORDER_NUMBER                  NUMBER(10,0)                  ,
  SCHEDULER_TASK_ID                  VARCHAR2(254)                 ,
  EXPIRES                            TIMESTAMP                     ,
  CONTINUE_ON_ERROR                  NUMBER(5,0)          NOT NULL ,
  UNHANDLED_EXCEPTION                BLOB                          ,
  STOP_REASON                        NUMBER(10,0)         NOT NULL ,
  PREVIOUS_STATE                     NUMBER(10,0)                  ,
  INVOCATION_COUNTER                 NUMBER(10,0)         NOT NULL ,
  FOR_EACH_START_COUNTER_VALUE       NUMBER(20,0)                  ,
  FOR_EACH_FINAL_COUNTER_VALUE       NUMBER(20,0)                  ,
  FOR_EACH_CURRENT_COUNTER_VALUE     NUMBER(20,0)                  ,
  FOR_EACH_COMPLETED_BRANCHES        NUMBER(20,0)                  ,
  FOR_EACH_FAILED_BRANCHES           NUMBER(20,0)                  ,
  FOR_EACH_MAX_COMPL_BRANCHES        NUMBER(20,0)                  ,
  FOR_EACH_AWAITED_BRANCHES          NUMBER(20,0)                  ,
  IS51_ACTIVITY                      NUMBER(5,0)          NOT NULL ,
  MAY_HAVE_SUBPROCESS                NUMBER(5,0)                   ,
  SKIP_REQUESTED                     NUMBER(5,0)          NOT NULL ,
  JUMP_TARGET_ATID                   RAW(16)                       ,
  SUB_STATE                          NUMBER(10,0)         NOT NULL ,
  PENDING_REQUEST_DATA               BLOB                          ,
  XTID                               RAW(16)                       ,
  EXPIRATION_COUNTER                 NUMBER(10,0)                  ,
  PREVIOUS_EXPIRATION_DATE           TIMESTAMP                     ,
  TARGET_IORAIID                     RAW(16)                       ,
  DISPLAY_ID_EXT                     VARCHAR2(32)                  ,
  MAX_COMPENSATION_NUMBER            NUMBER(20,0)                  ,
  HAS_WORK_ITEM                      NUMBER(5,0)                   ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T ADD(
  PRIMARY KEY ( AIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.AIB_PI_ATID_EH_FE ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID, ATID, EHIID, ENCLOSING_FEIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.AIB_PI_EH_FE_AT ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID, EHIID, ENCLOSING_FEIID, ATID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.AIB_PI_DIS_EH_FE ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID, DISPLAY_ID_EXT, EHIID, ENCLOSING_FEIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.AIB_PTID ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.AIB_PIID_STAT_AIID ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID, STATE, AIID, ACTIVATED
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.AIB_AI_AT_STAT_PI ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  AIID, ATID, STATE, PIID, OWNER, ACTIVATED
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.AIB_SIID ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  SIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.AIB_ATID_STAT ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  ATID, STATE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.AIB_WSID1 ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  WSID_1, STATE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.AIB_WSID2 ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  WSID_2, STATE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.AIB_PIID ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.VARIABLE_INSTANCE_B_T
(
  CTID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  DATA                               BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.VARIABLE_INSTANCE_B_T ADD(
  PRIMARY KEY ( CTID, PIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.CI_PIID ON @SCHEMA@.VARIABLE_INSTANCE_B_T
(   
  PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_T
(
  SVIID                              RAW(16)              NOT NULL ,
  CTID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  SIID                               RAW(16)              NOT NULL ,
  EHIID                              RAW(16)                       ,
  FEIID                              RAW(16)                       ,
  DATA                               BLOB                          ,
  IS_ACTIVE                          NUMBER(5,0)          NOT NULL ,
  IS_INITIALIZED                     NUMBER(5,0)          NOT NULL ,
  IS_QUERYABLE                       NUMBER(5,0)          NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_T ADD(
  PRIMARY KEY ( SVIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.SVI_PI_CT_EH_FE ON @SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_T
(   
  PIID, CTID, IS_ACTIVE, EHIID, FEIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SVI_CT_SI_EH_AC ON @SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_T
(   
  SIID, CTID, IS_ACTIVE, EHIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.STAFF_MESSAGE_INSTANCE_B_T
(
  AIID                               RAW(16)              NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  DATA                               BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.STAFF_MESSAGE_INSTANCE_B_T ADD(
  PRIMARY KEY ( AIID, KIND )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.SMI_PIID ON @SCHEMA@.STAFF_MESSAGE_INSTANCE_B_T
(   
  PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.EVENT_INSTANCE_B_T
(
  EIID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  VTID                               RAW(16)              NOT NULL ,
  IS_TWO_WAY                         NUMBER(5,0)          NOT NULL ,
  IS_PRIMARY_EVENT_INSTANCE          NUMBER(5,0)          NOT NULL ,
  STATE                              NUMBER(10,0)         NOT NULL ,
  AIID                               RAW(16)                       ,
  EHTID                              RAW(16)                       ,
  SIID                               RAW(16)                       ,
  TKIID                              RAW(16)                       ,
  NEXT_POSTED_EVENT                  RAW(16)                       ,
  LAST_POSTED_EVENT                  RAW(16)                       ,
  POST_COUNT                         NUMBER(10,0)         NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  MESSAGE                            BLOB                          ,
  REPLY_CONTEXT                      BLOB                          ,
  POST_TIME                          TIMESTAMP                     ,
  MAX_NUMBER_OF_POSTS                NUMBER(10,0)         NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.EVENT_INSTANCE_B_T ADD(
  PRIMARY KEY ( EIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.EI_PIID_PRIM ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  PIID, IS_PRIMARY_EVENT_INSTANCE, STATE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.EI_PIID_VTID ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  PIID, VTID, IS_PRIMARY_EVENT_INSTANCE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.EI_AIID ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  AIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.EI_STATE_VTID ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  VTID, STATE, EIID, AIID, PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.EI_WSID1 ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  WSID_1
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.EI_WSID2 ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  WSID_2
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.REQUEST_INSTANCE_B_T
(
  RIID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  VTID                               RAW(16)              NOT NULL ,
  ATID                               RAW(16)              NOT NULL ,
  EHIID                              RAW(16)                       ,
  TKIID                              RAW(16)                       ,
  FEIID                              RAW(16)                       ,
  INSTANTIATING                      NUMBER(5,0)          NOT NULL ,
  REPLY_CONTEXT                      BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.REQUEST_INSTANCE_B_T ADD(
  PRIMARY KEY ( RIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.RI_PIID_VTID_EHIID ON @SCHEMA@.REQUEST_INSTANCE_B_T
(   
  PIID, VTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.PARTNER_LINK_INSTANCE_B_T
(
  PIID                               RAW(16)              NOT NULL ,
  NAME                               VARCHAR2(220)        NOT NULL ,
  ENDPOINT_REFERENCE                 BLOB                          ,
  SERVICE_DEFINITION                 BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.PARTNER_LINK_INSTANCE_B_T ADD(
  PRIMARY KEY ( PIID, NAME )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.PA_PIID ON @SCHEMA@.PARTNER_LINK_INSTANCE_B_T
(   
  PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.VARIABLE_SNAPSHOT_B_T
(
  SNID                               RAW(16)              NOT NULL ,
  CTID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  DATA                               BLOB                          ,
  COPY_VERSION                       NUMBER(5,0)          NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.VARIABLE_SNAPSHOT_B_T ADD(
  PRIMARY KEY ( SNID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.SN_PIID_CTID ON @SCHEMA@.VARIABLE_SNAPSHOT_B_T
(   
  PIID, CTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.SUSPENDED_MESSAGE_INSTANCE_B_T
(
  PKID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  ENGINE_MESSAGE                     BLOB                 NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.SUSPENDED_MESSAGE_INSTANCE_B_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.PIID ON @SCHEMA@.SUSPENDED_MESSAGE_INSTANCE_B_T
(   
  PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.CROSSING_LINK_INSTANCE_B_T
(
  PKID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  SOURCE_ATID                        RAW(16)              NOT NULL ,
  TARGET_ATID                        RAW(16)              NOT NULL ,
  EHIID                              RAW(16)                       ,
  FEIID                              RAW(16)                       ,
  CONDITION_VALUE                    NUMBER(10,0)         NOT NULL ,
  DESCRIPTION                        VARCHAR2(254)                 ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.CROSSING_LINK_INSTANCE_B_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.CL_PI_TAT_EH_FE_SA ON @SCHEMA@.CROSSING_LINK_INSTANCE_B_T
(   
  PIID, TARGET_ATID, EHIID, FEIID, SOURCE_ATID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.INVOKE_RESULT_B_T
(
  PIID                               RAW(16)              NOT NULL ,
  ATID                               RAW(16)              NOT NULL ,
  STATE                              NUMBER(10,0)         NOT NULL ,
  INVOKE_RESULT                      BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.INVOKE_RESULT_B_T ADD(
  PRIMARY KEY ( PIID, ATID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.INVOKE_RESULT2_B_T
(
  IRID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  ATID                               RAW(16)              NOT NULL ,
  EHIID                              RAW(16)                       ,
  FEIID                              RAW(16)                       ,
  STATE                              NUMBER(10,0)         NOT NULL ,
  INVOKE_RESULT                      BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.INVOKE_RESULT2_B_T ADD(
  PRIMARY KEY ( IRID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.IR2_PI_AT_EH_FE ON @SCHEMA@.INVOKE_RESULT2_B_T
(   
  PIID, ATID, EHIID, FEIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.EVENT_HANDLER_INSTANCE_B_T
(
  EHIID                              RAW(16)              NOT NULL ,
  EHTID                              RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  SIID                               RAW(16)              NOT NULL ,
  PARENT_EHIID                       RAW(16)                       ,
  FEIID                              RAW(16)                       ,
  SCHEDULER_TASK_ID                  VARCHAR2(254)                 ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.EVENT_HANDLER_INSTANCE_B_T ADD(
  PRIMARY KEY ( EHIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.EHI_PIID_EHTID ON @SCHEMA@.EVENT_HANDLER_INSTANCE_B_T
(   
  PIID, EHTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.EHI_SIID_EHTID ON @SCHEMA@.EVENT_HANDLER_INSTANCE_B_T
(   
  SIID, EHTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.CORRELATION_SET_INSTANCE_B_T
(
  PIID                               RAW(16)              NOT NULL ,
  COID                               RAW(16)              NOT NULL ,
  SIID                               RAW(16)              NOT NULL ,
  PROCESS_NAME                       VARCHAR2(220)        NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  STATUS                             NUMBER(10,0)         NOT NULL ,
  HASH_CODE                          RAW(16)              NOT NULL ,
  DATA                               VARCHAR2(3072)                ,
  DATA_LONG                          CLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING
  LOB (DATA_LONG) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  );

ALTER TABLE @SCHEMA@.CORRELATION_SET_INSTANCE_B_T ADD(
  PRIMARY KEY ( PIID, COID, SIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE UNIQUE INDEX @SCHEMA@.CSIB_HASH_PN ON @SCHEMA@.CORRELATION_SET_INSTANCE_B_T
(   
  HASH_CODE, PROCESS_NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.CSIB_PIID ON @SCHEMA@.CORRELATION_SET_INSTANCE_B_T
(   
  PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.CORRELATION_SET_PROPERTIES_B_T
(
  PIID                               RAW(16)              NOT NULL ,
  COID                               RAW(16)              NOT NULL ,
  SIID                               RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  DATA                               BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.CORRELATION_SET_PROPERTIES_B_T ADD(
  PRIMARY KEY ( PIID, COID, SIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.UNDO_ACTION_B_T
(
  PKID                               RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  ATID                               RAW(16)              NOT NULL ,
  PARENT_ATID                        RAW(16)                       ,
  PARENT_PIID                        RAW(16)                       ,
  PARENT_AIID                        RAW(16)                       ,
  PARENT_EHIID                       RAW(16)                       ,
  PARENT_FEIID                       RAW(16)                       ,
  PROCESS_NAME                       VARCHAR2(220)        NOT NULL ,
  CSCOPE_ID                          VARCHAR2(100)        NOT NULL ,
  UUID                               VARCHAR2(100)        NOT NULL ,
  COMP_CREATION_TIME                 TIMESTAMP            NOT NULL ,
  DO_OP_WAS_TXNAL                    NUMBER(5,0)          NOT NULL ,
  STATE                              NUMBER(10,0)         NOT NULL ,
  INPUT_DATA                         BLOB                 NOT NULL ,
  FAULT_DATA                         BLOB                          ,
  CREATED                            NUMBER(10,0)         NOT NULL ,
  PROCESS_ADMIN                      VARCHAR2(128)        NOT NULL ,
  IS_VISIBLE                         NUMBER(5,0)          NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.UNDO_ACTION_B_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.UA_CSID_DOOP_UUID ON @SCHEMA@.UNDO_ACTION_B_T
(   
  CSCOPE_ID, DO_OP_WAS_TXNAL, UUID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.UA_CSID_STATE_CCT ON @SCHEMA@.UNDO_ACTION_B_T
(   
  CSCOPE_ID, STATE, UUID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.UA_STATE_ISV ON @SCHEMA@.UNDO_ACTION_B_T
(   
  STATE, IS_VISIBLE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.UA_AIID_STATE_UUID ON @SCHEMA@.UNDO_ACTION_B_T
(   
  PARENT_AIID, STATE, UUID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.UA_PIID ON @SCHEMA@.UNDO_ACTION_B_T
(   
  PARENT_PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.UA_PT_AT_CS_UU_CCT ON @SCHEMA@.UNDO_ACTION_B_T
(   
  PTID, ATID, CSCOPE_ID, UUID, COMP_CREATION_TIME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T
(
  PKID                               RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  SVIID                              RAW(16)                       ,
  NAMESPACE                          VARCHAR2(220)        NOT NULL ,
  LOCALNAME                          VARCHAR2(220)        NOT NULL ,
  PURPOSE                            VARCHAR2(220)        NOT NULL ,
  STATEMENT                          BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.CSI_PIID_NS_LN_P ON @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T
(   
  PIID, NAMESPACE, LOCALNAME, PURPOSE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.CSI_SVIID_NS_LN_P ON @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T
(   
  SVIID, NAMESPACE, LOCALNAME, PURPOSE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.COMP_WORK_PENDING_B_T
(
  PKID                               RAW(16)              NOT NULL ,
  PARENT_PIID                        RAW(16)              NOT NULL ,
  PARENT_ATID                        RAW(16)              NOT NULL ,
  PARENT_EHIID                       RAW(16)                       ,
  PARENT_FEIID                       RAW(16)                       ,
  STATE                              NUMBER(10,0)         NOT NULL ,
  CSCOPE_ID                          VARCHAR2(100)        NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.COMP_WORK_PENDING_B_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.CWP_PI_AT_CS_EH_FE ON @SCHEMA@.COMP_WORK_PENDING_B_T
(   
  PARENT_PIID, PARENT_ATID, CSCOPE_ID, PARENT_EHIID, PARENT_FEIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.CWP_PI_AT_EHI ON @SCHEMA@.COMP_WORK_PENDING_B_T
(   
  PARENT_PIID, PARENT_ATID, PARENT_EHIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
(
  AIID                               RAW(16)              NOT NULL ,
  SIID                               RAW(16)              NOT NULL ,
  ATID                               RAW(16)                       ,
  PIID                               RAW(16)              NOT NULL ,
  COMPLETION_NUMBER                  NUMBER(20,0)         NOT NULL ,
  STATE                              NUMBER(10,0)         NOT NULL ,
  COMPENSATE_AIID                    RAW(16)                       ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T ADD(
  PRIMARY KEY ( AIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.CPAI_SI_S_CN_AI_PI ON @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
(   
  SIID, STATE, COMPLETION_NUMBER, AIID, PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.CPAI_PIID ON @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
(   
  PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.RESTART_EVENT_B_T
(
  PKID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  PORT_TYPE                          VARCHAR2(254)        NOT NULL ,
  OPERATION                          VARCHAR2(254)        NOT NULL ,
  NAMESPACE                          VARCHAR2(254)        NOT NULL ,
  INPUT_MESSAGE                      BLOB                          ,
  REPLY_CTX                          BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.RESTART_EVENT_B_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.REB_PIID ON @SCHEMA@.RESTART_EVENT_B_T
(   
  PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.PROGRESS_COUNTER_T
(
  PIID                               RAW(16)              NOT NULL ,
  COUNTER                            NUMBER(20,0)         NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.PROGRESS_COUNTER_T ADD(
  PRIMARY KEY ( PIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.RELEVANT_SCOPE_ATASK_T
(
  SIID                               RAW(16)              NOT NULL ,
  TKIID                              RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.RELEVANT_SCOPE_ATASK_T ADD(
  PRIMARY KEY ( SIID, TKIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.RSAT_PIID ON @SCHEMA@.RELEVANT_SCOPE_ATASK_T
(   
  PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.CONFIG_INFO_T
(
  IDENTIFIER                         VARCHAR2(64)         NOT NULL ,
  DESCRIPTION                        VARCHAR2(128)                 ,
  PROPERTY                           NUMBER(10,0)                  ,
  COUNTER                            NUMBER(20,0)                  ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.CONFIG_INFO_T ADD(
  PRIMARY KEY ( IDENTIFIER )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
(
  PIID                               RAW(16)              NOT NULL ,
  ATTR_KEY                           VARCHAR2(220)        NOT NULL ,
  VALUE                              VARCHAR2(254)                 ,
  DATA_TYPE                          VARCHAR2(254)                 ,
  DATA                               BLOB                          ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T ADD(
  PRIMARY KEY ( PIID, ATTR_KEY )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.PIA_VALUE ON @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
(   
  VALUE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.PIA_DATY ON @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
(   
  DATA_TYPE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.PROCESS_CONTEXT_T
(
  PIID                               RAW(16)              NOT NULL ,
  SHARED                             NUMBER(5,0)                   ,
  REPLY_CONTEXT                      BLOB                          ,
  SERVICE_CONTEXT                    BLOB                          ,
  STARTER_EXPIRES                    TIMESTAMP                     ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.PROCESS_CONTEXT_T ADD(
  PRIMARY KEY ( PIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(
  PKID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  ATID                               RAW(16)              NOT NULL ,
  EHIID                              RAW(16)                       ,
  FEIID                              RAW(16)                       ,
  AIID                               RAW(16)                       ,
  ATTR_KEY                           VARCHAR2(189)        NOT NULL ,
  ATTR_VALUE                         VARCHAR2(254)                 ,
  DATA_TYPE                          VARCHAR2(254)                 ,
  DATA                               BLOB                          ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE UNIQUE INDEX @SCHEMA@.AIA_UNIQUE ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
  PIID, ATID, EHIID, FEIID, ATTR_KEY
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.AIA_AIID ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
  AIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.AIA_VALUE ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
  ATTR_VALUE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.AIA_DATY ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
  DATA_TYPE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.NAVIGATION_EXCEPTION_T
(
  CORRELATION_ID                     RAW(220)             NOT NULL ,
  EXCEPTION_TYPE                     NUMBER(10,0)         NOT NULL ,
  PIID                               RAW(16)                       ,
  OUTPUT_MESSAGE                     BLOB                          ,
  TYPE_SYSTEM                        VARCHAR2(32)                  ,
  PROCESS_EXCEPTION                  BLOB                 NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.NAVIGATION_EXCEPTION_T ADD(
  PRIMARY KEY ( CORRELATION_ID, EXCEPTION_TYPE )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.NE_PIID ON @SCHEMA@.NAVIGATION_EXCEPTION_T
(   
  PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.AWAITED_INVOCATION_T
(
  CORRELATION_ID                     RAW(254)             NOT NULL ,
  CORRELATION_INFO                   BLOB                 NOT NULL ,
  AIID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.AWAITED_INVOCATION_T ADD(
  PRIMARY KEY ( CORRELATION_ID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.AWI_PIID ON @SCHEMA@.AWAITED_INVOCATION_T
(   
  PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.AWI_AIID ON @SCHEMA@.AWAITED_INVOCATION_T
(   
  AIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.STORED_QUERY_T
(
  SQID                               RAW(16)              NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  NAME                               VARCHAR2(64)         NOT NULL ,
  OWNER_ID                           VARCHAR2(128)        NOT NULL ,
  SELECT_CLAUSE                      CLOB                 NOT NULL ,
  WHERE_CLAUSE                       CLOB                          ,
  ORDER_CLAUSE                       VARCHAR2(254)                 ,
  THRESHOLD                          NUMBER(10,0)                  ,
  TIMEZONE                           VARCHAR2(63)                  ,
  CREATOR                            VARCHAR2(128)                 ,
  TYPE                               VARCHAR2(128)                 ,
  PROPERTY                           BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING
  LOB (SELECT_CLAUSE) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  )
  LOB (WHERE_CLAUSE) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  );

ALTER TABLE @SCHEMA@.STORED_QUERY_T ADD(
  PRIMARY KEY ( SQID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE UNIQUE INDEX @SCHEMA@.SQ_NAME ON @SCHEMA@.STORED_QUERY_T
(   
  KIND, OWNER_ID, NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.FOR_EACH_INSTANCE_B_T
(
  FEIID                              RAW(16)              NOT NULL ,
  PARENT_FEIID                       RAW(16)                       ,
  PIID                               RAW(16)              NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.FOR_EACH_INSTANCE_B_T ADD(
  PRIMARY KEY ( FEIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.FEI_PIID ON @SCHEMA@.FOR_EACH_INSTANCE_B_T
(   
  PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(
  PKID                               RAW(16)              NOT NULL ,
  CTID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  PAID                               RAW(16)              NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  VARIABLE_NAME                      VARCHAR2(254)        NOT NULL ,
  PROPERTY_NAME                      VARCHAR2(255)        NOT NULL ,
  PROPERTY_NAMESPACE                 VARCHAR2(254)        NOT NULL ,
  TYPE                               NUMBER(10,0)         NOT NULL ,
  GENERIC_VALUE                      VARCHAR2(512)                 ,
  STRING_VALUE                       VARCHAR2(512)                 ,
  NUMBER_VALUE                       NUMBER(20,0)                  ,
  DECIMAL_VALUE                      NUMBER                        ,
  TIMESTAMP_VALUE                    TIMESTAMP                     ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.QVI_PI_CT_PA ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, CTID, PAID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.QVI_PI_VARNAME ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, VARIABLE_NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.QVI_PI_PROPNAME ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, PROPERTY_NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.QVI_PI_NAMESPACE ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, PROPERTY_NAMESPACE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.QVI_PI_GEN_VALUE ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, GENERIC_VALUE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.QVI_PI_STR_VALUE ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, STRING_VALUE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.QVI_PI_NUM ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, NUMBER_VALUE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.QVI_PI_DEC ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, DECIMAL_VALUE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.QVI_PI_TIME ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, TIMESTAMP_VALUE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.SYNC_T
(
  IDENTIFIER                         VARCHAR2(254)        NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.SYNC_T ADD(
  PRIMARY KEY ( IDENTIFIER )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.MV_CTR_T
(
  ID                                 NUMBER(10,0)         NOT NULL ,
  SELECT_CLAUSE                      VARCHAR2(1024)       NOT NULL ,
  WHERE_CLAUSE                       VARCHAR2(1024)                ,
  ORDER_CLAUSE                       VARCHAR2(512)                 ,
  TBL_SPACE                          VARCHAR2(32)         NOT NULL ,
  UPDATED                            TIMESTAMP            NOT NULL ,
  UPD_STARTED                        TIMESTAMP                     ,
  AVG_UPD_TIME                       NUMBER(20,0)                  ,
  UPD_INTERVAL                       NUMBER(20,0)         NOT NULL ,
  IS_UPDATING                        NUMBER(5,0)          NOT NULL ,
  ACTIVE_MV                          NUMBER(5,0)          NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.MV_CTR_T ADD(
  PRIMARY KEY ( ID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.MV_MODS_T
(
  PKID                               RAW(16)              NOT NULL ,
  OID                                RAW(16)              NOT NULL ,
  MODIFIED                           TIMESTAMP            NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.MV_MODS_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(
  PKID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)                       ,
  CREATION_TIME                      TIMESTAMP            NOT NULL ,
  REASON                             NUMBER(10,0)         NOT NULL ,
  ENGINE_MESSAGE_S                   RAW(2000)                     ,
  ENGINE_MESSAGE_L                   BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.SEM_PIID ON @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(   
  PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SEM_REAS ON @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(   
  REASON, CREATION_TIME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.NAVIGATION_CLEANUP_TIMER_B_T
(
  PKID                               RAW(16)              NOT NULL ,
  SCHEDULED_TIME                     TIMESTAMP            NOT NULL ,
  SCHEDULER_ID                       VARCHAR2(254)        NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.NAVIGATION_CLEANUP_TIMER_B_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.SCHEDULER_ACTION_T
(
  SCHEDULER_ID                       VARCHAR2(254)        NOT NULL ,
  OID                                RAW(16)              NOT NULL ,
  ACTION_OBJECT                      BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.SCHEDULER_ACTION_T ADD(
  PRIMARY KEY ( SCHEDULER_ID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.SCEACT_OID ON @SCHEMA@.SCHEDULER_ACTION_T
(   
  OID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.QUERY_TABLE_T
(
  NAME                               VARCHAR2(32)         NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  TYPE                               NUMBER(10,0)         NOT NULL ,
  VERSION                            NUMBER(10,0)         NOT NULL ,
  LAST_UPDATED                       TIMESTAMP            NOT NULL ,
  PRIMARY_VIEW                       VARCHAR2(32)                  ,
  DEFINITION                         BLOB                 NOT NULL ,
  VV_CFG                             BLOB                          ,
  DV_CFG                             BLOB                          ,
  MV_CFG                             BLOB                          ,
  MT_CFG                             BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.QUERY_TABLE_T ADD(
  PRIMARY KEY ( NAME )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.QT_KI ON @SCHEMA@.QUERY_TABLE_T
(   
  KIND
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.QT_TY ON @SCHEMA@.QUERY_TABLE_T
(   
  TYPE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.QUERY_TABLE_REF_T
(
  REFEREE                            VARCHAR2(32)         NOT NULL ,
  SOURCE                             VARCHAR2(32)         NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.QUERY_TABLE_REF_T ADD(
  PRIMARY KEY ( REFEREE, SOURCE )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.QTR_SRC ON @SCHEMA@.QUERY_TABLE_REF_T
(   
  SOURCE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.MIGRATION_FRONT_T
(
  PIID                               RAW(16)              NOT NULL ,
  MPTID                              RAW(16)              NOT NULL ,
  AIID                               RAW(16)              NOT NULL ,
  STATE                              NUMBER(10,0)         NOT NULL ,
  SUB_STATE                          NUMBER(10,0)         NOT NULL ,
  STOP_REASON                        NUMBER(10,0)         NOT NULL ,
  SOURCE_ATID                        RAW(16)              NOT NULL ,
  TARGET_ATID                        RAW(16)              NOT NULL ,
  MIGRATION_TIME                     TIMESTAMP            NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.MIGRATION_FRONT_T ADD(
  PRIMARY KEY ( PIID, MPTID, AIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.MGF_MPTID ON @SCHEMA@.MIGRATION_FRONT_T
(   
  MPTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
(
  SIID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  COUNTER                            NUMBER(20,0)                  ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.SCOPE_COMPLETION_COUNTER_T ADD(
  PRIMARY KEY ( SIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.SCC_PIID ON @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
(   
  PIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.AUDIT_LOG_T
(
  ALID                               RAW(16)              NOT NULL ,
  EVENT_TIME                         TIMESTAMP            NOT NULL ,
  EVENT_TIME_UTC                     TIMESTAMP                     ,
  AUDIT_EVENT                        NUMBER(10,0)         NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)                       ,
  AIID                               RAW(16)                       ,
  SIID                               RAW(16)                       ,
  VARIABLE_NAME                      VARCHAR2(254)                 ,
  PROCESS_TEMPL_NAME                 VARCHAR2(254)        NOT NULL ,
  PROCESS_INST_NAME                  VARCHAR2(254)                 ,
  TOP_LEVEL_PI_NAME                  VARCHAR2(254)                 ,
  TOP_LEVEL_PIID                     RAW(16)                       ,
  PARENT_PI_NAME                     VARCHAR2(254)                 ,
  PARENT_PIID                        RAW(16)                       ,
  VALID_FROM                         TIMESTAMP                     ,
  VALID_FROM_UTC                     TIMESTAMP                     ,
  ATID                               RAW(16)                       ,
  ACTIVITY_NAME                      VARCHAR2(254)                 ,
  ACTIVITY_KIND                      NUMBER(10,0)                  ,
  ACTIVITY_STATE                     NUMBER(10,0)                  ,
  CONTROL_LINK_NAME                  VARCHAR2(254)                 ,
  IMPL_NAME                          VARCHAR2(254)                 ,
  PRINCIPAL                          VARCHAR2(128)                 ,
  TERMINAL_NAME                      VARCHAR2(254)                 ,
  VARIABLE_DATA                      BLOB                          ,
  EXCEPTION_TEXT                     CLOB                          ,
  DESCRIPTION                        VARCHAR2(254)                 ,
  CORR_SET_INFO                      CLOB                          ,
  USER_NAME                          VARCHAR2(128)                 ,
  ADDITIONAL_INFO                    CLOB                          ,
  OBJECT_META_TYPE                   NUMBER(10,0)                  ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @AUDITLOG@
  LOGGING
  LOB (EXCEPTION_TEXT) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  )
  LOB (CORR_SET_INFO) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  )
  LOB (ADDITIONAL_INFO) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  );

ALTER TABLE @SCHEMA@.AUDIT_LOG_T ADD(
  PRIMARY KEY ( ALID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.WORK_ITEM_T
(
  WIID                               RAW(16)              NOT NULL ,
  PARENT_WIID                        RAW(16)                       ,
  OWNER_ID                           VARCHAR2(128)                 ,
  GROUP_NAME                         VARCHAR2(128)                 ,
  EVERYBODY                          NUMBER(5,0)          NOT NULL ,
  EXCLUDE                            NUMBER(5,0)          NOT NULL ,
  QIID                               RAW(16)                       ,
  OBJECT_TYPE                        NUMBER(10,0)         NOT NULL ,
  OBJECT_ID                          RAW(16)              NOT NULL ,
  ASSOCIATED_OBJECT_TYPE             NUMBER(10,0)         NOT NULL ,
  ASSOCIATED_OID                     RAW(16)                       ,
  REASON                             NUMBER(10,0)         NOT NULL ,
  CREATION_TIME                      TIMESTAMP            NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  AUTH_INFO                          NUMBER(10,0)         NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @WORKITEM@
  LOGGING;

ALTER TABLE @SCHEMA@.WORK_ITEM_T ADD(
  PRIMARY KEY ( WIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.WI_ASSOBJ_REASON ON @SCHEMA@.WORK_ITEM_T
(   
  ASSOCIATED_OID, ASSOCIATED_OBJECT_TYPE, REASON, PARENT_WIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_OBJID_TYPE_QIID ON @SCHEMA@.WORK_ITEM_T
(   
  OBJECT_ID, OBJECT_TYPE, QIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_OBJID_TYPE_REAS ON @SCHEMA@.WORK_ITEM_T
(   
  OBJECT_ID, OBJECT_TYPE, REASON
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_GROUP_NAME ON @SCHEMA@.WORK_ITEM_T
(   
  GROUP_NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_AUTH_L ON @SCHEMA@.WORK_ITEM_T
(   
  EVERYBODY, GROUP_NAME, OWNER_ID, QIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_AUTH_U ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, QIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_AUTH_O ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, OWNER_ID DESC
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_AUTH_G ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, GROUP_NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_AUTH_E ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, EVERYBODY
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_AUTH_R ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, REASON DESC
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_REASON ON @SCHEMA@.WORK_ITEM_T
(   
  REASON
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_OWNER ON @SCHEMA@.WORK_ITEM_T
(   
  OWNER_ID, OBJECT_ID, REASON, OBJECT_TYPE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_QIID ON @SCHEMA@.WORK_ITEM_T
(   
  QIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_QRY ON @SCHEMA@.WORK_ITEM_T
(   
  OBJECT_ID, REASON, EVERYBODY, OWNER_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_QI_OID_RS_OWN ON @SCHEMA@.WORK_ITEM_T
(   
  QIID, OBJECT_ID, REASON, OWNER_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_QI_OID_OWN ON @SCHEMA@.WORK_ITEM_T
(   
  QIID, OBJECT_ID, OWNER_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_OT_OID_RS ON @SCHEMA@.WORK_ITEM_T
(   
  OBJECT_TYPE, OBJECT_ID, REASON
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_WI_QI ON @SCHEMA@.WORK_ITEM_T
(   
  WIID, QIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_PWIID_OID ON @SCHEMA@.WORK_ITEM_T
(   
  PARENT_WIID, OBJECT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_PWIID_QIID ON @SCHEMA@.WORK_ITEM_T
(   
  PARENT_WIID, QIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_AUTH_GR_O_E ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, GROUP_NAME, OWNER_ID, EVERYBODY
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_PD1 ON @SCHEMA@.WORK_ITEM_T
(   
  OWNER_ID, AUTH_INFO, OBJECT_TYPE, REASON, OBJECT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_PD2 ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, OBJECT_TYPE, REASON, OBJECT_ID, QIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.RETRIEVED_USER_T
(
  QIID                               RAW(16)              NOT NULL ,
  OWNER_ID                           VARCHAR2(128)        NOT NULL ,
  REASON                             NUMBER(10,0)         NOT NULL ,
  ASSOCIATED_OID                     RAW(16)                       ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @WORKITEM@
  LOGGING;

ALTER TABLE @SCHEMA@.RETRIEVED_USER_T ADD(
  PRIMARY KEY ( QIID, OWNER_ID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.RUT_OWN_QIID ON @SCHEMA@.RETRIEVED_USER_T
(   
  OWNER_ID, QIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.RUT_ASSOC ON @SCHEMA@.RETRIEVED_USER_T
(   
  ASSOCIATED_OID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.RUT_QIID ON @SCHEMA@.RETRIEVED_USER_T
(   
  QIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.RUT_OWN_QIDESC ON @SCHEMA@.RETRIEVED_USER_T
(   
  OWNER_ID, QIID DESC
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.RETRIEVED_GROUP_T
(
  QIID                               RAW(16)              NOT NULL ,
  GROUP_NAME                         VARCHAR2(128)        NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @WORKITEM@
  LOGGING;

ALTER TABLE @SCHEMA@.RETRIEVED_GROUP_T ADD(
  PRIMARY KEY ( QIID, GROUP_NAME )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.WIS_META_DATA_T
(
  WSID                               RAW(16)              NOT NULL ,
  HASH_CODE                          NUMBER(10,0)         NOT NULL ,
  OBJECT_TYPE                        NUMBER(10,0)         NOT NULL ,
  LAST_CHECK                         TIMESTAMP            NOT NULL ,
  UNUSED                             NUMBER(5,0)          NOT NULL ,
  AUTH_INFO_RETRIEVED_USER           NUMBER(5,0)          NOT NULL ,
  AUTH_INFO_OWNER_ID                 NUMBER(5,0)          NOT NULL ,
  AUTH_INFO_EVERYBODY                NUMBER(5,0)          NOT NULL ,
  AUTH_INFO_GROUP                    NUMBER(5,0)          NOT NULL ,
  AUTH_INFO_RETRIEVED_GROUP          NUMBER(5,0)          NOT NULL ,
  AUTH_INFO_EMPTY                    NUMBER(5,0)          NOT NULL ,
  SHARING_PATTERN                    NUMBER(10,0)         NOT NULL ,
  REASONS                            RAW(32)              NOT NULL ,
  PARAMETER_A                        NUMBER(10,0)                  ,
  PARAMETER_B                        NUMBER(10,0)                  ,
  PARAMETER_C                        NUMBER(10,0)                  ,
  PARAMETER_D                        RAW(16)                       ,
  PARAMETER_E                        TIMESTAMP                     ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @WORKITEM@
  LOGGING;

ALTER TABLE @SCHEMA@.WIS_META_DATA_T ADD(
  PRIMARY KEY ( WSID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.WMD_HCUNU ON @SCHEMA@.WIS_META_DATA_T
(   
  HASH_CODE, UNUSED
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.E_SWI_T
(
  PKID                               RAW(16)              NOT NULL ,
  WIID                               RAW(16)              NOT NULL ,
  WSID                               RAW(16)              NOT NULL ,
  HASH_CODE                          NUMBER(10,0)         NOT NULL ,
  WIS_HASH_CODE                      NUMBER(10,0)                  ,
  PARENT_WIID                        RAW(16)                       ,
  REASON                             NUMBER(10,0)         NOT NULL ,
  INHERITED                          NUMBER(5,0)                   ,
  QIID                               RAW(16)                       ,
  OBJECT_TYPE                        NUMBER(10,0)         NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  SHARING_PATTERN                    NUMBER(10,0)         NOT NULL ,
  ACCESS_KEY                         NUMBER(10,0)         NOT NULL ,
  TEMPLATE_ID                        RAW(16)                       ,
  PARAMETER_A                        NUMBER(10,0)                  ,
  PARAMETER_B                        NUMBER(10,0)                  ,
  PARAMETER_C                        NUMBER(10,0)                  ,
  PARAMETER_D                        RAW(16)                       ,
  PARAMETER_E                        TIMESTAMP                     ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @WORKITEM@
  LOGGING;

ALTER TABLE @SCHEMA@.E_SWI_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.WE_WSID ON @SCHEMA@.E_SWI_T
(   
  WSID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WE_HASHCODE ON @SCHEMA@.E_SWI_T
(   
  HASH_CODE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WE_WIID ON @SCHEMA@.E_SWI_T
(   
  WIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WE_QIID ON @SCHEMA@.E_SWI_T
(   
  QIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.SWI_T
(
  PKID                               RAW(16)              NOT NULL ,
  WIID                               RAW(16)              NOT NULL ,
  PARENT_WIID                        RAW(16)                       ,
  OWNER_ID                           VARCHAR2(128)                 ,
  GROUP_NAME                         VARCHAR2(128)                 ,
  EVERYBODY                          NUMBER(5,0)          NOT NULL ,
  QIID                               RAW(16)                       ,
  OBJECT_TYPE                        NUMBER(10,0)         NOT NULL ,
  REASON                             NUMBER(10,0)         NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  AUTH_INFO                          NUMBER(10,0)         NOT NULL ,
  SHARING_PATTERN                    NUMBER(10,0)         NOT NULL ,
  ACCESS_KEY                         NUMBER(10,0)         NOT NULL ,
  WSID                               RAW(16)              NOT NULL ,
  HASH_CODE                          NUMBER(10,0)         NOT NULL ,
  WIS_HASH_CODE                      NUMBER(10,0)                  ,
  INHERITED                          NUMBER(5,0)                   ,
  TEMPLATE_ID                        RAW(16)                       ,
  PARAMETER_A                        NUMBER(10,0)                  ,
  PARAMETER_B                        NUMBER(10,0)                  ,
  PARAMETER_C                        NUMBER(10,0)                  ,
  PARAMETER_D                        RAW(16)                       ,
  PARAMETER_E                        TIMESTAMP                     ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @WORKITEM@
  LOGGING;

ALTER TABLE @SCHEMA@.SWI_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.SWI_WSID ON @SCHEMA@.SWI_T
(   
  WSID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SWI_HASHCODE ON @SCHEMA@.SWI_T
(   
  HASH_CODE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SWI_OTRPD ON @SCHEMA@.SWI_T
(   
  OBJECT_TYPE, REASON, TEMPLATE_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SWI_WIID ON @SCHEMA@.SWI_T
(   
  WIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SWI_QIID ON @SCHEMA@.SWI_T
(   
  QIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SWI_OWN ON @SCHEMA@.SWI_T
(   
  OWNER_ID, ACCESS_KEY, WSID, REASON
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SWI_GRP ON @SCHEMA@.SWI_T
(   
  GROUP_NAME, ACCESS_KEY, WSID, REASON
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SWI_ACCK1 ON @SCHEMA@.SWI_T
(   
  ACCESS_KEY, REASON, WSID, QIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SWI_ACCK2 ON @SCHEMA@.SWI_T
(   
  ACCESS_KEY, REASON, QIID, WSID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SWI_ACCK3 ON @SCHEMA@.SWI_T
(   
  ACCESS_KEY, REASON, OWNER_ID, WSID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SWI_ACCK4 ON @SCHEMA@.SWI_T
(   
  ACCESS_KEY, REASON, WSID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SWI_ACCK5 ON @SCHEMA@.SWI_T
(   
  ACCESS_KEY, OWNER_ID, REASON, WSID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SWI_ACCK6 ON @SCHEMA@.SWI_T
(   
  ACCESS_KEY, GROUP_NAME, REASON, WSID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.STAFF_QUERY_INSTANCE_T
(
  QIID                               RAW(16)              NOT NULL ,
  QTID                               RAW(16)              NOT NULL ,
  EVERYBODY                          NUMBER(5,0)          NOT NULL ,
  NOBODY                             NUMBER(5,0)          NOT NULL ,
  IS_SHAREABLE                       NUMBER(5,0)          NOT NULL ,
  IS_TRANSFERRED                     NUMBER(5,0)          NOT NULL ,
  SR_HASH_CODE                       NUMBER(10,0)                  ,
  GROUP_NAME                         VARCHAR2(128)                 ,
  CONTEXT_VALUES                     VARCHAR2(3072)                ,
  CONTEXT_VALUES_LONG                CLOB                          ,
  HASH_CODE                          NUMBER(10,0)                  ,
  EXPIRES                            TIMESTAMP                     ,
  ASSOCIATED_OBJECT_TYPE             NUMBER(10,0)         NOT NULL ,
  ASSOCIATED_OID                     RAW(16)              NOT NULL ,
  NORMALIZED                         NUMBER(5,0)                   ,
  DENORMALIZED                       NUMBER(5,0)                   ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @STAFFQRY@
  LOGGING
  LOB (CONTEXT_VALUES_LONG) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  );

ALTER TABLE @SCHEMA@.STAFF_QUERY_INSTANCE_T ADD(
  PRIMARY KEY ( QIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.SQI_QTID ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
  QTID, HASH_CODE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SQI_ASSOCID ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
  ASSOCIATED_OID, ASSOCIATED_OBJECT_TYPE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SQI_QIIDGN ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
  QIID, GROUP_NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.SQI_QIIDTREX ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
  QIID, IS_TRANSFERRED, EXPIRES
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.STAFF_LOCK_T
(
  QTID                               RAW(16)              NOT NULL ,
  HASH_CODE                          NUMBER(10,0)         NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @STAFFQRY@
  LOGGING;

ALTER TABLE @SCHEMA@.STAFF_LOCK_T ADD(
  PRIMARY KEY ( QTID, HASH_CODE )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.APPLICATION_COMPONENT_T
(
  ACOID                              RAW(16)              NOT NULL ,
  NAME                               VARCHAR2(64)         NOT NULL ,
  CALENDAR_NAME                      VARCHAR2(254)                 ,
  JNDI_NAME_CALENDAR                 VARCHAR2(254)                 ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR2(254)        NOT NULL ,
  DURATION_UNTIL_DELETED             VARCHAR2(254)                 ,
  EVENT_HANDLER_NAME                 VARCHAR2(64)                  ,
  INSTANCE_CREATOR_QTID              RAW(16)                       ,
  SUPPORTS_AUTO_CLAIM                NUMBER(5,0)          NOT NULL ,
  SUPPORTS_FOLLOW_ON_TASK            NUMBER(5,0)          NOT NULL ,
  SUPPORTS_CLAIM_SUSPENDED           NUMBER(5,0)          NOT NULL ,
  SUPPORTS_DELEGATION                NUMBER(5,0)          NOT NULL ,
  SUPPORTS_SUB_TASK                  NUMBER(5,0)          NOT NULL ,
  BUSINESS_RELEVANCE                 NUMBER(5,0)          NOT NULL ,
  SUBSTITUTION_POLICY                NUMBER(10,0)         NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.APPLICATION_COMPONENT_T ADD(
  PRIMARY KEY ( ACOID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE UNIQUE INDEX @SCHEMA@.ACO_NAME ON @SCHEMA@.APPLICATION_COMPONENT_T
(   
  NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.ESCALATION_TEMPLATE_T
(
  ESTID                              RAW(16)              NOT NULL ,
  FIRST_ESTID                        RAW(16)                       ,
  PREVIOUS_ESTID                     RAW(16)                       ,
  TKTID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  MNTID                              RAW(16)                       ,
  NAME                               VARCHAR2(220)                 ,
  ACTIVATION_STATE                   NUMBER(10,0)         NOT NULL ,
  AT_LEAST_EXPECTED_STATE            NUMBER(10,0)         NOT NULL ,
  DURATION_UNTIL_ESCALATION          VARCHAR2(254)                 ,
  DURATION_UNTIL_REPEATS             VARCHAR2(254)                 ,
  INCREASE_PRIORITY                  NUMBER(10,0)         NOT NULL ,
  ACTION                             NUMBER(10,0)         NOT NULL ,
  ESCALATION_RECEIVER_QTID           RAW(16)                       ,
  RECEIVER_EMAIL_QTID                RAW(16)                       
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.ESCALATION_TEMPLATE_T ADD(
  PRIMARY KEY ( ESTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.ET_TKTID ON @SCHEMA@.ESCALATION_TEMPLATE_T
(   
  TKTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.ET_CCID ON @SCHEMA@.ESCALATION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.ESC_TEMPL_CPROP_T
(
  ESTID                              RAW(16)              NOT NULL ,
  NAME                               VARCHAR2(220)        NOT NULL ,
  TKTID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  STRING_VALUE                       VARCHAR2(254)                 ,
  DATA_TYPE                          VARCHAR2(254)                 ,
  DATA                               BLOB                          
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.ESC_TEMPL_CPROP_T ADD(
  PRIMARY KEY ( ESTID, NAME )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.ETCP_TKTID ON @SCHEMA@.ESC_TEMPL_CPROP_T
(   
  TKTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.ETCP_CCID ON @SCHEMA@.ESC_TEMPL_CPROP_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.ESC_TEMPL_LDESC_T
(
  ESTID                              RAW(16)              NOT NULL ,
  LOCALE                             VARCHAR2(32)         NOT NULL ,
  TKTID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  DISPLAY_NAME                       VARCHAR2(64)                  ,
  DESCRIPTION                        VARCHAR2(254)                 ,
  DOCUMENTATION                      CLOB                          
) TABLESPACE @TEMPLATE@
  LOGGING
  LOB (DOCUMENTATION) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  );

ALTER TABLE @SCHEMA@.ESC_TEMPL_LDESC_T ADD(
  PRIMARY KEY ( ESTID, LOCALE )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.ETLD_TKTID ON @SCHEMA@.ESC_TEMPL_LDESC_T
(   
  TKTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.ETLD_CCID ON @SCHEMA@.ESC_TEMPL_LDESC_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.TTASK_MESSAGE_DEFINITION_T
(
  TMTID                              RAW(16)              NOT NULL ,
  TKTID                              RAW(16)                       ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  FAULT_NAME                         VARCHAR2(254)                 ,
  MESSAGE_TYPE_NS                    VARCHAR2(220)        NOT NULL ,
  MESSAGE_TYPE_NAME                  VARCHAR2(220)        NOT NULL ,
  MESSAGE_DEFINITION                 BLOB                          
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.TTASK_MESSAGE_DEFINITION_T ADD(
  PRIMARY KEY ( TMTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.TTMD_TKTID ON @SCHEMA@.TTASK_MESSAGE_DEFINITION_T
(   
  TKTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TTMD_CCID ON @SCHEMA@.TTASK_MESSAGE_DEFINITION_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.TASK_TEMPLATE_T
(
  TKTID                              RAW(16)              NOT NULL ,
  NAME                               VARCHAR2(220)        NOT NULL ,
  DEFINITION_NAME                    VARCHAR2(220)        NOT NULL ,
  NAMESPACE                          VARCHAR2(254)        NOT NULL ,
  TARGET_NAMESPACE                   VARCHAR2(254)        NOT NULL ,
  VALID_FROM                         TIMESTAMP            NOT NULL ,
  APPLICATION_NAME                   VARCHAR2(220)                 ,
  APPLICATION_DEFAULTS_ID            RAW(16)                       ,
  CONTAINMENT_CONTEXT_ID             RAW(16)                       ,
  SVTID                              RAW(16)                       ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  STATE                              NUMBER(10,0)         NOT NULL ,
  AUTO_DELETE_MODE                   NUMBER(10,0)         NOT NULL ,
  IS_AD_HOC                          NUMBER(5,0)          NOT NULL ,
  IS_INLINE                          NUMBER(5,0)          NOT NULL ,
  IS_SHARED                          NUMBER(5,0)          NOT NULL ,
  SUPPORTS_CLAIM_SUSPENDED           NUMBER(5,0)          NOT NULL ,
  SUPPORTS_AUTO_CLAIM                NUMBER(5,0)          NOT NULL ,
  SUPPORTS_FOLLOW_ON_TASK            NUMBER(5,0)          NOT NULL ,
  SUPPORTS_DELEGATION                NUMBER(5,0)          NOT NULL ,
  SUPPORTS_SUB_TASK                  NUMBER(5,0)          NOT NULL ,
  CONTEXT_AUTHORIZATION              NUMBER(10,0)         NOT NULL ,
  AUTONOMY                           NUMBER(10,0)         NOT NULL ,
  ADMIN_QTID                         RAW(16)                       ,
  EDITOR_QTID                        RAW(16)                       ,
  INSTANCE_CREATOR_QTID              RAW(16)                       ,
  POTENTIAL_STARTER_QTID             RAW(16)                       ,
  POTENTIAL_OWNER_QTID               RAW(16)                       ,
  READER_QTID                        RAW(16)                       ,
  DEFAULT_LOCALE                     VARCHAR2(32)                  ,
  CALENDAR_NAME                      VARCHAR2(254)                 ,
  DURATION_UNTIL_DELETED             VARCHAR2(254)                 ,
  DURATION_UNTIL_DUE                 VARCHAR2(254)                 ,
  DURATION_UNTIL_EXPIRES             VARCHAR2(254)                 ,
  JNDI_NAME_CALENDAR                 VARCHAR2(254)                 ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR2(254)        NOT NULL ,
  TYPE                               VARCHAR2(254)                 ,
  EVENT_HANDLER_NAME                 VARCHAR2(64)                  ,
  PRIORITY                           NUMBER(10,0)                  ,
  PRIORITY_DEFINITION                VARCHAR2(254)                 ,
  BUSINESS_RELEVANCE                 NUMBER(5,0)          NOT NULL ,
  SUBSTITUTION_POLICY                NUMBER(10,0)         NOT NULL ,
  CONTACTS_QTIDS                     BLOB                          ,
  UI_SETTINGS                        BLOB                          ,
  ASSIGNMENT_TYPE                    NUMBER(10,0)         NOT NULL ,
  INHERITED_AUTH                     NUMBER(10,0)         NOT NULL ,
  PARALLEL_INHERITED_AUTH            NUMBER(10,0)         NOT NULL ,
  NATIVE_LOOKUP_NAME                 VARCHAR2(254)                 ,
  WORK_BASKET                        VARCHAR2(254)                 ,
  EAR_VERSION                        NUMBER(10,0)         NOT NULL ,
  SCHEMA_VERSION                     NUMBER(10,0)         NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T ADD(
  PRIMARY KEY ( TKTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE UNIQUE INDEX @SCHEMA@.TT_NAME_VF_NS ON @SCHEMA@.TASK_TEMPLATE_T
(   
  NAME, VALID_FROM, NAMESPACE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TT_CCID_STATE ON @SCHEMA@.TASK_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID, STATE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TT_KND_INLN_VAL ON @SCHEMA@.TASK_TEMPLATE_T
(   
  KIND, IS_INLINE, VALID_FROM
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TT_NATLOOK_ADHOC ON @SCHEMA@.TASK_TEMPLATE_T
(   
  NATIVE_LOOKUP_NAME, IS_AD_HOC
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.TASK_TEMPL_CPROP_T
(
  TKTID                              RAW(16)              NOT NULL ,
  NAME                               VARCHAR2(220)        NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  DATA_TYPE                          VARCHAR2(254)                 ,
  STRING_VALUE                       VARCHAR2(254)                 ,
  DATA                               BLOB                          
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.TASK_TEMPL_CPROP_T ADD(
  PRIMARY KEY ( TKTID, NAME )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.TTCP_TKTID ON @SCHEMA@.TASK_TEMPL_CPROP_T
(   
  TKTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TTCP_CCID ON @SCHEMA@.TASK_TEMPL_CPROP_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.TASK_TEMPL_LDESC_T
(
  TKTID                              RAW(16)              NOT NULL ,
  LOCALE                             VARCHAR2(32)         NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  DISPLAY_NAME                       VARCHAR2(64)                  ,
  DESCRIPTION                        VARCHAR2(254)                 ,
  DOCUMENTATION                      CLOB                          
) TABLESPACE @TEMPLATE@
  LOGGING
  LOB (DOCUMENTATION) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  );

ALTER TABLE @SCHEMA@.TASK_TEMPL_LDESC_T ADD(
  PRIMARY KEY ( TKTID, LOCALE )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.TTLD_TKTID ON @SCHEMA@.TASK_TEMPL_LDESC_T
(   
  TKTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TTLD_CCID ON @SCHEMA@.TASK_TEMPL_LDESC_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TTLD_TT_LOC ON @SCHEMA@.TASK_TEMPL_LDESC_T
(   
  TKTID, LOCALE DESC
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.TSERVICE_DESCRIPTION_T
(
  SVTID                              RAW(16)              NOT NULL ,
  TKTID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  IS_ONE_WAY                         NUMBER(5,0)          NOT NULL ,
  SERVICE_REF_NAME                   VARCHAR2(254)                 ,
  OPERATION                          VARCHAR2(254)        NOT NULL ,
  PORT                               VARCHAR2(254)                 ,
  PORT_TYPE_NS                       VARCHAR2(254)        NOT NULL ,
  PORT_TYPE_NAME                     VARCHAR2(254)        NOT NULL ,
  S_BEAN_JNDI_NAME                   VARCHAR2(254)                 ,
  SERVICE                            VARCHAR2(254)                 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.TSERVICE_DESCRIPTION_T ADD(
  PRIMARY KEY ( SVTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.TSD_TKTID ON @SCHEMA@.TSERVICE_DESCRIPTION_T
(   
  TKTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TSD_CCID ON @SCHEMA@.TSERVICE_DESCRIPTION_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.TASK_CELL_MAP_T
(
  TKTID                              RAW(16)              NOT NULL ,
  CELL                               VARCHAR2(220)        NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.TASK_CELL_MAP_T ADD(
  PRIMARY KEY ( TKTID, CELL )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.TMAIL_T
(
  MNTID                              RAW(16)              NOT NULL ,
  FROM_STATE                         NUMBER(10,0)         NOT NULL ,
  TO_STATE                           NUMBER(10,0)         NOT NULL ,
  LOCALE                             VARCHAR2(32)         NOT NULL ,
  HASH_CODE                          NUMBER(10,0)         NOT NULL ,
  SUBJECT                            VARCHAR2(254)        NOT NULL ,
  BODY_TEXT                          CLOB                          
) TABLESPACE @TEMPLATE@
  LOGGING
  LOB (BODY_TEXT) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  );

ALTER TABLE @SCHEMA@.TMAIL_T ADD(
  PRIMARY KEY ( MNTID, FROM_STATE, TO_STATE, LOCALE )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.EMT_HC ON @SCHEMA@.TMAIL_T
(   
  HASH_CODE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.COMPLETION_TEMPLATE_T
(
  CMTID                              RAW(16)              NOT NULL ,
  ORDER_NUMBER                       NUMBER(10,0)         NOT NULL ,
  TKTID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  COMPL_CONDITION                    BLOB                          ,
  CRITERION_FOR                      VARCHAR2(254)                 ,
  COMPLETION_NAME                    VARCHAR2(220)                 ,
  IS_DEFAULT_COMPLETION              NUMBER(5,0)          NOT NULL ,
  PREFIX_MAP                         BLOB                          ,
  USE_DEFAULT_RESULT_CONSTRUCT       NUMBER(5,0)          NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.COMPLETION_TEMPLATE_T ADD(
  PRIMARY KEY ( CMTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.CMPT_TKTID_ORDER ON @SCHEMA@.COMPLETION_TEMPLATE_T
(   
  TKTID, ORDER_NUMBER
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.CMPT_CCID ON @SCHEMA@.COMPLETION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(
  RATID                              RAW(16)              NOT NULL ,
  ORDER_NUMBER                       NUMBER(10,0)         NOT NULL ,
  CMTID                              RAW(16)              NOT NULL ,
  TKTID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  AGGR_PART                          VARCHAR2(254)                 ,
  AGGR_LOCATION                      BLOB                          ,
  AGGR_FUNCTION                      VARCHAR2(254)        NOT NULL ,
  AGGR_CONDITION                     BLOB                          ,
  PREFIX_MAP                         BLOB                          
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T ADD(
  PRIMARY KEY ( RATID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.RAGT_CMTID_ORD_TT ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(   
  CMTID, ORDER_NUMBER, TKTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.RAGT_CCID ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.ESCALATION_INSTANCE_T
(
  ESIID                              RAW(16)              NOT NULL ,
  ESTID                              RAW(16)                       ,
  FIRST_ESIID                        RAW(16)                       ,
  PREVIOUS_ESIID                     RAW(16)                       ,
  TKIID                              RAW(16)              NOT NULL ,
  MNTID                              RAW(16)                       ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  NAME                               VARCHAR2(220)                 ,
  STATE                              NUMBER(10,0)         NOT NULL ,
  ACTIVATION_STATE                   NUMBER(10,0)         NOT NULL ,
  AT_LEAST_EXPECTED_STATE            NUMBER(10,0)         NOT NULL ,
  ACTIVATION_TIME                    TIMESTAMP                     ,
  ESCALATION_TIME                    TIMESTAMP                     ,
  DURATION_UNTIL_ESCALATION          VARCHAR2(254)                 ,
  DURATION_UNTIL_REPEATS             VARCHAR2(254)                 ,
  INCREASE_PRIORITY                  NUMBER(10,0)         NOT NULL ,
  ACTION                             NUMBER(10,0)         NOT NULL ,
  ESCALATION_RECEIVER_QTID           RAW(16)                       ,
  RECEIVER_EMAIL_QTID                RAW(16)                       ,
  SCHEDULER_ID                       VARCHAR2(254)                 ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T ADD(
  PRIMARY KEY ( ESIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.ESI_FIRST ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  FIRST_ESIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.ESI_TKIID_ASTATE ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  TKIID, ACTIVATION_STATE, STATE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.ESI_TKIID_STATE ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  TKIID, STATE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.ESI_PREV ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  PREVIOUS_ESIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.ESI_ESTID ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  ESTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.ESI_CCID ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.ESI_EST_ESI ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  ESTID, ESIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.ESI_WSID1 ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  WSID_1
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.ESI_WSID2 ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  WSID_2
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.ESC_INST_CPROP_T
(
  ESIID                              RAW(16)              NOT NULL ,
  NAME                               VARCHAR2(220)        NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  STRING_VALUE                       VARCHAR2(254)                 ,
  DATA_TYPE                          VARCHAR2(254)                 ,
  DATA                               BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.ESC_INST_CPROP_T ADD(
  PRIMARY KEY ( ESIID, NAME )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.EICP_CCID ON @SCHEMA@.ESC_INST_CPROP_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.ESC_INST_LDESC_T
(
  ESIID                              RAW(16)              NOT NULL ,
  LOCALE                             VARCHAR2(32)         NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  DISPLAY_NAME                       VARCHAR2(64)                  ,
  DESCRIPTION                        VARCHAR2(254)                 ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.ESC_INST_LDESC_T ADD(
  PRIMARY KEY ( ESIID, LOCALE )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.EILD_CCID ON @SCHEMA@.ESC_INST_LDESC_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.EIDOCUMENTATION_T
(
  ESIID                              RAW(16)              NOT NULL ,
  LOCALE                             VARCHAR2(32)         NOT NULL ,
  TKIID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  DOCUMENTATION                      CLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING
  LOB (DOCUMENTATION) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  );

ALTER TABLE @SCHEMA@.EIDOCUMENTATION_T ADD(
  PRIMARY KEY ( ESIID, LOCALE )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.EIDOC_CCID ON @SCHEMA@.EIDOCUMENTATION_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.ISERVICE_DESCRIPTION_T
(
  SVTID                              RAW(16)              NOT NULL ,
  TKIID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  IS_ONE_WAY                         NUMBER(5,0)          NOT NULL ,
  SERVICE_REF_NAME                   VARCHAR2(254)                 ,
  OPERATION                          VARCHAR2(254)        NOT NULL ,
  PORT                               VARCHAR2(254)                 ,
  PORT_TYPE_NS                       VARCHAR2(254)        NOT NULL ,
  PORT_TYPE_NAME                     VARCHAR2(254)        NOT NULL ,
  S_BEAN_JNDI_NAME                   VARCHAR2(254)                 ,
  SERVICE                            VARCHAR2(254)                 ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.ISERVICE_DESCRIPTION_T ADD(
  PRIMARY KEY ( SVTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.ISD_TKIID ON @SCHEMA@.ISERVICE_DESCRIPTION_T
(   
  TKIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.ISD_CCID ON @SCHEMA@.ISERVICE_DESCRIPTION_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.TASK_INSTANCE_T
(
  TKIID                              RAW(16)              NOT NULL ,
  NAME                               VARCHAR2(220)        NOT NULL ,
  NAMESPACE                          VARCHAR2(254)        NOT NULL ,
  TKTID                              RAW(16)                       ,
  TOP_TKIID                          RAW(16)              NOT NULL ,
  FOLLOW_ON_TKIID                    RAW(16)                       ,
  APPLICATION_NAME                   VARCHAR2(220)                 ,
  APPLICATION_DEFAULTS_ID            RAW(16)                       ,
  CONTAINMENT_CONTEXT_ID             RAW(16)                       ,
  PARENT_CONTEXT_ID                  RAW(16)                       ,
  STATE                              NUMBER(10,0)         NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  AUTO_DELETE_MODE                   NUMBER(10,0)         NOT NULL ,
  HIERARCHY_POSITION                 NUMBER(10,0)         NOT NULL ,
  TYPE                               VARCHAR2(254)                 ,
  SVTID                              RAW(16)                       ,
  SUPPORTS_CLAIM_SUSPENDED           NUMBER(5,0)          NOT NULL ,
  SUPPORTS_AUTO_CLAIM                NUMBER(5,0)          NOT NULL ,
  SUPPORTS_FOLLOW_ON_TASK            NUMBER(5,0)          NOT NULL ,
  IS_AD_HOC                          NUMBER(5,0)          NOT NULL ,
  IS_ESCALATED                       NUMBER(5,0)          NOT NULL ,
  IS_INLINE                          NUMBER(5,0)          NOT NULL ,
  IS_SUSPENDED                       NUMBER(5,0)          NOT NULL ,
  IS_WAITING_FOR_SUBTASK             NUMBER(5,0)          NOT NULL ,
  SUPPORTS_DELEGATION                NUMBER(5,0)          NOT NULL ,
  SUPPORTS_SUB_TASK                  NUMBER(5,0)          NOT NULL ,
  IS_CHILD                           NUMBER(5,0)          NOT NULL ,
  HAS_ESCALATIONS                    NUMBER(5,0)                   ,
  START_TIME                         TIMESTAMP                     ,
  ACTIVATION_TIME                    TIMESTAMP                     ,
  LAST_MODIFICATION_TIME             TIMESTAMP                     ,
  LAST_STATE_CHANGE_TIME             TIMESTAMP                     ,
  COMPLETION_TIME                    TIMESTAMP                     ,
  DUE_TIME                           TIMESTAMP                     ,
  EXPIRATION_TIME                    TIMESTAMP                     ,
  FIRST_ACTIVATION_TIME              TIMESTAMP                     ,
  DEFAULT_LOCALE                     VARCHAR2(32)                  ,
  DURATION_UNTIL_DELETED             VARCHAR2(254)                 ,
  DURATION_UNTIL_DUE                 VARCHAR2(254)                 ,
  DURATION_UNTIL_EXPIRES             VARCHAR2(254)                 ,
  CALENDAR_NAME                      VARCHAR2(254)                 ,
  JNDI_NAME_CALENDAR                 VARCHAR2(254)                 ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR2(254)                 ,
  CONTEXT_AUTHORIZATION              NUMBER(10,0)         NOT NULL ,
  ORIGINATOR                         VARCHAR2(128)                 ,
  STARTER                            VARCHAR2(128)                 ,
  OWNER                              VARCHAR2(128)                 ,
  ADMIN_QTID                         RAW(16)                       ,
  EDITOR_QTID                        RAW(16)                       ,
  POTENTIAL_OWNER_QTID               RAW(16)                       ,
  POTENTIAL_STARTER_QTID             RAW(16)                       ,
  READER_QTID                        RAW(16)                       ,
  PRIORITY                           NUMBER(10,0)                  ,
  SCHEDULER_ID                       VARCHAR2(254)                 ,
  SERVICE_TICKET                     VARCHAR2(254)                 ,
  EVENT_HANDLER_NAME                 VARCHAR2(64)                  ,
  BUSINESS_RELEVANCE                 NUMBER(5,0)          NOT NULL ,
  RESUMES                            TIMESTAMP                     ,
  SUBSTITUTION_POLICY                NUMBER(10,0)         NOT NULL ,
  DELETION_TIME                      TIMESTAMP                     ,
  ASSIGNMENT_TYPE                    NUMBER(10,0)         NOT NULL ,
  INHERITED_AUTH                     NUMBER(10,0)         NOT NULL ,
  PARALLEL_INHERITED_AUTH            NUMBER(10,0)         NOT NULL ,
  INVOKED_INSTANCE_ID                RAW(16)                       ,
  INVOKED_INSTANCE_TYPE              NUMBER(10,0)         NOT NULL ,
  WORK_BASKET                        VARCHAR2(254)                 ,
  IS_READ                            NUMBER(5,0)          NOT NULL ,
  IS_TRANSFERRED_TO_WORK_BASKET      NUMBER(5,0)          NOT NULL ,
  CREATED_WITH_VERSION               NUMBER(10,0)         NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T ADD(
  PRIMARY KEY ( TKIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.TI_PARENT ON @SCHEMA@.TASK_INSTANCE_T
(   
  PARENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_ACOID ON @SCHEMA@.TASK_INSTANCE_T
(   
  APPLICATION_DEFAULTS_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_NAME ON @SCHEMA@.TASK_INSTANCE_T
(   
  NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_STATE ON @SCHEMA@.TASK_INSTANCE_T
(   
  STATE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_SERVICET ON @SCHEMA@.TASK_INSTANCE_T
(   
  SERVICE_TICKET
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_CCID ON @SCHEMA@.TASK_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_TK_TOPTK ON @SCHEMA@.TASK_INSTANCE_T
(   
  TKTID, TKIID, TOP_TKIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_TOPTKIID ON @SCHEMA@.TASK_INSTANCE_T
(   
  TOP_TKIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_TI_KND_ST ON @SCHEMA@.TASK_INSTANCE_T
(   
  TKIID, KIND, STATE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_ST_KND_TI_NAME ON @SCHEMA@.TASK_INSTANCE_T
(   
  STATE, KIND, TKIID, NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_TT_KND ON @SCHEMA@.TASK_INSTANCE_T
(   
  TKTID, KIND
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_WOBA ON @SCHEMA@.TASK_INSTANCE_T
(   
  WORK_BASKET
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_TYPE ON @SCHEMA@.TASK_INSTANCE_T
(   
  TYPE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_WSID1 ON @SCHEMA@.TASK_INSTANCE_T
(   
  WSID_1, KIND
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_WSID2 ON @SCHEMA@.TASK_INSTANCE_T
(   
  WSID_2, KIND
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_WSID1S ON @SCHEMA@.TASK_INSTANCE_T
(   
  WSID_1, KIND, STATE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_WSID2S ON @SCHEMA@.TASK_INSTANCE_T
(   
  WSID_2, KIND, STATE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_Q1 ON @SCHEMA@.TASK_INSTANCE_T
(   
  KIND, PRIORITY, OWNER, STARTER, ORIGINATOR
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.TASK_CONTEXT_T
(
  TKIID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  SERVICE_CONTEXT                    BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.TASK_CONTEXT_T ADD(
  PRIMARY KEY ( TKIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.TC_CCID ON @SCHEMA@.TASK_CONTEXT_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.CONTACT_QUERIES_T
(
  TKIID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  CONTACTS_QTIDS                     BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.CONTACT_QUERIES_T ADD(
  PRIMARY KEY ( TKIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.CQ_CCID ON @SCHEMA@.CONTACT_QUERIES_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.UISETTINGS_T
(
  TKIID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  UI_SETTINGS                        BLOB                 NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.UISETTINGS_T ADD(
  PRIMARY KEY ( TKIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.UIS_CCID ON @SCHEMA@.UISETTINGS_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.REPLY_HANDLER_T
(
  TKIID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  REPLY_HANDLER                      BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.REPLY_HANDLER_T ADD(
  PRIMARY KEY ( TKIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.RH_CCID ON @SCHEMA@.REPLY_HANDLER_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.TASK_TIMER_T
(
  OID                                RAW(16)              NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  SCHEDULER_ID                       VARCHAR2(254)        NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.TASK_TIMER_T ADD(
  PRIMARY KEY ( OID, KIND )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.TASK_INST_CPROP_T
(
  TKIID                              RAW(16)              NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  NAME                               VARCHAR2(220)        NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  DATA_TYPE                          VARCHAR2(254)                 ,
  STRING_VALUE                       VARCHAR2(254)                 ,
  DATA                               BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.TASK_INST_CPROP_T ADD(
  PRIMARY KEY ( TKIID, NAME )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.TICP_CCID ON @SCHEMA@.TASK_INST_CPROP_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.TASK_INST_LDESC_T
(
  TKIID                              RAW(16)              NOT NULL ,
  LOCALE                             VARCHAR2(32)         NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  DISPLAY_NAME                       VARCHAR2(64)                  ,
  DESCRIPTION                        VARCHAR2(254)                 ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.TASK_INST_LDESC_T ADD(
  PRIMARY KEY ( TKIID, LOCALE )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.TILD_CCID ON @SCHEMA@.TASK_INST_LDESC_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TILD_PD1 ON @SCHEMA@.TASK_INST_LDESC_T
(   
  LOCALE, TKIID, DESCRIPTION
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TILD_PD2 ON @SCHEMA@.TASK_INST_LDESC_T
(   
  LOCALE, TKIID, DISPLAY_NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.TIDOCUMENTATION_T
(
  TKIID                              RAW(16)              NOT NULL ,
  LOCALE                             VARCHAR2(32)         NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  DOCUMENTATION                      CLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING
  LOB (DOCUMENTATION) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  );

ALTER TABLE @SCHEMA@.TIDOCUMENTATION_T ADD(
  PRIMARY KEY ( TKIID, LOCALE )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.TIDOC_CCID ON @SCHEMA@.TIDOCUMENTATION_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
(
  TMTID                              RAW(16)              NOT NULL ,
  TKIID                              RAW(16)                       ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  FAULT_NAME                         VARCHAR2(254)                 ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  MESSAGE_TYPE_NS                    VARCHAR2(220)        NOT NULL ,
  MESSAGE_TYPE_NAME                  VARCHAR2(220)        NOT NULL ,
  MESSAGE_DEFINITION                 BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.ITASK_MESSAGE_DEFINITION_T ADD(
  PRIMARY KEY ( TMTID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.ITMD_IDKINSTYPE ON @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
(   
  TKIID, MESSAGE_TYPE_NS, MESSAGE_TYPE_NAME, KIND
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.ITMD_TKIIDKINDFN ON @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
(   
  TKIID, KIND, FAULT_NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.ITMD_CCID ON @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.TASK_MESSAGE_INSTANCE_T
(
  TMIID                              RAW(16)              NOT NULL ,
  TMTID                              RAW(16)                       ,
  TKIID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  FAULT_NAME                         VARCHAR2(254)                 ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  MESSAGE_TYPE_NS                    VARCHAR2(220)        NOT NULL ,
  MESSAGE_TYPE_NAME                  VARCHAR2(220)        NOT NULL ,
  DATA                               BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.TASK_MESSAGE_INSTANCE_T ADD(
  PRIMARY KEY ( TMIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.TMI_TI_K ON @SCHEMA@.TASK_MESSAGE_INSTANCE_T
(   
  TKIID, KIND
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TMI_TMTID ON @SCHEMA@.TASK_MESSAGE_INSTANCE_T
(   
  TMTID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TMI_CCID ON @SCHEMA@.TASK_MESSAGE_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.TASK_AUDIT_LOG_T
(
  ALID                               RAW(16)              NOT NULL ,
  AUDIT_EVENT                        NUMBER(10,0)         NOT NULL ,
  TKIID                              RAW(16)                       ,
  TKTID                              RAW(16)                       ,
  ESIID                              RAW(16)                       ,
  ESTID                              RAW(16)                       ,
  TOP_TKIID                          RAW(16)                       ,
  FOLLOW_ON_TKIID                    RAW(16)                       ,
  PARENT_TKIID                       RAW(16)                       ,
  PARENT_CONTEXT_ID                  RAW(16)                       ,
  CONTAINMENT_CONTEXT_ID             RAW(16)                       ,
  WI_REASON                          NUMBER(10,0)                  ,
  NAME                               VARCHAR2(254)                 ,
  NAMESPACE                          VARCHAR2(254)                 ,
  VALID_FROM_UTC                     TIMESTAMP                     ,
  EVENT_TIME_UTC                     TIMESTAMP                     ,
  PARENT_TASK_NAME                   VARCHAR2(254)                 ,
  PARENT_TASK_NAMESPACE              VARCHAR2(254)                 ,
  TASK_KIND                          NUMBER(10,0)                  ,
  TASK_STATE                         NUMBER(10,0)                  ,
  FAULT_TYPE_NAME                    VARCHAR2(220)                 ,
  FAULT_NAMESPACE                    VARCHAR2(220)                 ,
  FAULT_NAME                         VARCHAR2(220)                 ,
  NEW_USER                           VARCHAR2(128)                 ,
  OLD_USER                           VARCHAR2(128)                 ,
  PRINCIPAL                          VARCHAR2(128)                 ,
  USERS                              CLOB                          ,
  DESCRIPTION                        CLOB                          ,
  MESSAGE_DATA                       BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @AUDITLOG@
  LOGGING
  LOB (USERS) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  )
  LOB (DESCRIPTION) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  );

ALTER TABLE @SCHEMA@.TASK_AUDIT_LOG_T ADD(
  PRIMARY KEY ( ALID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.IMAIL_T
(
  OBJECT_ID                          RAW(16)              NOT NULL ,
  FROM_STATE                         NUMBER(10,0)         NOT NULL ,
  TO_STATE                           NUMBER(10,0)         NOT NULL ,
  LOCALE                             VARCHAR2(32)         NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  SUBJECT                            VARCHAR2(254)        NOT NULL ,
  URI                                VARCHAR2(254)                 ,
  BODY_TEXT                          CLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING
  LOB (BODY_TEXT) STORE AS
  (
    TABLESPACE @LOBTS@
    ENABLE STORAGE IN ROW
    NOCACHE
  );

ALTER TABLE @SCHEMA@.IMAIL_T ADD(
  PRIMARY KEY ( OBJECT_ID, FROM_STATE, TO_STATE, LOCALE )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.IMN_CTX ON @SCHEMA@.IMAIL_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.TASK_HISTORY_T
(
  PKID                               RAW(16)              NOT NULL ,
  EVENT                              NUMBER(10,0)         NOT NULL ,
  TKIID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  PARENT_TKIID                       RAW(16)                       ,
  ESIID                              RAW(16)                       ,
  REASON                             NUMBER(10,0)         NOT NULL ,
  EVENT_TIME                         TIMESTAMP            NOT NULL ,
  NEXT_TIME                          TIMESTAMP                     ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  PRINCIPAL                          VARCHAR2(128)        NOT NULL ,
  WORK_ITEM_KIND                     NUMBER(10,0)         NOT NULL ,
  FROM_ID                            VARCHAR2(128)                 ,
  TO_ID                              VARCHAR2(128)                 ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.TASK_HISTORY_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.TH_TKIID ON @SCHEMA@.TASK_HISTORY_T
(   
  TKIID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.TH_CTXID ON @SCHEMA@.TASK_HISTORY_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.COMPLETION_INSTANCE_T
(
  CMIID                              RAW(16)              NOT NULL ,
  ORDER_NUMBER                       NUMBER(10,0)         NOT NULL ,
  TKIID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  COMPL_CONDITION                    BLOB                          ,
  CRITERION_FOR                      VARCHAR2(254)                 ,
  CRITERION_FOR_TIME                 TIMESTAMP                     ,
  COMPLETION_NAME                    VARCHAR2(220)                 ,
  IS_DEFAULT_COMPLETION              NUMBER(5,0)          NOT NULL ,
  PREFIX_MAP                         BLOB                          ,
  USE_DEFAULT_RESULT_CONSTRUCT       NUMBER(5,0)          NOT NULL ,
  SCHEDULER_ID                       VARCHAR2(254)                 ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.COMPLETION_INSTANCE_T ADD(
  PRIMARY KEY ( CMIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.CMPI_TKIID_ORDER ON @SCHEMA@.COMPLETION_INSTANCE_T
(   
  TKIID, ORDER_NUMBER
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.CMPI_CCID ON @SCHEMA@.COMPLETION_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(
  RAIID                              RAW(16)              NOT NULL ,
  ORDER_NUMBER                       NUMBER(10,0)         NOT NULL ,
  CMIID                              RAW(16)              NOT NULL ,
  TKIID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  AGGR_PART                          VARCHAR2(254)                 ,
  AGGR_LOCATION                      BLOB                          ,
  AGGR_FUNCTION                      VARCHAR2(254)        NOT NULL ,
  AGGR_CONDITION                     BLOB                          ,
  PREFIX_MAP                         BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T ADD(
  PRIMARY KEY ( RAIID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.RAGI_CMIID_ORDER ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(   
  CMIID, ORDER_NUMBER
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.RAGI_CCID ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.SAVED_TASK_MESSAGE_T
(
  STMID                              RAW(16)              NOT NULL ,
  RELATED_OID                        RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  SCHEDULER_ID                       VARCHAR2(254)                 ,
  CREATION_TIME                      TIMESTAMP            NOT NULL ,
  EXPECTED_ARRIVAL_TIME              TIMESTAMP            NOT NULL ,
  MESSAGE                            BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.SAVED_TASK_MESSAGE_T ADD(
  PRIMARY KEY ( STMID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.STM_ROID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  RELATED_OID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.STM_SID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  SCHEDULER_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.STM_CTXID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.WORK_BASKET_T
(
  WBID                               RAW(16)              NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  NAME                               VARCHAR2(254)        NOT NULL ,
  TYPE                               NUMBER(10,0)         NOT NULL ,
  OWNER                              VARCHAR2(128)                 ,
  SUBSTITUTION_POLICY                NUMBER(10,0)         NOT NULL ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR2(254)        NOT NULL ,
  DEFAULT_QUERY_TABLE                VARCHAR2(32)                  ,
  CUSTOM_TEXT1                       VARCHAR2(254)                 ,
  CUSTOM_TEXT2                       VARCHAR2(254)                 ,
  CUSTOM_TEXT3                       VARCHAR2(254)                 ,
  CUSTOM_TEXT4                       VARCHAR2(254)                 ,
  CUSTOM_TEXT5                       VARCHAR2(254)                 ,
  CUSTOM_TEXT6                       VARCHAR2(254)                 ,
  CUSTOM_TEXT7                       VARCHAR2(254)                 ,
  CUSTOM_TEXT8                       VARCHAR2(254)                 ,
  EXTENDED_DATA                      BLOB                          ,
  CREATION_TIME                      TIMESTAMP            NOT NULL ,
  LAST_MODIFICATION_TIME             TIMESTAMP            NOT NULL ,
  CREATED_WITH_VERSION               NUMBER(10,0)         NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.WORK_BASKET_T ADD(
  PRIMARY KEY ( WBID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.WBK_NAME ON @SCHEMA@.WORK_BASKET_T
(   
  NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WBK_TYPE ON @SCHEMA@.WORK_BASKET_T
(   
  TYPE
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WBK_WSID1 ON @SCHEMA@.WORK_BASKET_T
(   
  WSID_1
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.WBK_WSID2 ON @SCHEMA@.WORK_BASKET_T
(   
  WSID_2
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.WORK_BASKET_LDESC_T
(
  WBID                               RAW(16)              NOT NULL ,
  LOCALE                             VARCHAR2(32)         NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  DISPLAY_NAME                       VARCHAR2(64)                  ,
  DESCRIPTION                        VARCHAR2(254)                 ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.WORK_BASKET_LDESC_T ADD(
  PRIMARY KEY ( WBID, LOCALE )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE TABLE @SCHEMA@.WORK_BASKET_DIST_TARGET_T
(
  SOURCE_WBID                        RAW(16)              NOT NULL ,
  TARGET_WBID                        RAW(16)              NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.WORK_BASKET_DIST_TARGET_T ADD(
  PRIMARY KEY ( SOURCE_WBID, TARGET_WBID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.WBDT_TWB ON @SCHEMA@.WORK_BASKET_DIST_TARGET_T
(   
  TARGET_WBID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.BUSINESS_CATEGORY_T
(
  BCID                               RAW(16)              NOT NULL ,
  PARENT_BCID                        RAW(16)                       ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  NAME                               VARCHAR2(254)        NOT NULL ,
  PRIORITY                           NUMBER(10,0)                  ,
  SUBSTITUTION_POLICY                NUMBER(10,0)         NOT NULL ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR2(254)        NOT NULL ,
  DEFAULT_QUERY_TABLE                VARCHAR2(32)                  ,
  CUSTOM_TEXT1                       VARCHAR2(254)                 ,
  CUSTOM_TEXT2                       VARCHAR2(254)                 ,
  CUSTOM_TEXT3                       VARCHAR2(254)                 ,
  CUSTOM_TEXT4                       VARCHAR2(254)                 ,
  CUSTOM_TEXT5                       VARCHAR2(254)                 ,
  CUSTOM_TEXT6                       VARCHAR2(254)                 ,
  CUSTOM_TEXT7                       VARCHAR2(254)                 ,
  CUSTOM_TEXT8                       VARCHAR2(254)                 ,
  EXTENDED_DATA                      BLOB                          ,
  CREATION_TIME                      TIMESTAMP            NOT NULL ,
  LAST_MODIFICATION_TIME             TIMESTAMP            NOT NULL ,
  CREATED_WITH_VERSION               NUMBER(10,0)         NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.BUSINESS_CATEGORY_T ADD(
  PRIMARY KEY ( BCID )
  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.BCG_PARENTBCID ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  PARENT_BCID
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.BCG_NAME ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  NAME
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.BCG_WSID1 ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  WSID_1
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.BCG_WSID2 ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  WSID_2
) TABLESPACE @INDEXTS@
  LOGGING;

CREATE TABLE @SCHEMA@.BUSINESS_CATEGORY_LDESC_T
(
  BCID                               RAW(16)              NOT NULL ,
  LOCALE                             VARCHAR2(32)         NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  DISPLAY_NAME                       VARCHAR2(64)                  ,
  DESCRIPTION                        VARCHAR2(254)                 ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.BUSINESS_CATEGORY_LDESC_T ADD(
  PRIMARY KEY ( BCID, LOCALE )
  USING INDEX TABLESPACE @INDEXTS@
);
-- set schema version to: 700
INSERT INTO @SCHEMA@.SCHEMA_VERSION (SCHEMA_VERSION, DATA_MIGRATION) VALUES( 700, 0 );


-- View: ProcessTemplate
CREATE VIEW @SCHEMA@.PROCESS_TEMPLATE(PTID, NAME, DISPLAY_NAME, VALID_FROM, TARGET_NAMESPACE, APPLICATION_NAME, VERSION, CREATED, STATE, EXECUTION_MODE, DESCRIPTION, CAN_RUN_SYNC, CAN_RUN_INTERRUP, COMP_SPHERE, CONTINUE_ON_ERROR ) AS
 SELECT @SCHEMA@.PROCESS_TEMPLATE_B_T.PTID, @SCHEMA@.PROCESS_TEMPLATE_B_T.NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.DISPLAY_NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.VALID_FROM, @SCHEMA@.PROCESS_TEMPLATE_B_T.TARGET_NAMESPACE, @SCHEMA@.PROCESS_TEMPLATE_B_T.APPLICATION_NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.VERSION, @SCHEMA@.PROCESS_TEMPLATE_B_T.CREATED, @SCHEMA@.PROCESS_TEMPLATE_B_T.STATE, @SCHEMA@.PROCESS_TEMPLATE_B_T.EXECUTION_MODE, @SCHEMA@.PROCESS_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_TEMPLATE_B_T.CAN_CALL, @SCHEMA@.PROCESS_TEMPLATE_B_T.CAN_INITIATE, @SCHEMA@.PROCESS_TEMPLATE_B_T.COMPENSATION_SPHERE, @SCHEMA@.PROCESS_TEMPLATE_B_T.CONTINUE_ON_ERROR
 FROM @SCHEMA@.PROCESS_TEMPLATE_B_T;

-- View: ProcessTemplAttr
CREATE VIEW @SCHEMA@.PROCESS_TEMPL_ATTR(PTID, NAME, VALUE ) AS
 SELECT @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.PTID, @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.ATTR_KEY, @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.VALUE
 FROM @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T;

-- View: ProcessInstance
CREATE VIEW @SCHEMA@.PROCESS_INSTANCE(PTID, PIID, NAME, STATE, CREATED, STARTED, COMPLETED, PARENT_NAME, TOP_LEVEL_NAME, PARENT_PIID, TOP_LEVEL_PIID, STARTER, DESCRIPTION, TEMPLATE_NAME, TEMPLATE_DESCR, RESUMES, CONTINUE_ON_ERROR, IS_MIGRATED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.PROCESS_INSTANCE_B_T.PTID, @SCHEMA@.PROCESS_INSTANCE_B_T.PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.STATE, @SCHEMA@.PROCESS_INSTANCE_B_T.CREATED, @SCHEMA@.PROCESS_INSTANCE_B_T.STARTED, @SCHEMA@.PROCESS_INSTANCE_B_T.COMPLETED, @SCHEMA@.PROCESS_INSTANCE_B_T.PARENT_NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.TOP_LEVEL_NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.PARENT_PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.TOP_LEVEL_PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.STARTER, @SCHEMA@.PROCESS_INSTANCE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_TEMPLATE_B_T.NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_INSTANCE_B_T.RESUMES, @SCHEMA@.PROCESS_TEMPLATE_B_T.CONTINUE_ON_ERROR, @SCHEMA@.PROCESS_INSTANCE_B_T.IS_MIGRATED, @SCHEMA@.PROCESS_INSTANCE_B_T.WSID_1, @SCHEMA@.PROCESS_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.PROCESS_INSTANCE_B_T, @SCHEMA@.PROCESS_TEMPLATE_B_T
 WHERE @SCHEMA@.PROCESS_INSTANCE_B_T.PTID = @SCHEMA@.PROCESS_TEMPLATE_B_T.PTID;

-- View: ProcessAttribute
CREATE VIEW @SCHEMA@.PROCESS_ATTRIBUTE(PIID, NAME, VALUE, DATA_TYPE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.PIID, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.ATTR_KEY, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.VALUE, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.DATA_TYPE, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.WSID_1, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.WSID_2
 FROM @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T;

-- View: Activity
CREATE VIEW @SCHEMA@.ACTIVITY(PIID, AIID, PTID, ATID, SIID, STID, EHIID, ENCLOSING_FEIID, KIND, COMPLETED, ACTIVATED, FIRST_ACTIVATED, STARTED, STATE, SUB_STATE, STOP_REASON, OWNER, DESCRIPTION, EXPIRES, TEMPLATE_NAME, TEMPLATE_DESCR, BUSINESS_RELEVANCE, SKIP_REQUESTED, CONTINUE_ON_ERROR, INVOKED_INST_ID, INVOKED_INST_TYPE, PREVIOUS_EXPIRATION_TIME, HAS_WORK_ITEM, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ACTIVITY_INSTANCE_B_T.PIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.AIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.PTID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ATID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SIID, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.PARENT_STID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.EHIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ENCLOSING_FEIID, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.KIND, @SCHEMA@.ACTIVITY_INSTANCE_B_T.FINISHED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ACTIVATED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.FIRST_ACTIVATED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STARTED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SUB_STATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STOP_REASON, @SCHEMA@.ACTIVITY_INSTANCE_B_T.OWNER, @SCHEMA@.ACTIVITY_INSTANCE_B_T.DESCRIPTION, @SCHEMA@.ACTIVITY_INSTANCE_B_T.EXPIRES, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.NAME, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.BUSINESS_RELEVANCE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SKIP_REQUESTED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.CONTINUE_ON_ERROR, @SCHEMA@.ACTIVITY_INSTANCE_B_T.INVOKED_INSTANCE_ID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.INVOKED_INSTANCE_TYPE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.PREVIOUS_EXPIRATION_DATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.HAS_WORK_ITEM, @SCHEMA@.ACTIVITY_INSTANCE_B_T.WSID_1, @SCHEMA@.ACTIVITY_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.ACTIVITY_INSTANCE_B_T, @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 WHERE @SCHEMA@.ACTIVITY_INSTANCE_B_T.ATID = @SCHEMA@.ACTIVITY_TEMPLATE_B_T.ATID;

-- View: ActivityAttribute
CREATE VIEW @SCHEMA@.ACTIVITY_ATTRIBUTE(AIID, NAME, VALUE, DATA_TYPE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.AIID, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.ATTR_KEY, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.ATTR_VALUE, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.DATA_TYPE, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.WSID_1, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.WSID_2
 FROM @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T;

-- View: Event
CREATE VIEW @SCHEMA@.EVENT(EIID, AIID, PIID, EHTID, SIID, NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.EVENT_INSTANCE_B_T.EIID, @SCHEMA@.EVENT_INSTANCE_B_T.AIID, @SCHEMA@.EVENT_INSTANCE_B_T.PIID, @SCHEMA@.EVENT_INSTANCE_B_T.EHTID, @SCHEMA@.EVENT_INSTANCE_B_T.SIID, @SCHEMA@.SERVICE_TEMPLATE_B_T.NAME, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_1, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.EVENT_INSTANCE_B_T, @SCHEMA@.SERVICE_TEMPLATE_B_T
 WHERE @SCHEMA@.EVENT_INSTANCE_B_T.STATE = 2 AND @SCHEMA@.EVENT_INSTANCE_B_T.VTID = @SCHEMA@.SERVICE_TEMPLATE_B_T.VTID;

-- View: WorkItem
CREATE VIEW @SCHEMA@.WORK_ITEM(WIID, OWNER_ID, GROUP_NAME, EVERYBODY, OBJECT_TYPE, OBJECT_ID, ASSOC_OBJECT_TYPE, ASSOC_OID, REASON, CREATION_TIME, QIID, KIND ) AS
 SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO = 1
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO = 2
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO = 3
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.RETRIEVED_USER_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T, @SCHEMA@.RETRIEVED_USER_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO = 0 AND @SCHEMA@.WORK_ITEM_T.QIID = @SCHEMA@.RETRIEVED_USER_T.QIID;

-- View: SharedWorkItem
CREATE VIEW @SCHEMA@.SHARED_WORK_ITEM(WSID, OWNER_ID, GROUP_NAME, EVERYBODY, REASON ) AS
 SELECT @SCHEMA@.SWI_T.WSID, @SCHEMA@.SWI_T.OWNER_ID, @SCHEMA@.SWI_T.GROUP_NAME, @SCHEMA@.SWI_T.EVERYBODY, @SCHEMA@.SWI_T.REASON
 FROM @SCHEMA@.SWI_T
 WHERE @SCHEMA@.SWI_T.AUTH_INFO IN ( 1,2,3 )
 UNION ALL SELECT @SCHEMA@.SWI_T.WSID, @SCHEMA@.RETRIEVED_USER_T.OWNER_ID, @SCHEMA@.SWI_T.GROUP_NAME, @SCHEMA@.SWI_T.EVERYBODY, @SCHEMA@.SWI_T.REASON
 FROM @SCHEMA@.SWI_T, @SCHEMA@.RETRIEVED_USER_T
 WHERE @SCHEMA@.SWI_T.QIID = @SCHEMA@.RETRIEVED_USER_T.QIID AND @SCHEMA@.SWI_T.AUTH_INFO = 0;

-- View: ActivityService
CREATE VIEW @SCHEMA@.ACTIVITY_SERVICE(EIID, AIID, PIID, VTID, PORT_TYPE, NAME_SPACE_URI, OPERATION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.EVENT_INSTANCE_B_T.EIID, @SCHEMA@.EVENT_INSTANCE_B_T.AIID, @SCHEMA@.EVENT_INSTANCE_B_T.PIID, @SCHEMA@.EVENT_INSTANCE_B_T.VTID, @SCHEMA@.SERVICE_TEMPLATE_B_T.PORT_TYPE_NAME,@SCHEMA@.URI_TEMPLATE_B_T.URI, @SCHEMA@.SERVICE_TEMPLATE_B_T.OPERATION_NAME, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_1, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.EVENT_INSTANCE_B_T, @SCHEMA@.SERVICE_TEMPLATE_B_T, @SCHEMA@.URI_TEMPLATE_B_T
 WHERE @SCHEMA@.EVENT_INSTANCE_B_T.STATE = 2 AND @SCHEMA@.EVENT_INSTANCE_B_T.VTID = @SCHEMA@.SERVICE_TEMPLATE_B_T.VTID AND @SCHEMA@.SERVICE_TEMPLATE_B_T.PORT_TYPE_UTID = @SCHEMA@.URI_TEMPLATE_B_T.UTID;

-- View: QueryProperty
CREATE VIEW @SCHEMA@.QUERY_PROPERTY(PIID, VARIABLE_NAME, NAME, NAMESPACE, GENERIC_VALUE, STRING_VALUE, NUMBER_VALUE, DECIMAL_VALUE, TIMESTAMP_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PIID, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.VARIABLE_NAME, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PROPERTY_NAME, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PROPERTY_NAMESPACE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.GENERIC_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.STRING_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.NUMBER_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.DECIMAL_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.TIMESTAMP_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.WSID_1, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.WSID_2
 FROM @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T;

-- View: QueryPropTempl
CREATE VIEW @SCHEMA@.QUERY_PROP_TEMPL(PTID, NAME, PROPERTY_NAME, URI, QUERY_TYPE, JAVA_TYPE ) AS
 SELECT @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.PTID, @SCHEMA@.VARIABLE_TEMPLATE_B_T.NAME, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PROPERTY_NAME, @SCHEMA@.URI_TEMPLATE_B_T.URI, @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.QUERY_TYPE, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.JAVA_TYPE
 FROM @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T, @SCHEMA@.VARIABLE_TEMPLATE_B_T, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T, @SCHEMA@.URI_TEMPLATE_B_T
 WHERE @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.CTID = @SCHEMA@.VARIABLE_TEMPLATE_B_T.CTID AND @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.PAID = @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PAID AND @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PROPERTY_UTID = @SCHEMA@.URI_TEMPLATE_B_T.UTID;

-- View: MigrationFront
CREATE VIEW @SCHEMA@.MIGRATION_FRONT(PIID, AIID, SOURCE_PTID, TARGET_PTID, STATE, SUB_STATE, STOP_REASON, SOURCE_ATID, TARGET_ATID, MIGRATION_TIME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.MIGRATION_FRONT_T.PIID, @SCHEMA@.MIGRATION_FRONT_T.AIID, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.SOURCE_PTID, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.TARGET_PTID, @SCHEMA@.MIGRATION_FRONT_T.STATE, @SCHEMA@.MIGRATION_FRONT_T.SUB_STATE, @SCHEMA@.MIGRATION_FRONT_T.STOP_REASON, @SCHEMA@.MIGRATION_FRONT_T.SOURCE_ATID, @SCHEMA@.MIGRATION_FRONT_T.TARGET_ATID, @SCHEMA@.MIGRATION_FRONT_T.MIGRATION_TIME, @SCHEMA@.MIGRATION_FRONT_T.WSID_1, @SCHEMA@.MIGRATION_FRONT_T.WSID_2
 FROM @SCHEMA@.MIGRATION_FRONT_T, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
 WHERE @SCHEMA@.MIGRATION_FRONT_T.MPTID = @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.MPTID;

-- View: AuditLog
CREATE VIEW @SCHEMA@.AUDIT_LOG(ALID, EVENT_TIME, EVENT_TIME_UTC, AUDIT_EVENT, PTID, PIID, AIID, SIID, SCOPE_NAME, PROCESS_TEMPL_NAME, PROCESS_INST_NAME, TOP_LEVEL_PI_NAME, TOP_LEVEL_PIID, PARENT_PI_NAME, PARENT_PIID, VALID_FROM, VALID_FROM_UTC, ACTIVITY_NAME, ACTIVITY_KIND, ACTIVITY_STATE, CONTROL_LINK_NAME, IMPL_NAME, PRINCIPAL, TERMINAL_NAME, VARIABLE_DATA, EXCEPTION_TEXT, DESCRIPTION, CORR_SET_INFO, USER_NAME, ATID, ADDITIONAL_INFO, OBJECT_META_TYPE ) AS
 SELECT @SCHEMA@.AUDIT_LOG_T.ALID,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME_UTC,@SCHEMA@.AUDIT_LOG_T.AUDIT_EVENT,@SCHEMA@.AUDIT_LOG_T.PTID,@SCHEMA@.AUDIT_LOG_T.PIID,@SCHEMA@.AUDIT_LOG_T.AIID,@SCHEMA@.AUDIT_LOG_T.SIID,@SCHEMA@.AUDIT_LOG_T.VARIABLE_NAME,@SCHEMA@.AUDIT_LOG_T.PROCESS_TEMPL_NAME, @SCHEMA@.AUDIT_LOG_T.PROCESS_INST_NAME,@SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PI_NAME,@SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PIID,@SCHEMA@.AUDIT_LOG_T.PARENT_PI_NAME,@SCHEMA@.AUDIT_LOG_T.PARENT_PIID,@SCHEMA@.AUDIT_LOG_T.VALID_FROM,@SCHEMA@.AUDIT_LOG_T.VALID_FROM_UTC, @SCHEMA@.AUDIT_LOG_T.ACTIVITY_NAME,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_KIND,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_STATE,@SCHEMA@.AUDIT_LOG_T.CONTROL_LINK_NAME,@SCHEMA@.AUDIT_LOG_T.IMPL_NAME,@SCHEMA@.AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.AUDIT_LOG_T.TERMINAL_NAME,@SCHEMA@.AUDIT_LOG_T.VARIABLE_DATA,@SCHEMA@.AUDIT_LOG_T.EXCEPTION_TEXT,@SCHEMA@.AUDIT_LOG_T.DESCRIPTION,@SCHEMA@.AUDIT_LOG_T.CORR_SET_INFO,@SCHEMA@.AUDIT_LOG_T.USER_NAME, @SCHEMA@.AUDIT_LOG_T.ATID, @SCHEMA@.AUDIT_LOG_T.ADDITIONAL_INFO, @SCHEMA@.AUDIT_LOG_T.OBJECT_META_TYPE
 FROM @SCHEMA@.AUDIT_LOG_T;

-- View: AuditLogB
CREATE VIEW @SCHEMA@.AUDIT_LOG_B(ALID, EVENT_TIME, EVENT_TIME_UTC, AUDIT_EVENT, PTID, PIID, AIID, SIID, VARIABLE_NAME, PROCESS_TEMPL_NAME, TOP_LEVEL_PIID, PARENT_PIID, VALID_FROM, VALID_FROM_UTC, ATID, ACTIVITY_NAME, ACTIVITY_KIND, ACTIVITY_STATE, CONTROL_LINK_NAME, PRINCIPAL, VARIABLE_DATA, EXCEPTION_TEXT, DESCRIPTION, CORR_SET_INFO, USER_NAME, ADDITIONAL_INFO ) AS
 SELECT @SCHEMA@.AUDIT_LOG_T.ALID,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME_UTC,@SCHEMA@.AUDIT_LOG_T.AUDIT_EVENT,@SCHEMA@.AUDIT_LOG_T.PTID,@SCHEMA@.AUDIT_LOG_T.PIID,@SCHEMA@.AUDIT_LOG_T.AIID,@SCHEMA@.AUDIT_LOG_T.SIID,@SCHEMA@.AUDIT_LOG_T.VARIABLE_NAME,@SCHEMA@.AUDIT_LOG_T.PROCESS_TEMPL_NAME, @SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PIID,@SCHEMA@.AUDIT_LOG_T.PARENT_PIID,@SCHEMA@.AUDIT_LOG_T.VALID_FROM,@SCHEMA@.AUDIT_LOG_T.VALID_FROM_UTC,@SCHEMA@.AUDIT_LOG_T.ATID, @SCHEMA@.AUDIT_LOG_T.ACTIVITY_NAME,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_KIND,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_STATE,@SCHEMA@.AUDIT_LOG_T.CONTROL_LINK_NAME,@SCHEMA@.AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.AUDIT_LOG_T.VARIABLE_DATA,@SCHEMA@.AUDIT_LOG_T.EXCEPTION_TEXT,@SCHEMA@.AUDIT_LOG_T.DESCRIPTION,@SCHEMA@.AUDIT_LOG_T.CORR_SET_INFO,@SCHEMA@.AUDIT_LOG_T.USER_NAME, @SCHEMA@.AUDIT_LOG_T.ADDITIONAL_INFO
 FROM @SCHEMA@.AUDIT_LOG_T
 WHERE @SCHEMA@.AUDIT_LOG_T.OBJECT_META_TYPE = 1;

-- View: ApplicationComp
CREATE VIEW @SCHEMA@.APPLICATION_COMP(ACOID, BUSINESS_RELEVANCE, NAME, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON ) AS
 SELECT @SCHEMA@.APPLICATION_COMPONENT_T.ACOID, @SCHEMA@.APPLICATION_COMPONENT_T.BUSINESS_RELEVANCE, @SCHEMA@.APPLICATION_COMPONENT_T.NAME, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_DELEGATION, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_SUB_TASK, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_FOLLOW_ON_TASK
 FROM @SCHEMA@.APPLICATION_COMPONENT_T;

-- View: Task
CREATE VIEW @SCHEMA@.TASK(TKIID, ACTIVATED, APPLIC_DEFAULTS_ID, APPLIC_NAME, BUSINESS_RELEVANCE, COMPLETED, CONTAINMENT_CTX_ID, CTX_AUTHORIZATION, DUE, EXPIRES, FIRST_ACTIVATED, FOLLOW_ON_TKIID, IS_AD_HOC, IS_ESCALATED, IS_INLINE, IS_WAIT_FOR_SUB_TK, KIND, LAST_MODIFIED, LAST_STATE_CHANGE, NAME, NAME_SPACE, ORIGINATOR, OWNER, PARENT_CONTEXT_ID, PRIORITY, STARTED, STARTER, STATE, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON, HIERARCHY_POSITION, IS_CHILD, SUSPENDED, TKTID, TOP_TKIID, TYPE, RESUMES, ASSIGNMENT_TYPE, INHERITED_AUTH, INVOKED_INSTANCE_ID, INVOKED_INSTANCE_TYPE, WORK_BASKET, IS_READ, IS_TRANSFERRED_TO_WORK_BASKET, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INSTANCE_T.TKIID, @SCHEMA@.TASK_INSTANCE_T.ACTIVATION_TIME, @SCHEMA@.TASK_INSTANCE_T.APPLICATION_DEFAULTS_ID, @SCHEMA@.TASK_INSTANCE_T.APPLICATION_NAME, @SCHEMA@.TASK_INSTANCE_T.BUSINESS_RELEVANCE, @SCHEMA@.TASK_INSTANCE_T.COMPLETION_TIME, @SCHEMA@.TASK_INSTANCE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_INSTANCE_T.CONTEXT_AUTHORIZATION, @SCHEMA@.TASK_INSTANCE_T.DUE_TIME, @SCHEMA@.TASK_INSTANCE_T.EXPIRATION_TIME, @SCHEMA@.TASK_INSTANCE_T.FIRST_ACTIVATION_TIME, @SCHEMA@.TASK_INSTANCE_T.FOLLOW_ON_TKIID, @SCHEMA@.TASK_INSTANCE_T.IS_AD_HOC, @SCHEMA@.TASK_INSTANCE_T.IS_ESCALATED, @SCHEMA@.TASK_INSTANCE_T.IS_INLINE, @SCHEMA@.TASK_INSTANCE_T.IS_WAITING_FOR_SUBTASK, @SCHEMA@.TASK_INSTANCE_T.KIND, @SCHEMA@.TASK_INSTANCE_T.LAST_MODIFICATION_TIME, @SCHEMA@.TASK_INSTANCE_T.LAST_STATE_CHANGE_TIME, @SCHEMA@.TASK_INSTANCE_T.NAME, @SCHEMA@.TASK_INSTANCE_T.NAMESPACE, @SCHEMA@.TASK_INSTANCE_T.ORIGINATOR, @SCHEMA@.TASK_INSTANCE_T.OWNER, @SCHEMA@.TASK_INSTANCE_T.PARENT_CONTEXT_ID, @SCHEMA@.TASK_INSTANCE_T.PRIORITY, @SCHEMA@.TASK_INSTANCE_T.START_TIME, @SCHEMA@.TASK_INSTANCE_T.STARTER, @SCHEMA@.TASK_INSTANCE_T.STATE, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_DELEGATION, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_SUB_TASK, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_FOLLOW_ON_TASK, @SCHEMA@.TASK_INSTANCE_T.HIERARCHY_POSITION, @SCHEMA@.TASK_INSTANCE_T.IS_CHILD, @SCHEMA@.TASK_INSTANCE_T.IS_SUSPENDED, @SCHEMA@.TASK_INSTANCE_T.TKTID, @SCHEMA@.TASK_INSTANCE_T.TOP_TKIID, @SCHEMA@.TASK_INSTANCE_T.TYPE, @SCHEMA@.TASK_INSTANCE_T.RESUMES, @SCHEMA@.TASK_INSTANCE_T.ASSIGNMENT_TYPE, @SCHEMA@.TASK_INSTANCE_T.INHERITED_AUTH, @SCHEMA@.TASK_INSTANCE_T.INVOKED_INSTANCE_ID, @SCHEMA@.TASK_INSTANCE_T.INVOKED_INSTANCE_TYPE, @SCHEMA@.TASK_INSTANCE_T.WORK_BASKET, @SCHEMA@.TASK_INSTANCE_T.IS_READ, @SCHEMA@.TASK_INSTANCE_T.IS_TRANSFERRED_TO_WORK_BASKET, @SCHEMA@.TASK_INSTANCE_T.WSID_1, @SCHEMA@.TASK_INSTANCE_T.WSID_2
 FROM @SCHEMA@.TASK_INSTANCE_T;

-- View: TaskTempl
CREATE VIEW @SCHEMA@.TASK_TEMPL(TKTID, APPLIC_DEFAULTS_ID, APPLIC_NAME, BUSINESS_RELEVANCE, CONTAINMENT_CTX_ID, CTX_AUTHORIZATION, DEFINITION_NAME, DEFINITION_NS, IS_AD_HOC, IS_INLINE, KIND, NAME, NAMESPACE, PRIORITY, STATE, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON, TYPE, VALID_FROM, AUTONOMY, ASSIGNMENT_TYPE, INHERITED_AUTH, WORK_BASKET ) AS
 SELECT @SCHEMA@.TASK_TEMPLATE_T.TKTID, @SCHEMA@.TASK_TEMPLATE_T.APPLICATION_DEFAULTS_ID, @SCHEMA@.TASK_TEMPLATE_T.APPLICATION_NAME, @SCHEMA@.TASK_TEMPLATE_T.BUSINESS_RELEVANCE, @SCHEMA@.TASK_TEMPLATE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_TEMPLATE_T.CONTEXT_AUTHORIZATION, @SCHEMA@.TASK_TEMPLATE_T.DEFINITION_NAME, @SCHEMA@.TASK_TEMPLATE_T.TARGET_NAMESPACE, @SCHEMA@.TASK_TEMPLATE_T.IS_AD_HOC, @SCHEMA@.TASK_TEMPLATE_T.IS_INLINE, @SCHEMA@.TASK_TEMPLATE_T.KIND, @SCHEMA@.TASK_TEMPLATE_T.NAME, @SCHEMA@.TASK_TEMPLATE_T.NAMESPACE, @SCHEMA@.TASK_TEMPLATE_T.PRIORITY, @SCHEMA@.TASK_TEMPLATE_T.STATE, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_DELEGATION, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_SUB_TASK, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_FOLLOW_ON_TASK, @SCHEMA@.TASK_TEMPLATE_T.TYPE, @SCHEMA@.TASK_TEMPLATE_T.VALID_FROM, @SCHEMA@.TASK_TEMPLATE_T.AUTONOMY, @SCHEMA@.TASK_TEMPLATE_T.ASSIGNMENT_TYPE, @SCHEMA@.TASK_TEMPLATE_T.INHERITED_AUTH, @SCHEMA@.TASK_TEMPLATE_T.WORK_BASKET
 FROM @SCHEMA@.TASK_TEMPLATE_T;

-- View: Escalation
CREATE VIEW @SCHEMA@.ESCALATION(ESIID, ACTION, ACTIVATION_STATE, ACTIVATION_TIME, ESCALATION_TIME, AT_LEAST_EXP_STATE, ESTID, FIRST_ESIID, INCREASE_PRIORITY, NAME, STATE, TKIID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESCALATION_INSTANCE_T.ESIID, @SCHEMA@.ESCALATION_INSTANCE_T.ACTION, @SCHEMA@.ESCALATION_INSTANCE_T.ACTIVATION_STATE, @SCHEMA@.ESCALATION_INSTANCE_T.ACTIVATION_TIME, @SCHEMA@.ESCALATION_INSTANCE_T.ESCALATION_TIME, @SCHEMA@.ESCALATION_INSTANCE_T.AT_LEAST_EXPECTED_STATE, @SCHEMA@.ESCALATION_INSTANCE_T.ESTID, @SCHEMA@.ESCALATION_INSTANCE_T.FIRST_ESIID, @SCHEMA@.ESCALATION_INSTANCE_T.INCREASE_PRIORITY, @SCHEMA@.ESCALATION_INSTANCE_T.NAME, @SCHEMA@.ESCALATION_INSTANCE_T.STATE, @SCHEMA@.ESCALATION_INSTANCE_T.TKIID, @SCHEMA@.ESCALATION_INSTANCE_T.WSID_1, @SCHEMA@.ESCALATION_INSTANCE_T.WSID_2
 FROM @SCHEMA@.ESCALATION_INSTANCE_T;

-- View: EscTempl
CREATE VIEW @SCHEMA@.ESC_TEMPL(ESTID, FIRST_ESTID, PREVIOUS_ESTID, TKTID, CONTAINMENT_CTX_ID, NAME, ACTIVATION_STATE, AT_LEAST_EXP_STATE, INCREASE_PRIORITY, ACTION ) AS
 SELECT @SCHEMA@.ESCALATION_TEMPLATE_T.ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.FIRST_ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.PREVIOUS_ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.TKTID, @SCHEMA@.ESCALATION_TEMPLATE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.ESCALATION_TEMPLATE_T.NAME, @SCHEMA@.ESCALATION_TEMPLATE_T.ACTIVATION_STATE, @SCHEMA@.ESCALATION_TEMPLATE_T.AT_LEAST_EXPECTED_STATE, @SCHEMA@.ESCALATION_TEMPLATE_T.INCREASE_PRIORITY, @SCHEMA@.ESCALATION_TEMPLATE_T.ACTION
 FROM @SCHEMA@.ESCALATION_TEMPLATE_T;

-- View: EscTemplDesc
CREATE VIEW @SCHEMA@.ESC_TEMPL_DESC(ESTID, LOCALE, TKTID, DISPLAY_NAME, DESCRIPTION ) AS
 SELECT @SCHEMA@.ESC_TEMPL_LDESC_T.ESTID, @SCHEMA@.ESC_TEMPL_LDESC_T.LOCALE, @SCHEMA@.ESC_TEMPL_LDESC_T.TKTID, @SCHEMA@.ESC_TEMPL_LDESC_T.DISPLAY_NAME, @SCHEMA@.ESC_TEMPL_LDESC_T.DESCRIPTION
 FROM @SCHEMA@.ESC_TEMPL_LDESC_T;

-- View: TaskTemplCProp
CREATE VIEW @SCHEMA@.TASK_TEMPL_CPROP(TKTID, NAME, DATA_TYPE, STRING_VALUE ) AS
 SELECT @SCHEMA@.TASK_TEMPL_CPROP_T.TKTID, @SCHEMA@.TASK_TEMPL_CPROP_T.NAME, @SCHEMA@.TASK_TEMPL_CPROP_T.DATA_TYPE, @SCHEMA@.TASK_TEMPL_CPROP_T.STRING_VALUE
 FROM @SCHEMA@.TASK_TEMPL_CPROP_T;

-- View: EscTemplCProp
CREATE VIEW @SCHEMA@.ESC_TEMPL_CPROP(ESTID, NAME, TKTID, DATA_TYPE, VALUE ) AS
 SELECT @SCHEMA@.ESC_TEMPL_CPROP_T.ESTID, @SCHEMA@.ESC_TEMPL_CPROP_T.NAME, @SCHEMA@.ESC_TEMPL_CPROP_T.TKTID, @SCHEMA@.ESC_TEMPL_CPROP_T.DATA_TYPE, @SCHEMA@.ESC_TEMPL_CPROP_T.STRING_VALUE
 FROM @SCHEMA@.ESC_TEMPL_CPROP_T;

-- View: TaskTemplDesc
CREATE VIEW @SCHEMA@.TASK_TEMPL_DESC(TKTID, LOCALE, DESCRIPTION, DISPLAY_NAME ) AS
 SELECT @SCHEMA@.TASK_TEMPL_LDESC_T.TKTID, @SCHEMA@.TASK_TEMPL_LDESC_T.LOCALE, @SCHEMA@.TASK_TEMPL_LDESC_T.DESCRIPTION, @SCHEMA@.TASK_TEMPL_LDESC_T.DISPLAY_NAME
 FROM @SCHEMA@.TASK_TEMPL_LDESC_T;

-- View: TaskCProp
CREATE VIEW @SCHEMA@.TASK_CPROP(TKIID, NAME, DATA_TYPE, STRING_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INST_CPROP_T.TKIID, @SCHEMA@.TASK_INST_CPROP_T.NAME, @SCHEMA@.TASK_INST_CPROP_T.DATA_TYPE, @SCHEMA@.TASK_INST_CPROP_T.STRING_VALUE, @SCHEMA@.TASK_INST_CPROP_T.WSID_1, @SCHEMA@.TASK_INST_CPROP_T.WSID_2
 FROM @SCHEMA@.TASK_INST_CPROP_T;

-- View: TaskDesc
CREATE VIEW @SCHEMA@.TASK_DESC(TKIID, LOCALE, DESCRIPTION, DISPLAY_NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INST_LDESC_T.TKIID, @SCHEMA@.TASK_INST_LDESC_T.LOCALE, @SCHEMA@.TASK_INST_LDESC_T.DESCRIPTION, @SCHEMA@.TASK_INST_LDESC_T.DISPLAY_NAME, @SCHEMA@.TASK_INST_LDESC_T.WSID_1, @SCHEMA@.TASK_INST_LDESC_T.WSID_2
 FROM @SCHEMA@.TASK_INST_LDESC_T;

-- View: EscalationCProp
CREATE VIEW @SCHEMA@.ESCALATION_CPROP(ESIID, NAME, DATA_TYPE, STRING_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESC_INST_CPROP_T.ESIID, @SCHEMA@.ESC_INST_CPROP_T.NAME, @SCHEMA@.ESC_INST_CPROP_T.DATA_TYPE, @SCHEMA@.ESC_INST_CPROP_T.STRING_VALUE, @SCHEMA@.ESC_INST_CPROP_T.WSID_1, @SCHEMA@.ESC_INST_CPROP_T.WSID_2
 FROM @SCHEMA@.ESC_INST_CPROP_T;

-- View: TaskHistory
CREATE VIEW @SCHEMA@.TASK_HISTORY(TKIID, ESIID, PARENT_TKIID, EVENT, REASON, EVENT_TIME, NEXT_TIME, PRINCIPAL, WORK_ITEM_KIND, FROM_ID, TO_ID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_HISTORY_T.TKIID, @SCHEMA@.TASK_HISTORY_T.ESIID, @SCHEMA@.TASK_HISTORY_T.PARENT_TKIID, @SCHEMA@.TASK_HISTORY_T.EVENT, @SCHEMA@.TASK_HISTORY_T.REASON, @SCHEMA@.TASK_HISTORY_T.EVENT_TIME, @SCHEMA@.TASK_HISTORY_T.NEXT_TIME, @SCHEMA@.TASK_HISTORY_T.PRINCIPAL, @SCHEMA@.TASK_HISTORY_T.WORK_ITEM_KIND, @SCHEMA@.TASK_HISTORY_T.FROM_ID, @SCHEMA@.TASK_HISTORY_T.TO_ID, @SCHEMA@.TASK_HISTORY_T.WSID_1, @SCHEMA@.TASK_HISTORY_T.WSID_2
 FROM @SCHEMA@.TASK_HISTORY_T;

-- View: EscalationDesc
CREATE VIEW @SCHEMA@.ESCALATION_DESC(ESIID, LOCALE, DESCRIPTION, DISPLAY_NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESC_INST_LDESC_T.ESIID, @SCHEMA@.ESC_INST_LDESC_T.LOCALE, @SCHEMA@.ESC_INST_LDESC_T.DESCRIPTION, @SCHEMA@.ESC_INST_LDESC_T.DISPLAY_NAME, @SCHEMA@.ESC_INST_LDESC_T.WSID_1, @SCHEMA@.ESC_INST_LDESC_T.WSID_2
 FROM @SCHEMA@.ESC_INST_LDESC_T;

-- View: TaskAuditLog
CREATE VIEW @SCHEMA@.TASK_AUDIT_LOG(ALID, AUDIT_EVENT, CONTAINMENT_CTX_ID, ESIID, ESTID, EVENT_TIME, FAULT_NAME, FAULT_TYPE_NAME, FAULT_NAME_SPACE, FOLLOW_ON_TKIID, NAME, NAMESPACE, NEW_USER, OLD_USER, PARENT_CONTEXT_ID, PARENT_TASK_NAME, PARENT_TASK_NAMESP, PARENT_TKIID, PRINCIPAL, TASK_KIND, TASK_STATE, TKIID, TKTID, TOP_TKIID, VAILD_FROM, WORK_ITEM_REASON, USERS, DESCRIPTION, MESSAGE_DATA ) AS
 SELECT @SCHEMA@.TASK_AUDIT_LOG_T.ALID, @SCHEMA@.TASK_AUDIT_LOG_T.AUDIT_EVENT, @SCHEMA@.TASK_AUDIT_LOG_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_AUDIT_LOG_T.ESIID, @SCHEMA@.TASK_AUDIT_LOG_T.ESTID, @SCHEMA@.TASK_AUDIT_LOG_T.EVENT_TIME_UTC, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_TYPE_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.FOLLOW_ON_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.NAME, @SCHEMA@.TASK_AUDIT_LOG_T.NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.NEW_USER, @SCHEMA@.TASK_AUDIT_LOG_T.OLD_USER, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_CONTEXT_ID, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TASK_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TASK_NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.TASK_AUDIT_LOG_T.TASK_KIND, @SCHEMA@.TASK_AUDIT_LOG_T.TASK_STATE, @SCHEMA@.TASK_AUDIT_LOG_T.TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.TKTID, @SCHEMA@.TASK_AUDIT_LOG_T.TOP_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.VALID_FROM_UTC, @SCHEMA@.TASK_AUDIT_LOG_T.WI_REASON, @SCHEMA@.TASK_AUDIT_LOG_T.USERS, @SCHEMA@.TASK_AUDIT_LOG_T.DESCRIPTION, @SCHEMA@.TASK_AUDIT_LOG_T.MESSAGE_DATA
 FROM @SCHEMA@.TASK_AUDIT_LOG_T;

-- View: WorkBasket
CREATE VIEW @SCHEMA@.WORK_BASKET(WBID, NAME, TYPE, OWNER, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_T.WBID, @SCHEMA@.WORK_BASKET_T.NAME, @SCHEMA@.WORK_BASKET_T.TYPE, @SCHEMA@.WORK_BASKET_T.OWNER, @SCHEMA@.WORK_BASKET_T.DEFAULT_QUERY_TABLE, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT1, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT2, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT3, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT4, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT5, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT6, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT7, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT8, @SCHEMA@.WORK_BASKET_T.CREATION_TIME, @SCHEMA@.WORK_BASKET_T.LAST_MODIFICATION_TIME, @SCHEMA@.WORK_BASKET_T.WSID_1, @SCHEMA@.WORK_BASKET_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_T;

-- View: WorkBasketLDesc
CREATE VIEW @SCHEMA@.WORK_BASKET_LDESC(WBID, LOCALE, DISPLAY_NAME, DESCRIPTION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_LDESC_T.WBID, @SCHEMA@.WORK_BASKET_LDESC_T.LOCALE, @SCHEMA@.WORK_BASKET_LDESC_T.DISPLAY_NAME, @SCHEMA@.WORK_BASKET_LDESC_T.DESCRIPTION, @SCHEMA@.WORK_BASKET_LDESC_T.WSID_1, @SCHEMA@.WORK_BASKET_LDESC_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_LDESC_T;

-- View: WorkBasketDistTarget
CREATE VIEW @SCHEMA@.WORK_BASKET_DIST_TARGET(WBID, NAME, TYPE, OWNER, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, SOURCE_WBID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_DIST_TARGET_T.TARGET_WBID, @SCHEMA@.WORK_BASKET_T.NAME, @SCHEMA@.WORK_BASKET_T.TYPE, @SCHEMA@.WORK_BASKET_T.OWNER, @SCHEMA@.WORK_BASKET_T.DEFAULT_QUERY_TABLE, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT1, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT2, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT3, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT4, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT5, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT6, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT7, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT8, @SCHEMA@.WORK_BASKET_T.CREATION_TIME, @SCHEMA@.WORK_BASKET_T.LAST_MODIFICATION_TIME, @SCHEMA@.WORK_BASKET_DIST_TARGET_T.SOURCE_WBID, @SCHEMA@.WORK_BASKET_T.WSID_1, @SCHEMA@.WORK_BASKET_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_DIST_TARGET_T, @SCHEMA@.WORK_BASKET_T
 WHERE @SCHEMA@.WORK_BASKET_T.WBID = @SCHEMA@.WORK_BASKET_DIST_TARGET_T.TARGET_WBID;

-- View: BusinessCategory
CREATE VIEW @SCHEMA@.BUSINESS_CATEGORY(BCID, PARENT_BCID, NAME, PRIORITY, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.BUSINESS_CATEGORY_T.BCID, @SCHEMA@.BUSINESS_CATEGORY_T.PARENT_BCID, @SCHEMA@.BUSINESS_CATEGORY_T.NAME, @SCHEMA@.BUSINESS_CATEGORY_T.PRIORITY, @SCHEMA@.BUSINESS_CATEGORY_T.DEFAULT_QUERY_TABLE, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT1, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT2, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT3, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT4, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT5, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT6, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT7, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT8, @SCHEMA@.BUSINESS_CATEGORY_T.CREATION_TIME, @SCHEMA@.BUSINESS_CATEGORY_T.LAST_MODIFICATION_TIME, @SCHEMA@.BUSINESS_CATEGORY_T.WSID_1, @SCHEMA@.BUSINESS_CATEGORY_T.WSID_2
 FROM @SCHEMA@.BUSINESS_CATEGORY_T;

-- View: BusinessCategoryLDesc
CREATE VIEW @SCHEMA@.BUSINESS_CATEGORY_LDESC(BCID, LOCALE, DISPLAY_NAME, DESCRIPTION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.BCID, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.LOCALE, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.DISPLAY_NAME, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.DESCRIPTION, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.WSID_1, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.WSID_2
 FROM @SCHEMA@.BUSINESS_CATEGORY_LDESC_T;


-- start import scheduler DDL: createSchemaOracle.ddl



CREATE TABLE @SCHEMA@."SCHED_TASK"("TASKID" NUMBER(19) NOT NULL,
               "VERSION" VARCHAR2(5) NOT NULL,
               "ROW_VERSION" NUMBER(10) NOT NULL,
               "TASKTYPE" NUMBER(10) NOT NULL,
               "TASKSUSPENDED" NUMBER(1) NOT NULL,
               "CANCELLED" NUMBER(1) NOT NULL,
               "NEXTFIRETIME" NUMBER(19) NOT NULL,
               "STARTBYINTERVAL" VARCHAR2(254),
               "STARTBYTIME" NUMBER(19),
               "VALIDFROMTIME" NUMBER(19),
               "VALIDTOTIME" NUMBER(19),
               "REPEATINTERVAL" VARCHAR2(254),
               "MAXREPEATS" NUMBER(10) NOT NULL,
               "REPEATSLEFT" NUMBER(10) NOT NULL,
               "TASKINFO" BLOB,
               "NAME" VARCHAR2(254),
               "AUTOPURGE" NUMBER(10) NOT NULL,
               "FAILUREACTION" NUMBER(10),
               "MAXATTEMPTS" NUMBER(10),
               "QOS" NUMBER(10),
               "PARTITIONID" NUMBER(10),
               "OWNERTOKEN" VARCHAR2(200) NOT NULL,
               "CREATETIME" NUMBER(19) NOT NULL,
               PRIMARY KEY ("TASKID") ) TABLESPACE "@SCHEDTS@";

CREATE INDEX @SCHEMA@."SCHED_TASK_IDX1" ON @SCHEMA@."SCHED_TASK" ("TASKID",
              "OWNERTOKEN") ;

CREATE INDEX @SCHEMA@."SCHED_TASK_IDX2" ON @SCHEMA@."SCHED_TASK" ("NEXTFIRETIME" ASC,
               "REPEATSLEFT",
               "PARTITIONID") ;

CREATE TABLE @SCHEMA@."SCHED_TREG" ("REGKEY" VARCHAR2(254) NOT NULL ,
               "REGVALUE" VARCHAR2(254) ,
               PRIMARY KEY ( "REGKEY" )) TABLESPACE "@SCHEDTS@";

CREATE TABLE @SCHEMA@."SCHED_LMGR" ("LEASENAME" VARCHAR2(254) NOT NULL,
               "LEASEOWNER" VARCHAR2(254),
               "LEASE_EXPIRE_TIME" NUMBER(19),
               "DISABLED" VARCHAR2(254),
               PRIMARY KEY ( "LEASENAME" )) TABLESPACE "@SCHEDTS@";

CREATE TABLE @SCHEMA@."SCHED_LMPR" ("LEASENAME" VARCHAR2(254) NOT NULL,
               "NAME" VARCHAR2(254) NOT NULL,
               "VALUE" VARCHAR2(254) NOT NULL ) TABLESPACE "@SCHEDTS@";

CREATE INDEX @SCHEMA@."SCHED_LMPR_IDX1" ON @SCHEMA@."SCHED_LMPR" ("LEASENAME",
               "NAME") ;

-- end import scheduler DDL: createSchemaOracle.ddl

QUIT
