--
-- Licensed Materials - Property of IBM
-- 5655-FLW (C) Copyright IBM Corporation 2006, 2010.
-- All Rights Reserved.
-- US Government Users Restricted Rights- 
-- Use, duplication or disclosure restricted 
-- by GSA ADP Schedule Contract with IBM Corp.
--
-- Scriptfile to create schema in Microsoft SQL Server
----------------------------------------------------------------------
-- Before running this script, you need to replace all occurences of
-- the replacement variables listed below with values appropriate for
-- your environment. Replacement variables are of the form: @VARIABLE@.
-- 
-- Note: if you do not find any replacement variables in this script 
--       this step might be already completed by a pre-processor.
-- 
-- @SCHEMA@       = schema (userId) name
----------------------------------------------------------------------
-- Process this script using the isql command line processor
-- example: isql -U<userid> -P<password> -d<databasename> -i createSchema.sql
--

-- ANSI_PADDING required to not truncate trailing zeros in varbinary columns
SET ANSI_PADDING ON
go

CREATE SCHEMA @SCHEMA@
go

-------------------
-- Create tables --
-------------------

CREATE TABLE @SCHEMA@.SCHEMA_VERSION
(
    SCHEMA_VERSION                     INTEGER                            NOT NULL ,
    DATA_MIGRATION                     SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( SCHEMA_VERSION )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX SCHEMA_VERSIONP ON @SCHEMA@.SCHEMA_VERSION
( 
    SCHEMA_VERSION
)
go


CREATE TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
(
    PTID                               BINARY(16)                         NOT NULL ,
    NAME                               NVARCHAR(220)                      NOT NULL ,
    DEFINITION_NAME                    NVARCHAR(220)                          NULL ,
    DISPLAY_NAME                       NVARCHAR(64)                           NULL ,
    APPLICATION_NAME                   NVARCHAR(220)                          NULL ,
    DISPLAY_ID                         INTEGER                            NOT NULL ,
    DISPLAY_ID_EXT                     NVARCHAR(32)                           NULL ,
    DESCRIPTION                        NVARCHAR(254)                          NULL ,
    DOCUMENTATION                      NTEXT                                  NULL ,
    EXECUTION_MODE                     INTEGER                            NOT NULL ,
    IS_SHARED                          SMALLINT                           NOT NULL ,
    IS_AD_HOC                          SMALLINT                           NOT NULL ,
    STATE                              INTEGER                            NOT NULL ,
    VALID_FROM                         DATETIME                           NOT NULL ,
    TARGET_NAMESPACE                   NVARCHAR(250)                          NULL ,
    CREATED                            DATETIME                           NOT NULL ,
    AUTO_DELETE                        SMALLINT                           NOT NULL ,
    EXTENDED_AUTO_DELETE               INTEGER                            NOT NULL ,
    VERSION                            NVARCHAR(32)                           NULL ,
    SCHEMA_VERSION                     INTEGER                            NOT NULL ,
    ABSTRACT_BASE_NAME                 NVARCHAR(254)                          NULL ,
    S_BEAN_LOOKUP_NAME                 NVARCHAR(254)                          NULL ,
    S_BEAN60_LOOKUP_NAME               NVARCHAR(254)                          NULL ,
    E_BEAN_LOOKUP_NAME                 NVARCHAR(254)                          NULL ,
    PROCESS_BASE_NAME                  NVARCHAR(254)                          NULL ,
    S_BEAN_HOME_NAME                   NVARCHAR(254)                          NULL ,
    E_BEAN_HOME_NAME                   NVARCHAR(254)                          NULL ,
    BPEWS_UTID                         BINARY(16)                             NULL ,
    WPC_UTID                           BINARY(16)                             NULL ,
    BUSINESS_RELEVANCE                 SMALLINT                           NOT NULL ,
    ADMINISTRATOR_QTID                 BINARY(16)                             NULL ,
    READER_QTID                        BINARY(16)                             NULL ,
    A_TKTID                            BINARY(16)                             NULL ,
    A_TKTIDFOR_ACTS                    BINARY(16)                             NULL ,
    COMPENSATION_SPHERE                INTEGER                            NOT NULL ,
    AUTONOMY                           INTEGER                            NOT NULL ,
    CAN_CALL                           SMALLINT                           NOT NULL ,
    CAN_INITIATE                       SMALLINT                           NOT NULL ,
    CONTINUE_ON_ERROR                  SMALLINT                           NOT NULL ,
    IGNORE_MISSING_DATA                INTEGER                            NOT NULL ,
    EAR_VERSION                        INTEGER                            NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX PROCESS_TEMPLATE_B_P ON @SCHEMA@.PROCESS_TEMPLATE_B_T
( 
    PTID
)
go


CREATE UNIQUE INDEX PTB_NAME_VALID ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
    NAME, VALID_FROM
)
go

CREATE INDEX PTB_NAME_VF_STATE ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
    NAME, VALID_FROM, STATE, PTID
)
go

CREATE INDEX PTB_TOP_APP ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
    APPLICATION_NAME
)
go

CREATE INDEX PTB_STATE_PTID ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
    STATE, PTID
)
go

CREATE INDEX PTB_NAME ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
    PTID, NAME
)
go

CREATE INDEX PTB_SBLKN ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
    S_BEAN60_LOOKUP_NAME
)
go

CREATE TABLE @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T
(
    PTID                               BINARY(16)                         NOT NULL ,
    ATTR_KEY                           NVARCHAR(220)                      NOT NULL ,
    VALUE                              NVARCHAR(254)                          NULL ,
    DISPLAY_ID_EXT                     NVARCHAR(32)                           NULL ,
    PRIMARY KEY NONCLUSTERED ( PTID, ATTR_KEY )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX PROCESS_TEMPLATE_ATTRIBUTE_B_P ON @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T
( 
    PTID, ATTR_KEY
)
go


CREATE INDEX PTAB_PTID ON @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.SCOPE_TEMPLATE_B_T
(
    STID                               BINARY(16)                         NOT NULL ,
    PARENT_STID                        BINARY(16)                             NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    COMP_HANDLER_ATID                  BINARY(16)                             NULL ,
    IMPLEMENTS_EHTID                   BINARY(16)                             NULL ,
    FOR_EACH_ATID                      BINARY(16)                             NULL ,
    DISPLAY_ID                         INTEGER                            NOT NULL ,
    DISPLAY_ID_EXT                     NVARCHAR(32)                           NULL ,
    ISOLATED                           SMALLINT                           NOT NULL ,
    IS_COMPENSABLE                     SMALLINT                           NOT NULL ,
    BUSINESS_RELEVANCE                 SMALLINT                           NOT NULL ,
    A_TKTID                            BINARY(16)                             NULL ,
    IS_IMPLICIT                        SMALLINT                           NOT NULL ,
    HAS_COMPENSATION_HANDLER           SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( STID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX SCOPE_TEMPLATE_B_P ON @SCHEMA@.SCOPE_TEMPLATE_B_T
( 
    STID
)
go


CREATE INDEX ST_PTID ON @SCHEMA@.SCOPE_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.SERVICE_TEMPLATE_B_T
(
    VTID                               BINARY(16)                         NOT NULL ,
    PORT_TYPE_NAME                     NVARCHAR(254)                      NOT NULL ,
    PORT_TYPE_UTID                     BINARY(16)                         NOT NULL ,
    OPERATION_NAME                     NVARCHAR(254)                      NOT NULL ,
    NAME                               NVARCHAR(254)                          NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    TRANSACTION_BEHAVIOR               INTEGER                            NOT NULL ,
    IS_TWO_WAY                         SMALLINT                           NOT NULL ,
    NUMBER_OF_RECEIVE_ACTS             INTEGER                            NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( VTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX SERVICE_TEMPLATE_B_P ON @SCHEMA@.SERVICE_TEMPLATE_B_T
( 
    VTID
)
go


CREATE INDEX VT_VTID_PTUTID ON @SCHEMA@.SERVICE_TEMPLATE_B_T
(   
    VTID, PORT_TYPE_UTID
)
go

CREATE INDEX VT_PTID ON @SCHEMA@.SERVICE_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.ACTIVITY_SERVICE_TEMPLATE_B_T
(
    ATID                               BINARY(16)                         NOT NULL ,
    VTID                               BINARY(16)                         NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    PARTNER_LINK_NAME                  NVARCHAR(220)                          NULL ,
    INPUT_CTID                         BINARY(16)                             NULL ,
    OUTPUT_CTID                        BINARY(16)                             NULL ,
    LINK_ORDER_NUMBER                  INTEGER                                NULL ,
    POTENTIAL_OWNER_QTID               BINARY(16)                             NULL ,
    READER_QTID                        BINARY(16)                             NULL ,
    EDITOR_QTID                        BINARY(16)                             NULL ,
    TKTID                              BINARY(16)                             NULL ,
    UNDO_MSG_TEMPLATE                  IMAGE                                  NULL ,
    DISPLAY_ID_EXT                     NVARCHAR(32)                           NULL ,
    PRIMARY KEY NONCLUSTERED ( ATID, VTID, KIND )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX ACTIVITY_SERVICE_TEMPLATE_B_P ON @SCHEMA@.ACTIVITY_SERVICE_TEMPLATE_B_T
( 
    ATID, VTID, KIND
)
go


CREATE INDEX AST_PTID ON @SCHEMA@.ACTIVITY_SERVICE_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.SERVICE_LOCATION_TEMPLATE_B_T
(
    PTID                               BINARY(16)                         NOT NULL ,
    VTID                               BINARY(16)                         NOT NULL ,
    MODULE_NAME                        NVARCHAR(220)                      NOT NULL ,
    EXPORT_NAME                        NTEXT                                  NULL ,
    COMPONENT_NAME                     NTEXT                              NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PTID, VTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX SERVICE_LOCATION_TEMPLATE_B_P ON @SCHEMA@.SERVICE_LOCATION_TEMPLATE_B_T
( 
    PTID, VTID
)
go


CREATE INDEX SLT_PTID ON @SCHEMA@.SERVICE_LOCATION_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.SERVICE_FAULT_TEMPLATE_B_T
(
    VTID                               BINARY(16)                         NOT NULL ,
    FAULT_NAME                         NVARCHAR(220)                      NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    MESSAGE_DEFINITION                 IMAGE                              NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( VTID, FAULT_NAME )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX SERVICE_FAULT_TEMPLATE_B_P ON @SCHEMA@.SERVICE_FAULT_TEMPLATE_B_T
( 
    VTID, FAULT_NAME
)
go


CREATE INDEX SFT_PTID ON @SCHEMA@.SERVICE_FAULT_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
(
    ATID                               BINARY(16)                         NOT NULL ,
    PARENT_STID                        BINARY(16)                             NULL ,
    IMPLEMENTS_STID                    BINARY(16)                             NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    IMPLEMENTS_EHTID                   BINARY(16)                             NULL ,
    ENCLOSING_FOR_EACH_ATID            BINARY(16)                             NULL ,
    IS_EVENT_HANDLER_END_ACTIVITY      SMALLINT                           NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    NAME                               NVARCHAR(220)                          NULL ,
    DISPLAY_NAME                       NVARCHAR(64)                           NULL ,
    JOIN_CONDITION                     INTEGER                            NOT NULL ,
    JOIN_CONDITION_NAME                NVARCHAR(254)                          NULL ,
    EXIT_CONDITION                     INTEGER                            NOT NULL ,
    EXIT_CONDITION_NAME                NVARCHAR(254)                          NULL ,
    EXIT_CONDITION_EXECUTE_AT          INTEGER                            NOT NULL ,
    NUMBER_OF_LINKS                    INTEGER                            NOT NULL ,
    SUPPRESS_JOIN_FAILURE              SMALLINT                           NOT NULL ,
    SOURCES_TYPE                       INTEGER                            NOT NULL ,
    TARGETS_TYPE                       INTEGER                            NOT NULL ,
    CREATE_INSTANCE                    SMALLINT                               NULL ,
    IS_END_ACTIVITY                    SMALLINT                           NOT NULL ,
    FAULT_NAME                         NVARCHAR(254)                          NULL ,
    HAS_OWN_FAULT_HANDLER              SMALLINT                           NOT NULL ,
    COMPLEX_BEGIN_ATID                 BINARY(16)                             NULL ,
    CORRESPONDING_END_ATID             BINARY(16)                             NULL ,
    PARENT_ATID                        BINARY(16)                             NULL ,
    HAS_CROSSING_LINK                  SMALLINT                               NULL ,
    SCRIPT_NAME                        NVARCHAR(254)                          NULL ,
    AFFILIATION                        INTEGER                            NOT NULL ,
    TRANSACTION_BEHAVIOR               INTEGER                            NOT NULL ,
    DESCRIPTION                        NVARCHAR(254)                          NULL ,
    DOCUMENTATION                      NTEXT                                  NULL ,
    BUSINESS_RELEVANCE                 SMALLINT                           NOT NULL ,
    FAULT_NAME_UTID                    BINARY(16)                             NULL ,
    FAULT_VARIABLE_CTID                BINARY(16)                             NULL ,
    DISPLAY_ID                         INTEGER                            NOT NULL ,
    DISPLAY_ID_EXT                     NVARCHAR(32)                           NULL ,
    IS_TRANSACTIONAL                   SMALLINT                           NOT NULL ,
    CONTINUE_ON_ERROR                  SMALLINT                           NOT NULL ,
    ENCLOSED_FTID                      BINARY(16)                             NULL ,
    EXPRESSION                         NTEXT                                  NULL ,
    EXIT_EXPRESSION                    NTEXT                                  NULL ,
    HAS_INBOUND_LINK                   SMALLINT                           NOT NULL ,
    COMPENSATION_STID                  BINARY(16)                             NULL ,
    COMPENSATION_ATID                  BINARY(16)                             NULL ,
    A_TKTID                            BINARY(16)                             NULL ,
    IS_IN_GFLOW                        SMALLINT                           NOT NULL ,
    IS_REGION_BEGIN                    SMALLINT                           NOT NULL ,
    CORRESPONDING_IORATID              BINARY(16)                             NULL ,
    IS_GFLOW                           SMALLINT                           NOT NULL ,
    CUSTOM_IMPLEMENTATION              IMAGE                                  NULL ,
    EXPRESSION_MAP                     IMAGE                                  NULL ,
    EXIT_EXPRESSION_MAP                IMAGE                                  NULL ,
    GENERATED_BY                       NVARCHAR(220)                          NULL ,
    PRIMARY KEY NONCLUSTERED ( ATID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX ACTIVITY_TEMPLATE_B_P ON @SCHEMA@.ACTIVITY_TEMPLATE_B_T
( 
    ATID
)
go


CREATE INDEX ATB_PTID ON @SCHEMA@.ACTIVITY_TEMPLATE_B_T
(   
    PTID
)
go

CREATE INDEX ATB_NAME ON @SCHEMA@.ACTIVITY_TEMPLATE_B_T
(   
    NAME
)
go

CREATE INDEX ATB_KIND_BR_NAME ON @SCHEMA@.ACTIVITY_TEMPLATE_B_T
(   
    KIND, BUSINESS_RELEVANCE, NAME
)
go

CREATE TABLE @SCHEMA@.ALARM_TEMPLATE_B_T
(
    XTID                               BINARY(16)                         NOT NULL ,
    ATID                               BINARY(16)                         NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    EXPRESSION                         IMAGE                                  NULL ,
    EXPRESSION_NAME                    NVARCHAR(254)                          NULL ,
    DURATION                           NVARCHAR(254)                          NULL ,
    CALENDAR                           NVARCHAR(254)                          NULL ,
    CALENDAR_JNDI_NAME                 NVARCHAR(254)                          NULL ,
    REPEAT_KIND                        INTEGER                            NOT NULL ,
    REPEAT_EXPRESSION                  IMAGE                                  NULL ,
    REPEAT_EXP_NAME                    NVARCHAR(254)                          NULL ,
    ON_ALARM_ORDER_NUMBER              INTEGER                                NULL ,
    EXPRESSION_MAP                     IMAGE                                  NULL ,
    REPEAT_EXPRESSION_MAP              IMAGE                                  NULL ,
    DISPLAY_ID_EXT                     NVARCHAR(32)                           NULL ,
    PRIMARY KEY NONCLUSTERED ( XTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX ALARM_TEMPLATE_B_P ON @SCHEMA@.ALARM_TEMPLATE_B_T
( 
    XTID
)
go


CREATE INDEX XT_PTID ON @SCHEMA@.ALARM_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
(
    FTID                               BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    FAULT_NAME                         NVARCHAR(254)                          NULL ,
    CTID                               BINARY(16)                             NULL ,
    STID                               BINARY(16)                             NULL ,
    ATID                               BINARY(16)                             NULL ,
    FAULT_LINK_SOURCE_ATID             BINARY(16)                             NULL ,
    FAULT_LINK_TARGET_ATID             BINARY(16)                             NULL ,
    IMPLEMENTATION_ATID                BINARY(16)                         NOT NULL ,
    FAULT_NAME_UTID                    BINARY(16)                             NULL ,
    ORDER_NUMBER                       INTEGER                            NOT NULL ,
    DISPLAY_ID_EXT                     NVARCHAR(32)                           NULL ,
    PRIMARY KEY NONCLUSTERED ( FTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX FAULT_HANDLER_TEMPLATE_B_P ON @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
( 
    FTID
)
go


CREATE INDEX FT_PTID ON @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.LINK_TEMPLATE_B_T
(
    SOURCE_ATID                        BINARY(16)                         NOT NULL ,
    TARGET_ATID                        BINARY(16)                         NOT NULL ,
    FLOW_BEGIN_ATID                    BINARY(16)                             NULL ,
    ENCLOSING_FOR_EACH_ATID            BINARY(16)                             NULL ,
    DISPLAY_ID                         INTEGER                            NOT NULL ,
    DISPLAY_ID_EXT                     NVARCHAR(32)                           NULL ,
    NAME                               NVARCHAR(254)                          NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    LIFETIME                           INTEGER                            NOT NULL ,
    TRANSITION_CONDITION               INTEGER                            NOT NULL ,
    TRANSITION_CONDITION_NAME          NVARCHAR(254)                          NULL ,
    ORDER_NUMBER                       INTEGER                            NOT NULL ,
    SEQUENCE_NUMBER                    INTEGER                            NOT NULL ,
    BUSINESS_RELEVANCE                 SMALLINT                           NOT NULL ,
    DESCRIPTION                        NVARCHAR(254)                          NULL ,
    DOCUMENTATION                      NTEXT                                  NULL ,
    EXPRESSION                         NTEXT                                  NULL ,
    IS_INBOUND_LINK                    SMALLINT                           NOT NULL ,
    OUTBOUND_ATID                      BINARY(16)                             NULL ,
    EXPRESSION_MAP                     IMAGE                                  NULL ,
    GENERATED_BY                       NVARCHAR(220)                          NULL ,
    RTID                               BINARY(16)                             NULL ,
    PRIMARY KEY NONCLUSTERED ( SOURCE_ATID, TARGET_ATID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX LINK_TEMPLATE_B_P ON @SCHEMA@.LINK_TEMPLATE_B_T
( 
    SOURCE_ATID, TARGET_ATID
)
go


CREATE INDEX LNK_PTID ON @SCHEMA@.LINK_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.LINK_BOUNDARY_TEMPLATE_B_T
(
    SOURCE_ATID                        BINARY(16)                         NOT NULL ,
    TARGET_ATID                        BINARY(16)                         NOT NULL ,
    BOUNDARY_STID                      BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    IS_OUTMOST_BOUNDARY                SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( SOURCE_ATID, TARGET_ATID, BOUNDARY_STID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX LINK_BOUNDARY_TEMPLATE_B_P ON @SCHEMA@.LINK_BOUNDARY_TEMPLATE_B_T
( 
    SOURCE_ATID, TARGET_ATID, BOUNDARY_STID
)
go


CREATE INDEX BND_PTID ON @SCHEMA@.LINK_BOUNDARY_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.RESET_TEMPLATE_B_T
(
    LOOP_ENTRY_ATID                    BINARY(16)                         NOT NULL ,
    LOOP_BODY_ATID                     BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( LOOP_ENTRY_ATID, LOOP_BODY_ATID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX RESET_TEMPLATE_B_P ON @SCHEMA@.RESET_TEMPLATE_B_T
( 
    LOOP_ENTRY_ATID, LOOP_BODY_ATID
)
go


CREATE INDEX RST_PTID ON @SCHEMA@.RESET_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.VARIABLE_MAPPING_TEMPLATE_B_T
(
    PTID                               BINARY(16)                         NOT NULL ,
    ATID                               BINARY(16)                         NOT NULL ,
    VTID                               BINARY(16)                         NOT NULL ,
    SOURCE_CTID                        BINARY(16)                         NOT NULL ,
    TARGET_CTID                        BINARY(16)                         NOT NULL ,
    PARAMETER                          NVARCHAR(254)                      NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PTID, ATID, VTID, SOURCE_CTID, TARGET_CTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX VARIABLE_MAPPING_TEMPLATE_B_P ON @SCHEMA@.VARIABLE_MAPPING_TEMPLATE_B_T
( 
    PTID, ATID, VTID, SOURCE_CTID, TARGET_CTID
)
go


CREATE INDEX VMT_TCTID ON @SCHEMA@.VARIABLE_MAPPING_TEMPLATE_B_T
(   
    PTID, ATID, VTID, TARGET_CTID
)
go

CREATE TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
(
    CTID                               BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    EHTID                              BINARY(16)                             NULL ,
    STID                               BINARY(16)                             NULL ,
    FTID                               BINARY(16)                             NULL ,
    DERIVED                            SMALLINT                           NOT NULL ,
    DISPLAY_ID                         INTEGER                            NOT NULL ,
    DISPLAY_ID_EXT                     NVARCHAR(32)                           NULL ,
    FROM_SPEC                          INTEGER                            NOT NULL ,
    NAME                               NVARCHAR(254)                      NOT NULL ,
    MESSAGE_TEMPLATE                   IMAGE                                  NULL ,
    IS_QUERYABLE                       SMALLINT                           NOT NULL ,
    BUSINESS_RELEVANCE                 SMALLINT                           NOT NULL ,
    GENERATED_BY                       NVARCHAR(220)                          NULL ,
    SEQUENCE_NUMBER                    INTEGER                            NOT NULL ,
    FROM_VARIABLE_CTID                 BINARY(16)                             NULL ,
    FROM_PARAMETER2                    NVARCHAR(254)                          NULL ,
    FROM_PARAMETER3                    IMAGE                                  NULL ,
    FROM_PARAMETER3_LANGUAGE           INTEGER                            NOT NULL ,
    FROM_EXPRESSION_MAP                IMAGE                                  NULL ,
    PRIMARY KEY NONCLUSTERED ( CTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX VARIABLE_TEMPLATE_B_P ON @SCHEMA@.VARIABLE_TEMPLATE_B_T
( 
    CTID
)
go


CREATE INDEX CT_PTID ON @SCHEMA@.VARIABLE_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.VARIABLE_STACK_TEMPLATE_B_T
(
    VSID                               BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    CTID                               BINARY(16)                         NOT NULL ,
    STID                               BINARY(16)                         NOT NULL ,
    FTID                               BINARY(16)                             NULL ,
    EHTID                              BINARY(16)                             NULL ,
    NAME                               NVARCHAR(255)                      NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( VSID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX VARIABLE_STACK_TEMPLATE_B_P ON @SCHEMA@.VARIABLE_STACK_TEMPLATE_B_T
( 
    VSID
)
go


CREATE INDEX VS_PTID ON @SCHEMA@.VARIABLE_STACK_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.ACTIVITY_FAULT_TEMPLATE_B_T
(
    AFID                               BINARY(16)                         NOT NULL ,
    ATID                               BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    FAULT_NAME                         NVARCHAR(254)                      NOT NULL ,
    FAULT_UTID                         BINARY(16)                             NULL ,
    MESSAGE                            IMAGE                              NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( AFID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX ACTIVITY_FAULT_TEMPLATE_B_P ON @SCHEMA@.ACTIVITY_FAULT_TEMPLATE_B_T
( 
    AFID
)
go


CREATE INDEX AF_PTID ON @SCHEMA@.ACTIVITY_FAULT_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T
(
    PTID                               BINARY(16)                         NOT NULL ,
    PARTNER_LINK_NAME                  NVARCHAR(220)                      NOT NULL ,
    PROCESS_NAME                       NVARCHAR(220)                          NULL ,
    TARGET_NAMESPACE                   NVARCHAR(250)                          NULL ,
    RESOLUTION_SCOPE                   INTEGER                            NOT NULL ,
    MY_ROLE                            SMALLINT                           NOT NULL ,
    MY_ROLE_IMPL                       IMAGE                                  NULL ,
    MY_ROLE_LOCALNAME                  NVARCHAR(220)                          NULL ,
    MY_ROLE_NAMESPACE                  NVARCHAR(220)                          NULL ,
    THEIR_ROLE                         SMALLINT                           NOT NULL ,
    THEIR_ROLE_IMPL                    IMAGE                                  NULL ,
    THEIR_ROLE_LOCALNAME               NVARCHAR(220)                          NULL ,
    THEIR_ROLE_NAMESPACE               NVARCHAR(220)                          NULL ,
    DISPLAY_ID_EXT                     NVARCHAR(32)                           NULL ,
    PRIMARY KEY NONCLUSTERED ( PTID, PARTNER_LINK_NAME )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX PARTNER_LINK_TEMPLATE_B_P ON @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T
( 
    PTID, PARTNER_LINK_NAME
)
go


CREATE TABLE @SCHEMA@.URI_TEMPLATE_B_T
(
    UTID                               BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    URI                                NVARCHAR(220)                      NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( UTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX URI_TEMPLATE_B_P ON @SCHEMA@.URI_TEMPLATE_B_T
( 
    UTID
)
go


CREATE UNIQUE INDEX UT_PTID_URI ON @SCHEMA@.URI_TEMPLATE_B_T
(   
    PTID, URI
)
go

CREATE INDEX UT_UTID_URI ON @SCHEMA@.URI_TEMPLATE_B_T
(   
    UTID, URI
)
go

CREATE TABLE @SCHEMA@.CLIENT_SETTING_TEMPLATE_B_T
(
    CSID                               BINARY(16)                         NOT NULL ,
    ATID                               BINARY(16)                             NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    VTID                               BINARY(16)                             NULL ,
    SETTINGS                           IMAGE                                  NULL ,
    PRIMARY KEY NONCLUSTERED ( CSID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX CLIENT_SETTING_TEMPLATE_B_P ON @SCHEMA@.CLIENT_SETTING_TEMPLATE_B_T
( 
    CSID
)
go


CREATE INDEX CS_PTID ON @SCHEMA@.CLIENT_SETTING_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.ASSIGN_TEMPLATE_B_T
(
    ATID                               BINARY(16)                         NOT NULL ,
    ORDER_NUMBER                       INTEGER                            NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    FROM_SPEC                          INTEGER                            NOT NULL ,
    FROM_VARIABLE_CTID                 BINARY(16)                             NULL ,
    FROM_PARAMETER2                    NVARCHAR(254)                          NULL ,
    FROM_PARAMETER3                    IMAGE                                  NULL ,
    FROM_PARAMETER3_LANGUAGE           INTEGER                            NOT NULL ,
    TO_SPEC                            INTEGER                            NOT NULL ,
    TO_VARIABLE_CTID                   BINARY(16)                             NULL ,
    TO_PARAMETER2                      NVARCHAR(254)                          NULL ,
    TO_PARAMETER3                      IMAGE                                  NULL ,
    TO_PARAMETER3_LANGUAGE             INTEGER                            NOT NULL ,
    FROM_EXPRESSION_MAP                IMAGE                                  NULL ,
    TO_EXPRESSION_MAP                  IMAGE                                  NULL ,
    PRIMARY KEY NONCLUSTERED ( ATID, ORDER_NUMBER )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX ASSIGN_TEMPLATE_B_P ON @SCHEMA@.ASSIGN_TEMPLATE_B_T
( 
    ATID, ORDER_NUMBER
)
go


CREATE INDEX ASTB_PTID ON @SCHEMA@.ASSIGN_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.CORRELATION_SET_TEMPLATE_B_T
(
    COID                               BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    STID                               BINARY(16)                         NOT NULL ,
    NAME                               NVARCHAR(255)                      NOT NULL ,
    DISPLAY_ID_EXT                     NVARCHAR(32)                           NULL ,
    PRIMARY KEY NONCLUSTERED ( COID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX CORRELATION_SET_TEMPLATE_B_P ON @SCHEMA@.CORRELATION_SET_TEMPLATE_B_T
( 
    COID
)
go


CREATE INDEX CSTB_PTID ON @SCHEMA@.CORRELATION_SET_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.CORRELATION_TEMPLATE_B_T
(
    ATID                               BINARY(16)                         NOT NULL ,
    VTID                               BINARY(16)                         NOT NULL ,
    COID                               BINARY(16)                         NOT NULL ,
    IS_FOR_EVENT_HANDLER               SMALLINT                           NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    INITIATE                           INTEGER                            NOT NULL ,
    PATTERN                            INTEGER                            NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ATID, VTID, COID, IS_FOR_EVENT_HANDLER )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX CORRELATION_TEMPLATE_B_P ON @SCHEMA@.CORRELATION_TEMPLATE_B_T
( 
    ATID, VTID, COID, IS_FOR_EVENT_HANDLER
)
go


CREATE INDEX COID_PTID ON @SCHEMA@.CORRELATION_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
(
    PAID                               BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    COID                               BINARY(16)                         NOT NULL ,
    SEQUENCE_NUMBER                    INTEGER                            NOT NULL ,
    PROPERTY_UTID                      BINARY(16)                         NOT NULL ,
    PROPERTY_NAME                      NVARCHAR(255)                      NOT NULL ,
    JAVA_TYPE                          NVARCHAR(255)                      NOT NULL ,
    MSG_TYPE_UTID                      BINARY(16)                         NOT NULL ,
    MSG_TYPE_NAME                      NVARCHAR(255)                      NOT NULL ,
    MSG_TYPE_KIND                      INTEGER                            NOT NULL ,
    PROPERTY_TYPE_UTID                 BINARY(16)                             NULL ,
    PROPERTY_TYPE_NAME                 NVARCHAR(255)                          NULL ,
    PART                               NVARCHAR(255)                          NULL ,
    QUERY                              NVARCHAR(255)                          NULL ,
    QUERY_LANGUAGE                     INTEGER                            NOT NULL ,
    IS_DEFINED_INLINE                  SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PAID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX PROPERTY_ALIAS_TEMPLATE_B_P ON @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
( 
    PAID
)
go


CREATE INDEX PATB_COID_UTID ON @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
(   
    COID, MSG_TYPE_UTID
)
go

CREATE INDEX PATB_PTID_UTIDS ON @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
(   
    PTID, MSG_TYPE_UTID, PROPERTY_UTID
)
go

CREATE TABLE @SCHEMA@.EVENT_HANDLER_TEMPLATE_B_T
(
    EHTID                              BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    STID                               BINARY(16)                         NOT NULL ,
    IMPL_ATID                          BINARY(16)                         NOT NULL ,
    VTID                               BINARY(16)                             NULL ,
    INPUT_CTID                         BINARY(16)                             NULL ,
    TKTID                              BINARY(16)                             NULL ,
    KIND                               INTEGER                            NOT NULL ,
    DISPLAY_ID_EXT                     NVARCHAR(32)                           NULL ,
    PRIMARY KEY NONCLUSTERED ( EHTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX EVENT_HANDLER_TEMPLATE_B_P ON @SCHEMA@.EVENT_HANDLER_TEMPLATE_B_T
( 
    EHTID
)
go


CREATE INDEX EHT_PTID ON @SCHEMA@.EVENT_HANDLER_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.EHALARM_TEMPLATE_B_T
(
    EHTID                              BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    EXPRESSION                         IMAGE                                  NULL ,
    EXPRESSION_NAME                    NVARCHAR(254)                          NULL ,
    DURATION                           NVARCHAR(254)                          NULL ,
    CALENDAR                           NVARCHAR(254)                          NULL ,
    CALENDAR_JNDI_NAME                 NVARCHAR(254)                          NULL ,
    REPEAT_KIND                        INTEGER                            NOT NULL ,
    REPEAT_EXPRESSION                  IMAGE                                  NULL ,
    REPEAT_EXP_NAME                    NVARCHAR(254)                          NULL ,
    REPEAT_DURATION                    NVARCHAR(254)                          NULL ,
    REPEAT_CALENDAR                    NVARCHAR(254)                          NULL ,
    REPEAT_CALENDAR_JNDI_NAME          NVARCHAR(254)                          NULL ,
    EXPRESSION_MAP                     IMAGE                                  NULL ,
    REPEAT_EXPRESSION_MAP              IMAGE                                  NULL ,
    PRIMARY KEY NONCLUSTERED ( EHTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX EHALARM_TEMPLATE_B_P ON @SCHEMA@.EHALARM_TEMPLATE_B_T
( 
    EHTID
)
go


CREATE INDEX EXT_PTID ON @SCHEMA@.EHALARM_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.CUSTOM_EXT_TEMPLATE_B_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    NAMESPACE                          NVARCHAR(220)                      NOT NULL ,
    LOCALNAME                          NVARCHAR(220)                      NOT NULL ,
    TEMPLATE_INFO                      IMAGE                                  NULL ,
    INSTANCE_INFO                      IMAGE                                  NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX CUSTOM_EXT_TEMPLATE_B_P ON @SCHEMA@.CUSTOM_EXT_TEMPLATE_B_T
( 
    PKID
)
go


CREATE INDEX CETB_PTID ON @SCHEMA@.CUSTOM_EXT_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.CUSTOM_STMT_TEMPLATE_B_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    NAMESPACE                          NVARCHAR(220)                      NOT NULL ,
    LOCALNAME                          NVARCHAR(220)                      NOT NULL ,
    PURPOSE                            NVARCHAR(220)                      NOT NULL ,
    STATEMENT                          IMAGE                                  NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX CUSTOM_STMT_TEMPLATE_B_P ON @SCHEMA@.CUSTOM_STMT_TEMPLATE_B_T
( 
    PKID
)
go


CREATE INDEX CST_PTID ON @SCHEMA@.CUSTOM_STMT_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.PROCESS_CELL_MAP_T
(
    PTID                               BINARY(16)                         NOT NULL ,
    CELL                               NVARCHAR(220)                      NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PTID, CELL )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX PROCESS_CELL_MAP_P ON @SCHEMA@.PROCESS_CELL_MAP_T
( 
    PTID, CELL
)
go


CREATE TABLE @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
(
    ATID                               BINARY(16)                         NOT NULL ,
    ATTR_KEY                           NVARCHAR(192)                      NOT NULL ,
    ATTR_VALUE                         NVARCHAR(254)                          NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    DISPLAY_ID_EXT                     NVARCHAR(32)                           NULL ,
    PRIMARY KEY NONCLUSTERED ( ATID, ATTR_KEY )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX ACTIVITY_TEMPLATE_ATTR_B_P ON @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
( 
    ATID, ATTR_KEY
)
go


CREATE INDEX ATAB_PTID ON @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
(   
    PTID
)
go

CREATE INDEX ATAB_VALUE ON @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
(   
    ATTR_VALUE
)
go

CREATE TABLE @SCHEMA@.FOR_EACH_TEMPLATE_B_T
(
    ATID                               BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    COUNTER_CTID                       BINARY(16)                         NOT NULL ,
    SUCCESSFUL_BRANCHES_ONLY           SMALLINT                           NOT NULL ,
    START_COUNTER_LANGUAGE             INTEGER                            NOT NULL ,
    FINAL_COUNTER_LANGUAGE             INTEGER                            NOT NULL ,
    COMPLETION_CONDITION_LANGUAGE      INTEGER                            NOT NULL ,
    START_COUNTER_EXPRESSION           IMAGE                                  NULL ,
    FINAL_COUNTER_EXPRESSION           IMAGE                                  NULL ,
    COMPLETION_COND_EXPRESSION         IMAGE                                  NULL ,
    FOR_EACH_METHOD                    NVARCHAR(254)                          NULL ,
    START_COUNTER_EXPRESSION_MAP       IMAGE                                  NULL ,
    FINAL_COUNTER_EXPRESSION_MAP       IMAGE                                  NULL ,
    COMPLETION_COND_EXPRESSION_MAP     IMAGE                                  NULL ,
    PRIMARY KEY NONCLUSTERED ( ATID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX FOR_EACH_TEMPLATE_B_P ON @SCHEMA@.FOR_EACH_TEMPLATE_B_T
( 
    ATID
)
go


CREATE INDEX FET_PTID ON @SCHEMA@.FOR_EACH_TEMPLATE_B_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.GRAPHICAL_PROCESS_MODEL_T
(
    PTID                               BINARY(16)                         NOT NULL ,
    SOURCE                             NVARCHAR(100)                      NOT NULL ,
    KIND                               NVARCHAR(100)                      NOT NULL ,
    GRAPHICAL_DATA                     IMAGE                                  NULL ,
    ID_MAPPING                         IMAGE                                  NULL ,
    PRIMARY KEY NONCLUSTERED ( PTID, SOURCE, KIND )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX GRAPHICAL_PROCESS_MODEL_P ON @SCHEMA@.GRAPHICAL_PROCESS_MODEL_T
( 
    PTID, SOURCE, KIND
)
go


CREATE TABLE @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    CTID                               BINARY(16)                         NOT NULL ,
    PAID                               BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    QUERY_TYPE                         INTEGER                            NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX QUERYABLE_VARIABLE_TEMPLATE_P ON @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T
( 
    PKID
)
go


CREATE INDEX QVT_PTID ON @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(
    MPTID                              BINARY(16)                         NOT NULL ,
    SOURCE_PTID                        BINARY(16)                         NOT NULL ,
    TARGET_PTID                        BINARY(16)                         NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( MPTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX MIGRATION_PLAN_TEMPLATE_P ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
( 
    MPTID
)
go


CREATE UNIQUE INDEX MPT_PTIDS ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(   
    SOURCE_PTID, TARGET_PTID
)
go

CREATE INDEX MPT_TPTID ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(   
    TARGET_PTID
)
go

CREATE TABLE @SCHEMA@.IDMAPPING_TEMPLATE_T
(
    MPTID                              BINARY(16)                         NOT NULL ,
    SOURCE_OID                         BINARY(16)                         NOT NULL ,
    TARGET_OID                         BINARY(16)                         NOT NULL ,
    SOURCE_PTID                        BINARY(16)                         NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( MPTID, SOURCE_OID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX IDMAPPING_TEMPLATE_P ON @SCHEMA@.IDMAPPING_TEMPLATE_T
( 
    MPTID, SOURCE_OID
)
go


CREATE INDEX IDMT_PTID ON @SCHEMA@.IDMAPPING_TEMPLATE_T
(   
    SOURCE_PTID
)
go

CREATE TABLE @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(
    CGTID                              BINARY(16)                         NOT NULL ,
    MPTID                              BINARY(16)                         NOT NULL ,
    SOURCE_PTID                        BINARY(16)                         NOT NULL ,
    MANDATORY                          SMALLINT                           NOT NULL ,
    CHANGES                            NTEXT                              NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( CGTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX CHANGE_GROUP_TEMPLATE_P ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
( 
    CGTID
)
go


CREATE INDEX CGT_MT ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(   
    MPTID
)
go

CREATE INDEX CGT_PT ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(   
    SOURCE_PTID
)
go

CREATE TABLE @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(
    CGTID                              BINARY(16)                         NOT NULL ,
    SOURCE_ATID                        BINARY(16)                         NOT NULL ,
    MPTID                              BINARY(16)                         NOT NULL ,
    SOURCE_PTID                        BINARY(16)                         NOT NULL ,
    RELATIONSHIP                       INTEGER                            NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( CGTID, SOURCE_ATID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX CHANGE_GROUP_IMPACT_TEMPLATE_P ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
( 
    CGTID, SOURCE_ATID
)
go


CREATE INDEX CGIT_MT ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
    MPTID
)
go

CREATE INDEX CGIT_PT ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
    SOURCE_PTID
)
go

CREATE TABLE @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
(
    MPTID                              BINARY(16)                         NOT NULL ,
    TARGET_CTID                        BINARY(16)                         NOT NULL ,
    TARGET_STID                        BINARY(16)                         NOT NULL ,
    SOURCE_PTID                        BINARY(16)                         NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( MPTID, TARGET_CTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX MIGRATION_PLAN_VAR_TEMPLATE_P ON @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
( 
    MPTID, TARGET_CTID
)
go


CREATE INDEX MPVT_PT ON @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
(   
    SOURCE_PTID
)
go

CREATE TABLE @SCHEMA@.REGION_TEMPLATE_T
(
    RTID                               BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    BEGIN_ATID                         BINARY(16)                             NULL ,
    END_ATID                           BINARY(16)                             NULL ,
    REGION_TYPE                        INTEGER                            NOT NULL ,
    BEGIN_ORDER_NUMBER                 INTEGER                            NOT NULL ,
    PARENT_RTID                        BINARY(16)                             NULL ,
    PRIMARY KEY NONCLUSTERED ( RTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX REGION_TEMPLATE_P ON @SCHEMA@.REGION_TEMPLATE_T
( 
    RTID
)
go


CREATE INDEX RGT_PTID ON @SCHEMA@.REGION_TEMPLATE_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.REGION_CONTENT_TEMPLATE_T
(
    RTID                               BINARY(16)                         NOT NULL ,
    CONTAINED_ATID                     BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( RTID, CONTAINED_ATID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX REGION_CONTENT_TEMPLATE_P ON @SCHEMA@.REGION_CONTENT_TEMPLATE_T
( 
    RTID, CONTAINED_ATID
)
go


CREATE INDEX RCT_PTID ON @SCHEMA@.REGION_CONTENT_TEMPLATE_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.CHANGE_TEMPLATE_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    MPTID                              BINARY(16)                         NOT NULL ,
    PROPERTY                           INTEGER                            NOT NULL ,
    DISPLAY_ID_EXT                     NVARCHAR(32)                       NOT NULL ,
    CHANGE_TYPE                        INTEGER                            NOT NULL ,
    SOURCE_PTID                        BINARY(16)                         NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX CHANGE_TEMPLATE_P ON @SCHEMA@.CHANGE_TEMPLATE_T
( 
    PKID
)
go


CREATE UNIQUE INDEX CT_MTPDIS ON @SCHEMA@.CHANGE_TEMPLATE_T
(   
    MPTID, PROPERTY, DISPLAY_ID_EXT
)
go

CREATE INDEX CGT_PTID ON @SCHEMA@.CHANGE_TEMPLATE_T
(   
    SOURCE_PTID
)
go

CREATE TABLE @SCHEMA@.STAFF_QUERY_TEMPLATE_T
(
    QTID                               BINARY(16)                         NOT NULL ,
    ASSOCIATED_OBJECT_TYPE             INTEGER                            NOT NULL ,
    ASSOCIATED_OID                     BINARY(16)                         NOT NULL ,
    T_QUERY                            NVARCHAR(32)                       NOT NULL ,
    QUERY                              IMAGE                              NOT NULL ,
    HASH_CODE                          INTEGER                            NOT NULL ,
    SUBSTITUTION_POLICY                INTEGER                            NOT NULL ,
    STAFF_VERB                         IMAGE                                  NULL ,
    PRIMARY KEY NONCLUSTERED ( QTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX STAFF_QUERY_TEMPLATE_P ON @SCHEMA@.STAFF_QUERY_TEMPLATE_T
( 
    QTID
)
go


CREATE INDEX SQT_HASH ON @SCHEMA@.STAFF_QUERY_TEMPLATE_T
(   
    ASSOCIATED_OID, HASH_CODE, T_QUERY, ASSOCIATED_OBJECT_TYPE
)
go

CREATE TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
(
    PIID                               BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    SHARED_PC_ID                       BINARY(16)                             NULL ,
    STATE                              INTEGER                            NOT NULL ,
    PENDING_REQUEST                    INTEGER                            NOT NULL ,
    CREATED                            DATETIME                               NULL ,
    STARTED                            DATETIME                               NULL ,
    COMPLETED                          DATETIME                               NULL ,
    LAST_STATE_CHANGE                  DATETIME                               NULL ,
    LAST_MODIFIED                      DATETIME                               NULL ,
    NAME                               NVARCHAR(220)                      NOT NULL ,
    PARENT_NAME                        NVARCHAR(220)                          NULL ,
    TOP_LEVEL_NAME                     NVARCHAR(220)                      NOT NULL ,
    COMPENSATION_SPHERE_NAME           NVARCHAR(100)                          NULL ,
    STARTER                            NVARCHAR(128)                          NULL ,
    DESCRIPTION                        NVARCHAR(254)                          NULL ,
    INPUT_SNID                         BINARY(16)                             NULL ,
    INPUT_ATID                         BINARY(16)                             NULL ,
    INPUT_VTID                         BINARY(16)                             NULL ,
    OUTPUT_SNID                        BINARY(16)                             NULL ,
    OUTPUT_ATID                        BINARY(16)                             NULL ,
    OUTPUT_VTID                        BINARY(16)                             NULL ,
    FAULT_NAME                         NVARCHAR(254)                          NULL ,
    TOP_LEVEL_PIID                     BINARY(16)                         NOT NULL ,
    PARENT_PIID                        BINARY(16)                             NULL ,
    PARENT_AIID                        BINARY(16)                             NULL ,
    TKIID                              BINARY(16)                             NULL ,
    TERMIN_ON_REC                      SMALLINT                           NOT NULL ,
    AWAITED_SUB_PROC                   SMALLINT                           NOT NULL ,
    IS_CREATING                        SMALLINT                           NOT NULL ,
    PREVIOUS_STATE                     INTEGER                                NULL ,
    EXECUTING_ISOLATED_SCOPE           SMALLINT                           NOT NULL ,
    SCHEDULER_TASK_ID                  NVARCHAR(254)                          NULL ,
    RESUMES                            DATETIME                               NULL ,
    PENDING_SKIP_REQUEST               SMALLINT                           NOT NULL ,
    IS_MIGRATED                        SMALLINT                           NOT NULL ,
    UNHANDLED_EXCEPTION                IMAGE                                  NULL ,
    CREATED_WITH_VERSION               INTEGER                            NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX PROCESS_INSTANCE_B_P ON @SCHEMA@.PROCESS_INSTANCE_B_T
( 
    PIID
)
go


CREATE UNIQUE INDEX PIB_NAME ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
    NAME
)
go

CREATE INDEX PIB_TOP ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
    TOP_LEVEL_PIID
)
go

CREATE INDEX PIB_PAP ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
    PARENT_PIID
)
go

CREATE INDEX PIB_PAR ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
    PARENT_AIID
)
go

CREATE INDEX PIB_PTID ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
    PTID
)
go

CREATE INDEX PIB_PIID_STATE ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
    PIID, STATE
)
go

CREATE INDEX PIB_STATE ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
    STATE
)
go

CREATE INDEX PIB_PIID_PTID_STAT ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
    PIID, PTID, STATE, STARTER, STARTED
)
go

CREATE INDEX PIB_WSID1 ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
    WSID_1, STATE
)
go

CREATE INDEX PIB_WSID2 ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
    WSID_2, STATE
)
go

CREATE INDEX PIB_SWI1 ON @SCHEMA@.PROCESS_INSTANCE_B_T
(   
    PIID, NAME, PTID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.PROCESS_INSTANCE_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.SCOPE_INSTANCE_B_T
(
    SIID                               BINARY(16)                         NOT NULL ,
    PARENT_SIID                        BINARY(16)                             NULL ,
    STID                               BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    EHIID                              BINARY(16)                             NULL ,
    ENCLOSING_FEIID                    BINARY(16)                             NULL ,
    ENCLOSING_FOR_EACH_END_AIID        BINARY(16)                             NULL ,
    COMPENSATE_AIID                    BINARY(16)                             NULL ,
    PARENT_COMP_SIID                   BINARY(16)                             NULL ,
    LAST_COMP_SIID                     BINARY(16)                             NULL ,
    RUNNING_EVENT_HANDLERS             INTEGER                            NOT NULL ,
    STATE                              INTEGER                            NOT NULL ,
    NOTIFY_PARENT                      SMALLINT                           NOT NULL ,
    AWAITED_SCOPES                     INTEGER                            NOT NULL ,
    AWAITED_SUB_PROCESSES              INTEGER                            NOT NULL ,
    BPEL_EXCEPTION                     IMAGE                                  NULL ,
    IS_ACTIVE                          SMALLINT                           NOT NULL ,
    INITIATED_COMP                     SMALLINT                           NOT NULL ,
    IS_TERMINATION_FROM_FOR_EACH       SMALLINT                           NOT NULL ,
    TOTAL_COMPL_NUMBER                 BIGINT                             NOT NULL ,
    SCOPE_COMPL_NUMBER                 BIGINT                             NOT NULL ,
    A_TKIID                            BINARY(16)                             NULL ,
    HAS_COMPENSATION_WORK              SMALLINT                           NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( SIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX SCOPE_INSTANCE_B_P ON @SCHEMA@.SCOPE_INSTANCE_B_T
( 
    SIID
)
go


CREATE INDEX SI_PI_ST_EH_STA_FE ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
    PIID, STID, STATE, EHIID, ENCLOSING_FEIID
)
go

CREATE INDEX SI_PI_ST_EH_ACT_FE ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
    PIID, STID, IS_ACTIVE, EHIID, ENCLOSING_FEIID
)
go

CREATE INDEX SI_PIID_PARSI ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
    PIID, PARENT_SIID, IS_ACTIVE
)
go

CREATE INDEX SI_PARCOMP_STA_ST ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
    PARENT_COMP_SIID, STATE, STID
)
go

CREATE INDEX SI_PIID_STATE ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
    PIID, STATE
)
go

CREATE INDEX SI_LAST_COMPSIID ON @SCHEMA@.SCOPE_INSTANCE_B_T
(   
    LAST_COMP_SIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.SCOPE_INSTANCE_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
(
    AIID                               BINARY(16)                         NOT NULL ,
    ATID                               BINARY(16)                         NOT NULL ,
    SIID                               BINARY(16)                             NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    EHIID                              BINARY(16)                             NULL ,
    ENCLOSING_FEIID                    BINARY(16)                             NULL ,
    P_TKIID                            BINARY(16)                             NULL ,
    A_TKIID                            BINARY(16)                             NULL ,
    INVOKED_INSTANCE_ID                BINARY(16)                             NULL ,
    INVOKED_INSTANCE_TYPE              INTEGER                            NOT NULL ,
    STATE                              INTEGER                            NOT NULL ,
    TRANS_COND_VALUES                  VARBINARY(66)                      NOT NULL ,
    NUMBER_LINKS_EVALUATED             INTEGER                            NOT NULL ,
    FINISHED                           DATETIME                               NULL ,
    ACTIVATED                          DATETIME                               NULL ,
    FIRST_ACTIVATED                    DATETIME                               NULL ,
    STARTED                            DATETIME                               NULL ,
    LAST_MODIFIED                      DATETIME                               NULL ,
    LAST_STATE_CHANGE                  DATETIME                               NULL ,
    OWNER                              NVARCHAR(128)                          NULL ,
    DESCRIPTION                        NVARCHAR(254)                          NULL ,
    LINK_ORDER_NUMBER                  INTEGER                                NULL ,
    SCHEDULER_TASK_ID                  NVARCHAR(254)                          NULL ,
    EXPIRES                            DATETIME                               NULL ,
    CONTINUE_ON_ERROR                  SMALLINT                           NOT NULL ,
    UNHANDLED_EXCEPTION                IMAGE                                  NULL ,
    STOP_REASON                        INTEGER                            NOT NULL ,
    PREVIOUS_STATE                     INTEGER                                NULL ,
    INVOCATION_COUNTER                 INTEGER                            NOT NULL ,
    FOR_EACH_START_COUNTER_VALUE       BIGINT                                 NULL ,
    FOR_EACH_FINAL_COUNTER_VALUE       BIGINT                                 NULL ,
    FOR_EACH_CURRENT_COUNTER_VALUE     BIGINT                                 NULL ,
    FOR_EACH_COMPLETED_BRANCHES        BIGINT                                 NULL ,
    FOR_EACH_FAILED_BRANCHES           BIGINT                                 NULL ,
    FOR_EACH_MAX_COMPL_BRANCHES        BIGINT                                 NULL ,
    FOR_EACH_AWAITED_BRANCHES          BIGINT                                 NULL ,
    IS51_ACTIVITY                      SMALLINT                           NOT NULL ,
    MAY_HAVE_SUBPROCESS                SMALLINT                               NULL ,
    SKIP_REQUESTED                     SMALLINT                           NOT NULL ,
    JUMP_TARGET_ATID                   BINARY(16)                             NULL ,
    SUB_STATE                          INTEGER                            NOT NULL ,
    PENDING_REQUEST_DATA               IMAGE                                  NULL ,
    XTID                               BINARY(16)                             NULL ,
    EXPIRATION_COUNTER                 INTEGER                                NULL ,
    PREVIOUS_EXPIRATION_DATE           DATETIME                               NULL ,
    TARGET_IORAIID                     BINARY(16)                             NULL ,
    DISPLAY_ID_EXT                     NVARCHAR(32)                           NULL ,
    MAX_COMPENSATION_NUMBER            BIGINT                                 NULL ,
    HAS_WORK_ITEM                      SMALLINT                               NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( AIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX ACTIVITY_INSTANCE_B_P ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
( 
    AIID
)
go


CREATE INDEX AIB_PI_ATID_EH_FE ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
    PIID, ATID, EHIID, ENCLOSING_FEIID
)
go

CREATE INDEX AIB_PI_EH_FE_AT ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
    PIID, EHIID, ENCLOSING_FEIID, ATID
)
go

CREATE INDEX AIB_PI_DIS_EH_FE ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
    PIID, DISPLAY_ID_EXT, EHIID, ENCLOSING_FEIID
)
go

CREATE INDEX AIB_PTID ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
    PTID
)
go

CREATE INDEX AIB_PIID_STAT_AIID ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
    PIID, STATE, AIID, ACTIVATED
)
go

CREATE INDEX AIB_AI_AT_STAT_PI ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
    AIID, ATID, STATE, PIID, OWNER, ACTIVATED
)
go

CREATE INDEX AIB_SIID ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
    SIID
)
go

CREATE INDEX AIB_ATID_STAT ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
    ATID, STATE
)
go

CREATE INDEX AIB_WSID1 ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
    WSID_1, STATE
)
go

CREATE INDEX AIB_WSID2 ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
    WSID_2, STATE
)
go

CREATE INDEX AIB_PIID ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
    PIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.ACTIVITY_INSTANCE_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.VARIABLE_INSTANCE_B_T
(
    CTID                               BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    DATA                               IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( CTID, PIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX VARIABLE_INSTANCE_B_P ON @SCHEMA@.VARIABLE_INSTANCE_B_T
( 
    CTID, PIID
)
go


CREATE INDEX CI_PIID ON @SCHEMA@.VARIABLE_INSTANCE_B_T
(   
    PIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.VARIABLE_INSTANCE_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_T
(
    SVIID                              BINARY(16)                         NOT NULL ,
    CTID                               BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    SIID                               BINARY(16)                         NOT NULL ,
    EHIID                              BINARY(16)                             NULL ,
    FEIID                              BINARY(16)                             NULL ,
    DATA                               IMAGE                                  NULL ,
    IS_ACTIVE                          SMALLINT                           NOT NULL ,
    IS_INITIALIZED                     SMALLINT                           NOT NULL ,
    IS_QUERYABLE                       SMALLINT                           NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( SVIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX SCOPED_VARIABLE_INSTANCE_B_P ON @SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_T
( 
    SVIID
)
go


CREATE INDEX SVI_PI_CT_EH_FE ON @SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_T
(   
    PIID, CTID, IS_ACTIVE, EHIID, FEIID
)
go

CREATE INDEX SVI_CT_SI_EH_AC ON @SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_T
(   
    SIID, CTID, IS_ACTIVE, EHIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.SCOPED_VARIABLE_INSTANCE_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.STAFF_MESSAGE_INSTANCE_B_T
(
    AIID                               BINARY(16)                         NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    DATA                               IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( AIID, KIND )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX STAFF_MESSAGE_INSTANCE_B_P ON @SCHEMA@.STAFF_MESSAGE_INSTANCE_B_T
( 
    AIID, KIND
)
go


CREATE INDEX SMI_PIID ON @SCHEMA@.STAFF_MESSAGE_INSTANCE_B_T
(   
    PIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.STAFF_MESSAGE_INSTANCE_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.EVENT_INSTANCE_B_T
(
    EIID                               BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    VTID                               BINARY(16)                         NOT NULL ,
    IS_TWO_WAY                         SMALLINT                           NOT NULL ,
    IS_PRIMARY_EVENT_INSTANCE          SMALLINT                           NOT NULL ,
    STATE                              INTEGER                            NOT NULL ,
    AIID                               BINARY(16)                             NULL ,
    EHTID                              BINARY(16)                             NULL ,
    SIID                               BINARY(16)                             NULL ,
    TKIID                              BINARY(16)                             NULL ,
    NEXT_POSTED_EVENT                  BINARY(16)                             NULL ,
    LAST_POSTED_EVENT                  BINARY(16)                             NULL ,
    POST_COUNT                         INTEGER                            NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    MESSAGE                            IMAGE                                  NULL ,
    REPLY_CONTEXT                      IMAGE                                  NULL ,
    POST_TIME                          DATETIME                               NULL ,
    MAX_NUMBER_OF_POSTS                INTEGER                            NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( EIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX EVENT_INSTANCE_B_P ON @SCHEMA@.EVENT_INSTANCE_B_T
( 
    EIID
)
go


CREATE INDEX EI_PIID_PRIM ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
    PIID, IS_PRIMARY_EVENT_INSTANCE, STATE
)
go

CREATE INDEX EI_PIID_VTID ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
    PIID, VTID, IS_PRIMARY_EVENT_INSTANCE
)
go

CREATE INDEX EI_AIID ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
    AIID
)
go

CREATE INDEX EI_STATE_VTID ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
    VTID, STATE, EIID, AIID, PIID
)
go

CREATE INDEX EI_WSID1 ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
    WSID_1
)
go

CREATE INDEX EI_WSID2 ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
    WSID_2
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.EVENT_INSTANCE_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.REQUEST_INSTANCE_B_T
(
    RIID                               BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    VTID                               BINARY(16)                         NOT NULL ,
    ATID                               BINARY(16)                         NOT NULL ,
    EHIID                              BINARY(16)                             NULL ,
    TKIID                              BINARY(16)                             NULL ,
    FEIID                              BINARY(16)                             NULL ,
    INSTANTIATING                      SMALLINT                           NOT NULL ,
    REPLY_CONTEXT                      IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( RIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX REQUEST_INSTANCE_B_P ON @SCHEMA@.REQUEST_INSTANCE_B_T
( 
    RIID
)
go


CREATE INDEX RI_PIID_VTID_EHIID ON @SCHEMA@.REQUEST_INSTANCE_B_T
(   
    PIID, VTID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.REQUEST_INSTANCE_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.PARTNER_LINK_INSTANCE_B_T
(
    PIID                               BINARY(16)                         NOT NULL ,
    NAME                               NVARCHAR(220)                      NOT NULL ,
    ENDPOINT_REFERENCE                 IMAGE                                  NULL ,
    SERVICE_DEFINITION                 IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PIID, NAME )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX PARTNER_LINK_INSTANCE_B_P ON @SCHEMA@.PARTNER_LINK_INSTANCE_B_T
( 
    PIID, NAME
)
go


CREATE INDEX PA_PIID ON @SCHEMA@.PARTNER_LINK_INSTANCE_B_T
(   
    PIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.PARTNER_LINK_INSTANCE_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.VARIABLE_SNAPSHOT_B_T
(
    SNID                               BINARY(16)                         NOT NULL ,
    CTID                               BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    DATA                               IMAGE                                  NULL ,
    COPY_VERSION                       SMALLINT                           NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( SNID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX VARIABLE_SNAPSHOT_B_P ON @SCHEMA@.VARIABLE_SNAPSHOT_B_T
( 
    SNID
)
go


CREATE INDEX SN_PIID_CTID ON @SCHEMA@.VARIABLE_SNAPSHOT_B_T
(   
    PIID, CTID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.VARIABLE_SNAPSHOT_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.SUSPENDED_MESSAGE_INSTANCE_B_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    ENGINE_MESSAGE                     IMAGE                              NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX SUSPENDED_MESSAGE_INSTANCE_B_P ON @SCHEMA@.SUSPENDED_MESSAGE_INSTANCE_B_T
( 
    PKID
)
go


CREATE INDEX PIID ON @SCHEMA@.SUSPENDED_MESSAGE_INSTANCE_B_T
(   
    PIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.SUSPENDED_MESSAGE_INSTANCE_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.CROSSING_LINK_INSTANCE_B_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    SOURCE_ATID                        BINARY(16)                         NOT NULL ,
    TARGET_ATID                        BINARY(16)                         NOT NULL ,
    EHIID                              BINARY(16)                             NULL ,
    FEIID                              BINARY(16)                             NULL ,
    CONDITION_VALUE                    INTEGER                            NOT NULL ,
    DESCRIPTION                        NVARCHAR(254)                          NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX CROSSING_LINK_INSTANCE_B_P ON @SCHEMA@.CROSSING_LINK_INSTANCE_B_T
( 
    PKID
)
go


CREATE INDEX CL_PI_TAT_EH_FE_SA ON @SCHEMA@.CROSSING_LINK_INSTANCE_B_T
(   
    PIID, TARGET_ATID, EHIID, FEIID, SOURCE_ATID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.CROSSING_LINK_INSTANCE_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.INVOKE_RESULT_B_T
(
    PIID                               BINARY(16)                         NOT NULL ,
    ATID                               BINARY(16)                         NOT NULL ,
    STATE                              INTEGER                            NOT NULL ,
    INVOKE_RESULT                      IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PIID, ATID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX INVOKE_RESULT_B_P ON @SCHEMA@.INVOKE_RESULT_B_T
( 
    PIID, ATID
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.INVOKE_RESULT_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.INVOKE_RESULT2_B_T
(
    IRID                               BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    ATID                               BINARY(16)                         NOT NULL ,
    EHIID                              BINARY(16)                             NULL ,
    FEIID                              BINARY(16)                             NULL ,
    STATE                              INTEGER                            NOT NULL ,
    INVOKE_RESULT                      IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( IRID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX INVOKE_RESULT2_B_P ON @SCHEMA@.INVOKE_RESULT2_B_T
( 
    IRID
)
go


CREATE INDEX IR2_PI_AT_EH_FE ON @SCHEMA@.INVOKE_RESULT2_B_T
(   
    PIID, ATID, EHIID, FEIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.INVOKE_RESULT2_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.EVENT_HANDLER_INSTANCE_B_T
(
    EHIID                              BINARY(16)                         NOT NULL ,
    EHTID                              BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    SIID                               BINARY(16)                         NOT NULL ,
    PARENT_EHIID                       BINARY(16)                             NULL ,
    FEIID                              BINARY(16)                             NULL ,
    SCHEDULER_TASK_ID                  NVARCHAR(254)                          NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( EHIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX EVENT_HANDLER_INSTANCE_B_P ON @SCHEMA@.EVENT_HANDLER_INSTANCE_B_T
( 
    EHIID
)
go


CREATE INDEX EHI_PIID_EHTID ON @SCHEMA@.EVENT_HANDLER_INSTANCE_B_T
(   
    PIID, EHTID
)
go

CREATE INDEX EHI_SIID_EHTID ON @SCHEMA@.EVENT_HANDLER_INSTANCE_B_T
(   
    SIID, EHTID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.EVENT_HANDLER_INSTANCE_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.CORRELATION_SET_INSTANCE_B_T
(
    PIID                               BINARY(16)                         NOT NULL ,
    COID                               BINARY(16)                         NOT NULL ,
    SIID                               BINARY(16)                         NOT NULL ,
    PROCESS_NAME                       NVARCHAR(220)                      NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    STATUS                             INTEGER                            NOT NULL ,
    HASH_CODE                          BINARY(16)                         NOT NULL ,
    DATA                               NVARCHAR(3072)                         NULL ,
    DATA_LONG                          NTEXT                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PIID, COID, SIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX CORRELATION_SET_INSTANCE_B_P ON @SCHEMA@.CORRELATION_SET_INSTANCE_B_T
( 
    PIID, COID, SIID
)
go


CREATE UNIQUE INDEX CSIB_HASH_PN ON @SCHEMA@.CORRELATION_SET_INSTANCE_B_T
(   
    HASH_CODE, PROCESS_NAME
)
go

CREATE INDEX CSIB_PIID ON @SCHEMA@.CORRELATION_SET_INSTANCE_B_T
(   
    PIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.CORRELATION_SET_INSTANCE_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.CORRELATION_SET_PROPERTIES_B_T
(
    PIID                               BINARY(16)                         NOT NULL ,
    COID                               BINARY(16)                         NOT NULL ,
    SIID                               BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    DATA                               IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PIID, COID, SIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX CORRELATION_SET_PROPERTIES_B_P ON @SCHEMA@.CORRELATION_SET_PROPERTIES_B_T
( 
    PIID, COID, SIID
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.CORRELATION_SET_PROPERTIES_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.UNDO_ACTION_B_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    ATID                               BINARY(16)                         NOT NULL ,
    PARENT_ATID                        BINARY(16)                             NULL ,
    PARENT_PIID                        BINARY(16)                             NULL ,
    PARENT_AIID                        BINARY(16)                             NULL ,
    PARENT_EHIID                       BINARY(16)                             NULL ,
    PARENT_FEIID                       BINARY(16)                             NULL ,
    PROCESS_NAME                       NVARCHAR(220)                      NOT NULL ,
    CSCOPE_ID                          NVARCHAR(100)                      NOT NULL ,
    UUID                               NVARCHAR(100)                      NOT NULL ,
    COMP_CREATION_TIME                 DATETIME                           NOT NULL ,
    DO_OP_WAS_TXNAL                    SMALLINT                           NOT NULL ,
    STATE                              INTEGER                            NOT NULL ,
    INPUT_DATA                         IMAGE                              NOT NULL ,
    FAULT_DATA                         IMAGE                                  NULL ,
    CREATED                            INTEGER                            NOT NULL ,
    PROCESS_ADMIN                      NVARCHAR(128)                      NOT NULL ,
    IS_VISIBLE                         SMALLINT                           NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX UNDO_ACTION_B_P ON @SCHEMA@.UNDO_ACTION_B_T
( 
    PKID
)
go


CREATE INDEX UA_CSID_DOOP_UUID ON @SCHEMA@.UNDO_ACTION_B_T
(   
    CSCOPE_ID, DO_OP_WAS_TXNAL, UUID
)
go

CREATE INDEX UA_CSID_STATE_CCT ON @SCHEMA@.UNDO_ACTION_B_T
(   
    CSCOPE_ID, STATE, UUID
)
go

CREATE INDEX UA_STATE_ISV ON @SCHEMA@.UNDO_ACTION_B_T
(   
    STATE, IS_VISIBLE
)
go

CREATE INDEX UA_AIID_STATE_UUID ON @SCHEMA@.UNDO_ACTION_B_T
(   
    PARENT_AIID, STATE, UUID
)
go

CREATE INDEX UA_PIID ON @SCHEMA@.UNDO_ACTION_B_T
(   
    PARENT_PIID
)
go

CREATE INDEX UA_PT_AT_CS_UU_CCT ON @SCHEMA@.UNDO_ACTION_B_T
(   
    PTID, ATID, CSCOPE_ID, UUID, COMP_CREATION_TIME
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.UNDO_ACTION_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    SVIID                              BINARY(16)                             NULL ,
    NAMESPACE                          NVARCHAR(220)                      NOT NULL ,
    LOCALNAME                          NVARCHAR(220)                      NOT NULL ,
    PURPOSE                            NVARCHAR(220)                      NOT NULL ,
    STATEMENT                          IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX CUSTOM_STMT_INSTANCE_B_P ON @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T
( 
    PKID
)
go


CREATE INDEX CSI_PIID_NS ON @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T
(   
    PIID, NAMESPACE
)
go

CREATE INDEX CSI_SVIID_NS ON @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T
(   
    SVIID, NAMESPACE
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.CUSTOM_STMT_INSTANCE_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.COMP_WORK_PENDING_B_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    PARENT_PIID                        BINARY(16)                         NOT NULL ,
    PARENT_ATID                        BINARY(16)                         NOT NULL ,
    PARENT_EHIID                       BINARY(16)                             NULL ,
    PARENT_FEIID                       BINARY(16)                             NULL ,
    STATE                              INTEGER                            NOT NULL ,
    CSCOPE_ID                          NVARCHAR(100)                      NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX COMP_WORK_PENDING_B_P ON @SCHEMA@.COMP_WORK_PENDING_B_T
( 
    PKID
)
go


CREATE INDEX CWP_PI_AT_CS_EH_FE ON @SCHEMA@.COMP_WORK_PENDING_B_T
(   
    PARENT_PIID, PARENT_ATID, CSCOPE_ID, PARENT_EHIID, PARENT_FEIID
)
go

CREATE INDEX CWP_PI_AT_EHI ON @SCHEMA@.COMP_WORK_PENDING_B_T
(   
    PARENT_PIID, PARENT_ATID, PARENT_EHIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.COMP_WORK_PENDING_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
(
    AIID                               BINARY(16)                         NOT NULL ,
    SIID                               BINARY(16)                         NOT NULL ,
    ATID                               BINARY(16)                             NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    COMPLETION_NUMBER                  BIGINT                             NOT NULL ,
    STATE                              INTEGER                            NOT NULL ,
    COMPENSATE_AIID                    BINARY(16)                             NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( AIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX COMP_PARENT_ACTIVITY_INST_B_P ON @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
( 
    AIID
)
go


CREATE INDEX CPAI_SI_S_CN_AI_PI ON @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
(   
    SIID, STATE, COMPLETION_NUMBER, AIID, PIID
)
go

CREATE INDEX CPAI_PIID ON @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
(   
    PIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.RESTART_EVENT_B_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    PORT_TYPE                          NVARCHAR(254)                      NOT NULL ,
    OPERATION                          NVARCHAR(254)                      NOT NULL ,
    NAMESPACE                          NVARCHAR(254)                      NOT NULL ,
    INPUT_MESSAGE                      IMAGE                                  NULL ,
    REPLY_CTX                          IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX RESTART_EVENT_B_P ON @SCHEMA@.RESTART_EVENT_B_T
( 
    PKID
)
go


CREATE INDEX REB_PIID ON @SCHEMA@.RESTART_EVENT_B_T
(   
    PIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.RESTART_EVENT_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.PROGRESS_COUNTER_T
(
    PIID                               BINARY(16)                         NOT NULL ,
    COUNTER                            BIGINT                             NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX PROGRESS_COUNTER_P ON @SCHEMA@.PROGRESS_COUNTER_T
( 
    PIID
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.PROGRESS_COUNTER_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.RELEVANT_SCOPE_ATASK_T
(
    SIID                               BINARY(16)                         NOT NULL ,
    TKIID                              BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( SIID, TKIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX RELEVANT_SCOPE_ATASK_P ON @SCHEMA@.RELEVANT_SCOPE_ATASK_T
( 
    SIID, TKIID
)
go


CREATE INDEX RSAT_PIID ON @SCHEMA@.RELEVANT_SCOPE_ATASK_T
(   
    PIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.RELEVANT_SCOPE_ATASK_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.CONFIG_INFO_T
(
    IDENTIFIER                         NVARCHAR(64)                       NOT NULL ,
    DESCRIPTION                        NVARCHAR(128)                          NULL ,
    PROPERTY                           INTEGER                                NULL ,
    COUNTER                            BIGINT                                 NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( IDENTIFIER )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX CONFIG_INFO_P ON @SCHEMA@.CONFIG_INFO_T
( 
    IDENTIFIER
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.CONFIG_INFO_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
(
    PIID                               BINARY(16)                         NOT NULL ,
    ATTR_KEY                           NVARCHAR(220)                      NOT NULL ,
    VALUE                              NVARCHAR(254)                          NULL ,
    DATA_TYPE                          NVARCHAR(254)                          NULL ,
    DATA                               IMAGE                                  NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PIID, ATTR_KEY )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX PROCESS_INSTANCE_ATTRIBUTE_P ON @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
( 
    PIID, ATTR_KEY
)
go


CREATE INDEX PIA_VALUE ON @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
(   
    VALUE
)
go

CREATE INDEX PIA_DATY ON @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
(   
    DATA_TYPE
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.PROCESS_CONTEXT_T
(
    PIID                               BINARY(16)                         NOT NULL ,
    SHARED                             SMALLINT                               NULL ,
    REPLY_CONTEXT                      IMAGE                                  NULL ,
    SERVICE_CONTEXT                    IMAGE                                  NULL ,
    STARTER_EXPIRES                    DATETIME                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX PROCESS_CONTEXT_P ON @SCHEMA@.PROCESS_CONTEXT_T
( 
    PIID
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.PROCESS_CONTEXT_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    ATID                               BINARY(16)                         NOT NULL ,
    EHIID                              BINARY(16)                             NULL ,
    FEIID                              BINARY(16)                             NULL ,
    AIID                               BINARY(16)                             NULL ,
    ATTR_KEY                           NVARCHAR(189)                      NOT NULL ,
    ATTR_VALUE                         NVARCHAR(254)                          NULL ,
    DATA_TYPE                          NVARCHAR(254)                          NULL ,
    DATA                               IMAGE                                  NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX ACTIVITY_INSTANCE_ATTR_B_P ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
( 
    PKID
)
go


CREATE UNIQUE INDEX AIA_UNIQUE ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
    PIID, ATID, EHIID, FEIID, ATTR_KEY
)
go

CREATE INDEX AIA_AIID ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
    AIID
)
go

CREATE INDEX AIA_VALUE ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
    ATTR_VALUE
)
go

CREATE INDEX AIA_DATY ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
    DATA_TYPE
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.NAVIGATION_EXCEPTION_T
(
    CORRELATION_ID                     VARBINARY(220)                     NOT NULL ,
    EXCEPTION_TYPE                     INTEGER                            NOT NULL ,
    PIID                               BINARY(16)                             NULL ,
    OUTPUT_MESSAGE                     IMAGE                                  NULL ,
    TYPE_SYSTEM                        NVARCHAR(32)                           NULL ,
    PROCESS_EXCEPTION                  IMAGE                              NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( CORRELATION_ID, EXCEPTION_TYPE )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX NAVIGATION_EXCEPTION_P ON @SCHEMA@.NAVIGATION_EXCEPTION_T
( 
    CORRELATION_ID, EXCEPTION_TYPE
)
go


CREATE INDEX NE_PIID ON @SCHEMA@.NAVIGATION_EXCEPTION_T
(   
    PIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.NAVIGATION_EXCEPTION_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.AWAITED_INVOCATION_T
(
    CORRELATION_ID                     VARBINARY(254)                     NOT NULL ,
    CORRELATION_INFO                   IMAGE                              NOT NULL ,
    AIID                               BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( CORRELATION_ID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX AWAITED_INVOCATION_P ON @SCHEMA@.AWAITED_INVOCATION_T
( 
    CORRELATION_ID
)
go


CREATE INDEX AWI_PIID ON @SCHEMA@.AWAITED_INVOCATION_T
(   
    PIID
)
go

CREATE INDEX AWI_AIID ON @SCHEMA@.AWAITED_INVOCATION_T
(   
    AIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.AWAITED_INVOCATION_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.STORED_QUERY_T
(
    SQID                               BINARY(16)                         NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    NAME                               NVARCHAR(64)                       NOT NULL ,
    OWNER_ID                           NVARCHAR(128)                      NOT NULL ,
    SELECT_CLAUSE                      NTEXT                              NOT NULL ,
    WHERE_CLAUSE                       NTEXT                                  NULL ,
    ORDER_CLAUSE                       NVARCHAR(254)                          NULL ,
    THRESHOLD                          INTEGER                                NULL ,
    TIMEZONE                           NVARCHAR(63)                           NULL ,
    CREATOR                            NVARCHAR(128)                          NULL ,
    TYPE                               NVARCHAR(128)                          NULL ,
    PROPERTY                           IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( SQID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX STORED_QUERY_P ON @SCHEMA@.STORED_QUERY_T
( 
    SQID
)
go


CREATE UNIQUE INDEX SQ_NAME ON @SCHEMA@.STORED_QUERY_T
(   
    KIND, OWNER_ID, NAME
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.STORED_QUERY_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.FOR_EACH_INSTANCE_B_T
(
    FEIID                              BINARY(16)                         NOT NULL ,
    PARENT_FEIID                       BINARY(16)                             NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( FEIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX FOR_EACH_INSTANCE_B_P ON @SCHEMA@.FOR_EACH_INSTANCE_B_T
( 
    FEIID
)
go


CREATE INDEX FEI_PIID ON @SCHEMA@.FOR_EACH_INSTANCE_B_T
(   
    PIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.FOR_EACH_INSTANCE_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    CTID                               BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    PAID                               BINARY(16)                         NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    VARIABLE_NAME                      NVARCHAR(254)                      NOT NULL ,
    PROPERTY_NAME                      NVARCHAR(255)                      NOT NULL ,
    PROPERTY_NAMESPACE                 NVARCHAR(254)                      NOT NULL ,
    TYPE                               INTEGER                            NOT NULL ,
    GENERIC_VALUE                      NVARCHAR(512)                          NULL ,
    STRING_VALUE                       NVARCHAR(512)                          NULL ,
    NUMBER_VALUE                       BIGINT                                 NULL ,
    DECIMAL_VALUE                      FLOAT(53)                              NULL ,
    TIMESTAMP_VALUE                    DATETIME                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX QUERYABLE_VARIABLE_INSTANCE_P ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
( 
    PKID
)
go


CREATE INDEX QVI_PI_CT_PA ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
    PIID, CTID, PAID
)
go

CREATE INDEX QVI_PI_VARNAME ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
    PIID, VARIABLE_NAME
)
go

CREATE INDEX QVI_PI_PROPNAME ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
    PIID, PROPERTY_NAME
)
go

CREATE INDEX QVI_PI_NAMESPACE ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
    PIID, PROPERTY_NAMESPACE
)
go

CREATE INDEX QVI_PI_GEN_VALUE ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
    PIID, GENERIC_VALUE
)
go

CREATE INDEX QVI_PI_STR_VALUE ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
    PIID, STRING_VALUE
)
go

CREATE INDEX QVI_PI_NUM ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
    PIID, NUMBER_VALUE
)
go

CREATE INDEX QVI_PI_DEC ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
    PIID, DECIMAL_VALUE
)
go

CREATE INDEX QVI_PI_TIME ON @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
(   
    PIID, TIMESTAMP_VALUE
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.SYNC_T
(
    IDENTIFIER                         NVARCHAR(254)                      NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( IDENTIFIER )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX SYNC_P ON @SCHEMA@.SYNC_T
( 
    IDENTIFIER
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.SYNC_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.MV_CTR_T
(
    ID                                 INTEGER                            NOT NULL ,
    SELECT_CLAUSE                      NVARCHAR(1024)                     NOT NULL ,
    WHERE_CLAUSE                       NVARCHAR(1024)                         NULL ,
    ORDER_CLAUSE                       NVARCHAR(512)                          NULL ,
    TBL_SPACE                          NVARCHAR(32)                       NOT NULL ,
    UPDATED                            DATETIME                           NOT NULL ,
    UPD_STARTED                        DATETIME                               NULL ,
    AVG_UPD_TIME                       BIGINT                                 NULL ,
    UPD_INTERVAL                       BIGINT                             NOT NULL ,
    IS_UPDATING                        SMALLINT                           NOT NULL ,
    ACTIVE_MV                          SMALLINT                           NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX MV_CTR_P ON @SCHEMA@.MV_CTR_T
( 
    ID
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.MV_CTR_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.MV_MODS_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    OID                                BINARY(16)                         NOT NULL ,
    MODIFIED                           DATETIME                           NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX MV_MODS_P ON @SCHEMA@.MV_MODS_T
( 
    PKID
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.MV_MODS_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                             NULL ,
    CREATION_TIME                      DATETIME                           NOT NULL ,
    REASON                             INTEGER                            NOT NULL ,
    ENGINE_MESSAGE_S                   VARBINARY(2000)                        NULL ,
    ENGINE_MESSAGE_L                   IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX SAVED_ENGINE_MESSAGE_B_P ON @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
( 
    PKID
)
go


CREATE INDEX SEM_PIID ON @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(   
    PIID
)
go

CREATE INDEX SEM_REAS ON @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(   
    REASON, CREATION_TIME
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.SAVED_ENGINE_MESSAGE_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.NAVIGATION_CLEANUP_TIMER_B_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    SCHEDULED_TIME                     DATETIME                           NOT NULL ,
    SCHEDULER_ID                       NVARCHAR(254)                      NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX NAVIGATION_CLEANUP_TIMER_B_P ON @SCHEMA@.NAVIGATION_CLEANUP_TIMER_B_T
( 
    PKID
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.NAVIGATION_CLEANUP_TIMER_B_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.SCHEDULER_ACTION_T
(
    SCHEDULER_ID                       NVARCHAR(254)                      NOT NULL ,
    OID                                BINARY(16)                         NOT NULL ,
    ACTION_OBJECT                      IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( SCHEDULER_ID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX SCHEDULER_ACTION_P ON @SCHEMA@.SCHEDULER_ACTION_T
( 
    SCHEDULER_ID
)
go


CREATE INDEX SCEACT_OID ON @SCHEMA@.SCHEDULER_ACTION_T
(   
    OID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.SCHEDULER_ACTION_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.QUERY_TABLE_T
(
    NAME                               NVARCHAR(32)                       NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    TYPE                               INTEGER                            NOT NULL ,
    VERSION                            INTEGER                            NOT NULL ,
    LAST_UPDATED                       DATETIME                           NOT NULL ,
    PRIMARY_VIEW                       NVARCHAR(32)                           NULL ,
    DEFINITION                         IMAGE                              NOT NULL ,
    VV_CFG                             IMAGE                                  NULL ,
    DV_CFG                             IMAGE                                  NULL ,
    MV_CFG                             IMAGE                                  NULL ,
    MT_CFG                             IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( NAME )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX QUERY_TABLE_P ON @SCHEMA@.QUERY_TABLE_T
( 
    NAME
)
go


CREATE INDEX QT_KI ON @SCHEMA@.QUERY_TABLE_T
(   
    KIND
)
go

CREATE INDEX QT_TY ON @SCHEMA@.QUERY_TABLE_T
(   
    TYPE
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.QUERY_TABLE_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.QUERY_TABLE_REF_T
(
    REFEREE                            NVARCHAR(32)                       NOT NULL ,
    SOURCE                             NVARCHAR(32)                       NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( REFEREE, SOURCE )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX QUERY_TABLE_REF_P ON @SCHEMA@.QUERY_TABLE_REF_T
( 
    REFEREE, SOURCE
)
go


CREATE INDEX QTR_SRC ON @SCHEMA@.QUERY_TABLE_REF_T
(   
    SOURCE
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.QUERY_TABLE_REF_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.MIGRATION_FRONT_T
(
    PIID                               BINARY(16)                         NOT NULL ,
    MPTID                              BINARY(16)                         NOT NULL ,
    AIID                               BINARY(16)                         NOT NULL ,
    STATE                              INTEGER                            NOT NULL ,
    SUB_STATE                          INTEGER                            NOT NULL ,
    STOP_REASON                        INTEGER                            NOT NULL ,
    SOURCE_ATID                        BINARY(16)                         NOT NULL ,
    TARGET_ATID                        BINARY(16)                         NOT NULL ,
    MIGRATION_TIME                     DATETIME                           NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PIID, MPTID, AIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX MIGRATION_FRONT_P ON @SCHEMA@.MIGRATION_FRONT_T
( 
    PIID, MPTID, AIID
)
go


CREATE INDEX MGF_MPTID ON @SCHEMA@.MIGRATION_FRONT_T
(   
    MPTID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.MIGRATION_FRONT_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
(
    SIID                               BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    COUNTER                            BIGINT                                 NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( SIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX SCOPE_COMPLETION_COUNTER_P ON @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
( 
    SIID
)
go


CREATE INDEX SCC_PIID ON @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
(   
    PIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.SCOPE_COMPLETION_COUNTER_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.AUDIT_LOG_T
(
    ALID                               BINARY(16)                         NOT NULL ,
    EVENT_TIME                         DATETIME                           NOT NULL ,
    EVENT_TIME_UTC                     DATETIME                               NULL ,
    AUDIT_EVENT                        INTEGER                            NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                             NULL ,
    AIID                               BINARY(16)                             NULL ,
    SIID                               BINARY(16)                             NULL ,
    VARIABLE_NAME                      NVARCHAR(254)                          NULL ,
    PROCESS_TEMPL_NAME                 NVARCHAR(254)                      NOT NULL ,
    PROCESS_INST_NAME                  NVARCHAR(254)                          NULL ,
    TOP_LEVEL_PI_NAME                  NVARCHAR(254)                          NULL ,
    TOP_LEVEL_PIID                     BINARY(16)                             NULL ,
    PARENT_PI_NAME                     NVARCHAR(254)                          NULL ,
    PARENT_PIID                        BINARY(16)                             NULL ,
    VALID_FROM                         DATETIME                               NULL ,
    VALID_FROM_UTC                     DATETIME                               NULL ,
    ATID                               BINARY(16)                             NULL ,
    ACTIVITY_NAME                      NVARCHAR(254)                          NULL ,
    ACTIVITY_KIND                      INTEGER                                NULL ,
    ACTIVITY_STATE                     INTEGER                                NULL ,
    CONTROL_LINK_NAME                  NVARCHAR(254)                          NULL ,
    IMPL_NAME                          NVARCHAR(254)                          NULL ,
    PRINCIPAL                          NVARCHAR(128)                          NULL ,
    TERMINAL_NAME                      NVARCHAR(254)                          NULL ,
    VARIABLE_DATA                      IMAGE                                  NULL ,
    EXCEPTION_TEXT                     NTEXT                                  NULL ,
    DESCRIPTION                        NVARCHAR(254)                          NULL ,
    CORR_SET_INFO                      NTEXT                                  NULL ,
    USER_NAME                          NVARCHAR(128)                          NULL ,
    ADDITIONAL_INFO                    NTEXT                                  NULL ,
    OBJECT_META_TYPE                   INTEGER                                NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ALID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX AUDIT_LOG_P ON @SCHEMA@.AUDIT_LOG_T
( 
    ALID
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.AUDIT_LOG_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.WORK_ITEM_T
(
    WIID                               BINARY(16)                         NOT NULL ,
    PARENT_WIID                        BINARY(16)                             NULL ,
    OWNER_ID                           NVARCHAR(128)                          NULL ,
    GROUP_NAME                         NVARCHAR(128)                          NULL ,
    EVERYBODY                          SMALLINT                           NOT NULL ,
    EXCLUDE                            SMALLINT                           NOT NULL ,
    QIID                               BINARY(16)                             NULL ,
    OBJECT_TYPE                        INTEGER                            NOT NULL ,
    OBJECT_ID                          BINARY(16)                         NOT NULL ,
    ASSOCIATED_OBJECT_TYPE             INTEGER                            NOT NULL ,
    ASSOCIATED_OID                     BINARY(16)                             NULL ,
    REASON                             INTEGER                            NOT NULL ,
    CREATION_TIME                      DATETIME                           NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    AUTH_INFO                          INTEGER                            NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( WIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX WORK_ITEM_P ON @SCHEMA@.WORK_ITEM_T
( 
    WIID
)
go


CREATE INDEX WI_ASSOBJ_REASON ON @SCHEMA@.WORK_ITEM_T
(   
    ASSOCIATED_OID, ASSOCIATED_OBJECT_TYPE, REASON, PARENT_WIID
)
go

CREATE INDEX WI_OBJID_TYPE_QIID ON @SCHEMA@.WORK_ITEM_T
(   
    OBJECT_ID, OBJECT_TYPE, QIID
)
go

CREATE INDEX WI_OBJID_TYPE_REAS ON @SCHEMA@.WORK_ITEM_T
(   
    OBJECT_ID, OBJECT_TYPE, REASON
)
go

CREATE INDEX WI_GROUP_NAME ON @SCHEMA@.WORK_ITEM_T
(   
    GROUP_NAME
)
go

CREATE INDEX WI_AUTH_L ON @SCHEMA@.WORK_ITEM_T
(   
    EVERYBODY, GROUP_NAME, OWNER_ID, QIID
)
go

CREATE INDEX WI_AUTH_U ON @SCHEMA@.WORK_ITEM_T
(   
    AUTH_INFO, QIID
)
go

CREATE INDEX WI_AUTH_O ON @SCHEMA@.WORK_ITEM_T
(   
    AUTH_INFO, OWNER_ID DESC
)
go

CREATE INDEX WI_AUTH_G ON @SCHEMA@.WORK_ITEM_T
(   
    AUTH_INFO, GROUP_NAME
)
go

CREATE INDEX WI_AUTH_E ON @SCHEMA@.WORK_ITEM_T
(   
    AUTH_INFO, EVERYBODY
)
go

CREATE INDEX WI_AUTH_R ON @SCHEMA@.WORK_ITEM_T
(   
    AUTH_INFO, REASON DESC
)
go

CREATE INDEX WI_REASON ON @SCHEMA@.WORK_ITEM_T
(   
    REASON
)
go

CREATE INDEX WI_OWNER ON @SCHEMA@.WORK_ITEM_T
(   
    OWNER_ID, OBJECT_ID, REASON, OBJECT_TYPE
)
go

CREATE INDEX WI_QIID ON @SCHEMA@.WORK_ITEM_T
(   
    QIID
)
go

CREATE INDEX WI_QRY ON @SCHEMA@.WORK_ITEM_T
(   
    OBJECT_ID, REASON, EVERYBODY, OWNER_ID
)
go

CREATE INDEX WI_QI_OID_RS_OWN ON @SCHEMA@.WORK_ITEM_T
(   
    QIID, OBJECT_ID, REASON, OWNER_ID
)
go

CREATE INDEX WI_QI_OID_OWN ON @SCHEMA@.WORK_ITEM_T
(   
    QIID, OBJECT_ID, OWNER_ID
)
go

CREATE INDEX WI_OT_OID_RS ON @SCHEMA@.WORK_ITEM_T
(   
    OBJECT_TYPE, OBJECT_ID, REASON
)
go

CREATE INDEX WI_WI_QI ON @SCHEMA@.WORK_ITEM_T
(   
    WIID, QIID
)
go

CREATE INDEX WI_PWIID_OID ON @SCHEMA@.WORK_ITEM_T
(   
    PARENT_WIID, OBJECT_ID
)
go

CREATE INDEX WI_PWIID_QIID ON @SCHEMA@.WORK_ITEM_T
(   
    PARENT_WIID, QIID
)
go

CREATE INDEX WI_AUTH_GR_O_E ON @SCHEMA@.WORK_ITEM_T
(   
    AUTH_INFO, GROUP_NAME, OWNER_ID, EVERYBODY
)
go

CREATE INDEX WI_PD1 ON @SCHEMA@.WORK_ITEM_T
(   
    OWNER_ID, AUTH_INFO, OBJECT_TYPE, REASON, OBJECT_ID
)
go

CREATE INDEX WI_PD2 ON @SCHEMA@.WORK_ITEM_T
(   
    AUTH_INFO, OBJECT_TYPE, REASON, OBJECT_ID, QIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.WORK_ITEM_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.RETRIEVED_USER_T
(
    QIID                               BINARY(16)                         NOT NULL ,
    OWNER_ID                           NVARCHAR(128)                      NOT NULL ,
    REASON                             INTEGER                            NOT NULL ,
    ASSOCIATED_OID                     BINARY(16)                             NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( QIID, OWNER_ID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX RETRIEVED_USER_P ON @SCHEMA@.RETRIEVED_USER_T
( 
    QIID, OWNER_ID
)
go


CREATE INDEX RUT_OWN_QIID ON @SCHEMA@.RETRIEVED_USER_T
(   
    OWNER_ID, QIID
)
go

CREATE INDEX RUT_ASSOC ON @SCHEMA@.RETRIEVED_USER_T
(   
    ASSOCIATED_OID
)
go

CREATE INDEX RUT_QIID ON @SCHEMA@.RETRIEVED_USER_T
(   
    QIID
)
go

CREATE INDEX RUT_OWN_QIDESC ON @SCHEMA@.RETRIEVED_USER_T
(   
    OWNER_ID, QIID DESC
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.RETRIEVED_USER_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.RETRIEVED_GROUP_T
(
    QIID                               BINARY(16)                         NOT NULL ,
    GROUP_NAME                         NVARCHAR(128)                      NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( QIID, GROUP_NAME )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX RETRIEVED_GROUP_P ON @SCHEMA@.RETRIEVED_GROUP_T
( 
    QIID, GROUP_NAME
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.RETRIEVED_GROUP_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.WIS_META_DATA_T
(
    WSID                               BINARY(16)                         NOT NULL ,
    HASH_CODE                          INTEGER                            NOT NULL ,
    OBJECT_TYPE                        INTEGER                            NOT NULL ,
    LAST_CHECK                         DATETIME                           NOT NULL ,
    UNUSED                             SMALLINT                           NOT NULL ,
    AUTH_INFO_RETRIEVED_USER           SMALLINT                           NOT NULL ,
    AUTH_INFO_OWNER_ID                 SMALLINT                           NOT NULL ,
    AUTH_INFO_EVERYBODY                SMALLINT                           NOT NULL ,
    AUTH_INFO_GROUP                    SMALLINT                           NOT NULL ,
    AUTH_INFO_RETRIEVED_GROUP          SMALLINT                           NOT NULL ,
    AUTH_INFO_EMPTY                    SMALLINT                           NOT NULL ,
    SHARING_PATTERN                    INTEGER                            NOT NULL ,
    REASONS                            BINARY(32)                         NOT NULL ,
    PARAMETER_A                        INTEGER                                NULL ,
    PARAMETER_B                        INTEGER                                NULL ,
    PARAMETER_C                        INTEGER                                NULL ,
    PARAMETER_D                        BINARY(16)                             NULL ,
    PARAMETER_E                        DATETIME                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( WSID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX WIS_META_DATA_P ON @SCHEMA@.WIS_META_DATA_T
( 
    WSID
)
go


CREATE INDEX WMD_HCUNU ON @SCHEMA@.WIS_META_DATA_T
(   
    HASH_CODE, UNUSED
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.WIS_META_DATA_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.E_SWI_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    WIID                               BINARY(16)                         NOT NULL ,
    WSID                               BINARY(16)                         NOT NULL ,
    HASH_CODE                          INTEGER                            NOT NULL ,
    WIS_HASH_CODE                      INTEGER                                NULL ,
    PARENT_WIID                        BINARY(16)                             NULL ,
    REASON                             INTEGER                            NOT NULL ,
    INHERITED                          SMALLINT                               NULL ,
    QIID                               BINARY(16)                             NULL ,
    OBJECT_TYPE                        INTEGER                            NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    SHARING_PATTERN                    INTEGER                            NOT NULL ,
    ACCESS_KEY                         INTEGER                            NOT NULL ,
    TEMPLATE_ID                        BINARY(16)                             NULL ,
    PARAMETER_A                        INTEGER                                NULL ,
    PARAMETER_B                        INTEGER                                NULL ,
    PARAMETER_C                        INTEGER                                NULL ,
    PARAMETER_D                        BINARY(16)                             NULL ,
    PARAMETER_E                        DATETIME                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX E_SWI_P ON @SCHEMA@.E_SWI_T
( 
    PKID
)
go


CREATE INDEX WE_WSID ON @SCHEMA@.E_SWI_T
(   
    WSID
)
go

CREATE INDEX WE_HASHCODE ON @SCHEMA@.E_SWI_T
(   
    HASH_CODE
)
go

CREATE INDEX WE_WIID ON @SCHEMA@.E_SWI_T
(   
    WIID
)
go

CREATE INDEX WE_QIID ON @SCHEMA@.E_SWI_T
(   
    QIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.E_SWI_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.SWI_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    WIID                               BINARY(16)                         NOT NULL ,
    PARENT_WIID                        BINARY(16)                             NULL ,
    OWNER_ID                           NVARCHAR(128)                          NULL ,
    GROUP_NAME                         NVARCHAR(128)                          NULL ,
    EVERYBODY                          SMALLINT                           NOT NULL ,
    QIID                               BINARY(16)                             NULL ,
    OBJECT_TYPE                        INTEGER                            NOT NULL ,
    REASON                             INTEGER                            NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    AUTH_INFO                          INTEGER                            NOT NULL ,
    SHARING_PATTERN                    INTEGER                            NOT NULL ,
    ACCESS_KEY                         INTEGER                            NOT NULL ,
    WSID                               BINARY(16)                         NOT NULL ,
    HASH_CODE                          INTEGER                            NOT NULL ,
    WIS_HASH_CODE                      INTEGER                                NULL ,
    INHERITED                          SMALLINT                               NULL ,
    TEMPLATE_ID                        BINARY(16)                             NULL ,
    PARAMETER_A                        INTEGER                                NULL ,
    PARAMETER_B                        INTEGER                                NULL ,
    PARAMETER_C                        INTEGER                                NULL ,
    PARAMETER_D                        BINARY(16)                             NULL ,
    PARAMETER_E                        DATETIME                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX SWI_P ON @SCHEMA@.SWI_T
( 
    PKID
)
go


CREATE INDEX SWI_WSID ON @SCHEMA@.SWI_T
(   
    WSID
)
go

CREATE INDEX SWI_HASHCODE ON @SCHEMA@.SWI_T
(   
    HASH_CODE
)
go

CREATE INDEX SWI_OTRPD ON @SCHEMA@.SWI_T
(   
    OBJECT_TYPE, REASON, TEMPLATE_ID
)
go

CREATE INDEX SWI_WIID ON @SCHEMA@.SWI_T
(   
    WIID
)
go

CREATE INDEX SWI_QIID ON @SCHEMA@.SWI_T
(   
    QIID
)
go

CREATE INDEX SWI_OWN ON @SCHEMA@.SWI_T
(   
    OWNER_ID, ACCESS_KEY, WSID, REASON
)
go

CREATE INDEX SWI_GRP ON @SCHEMA@.SWI_T
(   
    GROUP_NAME, ACCESS_KEY, WSID, REASON
)
go

CREATE INDEX SWI_ACCK1 ON @SCHEMA@.SWI_T
(   
    ACCESS_KEY, REASON, WSID, QIID
)
go

CREATE INDEX SWI_ACCK2 ON @SCHEMA@.SWI_T
(   
    ACCESS_KEY, REASON, QIID, WSID
)
go

CREATE INDEX SWI_ACCK3 ON @SCHEMA@.SWI_T
(   
    ACCESS_KEY, REASON, OWNER_ID, WSID
)
go

CREATE INDEX SWI_ACCK4 ON @SCHEMA@.SWI_T
(   
    ACCESS_KEY, REASON, WSID
)
go

CREATE INDEX SWI_ACCK5 ON @SCHEMA@.SWI_T
(   
    ACCESS_KEY, OWNER_ID, REASON, WSID
)
go

CREATE INDEX SWI_ACCK6 ON @SCHEMA@.SWI_T
(   
    ACCESS_KEY, GROUP_NAME, REASON, WSID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.SWI_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.STAFF_QUERY_INSTANCE_T
(
    QIID                               BINARY(16)                         NOT NULL ,
    QTID                               BINARY(16)                         NOT NULL ,
    EVERYBODY                          SMALLINT                           NOT NULL ,
    NOBODY                             SMALLINT                           NOT NULL ,
    IS_SHAREABLE                       SMALLINT                           NOT NULL ,
    IS_TRANSFERRED                     SMALLINT                           NOT NULL ,
    SR_HASH_CODE                       INTEGER                                NULL ,
    GROUP_NAME                         NVARCHAR(128)                          NULL ,
    CONTEXT_VALUES                     NVARCHAR(3072)                         NULL ,
    CONTEXT_VALUES_LONG                NTEXT                                  NULL ,
    HASH_CODE                          INTEGER                                NULL ,
    EXPIRES                            DATETIME                               NULL ,
    ASSOCIATED_OBJECT_TYPE             INTEGER                            NOT NULL ,
    ASSOCIATED_OID                     BINARY(16)                         NOT NULL ,
    NORMALIZED                         SMALLINT                               NULL ,
    DENORMALIZED                       SMALLINT                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( QIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX STAFF_QUERY_INSTANCE_P ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
( 
    QIID
)
go


CREATE INDEX SQI_QTID ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
    QTID, HASH_CODE
)
go

CREATE INDEX SQI_ASSOCID ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
    ASSOCIATED_OID, ASSOCIATED_OBJECT_TYPE
)
go

CREATE INDEX SQI_QIIDGN ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
    QIID, GROUP_NAME
)
go

CREATE INDEX SQI_QIIDTREX ON @SCHEMA@.STAFF_QUERY_INSTANCE_T
(   
    QIID, IS_TRANSFERRED, EXPIRES
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.STAFF_QUERY_INSTANCE_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.STAFF_LOCK_T
(
    QTID                               BINARY(16)                         NOT NULL ,
    HASH_CODE                          INTEGER                            NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( QTID, HASH_CODE )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX STAFF_LOCK_P ON @SCHEMA@.STAFF_LOCK_T
( 
    QTID, HASH_CODE
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.STAFF_LOCK_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.APPLICATION_COMPONENT_T
(
    ACOID                              BINARY(16)                         NOT NULL ,
    NAME                               NVARCHAR(64)                       NOT NULL ,
    CALENDAR_NAME                      NVARCHAR(254)                          NULL ,
    JNDI_NAME_CALENDAR                 NVARCHAR(254)                          NULL ,
    JNDI_NAME_STAFF_PROVIDER           NVARCHAR(254)                      NOT NULL ,
    DURATION_UNTIL_DELETED             NVARCHAR(254)                          NULL ,
    EVENT_HANDLER_NAME                 NVARCHAR(64)                           NULL ,
    INSTANCE_CREATOR_QTID              BINARY(16)                             NULL ,
    SUPPORTS_AUTO_CLAIM                SMALLINT                           NOT NULL ,
    SUPPORTS_FOLLOW_ON_TASK            SMALLINT                           NOT NULL ,
    SUPPORTS_CLAIM_SUSPENDED           SMALLINT                           NOT NULL ,
    SUPPORTS_DELEGATION                SMALLINT                           NOT NULL ,
    SUPPORTS_SUB_TASK                  SMALLINT                           NOT NULL ,
    BUSINESS_RELEVANCE                 SMALLINT                           NOT NULL ,
    SUBSTITUTION_POLICY                INTEGER                            NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ACOID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX APPLICATION_COMPONENT_P ON @SCHEMA@.APPLICATION_COMPONENT_T
( 
    ACOID
)
go


CREATE UNIQUE INDEX ACO_NAME ON @SCHEMA@.APPLICATION_COMPONENT_T
(   
    NAME
)
go

CREATE TABLE @SCHEMA@.ESCALATION_TEMPLATE_T
(
    ESTID                              BINARY(16)                         NOT NULL ,
    FIRST_ESTID                        BINARY(16)                             NULL ,
    PREVIOUS_ESTID                     BINARY(16)                             NULL ,
    TKTID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    MNTID                              BINARY(16)                             NULL ,
    NAME                               NVARCHAR(220)                          NULL ,
    ACTIVATION_STATE                   INTEGER                            NOT NULL ,
    AT_LEAST_EXPECTED_STATE            INTEGER                            NOT NULL ,
    DURATION_UNTIL_ESCALATION          NVARCHAR(254)                          NULL ,
    DURATION_UNTIL_REPEATS             NVARCHAR(254)                          NULL ,
    INCREASE_PRIORITY                  INTEGER                            NOT NULL ,
    ACTION                             INTEGER                            NOT NULL ,
    ESCALATION_RECEIVER_QTID           BINARY(16)                             NULL ,
    RECEIVER_EMAIL_QTID                BINARY(16)                             NULL ,
    PRIMARY KEY NONCLUSTERED ( ESTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX ESCALATION_TEMPLATE_P ON @SCHEMA@.ESCALATION_TEMPLATE_T
( 
    ESTID
)
go


CREATE INDEX ET_TKTID ON @SCHEMA@.ESCALATION_TEMPLATE_T
(   
    TKTID
)
go

CREATE INDEX ET_CCID ON @SCHEMA@.ESCALATION_TEMPLATE_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

CREATE TABLE @SCHEMA@.ESC_TEMPL_CPROP_T
(
    ESTID                              BINARY(16)                         NOT NULL ,
    NAME                               NVARCHAR(220)                      NOT NULL ,
    TKTID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    STRING_VALUE                       NVARCHAR(254)                          NULL ,
    DATA_TYPE                          NVARCHAR(254)                          NULL ,
    DATA                               IMAGE                                  NULL ,
    PRIMARY KEY NONCLUSTERED ( ESTID, NAME )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX ESC_TEMPL_CPROP_P ON @SCHEMA@.ESC_TEMPL_CPROP_T
( 
    ESTID, NAME
)
go


CREATE INDEX ETCP_TKTID ON @SCHEMA@.ESC_TEMPL_CPROP_T
(   
    TKTID
)
go

CREATE INDEX ETCP_CCID ON @SCHEMA@.ESC_TEMPL_CPROP_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

CREATE TABLE @SCHEMA@.ESC_TEMPL_LDESC_T
(
    ESTID                              BINARY(16)                         NOT NULL ,
    LOCALE                             NVARCHAR(32)                       NOT NULL ,
    TKTID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    DISPLAY_NAME                       NVARCHAR(64)                           NULL ,
    DESCRIPTION                        NVARCHAR(254)                          NULL ,
    DOCUMENTATION                      NTEXT                                  NULL ,
    PRIMARY KEY NONCLUSTERED ( ESTID, LOCALE )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX ESC_TEMPL_LDESC_P ON @SCHEMA@.ESC_TEMPL_LDESC_T
( 
    ESTID, LOCALE
)
go


CREATE INDEX ETLD_TKTID ON @SCHEMA@.ESC_TEMPL_LDESC_T
(   
    TKTID
)
go

CREATE INDEX ETLD_CCID ON @SCHEMA@.ESC_TEMPL_LDESC_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

CREATE TABLE @SCHEMA@.TTASK_MESSAGE_DEFINITION_T
(
    TMTID                              BINARY(16)                         NOT NULL ,
    TKTID                              BINARY(16)                             NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    FAULT_NAME                         NVARCHAR(254)                          NULL ,
    MESSAGE_TYPE_NS                    NVARCHAR(220)                      NOT NULL ,
    MESSAGE_TYPE_NAME                  NVARCHAR(220)                      NOT NULL ,
    MESSAGE_DEFINITION                 IMAGE                                  NULL ,
    PRIMARY KEY NONCLUSTERED ( TMTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX TTASK_MESSAGE_DEFINITION_P ON @SCHEMA@.TTASK_MESSAGE_DEFINITION_T
( 
    TMTID
)
go


CREATE INDEX TTMD_TKTID ON @SCHEMA@.TTASK_MESSAGE_DEFINITION_T
(   
    TKTID
)
go

CREATE INDEX TTMD_CCID ON @SCHEMA@.TTASK_MESSAGE_DEFINITION_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

CREATE TABLE @SCHEMA@.TASK_TEMPLATE_T
(
    TKTID                              BINARY(16)                         NOT NULL ,
    NAME                               NVARCHAR(220)                      NOT NULL ,
    DEFINITION_NAME                    NVARCHAR(220)                      NOT NULL ,
    NAMESPACE                          NVARCHAR(254)                      NOT NULL ,
    TARGET_NAMESPACE                   NVARCHAR(254)                      NOT NULL ,
    VALID_FROM                         DATETIME                           NOT NULL ,
    APPLICATION_NAME                   NVARCHAR(220)                          NULL ,
    APPLICATION_DEFAULTS_ID            BINARY(16)                             NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                             NULL ,
    SVTID                              BINARY(16)                             NULL ,
    KIND                               INTEGER                            NOT NULL ,
    STATE                              INTEGER                            NOT NULL ,
    AUTO_DELETE_MODE                   INTEGER                            NOT NULL ,
    IS_AD_HOC                          SMALLINT                           NOT NULL ,
    IS_INLINE                          SMALLINT                           NOT NULL ,
    IS_SHARED                          SMALLINT                           NOT NULL ,
    SUPPORTS_CLAIM_SUSPENDED           SMALLINT                           NOT NULL ,
    SUPPORTS_AUTO_CLAIM                SMALLINT                           NOT NULL ,
    SUPPORTS_FOLLOW_ON_TASK            SMALLINT                           NOT NULL ,
    SUPPORTS_DELEGATION                SMALLINT                           NOT NULL ,
    SUPPORTS_SUB_TASK                  SMALLINT                           NOT NULL ,
    CONTEXT_AUTHORIZATION              INTEGER                            NOT NULL ,
    AUTONOMY                           INTEGER                            NOT NULL ,
    ADMIN_QTID                         BINARY(16)                             NULL ,
    EDITOR_QTID                        BINARY(16)                             NULL ,
    INSTANCE_CREATOR_QTID              BINARY(16)                             NULL ,
    POTENTIAL_STARTER_QTID             BINARY(16)                             NULL ,
    POTENTIAL_OWNER_QTID               BINARY(16)                             NULL ,
    READER_QTID                        BINARY(16)                             NULL ,
    DEFAULT_LOCALE                     NVARCHAR(32)                           NULL ,
    CALENDAR_NAME                      NVARCHAR(254)                          NULL ,
    DURATION_UNTIL_DELETED             NVARCHAR(254)                          NULL ,
    DURATION_UNTIL_DUE                 NVARCHAR(254)                          NULL ,
    DURATION_UNTIL_EXPIRES             NVARCHAR(254)                          NULL ,
    JNDI_NAME_CALENDAR                 NVARCHAR(254)                          NULL ,
    JNDI_NAME_STAFF_PROVIDER           NVARCHAR(254)                      NOT NULL ,
    TYPE                               NVARCHAR(254)                          NULL ,
    EVENT_HANDLER_NAME                 NVARCHAR(64)                           NULL ,
    PRIORITY                           INTEGER                                NULL ,
    PRIORITY_DEFINITION                NVARCHAR(254)                          NULL ,
    BUSINESS_RELEVANCE                 SMALLINT                           NOT NULL ,
    SUBSTITUTION_POLICY                INTEGER                            NOT NULL ,
    CONTACTS_QTIDS                     IMAGE                                  NULL ,
    UI_SETTINGS                        IMAGE                                  NULL ,
    ASSIGNMENT_TYPE                    INTEGER                            NOT NULL ,
    INHERITED_AUTH                     INTEGER                            NOT NULL ,
    PARALLEL_INHERITED_AUTH            INTEGER                            NOT NULL ,
    NATIVE_LOOKUP_NAME                 NVARCHAR(254)                          NULL ,
    WORK_BASKET                        NVARCHAR(254)                          NULL ,
    EAR_VERSION                        INTEGER                            NOT NULL ,
    SCHEMA_VERSION                     INTEGER                            NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( TKTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX TASK_TEMPLATE_P ON @SCHEMA@.TASK_TEMPLATE_T
( 
    TKTID
)
go


CREATE INDEX TT_NAME_VF ON @SCHEMA@.TASK_TEMPLATE_T
(   
    NAME, VALID_FROM
)
go

CREATE INDEX TT_CCID_STATE ON @SCHEMA@.TASK_TEMPLATE_T
(   
    CONTAINMENT_CONTEXT_ID, STATE
)
go

CREATE INDEX TT_KND_INLN_VAL ON @SCHEMA@.TASK_TEMPLATE_T
(   
    KIND, IS_INLINE, VALID_FROM
)
go

CREATE INDEX TT_NATLOOK_ADHOC ON @SCHEMA@.TASK_TEMPLATE_T
(   
    NATIVE_LOOKUP_NAME, IS_AD_HOC
)
go

CREATE TABLE @SCHEMA@.TASK_TEMPL_CPROP_T
(
    TKTID                              BINARY(16)                         NOT NULL ,
    NAME                               NVARCHAR(220)                      NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    DATA_TYPE                          NVARCHAR(254)                          NULL ,
    STRING_VALUE                       NVARCHAR(254)                          NULL ,
    DATA                               IMAGE                                  NULL ,
    PRIMARY KEY NONCLUSTERED ( TKTID, NAME )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX TASK_TEMPL_CPROP_P ON @SCHEMA@.TASK_TEMPL_CPROP_T
( 
    TKTID, NAME
)
go


CREATE INDEX TTCP_TKTID ON @SCHEMA@.TASK_TEMPL_CPROP_T
(   
    TKTID
)
go

CREATE INDEX TTCP_CCID ON @SCHEMA@.TASK_TEMPL_CPROP_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

CREATE TABLE @SCHEMA@.TASK_TEMPL_LDESC_T
(
    TKTID                              BINARY(16)                         NOT NULL ,
    LOCALE                             NVARCHAR(32)                       NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    DISPLAY_NAME                       NVARCHAR(64)                           NULL ,
    DESCRIPTION                        NVARCHAR(254)                          NULL ,
    DOCUMENTATION                      NTEXT                                  NULL ,
    PRIMARY KEY NONCLUSTERED ( TKTID, LOCALE )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX TASK_TEMPL_LDESC_P ON @SCHEMA@.TASK_TEMPL_LDESC_T
( 
    TKTID, LOCALE
)
go


CREATE INDEX TTLD_TKTID ON @SCHEMA@.TASK_TEMPL_LDESC_T
(   
    TKTID
)
go

CREATE INDEX TTLD_CCID ON @SCHEMA@.TASK_TEMPL_LDESC_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

CREATE INDEX TTLD_TT_LOC ON @SCHEMA@.TASK_TEMPL_LDESC_T
(   
    TKTID, LOCALE DESC
)
go

CREATE TABLE @SCHEMA@.TSERVICE_DESCRIPTION_T
(
    SVTID                              BINARY(16)                         NOT NULL ,
    TKTID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    IS_ONE_WAY                         SMALLINT                           NOT NULL ,
    SERVICE_REF_NAME                   NVARCHAR(254)                          NULL ,
    OPERATION                          NVARCHAR(254)                      NOT NULL ,
    PORT                               NVARCHAR(254)                          NULL ,
    PORT_TYPE_NS                       NVARCHAR(254)                      NOT NULL ,
    PORT_TYPE_NAME                     NVARCHAR(254)                      NOT NULL ,
    S_BEAN_JNDI_NAME                   NVARCHAR(254)                          NULL ,
    SERVICE                            NVARCHAR(254)                          NULL ,
    PRIMARY KEY NONCLUSTERED ( SVTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX TSERVICE_DESCRIPTION_P ON @SCHEMA@.TSERVICE_DESCRIPTION_T
( 
    SVTID
)
go


CREATE INDEX TSD_TKTID ON @SCHEMA@.TSERVICE_DESCRIPTION_T
(   
    TKTID
)
go

CREATE INDEX TSD_CCID ON @SCHEMA@.TSERVICE_DESCRIPTION_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

CREATE TABLE @SCHEMA@.TASK_CELL_MAP_T
(
    TKTID                              BINARY(16)                         NOT NULL ,
    CELL                               NVARCHAR(220)                      NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( TKTID, CELL )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX TASK_CELL_MAP_P ON @SCHEMA@.TASK_CELL_MAP_T
( 
    TKTID, CELL
)
go


CREATE TABLE @SCHEMA@.TMAIL_T
(
    MNTID                              BINARY(16)                         NOT NULL ,
    FROM_STATE                         INTEGER                            NOT NULL ,
    TO_STATE                           INTEGER                            NOT NULL ,
    LOCALE                             NVARCHAR(32)                       NOT NULL ,
    HASH_CODE                          INTEGER                            NOT NULL ,
    SUBJECT                            NVARCHAR(254)                      NOT NULL ,
    BODY_TEXT                          NTEXT                                  NULL ,
    PRIMARY KEY NONCLUSTERED ( MNTID, FROM_STATE, TO_STATE, LOCALE )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX TMAIL_P ON @SCHEMA@.TMAIL_T
( 
    MNTID, FROM_STATE, TO_STATE, LOCALE
)
go


CREATE INDEX EMT_HC ON @SCHEMA@.TMAIL_T
(   
    HASH_CODE
)
go

CREATE TABLE @SCHEMA@.COMPLETION_TEMPLATE_T
(
    CMTID                              BINARY(16)                         NOT NULL ,
    ORDER_NUMBER                       INTEGER                            NOT NULL ,
    TKTID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    COMPL_CONDITION                    IMAGE                                  NULL ,
    CRITERION_FOR                      NVARCHAR(254)                          NULL ,
    COMPLETION_NAME                    NVARCHAR(220)                          NULL ,
    IS_DEFAULT_COMPLETION              SMALLINT                           NOT NULL ,
    PREFIX_MAP                         IMAGE                                  NULL ,
    USE_DEFAULT_RESULT_CONSTRUCT       SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( CMTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX COMPLETION_TEMPLATE_P ON @SCHEMA@.COMPLETION_TEMPLATE_T
( 
    CMTID
)
go


CREATE INDEX CMPT_TKTID_ORDER ON @SCHEMA@.COMPLETION_TEMPLATE_T
(   
    TKTID, ORDER_NUMBER
)
go

CREATE INDEX CMPT_CCID ON @SCHEMA@.COMPLETION_TEMPLATE_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

CREATE TABLE @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(
    RATID                              BINARY(16)                         NOT NULL ,
    ORDER_NUMBER                       INTEGER                            NOT NULL ,
    CMTID                              BINARY(16)                         NOT NULL ,
    TKTID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    AGGR_PART                          NVARCHAR(254)                          NULL ,
    AGGR_LOCATION                      IMAGE                                  NULL ,
    AGGR_FUNCTION                      NVARCHAR(254)                      NOT NULL ,
    AGGR_CONDITION                     IMAGE                                  NULL ,
    PREFIX_MAP                         IMAGE                                  NULL ,
    PRIMARY KEY NONCLUSTERED ( RATID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX RESULT_AGGREGATION_TEMPLATE_P ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
( 
    RATID
)
go


CREATE INDEX RAGT_CMTID_ORD_TT ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(   
    CMTID, ORDER_NUMBER, TKTID
)
go

CREATE INDEX RAGT_CCID ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

CREATE TABLE @SCHEMA@.ESCALATION_INSTANCE_T
(
    ESIID                              BINARY(16)                         NOT NULL ,
    ESTID                              BINARY(16)                             NULL ,
    FIRST_ESIID                        BINARY(16)                             NULL ,
    PREVIOUS_ESIID                     BINARY(16)                             NULL ,
    TKIID                              BINARY(16)                         NOT NULL ,
    MNTID                              BINARY(16)                             NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    NAME                               NVARCHAR(220)                          NULL ,
    STATE                              INTEGER                            NOT NULL ,
    ACTIVATION_STATE                   INTEGER                            NOT NULL ,
    AT_LEAST_EXPECTED_STATE            INTEGER                            NOT NULL ,
    ACTIVATION_TIME                    DATETIME                               NULL ,
    ESCALATION_TIME                    DATETIME                               NULL ,
    DURATION_UNTIL_ESCALATION          NVARCHAR(254)                          NULL ,
    DURATION_UNTIL_REPEATS             NVARCHAR(254)                          NULL ,
    INCREASE_PRIORITY                  INTEGER                            NOT NULL ,
    ACTION                             INTEGER                            NOT NULL ,
    ESCALATION_RECEIVER_QTID           BINARY(16)                             NULL ,
    RECEIVER_EMAIL_QTID                BINARY(16)                             NULL ,
    SCHEDULER_ID                       NVARCHAR(254)                          NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ESIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX ESCALATION_INSTANCE_P ON @SCHEMA@.ESCALATION_INSTANCE_T
( 
    ESIID
)
go


CREATE INDEX ESI_FIRST ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
    FIRST_ESIID
)
go

CREATE INDEX ESI_TKIID_ASTATE ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
    TKIID, ACTIVATION_STATE, STATE
)
go

CREATE INDEX ESI_TKIID_STATE ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
    TKIID, STATE
)
go

CREATE INDEX ESI_PREV ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
    PREVIOUS_ESIID
)
go

CREATE INDEX ESI_ESTID ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
    ESTID
)
go

CREATE INDEX ESI_CCID ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

CREATE INDEX ESI_EST_ESI ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
    ESTID, ESIID
)
go

CREATE INDEX ESI_WSID1 ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
    WSID_1
)
go

CREATE INDEX ESI_WSID2 ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
    WSID_2
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.ESCALATION_INSTANCE_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.ESC_INST_CPROP_T
(
    ESIID                              BINARY(16)                         NOT NULL ,
    NAME                               NVARCHAR(220)                      NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    STRING_VALUE                       NVARCHAR(254)                          NULL ,
    DATA_TYPE                          NVARCHAR(254)                          NULL ,
    DATA                               IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ESIID, NAME )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX ESC_INST_CPROP_P ON @SCHEMA@.ESC_INST_CPROP_T
( 
    ESIID, NAME
)
go


CREATE INDEX EICP_CCID ON @SCHEMA@.ESC_INST_CPROP_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.ESC_INST_CPROP_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.ESC_INST_LDESC_T
(
    ESIID                              BINARY(16)                         NOT NULL ,
    LOCALE                             NVARCHAR(32)                       NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    DISPLAY_NAME                       NVARCHAR(64)                           NULL ,
    DESCRIPTION                        NVARCHAR(254)                          NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ESIID, LOCALE )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX ESC_INST_LDESC_P ON @SCHEMA@.ESC_INST_LDESC_T
( 
    ESIID, LOCALE
)
go


CREATE INDEX EILD_CCID ON @SCHEMA@.ESC_INST_LDESC_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.ESC_INST_LDESC_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.EIDOCUMENTATION_T
(
    ESIID                              BINARY(16)                         NOT NULL ,
    LOCALE                             NVARCHAR(32)                       NOT NULL ,
    TKIID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    DOCUMENTATION                      NTEXT                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ESIID, LOCALE )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX EIDOCUMENTATION_P ON @SCHEMA@.EIDOCUMENTATION_T
( 
    ESIID, LOCALE
)
go


CREATE INDEX EIDOC_CCID ON @SCHEMA@.EIDOCUMENTATION_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.EIDOCUMENTATION_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.ISERVICE_DESCRIPTION_T
(
    SVTID                              BINARY(16)                         NOT NULL ,
    TKIID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    IS_ONE_WAY                         SMALLINT                           NOT NULL ,
    SERVICE_REF_NAME                   NVARCHAR(254)                          NULL ,
    OPERATION                          NVARCHAR(254)                      NOT NULL ,
    PORT                               NVARCHAR(254)                          NULL ,
    PORT_TYPE_NS                       NVARCHAR(254)                      NOT NULL ,
    PORT_TYPE_NAME                     NVARCHAR(254)                      NOT NULL ,
    S_BEAN_JNDI_NAME                   NVARCHAR(254)                          NULL ,
    SERVICE                            NVARCHAR(254)                          NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( SVTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX ISERVICE_DESCRIPTION_P ON @SCHEMA@.ISERVICE_DESCRIPTION_T
( 
    SVTID
)
go


CREATE INDEX ISD_TKIID ON @SCHEMA@.ISERVICE_DESCRIPTION_T
(   
    TKIID
)
go

CREATE INDEX ISD_CCID ON @SCHEMA@.ISERVICE_DESCRIPTION_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.ISERVICE_DESCRIPTION_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.TASK_INSTANCE_T
(
    TKIID                              BINARY(16)                         NOT NULL ,
    NAME                               NVARCHAR(220)                      NOT NULL ,
    NAMESPACE                          NVARCHAR(254)                      NOT NULL ,
    TKTID                              BINARY(16)                             NULL ,
    TOP_TKIID                          BINARY(16)                         NOT NULL ,
    FOLLOW_ON_TKIID                    BINARY(16)                             NULL ,
    APPLICATION_NAME                   NVARCHAR(220)                          NULL ,
    APPLICATION_DEFAULTS_ID            BINARY(16)                             NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                             NULL ,
    PARENT_CONTEXT_ID                  BINARY(16)                             NULL ,
    STATE                              INTEGER                            NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    AUTO_DELETE_MODE                   INTEGER                            NOT NULL ,
    HIERARCHY_POSITION                 INTEGER                            NOT NULL ,
    TYPE                               NVARCHAR(254)                          NULL ,
    SVTID                              BINARY(16)                             NULL ,
    SUPPORTS_CLAIM_SUSPENDED           SMALLINT                           NOT NULL ,
    SUPPORTS_AUTO_CLAIM                SMALLINT                           NOT NULL ,
    SUPPORTS_FOLLOW_ON_TASK            SMALLINT                           NOT NULL ,
    IS_AD_HOC                          SMALLINT                           NOT NULL ,
    IS_ESCALATED                       SMALLINT                           NOT NULL ,
    IS_INLINE                          SMALLINT                           NOT NULL ,
    IS_SUSPENDED                       SMALLINT                           NOT NULL ,
    IS_WAITING_FOR_SUBTASK             SMALLINT                           NOT NULL ,
    SUPPORTS_DELEGATION                SMALLINT                           NOT NULL ,
    SUPPORTS_SUB_TASK                  SMALLINT                           NOT NULL ,
    IS_CHILD                           SMALLINT                           NOT NULL ,
    HAS_ESCALATIONS                    SMALLINT                               NULL ,
    START_TIME                         DATETIME                               NULL ,
    ACTIVATION_TIME                    DATETIME                               NULL ,
    LAST_MODIFICATION_TIME             DATETIME                               NULL ,
    LAST_STATE_CHANGE_TIME             DATETIME                               NULL ,
    COMPLETION_TIME                    DATETIME                               NULL ,
    DUE_TIME                           DATETIME                               NULL ,
    EXPIRATION_TIME                    DATETIME                               NULL ,
    FIRST_ACTIVATION_TIME              DATETIME                               NULL ,
    DEFAULT_LOCALE                     NVARCHAR(32)                           NULL ,
    DURATION_UNTIL_DELETED             NVARCHAR(254)                          NULL ,
    DURATION_UNTIL_DUE                 NVARCHAR(254)                          NULL ,
    DURATION_UNTIL_EXPIRES             NVARCHAR(254)                          NULL ,
    CALENDAR_NAME                      NVARCHAR(254)                          NULL ,
    JNDI_NAME_CALENDAR                 NVARCHAR(254)                          NULL ,
    JNDI_NAME_STAFF_PROVIDER           NVARCHAR(254)                          NULL ,
    CONTEXT_AUTHORIZATION              INTEGER                            NOT NULL ,
    ORIGINATOR                         NVARCHAR(128)                          NULL ,
    STARTER                            NVARCHAR(128)                          NULL ,
    OWNER                              NVARCHAR(128)                          NULL ,
    ADMIN_QTID                         BINARY(16)                             NULL ,
    EDITOR_QTID                        BINARY(16)                             NULL ,
    POTENTIAL_OWNER_QTID               BINARY(16)                             NULL ,
    POTENTIAL_STARTER_QTID             BINARY(16)                             NULL ,
    READER_QTID                        BINARY(16)                             NULL ,
    PRIORITY                           INTEGER                                NULL ,
    SCHEDULER_ID                       NVARCHAR(254)                          NULL ,
    SERVICE_TICKET                     NVARCHAR(254)                          NULL ,
    EVENT_HANDLER_NAME                 NVARCHAR(64)                           NULL ,
    BUSINESS_RELEVANCE                 SMALLINT                           NOT NULL ,
    RESUMES                            DATETIME                               NULL ,
    SUBSTITUTION_POLICY                INTEGER                            NOT NULL ,
    DELETION_TIME                      DATETIME                               NULL ,
    ASSIGNMENT_TYPE                    INTEGER                            NOT NULL ,
    INHERITED_AUTH                     INTEGER                            NOT NULL ,
    PARALLEL_INHERITED_AUTH            INTEGER                            NOT NULL ,
    INVOKED_INSTANCE_ID                BINARY(16)                             NULL ,
    INVOKED_INSTANCE_TYPE              INTEGER                            NOT NULL ,
    WORK_BASKET                        NVARCHAR(254)                          NULL ,
    IS_READ                            SMALLINT                           NOT NULL ,
    IS_TRANSFERRED_TO_WORK_BASKET      SMALLINT                           NOT NULL ,
    CREATED_WITH_VERSION               INTEGER                            NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( TKIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX TASK_INSTANCE_P ON @SCHEMA@.TASK_INSTANCE_T
( 
    TKIID
)
go


CREATE INDEX TI_PARENT ON @SCHEMA@.TASK_INSTANCE_T
(   
    PARENT_CONTEXT_ID
)
go

CREATE INDEX TI_ACOID ON @SCHEMA@.TASK_INSTANCE_T
(   
    APPLICATION_DEFAULTS_ID
)
go

CREATE INDEX TI_NAME ON @SCHEMA@.TASK_INSTANCE_T
(   
    NAME
)
go

CREATE INDEX TI_STATE ON @SCHEMA@.TASK_INSTANCE_T
(   
    STATE
)
go

CREATE INDEX TI_SERVICET ON @SCHEMA@.TASK_INSTANCE_T
(   
    SERVICE_TICKET
)
go

CREATE INDEX TI_CCID ON @SCHEMA@.TASK_INSTANCE_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

CREATE INDEX TI_TK_TOPTK ON @SCHEMA@.TASK_INSTANCE_T
(   
    TKTID, TKIID, TOP_TKIID
)
go

CREATE INDEX TI_TOPTKIID ON @SCHEMA@.TASK_INSTANCE_T
(   
    TOP_TKIID
)
go

CREATE INDEX TI_TI_KND_ST ON @SCHEMA@.TASK_INSTANCE_T
(   
    TKIID, KIND, STATE
)
go

CREATE INDEX TI_ST_KND_TI_NAME ON @SCHEMA@.TASK_INSTANCE_T
(   
    STATE, KIND, TKIID, NAME
)
go

CREATE INDEX TI_TT_KND ON @SCHEMA@.TASK_INSTANCE_T
(   
    TKTID, KIND
)
go

CREATE INDEX TI_WOBA ON @SCHEMA@.TASK_INSTANCE_T
(   
    WORK_BASKET
)
go

CREATE INDEX TI_TYPE ON @SCHEMA@.TASK_INSTANCE_T
(   
    TYPE
)
go

CREATE INDEX TI_WSID1 ON @SCHEMA@.TASK_INSTANCE_T
(   
    WSID_1, KIND
)
go

CREATE INDEX TI_WSID2 ON @SCHEMA@.TASK_INSTANCE_T
(   
    WSID_2, KIND
)
go

CREATE INDEX TI_WSID1S ON @SCHEMA@.TASK_INSTANCE_T
(   
    WSID_1, KIND, STATE
)
go

CREATE INDEX TI_WSID2S ON @SCHEMA@.TASK_INSTANCE_T
(   
    WSID_2, KIND, STATE
)
go

CREATE INDEX TI_Q1 ON @SCHEMA@.TASK_INSTANCE_T
(   
    KIND, PRIORITY, OWNER, STARTER, ORIGINATOR
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.TASK_INSTANCE_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.TASK_CONTEXT_T
(
    TKIID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    SERVICE_CONTEXT                    IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( TKIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX TASK_CONTEXT_P ON @SCHEMA@.TASK_CONTEXT_T
( 
    TKIID
)
go


CREATE INDEX TC_CCID ON @SCHEMA@.TASK_CONTEXT_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.TASK_CONTEXT_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.CONTACT_QUERIES_T
(
    TKIID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    CONTACTS_QTIDS                     IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( TKIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX CONTACT_QUERIES_P ON @SCHEMA@.CONTACT_QUERIES_T
( 
    TKIID
)
go


CREATE INDEX CQ_CCID ON @SCHEMA@.CONTACT_QUERIES_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.CONTACT_QUERIES_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.UISETTINGS_T
(
    TKIID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    UI_SETTINGS                        IMAGE                              NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( TKIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX UISETTINGS_P ON @SCHEMA@.UISETTINGS_T
( 
    TKIID
)
go


CREATE INDEX UIS_CCID ON @SCHEMA@.UISETTINGS_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.UISETTINGS_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.REPLY_HANDLER_T
(
    TKIID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    REPLY_HANDLER                      IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( TKIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX REPLY_HANDLER_P ON @SCHEMA@.REPLY_HANDLER_T
( 
    TKIID
)
go


CREATE INDEX RH_CCID ON @SCHEMA@.REPLY_HANDLER_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.REPLY_HANDLER_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.TASK_TIMER_T
(
    OID                                BINARY(16)                         NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    SCHEDULER_ID                       NVARCHAR(254)                      NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( OID, KIND )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX TASK_TIMER_P ON @SCHEMA@.TASK_TIMER_T
( 
    OID, KIND
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.TASK_TIMER_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.TASK_INST_CPROP_T
(
    TKIID                              BINARY(16)                         NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    NAME                               NVARCHAR(220)                      NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    DATA_TYPE                          NVARCHAR(254)                          NULL ,
    STRING_VALUE                       NVARCHAR(254)                          NULL ,
    DATA                               IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( TKIID, NAME )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX TASK_INST_CPROP_P ON @SCHEMA@.TASK_INST_CPROP_T
( 
    TKIID, NAME
)
go


CREATE INDEX TICP_CCID ON @SCHEMA@.TASK_INST_CPROP_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.TASK_INST_CPROP_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.TASK_INST_LDESC_T
(
    TKIID                              BINARY(16)                         NOT NULL ,
    LOCALE                             NVARCHAR(32)                       NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    DISPLAY_NAME                       NVARCHAR(64)                           NULL ,
    DESCRIPTION                        NVARCHAR(254)                          NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( TKIID, LOCALE )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX TASK_INST_LDESC_P ON @SCHEMA@.TASK_INST_LDESC_T
( 
    TKIID, LOCALE
)
go


CREATE INDEX TILD_CCID ON @SCHEMA@.TASK_INST_LDESC_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

CREATE INDEX TILD_PD1 ON @SCHEMA@.TASK_INST_LDESC_T
(   
    LOCALE, TKIID, DESCRIPTION
)
go

CREATE INDEX TILD_PD2 ON @SCHEMA@.TASK_INST_LDESC_T
(   
    LOCALE, TKIID, DISPLAY_NAME
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.TASK_INST_LDESC_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.TIDOCUMENTATION_T
(
    TKIID                              BINARY(16)                         NOT NULL ,
    LOCALE                             NVARCHAR(32)                       NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    DOCUMENTATION                      NTEXT                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( TKIID, LOCALE )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX TIDOCUMENTATION_P ON @SCHEMA@.TIDOCUMENTATION_T
( 
    TKIID, LOCALE
)
go


CREATE INDEX TIDOC_CCID ON @SCHEMA@.TIDOCUMENTATION_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.TIDOCUMENTATION_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
(
    TMTID                              BINARY(16)                         NOT NULL ,
    TKIID                              BINARY(16)                             NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    FAULT_NAME                         NVARCHAR(254)                          NULL ,
    KIND                               INTEGER                            NOT NULL ,
    MESSAGE_TYPE_NS                    NVARCHAR(220)                      NOT NULL ,
    MESSAGE_TYPE_NAME                  NVARCHAR(220)                      NOT NULL ,
    MESSAGE_DEFINITION                 IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( TMTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX ITASK_MESSAGE_DEFINITION_P ON @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
( 
    TMTID
)
go


CREATE INDEX ITMD_IDKINSTYPE ON @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
(   
    TKIID, MESSAGE_TYPE_NS, MESSAGE_TYPE_NAME, KIND
)
go

CREATE INDEX ITMD_TKIIDKINDFN ON @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
(   
    TKIID, KIND, FAULT_NAME
)
go

CREATE INDEX ITMD_CCID ON @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.ITASK_MESSAGE_DEFINITION_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.TASK_MESSAGE_INSTANCE_T
(
    TMIID                              BINARY(16)                         NOT NULL ,
    TMTID                              BINARY(16)                             NULL ,
    TKIID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    FAULT_NAME                         NVARCHAR(254)                          NULL ,
    KIND                               INTEGER                            NOT NULL ,
    MESSAGE_TYPE_NS                    NVARCHAR(220)                      NOT NULL ,
    MESSAGE_TYPE_NAME                  NVARCHAR(220)                      NOT NULL ,
    DATA                               IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( TMIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX TASK_MESSAGE_INSTANCE_P ON @SCHEMA@.TASK_MESSAGE_INSTANCE_T
( 
    TMIID
)
go


CREATE INDEX TMI_TI_K ON @SCHEMA@.TASK_MESSAGE_INSTANCE_T
(   
    TKIID, KIND
)
go

CREATE INDEX TMI_TMTID ON @SCHEMA@.TASK_MESSAGE_INSTANCE_T
(   
    TMTID
)
go

CREATE INDEX TMI_CCID ON @SCHEMA@.TASK_MESSAGE_INSTANCE_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.TASK_MESSAGE_INSTANCE_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.TASK_AUDIT_LOG_T
(
    ALID                               BINARY(16)                         NOT NULL ,
    AUDIT_EVENT                        INTEGER                            NOT NULL ,
    TKIID                              BINARY(16)                             NULL ,
    TKTID                              BINARY(16)                             NULL ,
    ESIID                              BINARY(16)                             NULL ,
    ESTID                              BINARY(16)                             NULL ,
    TOP_TKIID                          BINARY(16)                             NULL ,
    FOLLOW_ON_TKIID                    BINARY(16)                             NULL ,
    PARENT_TKIID                       BINARY(16)                             NULL ,
    PARENT_CONTEXT_ID                  BINARY(16)                             NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                             NULL ,
    WI_REASON                          INTEGER                                NULL ,
    NAME                               NVARCHAR(254)                          NULL ,
    NAMESPACE                          NVARCHAR(254)                          NULL ,
    VALID_FROM_UTC                     DATETIME                               NULL ,
    EVENT_TIME_UTC                     DATETIME                               NULL ,
    PARENT_TASK_NAME                   NVARCHAR(254)                          NULL ,
    PARENT_TASK_NAMESPACE              NVARCHAR(254)                          NULL ,
    TASK_KIND                          INTEGER                                NULL ,
    TASK_STATE                         INTEGER                                NULL ,
    FAULT_TYPE_NAME                    NVARCHAR(220)                          NULL ,
    FAULT_NAMESPACE                    NVARCHAR(220)                          NULL ,
    FAULT_NAME                         NVARCHAR(220)                          NULL ,
    NEW_USER                           NVARCHAR(128)                          NULL ,
    OLD_USER                           NVARCHAR(128)                          NULL ,
    PRINCIPAL                          NVARCHAR(128)                          NULL ,
    USERS                              NTEXT                                  NULL ,
    DESCRIPTION                        NTEXT                                  NULL ,
    MESSAGE_DATA                       IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ALID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX TASK_AUDIT_LOG_P ON @SCHEMA@.TASK_AUDIT_LOG_T
( 
    ALID
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.TASK_AUDIT_LOG_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.IMAIL_T
(
    OBJECT_ID                          BINARY(16)                         NOT NULL ,
    FROM_STATE                         INTEGER                            NOT NULL ,
    TO_STATE                           INTEGER                            NOT NULL ,
    LOCALE                             NVARCHAR(32)                       NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    SUBJECT                            NVARCHAR(254)                      NOT NULL ,
    URI                                NVARCHAR(254)                          NULL ,
    BODY_TEXT                          NTEXT                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( OBJECT_ID, FROM_STATE, TO_STATE, LOCALE )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX IMAIL_P ON @SCHEMA@.IMAIL_T
( 
    OBJECT_ID, FROM_STATE, TO_STATE, LOCALE
)
go


CREATE INDEX IMN_CTX ON @SCHEMA@.IMAIL_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.IMAIL_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.TASK_HISTORY_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    EVENT                              INTEGER                            NOT NULL ,
    TKIID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    PARENT_TKIID                       BINARY(16)                             NULL ,
    ESIID                              BINARY(16)                             NULL ,
    REASON                             INTEGER                            NOT NULL ,
    EVENT_TIME                         DATETIME                           NOT NULL ,
    NEXT_TIME                          DATETIME                               NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    PRINCIPAL                          NVARCHAR(128)                      NOT NULL ,
    WORK_ITEM_KIND                     INTEGER                            NOT NULL ,
    FROM_ID                            NVARCHAR(128)                          NULL ,
    TO_ID                              NVARCHAR(128)                          NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX TASK_HISTORY_P ON @SCHEMA@.TASK_HISTORY_T
( 
    PKID
)
go


CREATE INDEX TH_TKIID ON @SCHEMA@.TASK_HISTORY_T
(   
    TKIID
)
go

CREATE INDEX TH_CTXID ON @SCHEMA@.TASK_HISTORY_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.TASK_HISTORY_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.COMPLETION_INSTANCE_T
(
    CMIID                              BINARY(16)                         NOT NULL ,
    ORDER_NUMBER                       INTEGER                            NOT NULL ,
    TKIID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    COMPL_CONDITION                    IMAGE                                  NULL ,
    CRITERION_FOR                      NVARCHAR(254)                          NULL ,
    CRITERION_FOR_TIME                 DATETIME                               NULL ,
    COMPLETION_NAME                    NVARCHAR(220)                          NULL ,
    IS_DEFAULT_COMPLETION              SMALLINT                           NOT NULL ,
    PREFIX_MAP                         IMAGE                                  NULL ,
    USE_DEFAULT_RESULT_CONSTRUCT       SMALLINT                           NOT NULL ,
    SCHEDULER_ID                       NVARCHAR(254)                          NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( CMIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX COMPLETION_INSTANCE_P ON @SCHEMA@.COMPLETION_INSTANCE_T
( 
    CMIID
)
go


CREATE INDEX CMPI_TKIID_ORDER ON @SCHEMA@.COMPLETION_INSTANCE_T
(   
    TKIID, ORDER_NUMBER
)
go

CREATE INDEX CMPI_CCID ON @SCHEMA@.COMPLETION_INSTANCE_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.COMPLETION_INSTANCE_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(
    RAIID                              BINARY(16)                         NOT NULL ,
    ORDER_NUMBER                       INTEGER                            NOT NULL ,
    CMIID                              BINARY(16)                         NOT NULL ,
    TKIID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    AGGR_PART                          NVARCHAR(254)                          NULL ,
    AGGR_LOCATION                      IMAGE                                  NULL ,
    AGGR_FUNCTION                      NVARCHAR(254)                      NOT NULL ,
    AGGR_CONDITION                     IMAGE                                  NULL ,
    PREFIX_MAP                         IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( RAIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX RESULT_AGGREGATION_INSTANCE_P ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
( 
    RAIID
)
go


CREATE INDEX RAGI_CMIID_ORDER ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(   
    CMIID, ORDER_NUMBER
)
go

CREATE INDEX RAGI_CCID ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.RESULT_AGGREGATION_INSTANCE_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.SAVED_TASK_MESSAGE_T
(
    STMID                              BINARY(16)                         NOT NULL ,
    RELATED_OID                        BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    SCHEDULER_ID                       NVARCHAR(254)                          NULL ,
    CREATION_TIME                      DATETIME                           NOT NULL ,
    EXPECTED_ARRIVAL_TIME              DATETIME                           NOT NULL ,
    MESSAGE                            IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( STMID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX SAVED_TASK_MESSAGE_P ON @SCHEMA@.SAVED_TASK_MESSAGE_T
( 
    STMID
)
go


CREATE INDEX STM_ROID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
    RELATED_OID
)
go

CREATE INDEX STM_SID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
    SCHEDULER_ID
)
go

CREATE INDEX STM_CTXID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.SAVED_TASK_MESSAGE_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.WORK_BASKET_T
(
    WBID                               BINARY(16)                         NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    NAME                               NVARCHAR(254)                      NOT NULL ,
    TYPE                               INTEGER                            NOT NULL ,
    OWNER                              NVARCHAR(128)                          NULL ,
    SUBSTITUTION_POLICY                INTEGER                            NOT NULL ,
    JNDI_NAME_STAFF_PROVIDER           NVARCHAR(254)                      NOT NULL ,
    DEFAULT_QUERY_TABLE                NVARCHAR(32)                           NULL ,
    CUSTOM_TEXT1                       NVARCHAR(254)                          NULL ,
    CUSTOM_TEXT2                       NVARCHAR(254)                          NULL ,
    CUSTOM_TEXT3                       NVARCHAR(254)                          NULL ,
    CUSTOM_TEXT4                       NVARCHAR(254)                          NULL ,
    CUSTOM_TEXT5                       NVARCHAR(254)                          NULL ,
    CUSTOM_TEXT6                       NVARCHAR(254)                          NULL ,
    CUSTOM_TEXT7                       NVARCHAR(254)                          NULL ,
    CUSTOM_TEXT8                       NVARCHAR(254)                          NULL ,
    EXTENDED_DATA                      IMAGE                                  NULL ,
    CREATION_TIME                      DATETIME                           NOT NULL ,
    LAST_MODIFICATION_TIME             DATETIME                           NOT NULL ,
    CREATED_WITH_VERSION               INTEGER                            NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( WBID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX WORK_BASKET_P ON @SCHEMA@.WORK_BASKET_T
( 
    WBID
)
go


CREATE INDEX WBK_NAME ON @SCHEMA@.WORK_BASKET_T
(   
    NAME
)
go

CREATE INDEX WBK_TYPE ON @SCHEMA@.WORK_BASKET_T
(   
    TYPE
)
go

CREATE INDEX WBK_WSID1 ON @SCHEMA@.WORK_BASKET_T
(   
    WSID_1
)
go

CREATE INDEX WBK_WSID2 ON @SCHEMA@.WORK_BASKET_T
(   
    WSID_2
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.WORK_BASKET_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.WORK_BASKET_LDESC_T
(
    WBID                               BINARY(16)                         NOT NULL ,
    LOCALE                             NVARCHAR(32)                       NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    DISPLAY_NAME                       NVARCHAR(64)                           NULL ,
    DESCRIPTION                        NVARCHAR(254)                          NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( WBID, LOCALE )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX WORK_BASKET_LDESC_P ON @SCHEMA@.WORK_BASKET_LDESC_T
( 
    WBID, LOCALE
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.WORK_BASKET_LDESC_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.WORK_BASKET_DIST_TARGET_T
(
    SOURCE_WBID                        BINARY(16)                         NOT NULL ,
    TARGET_WBID                        BINARY(16)                         NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( SOURCE_WBID, TARGET_WBID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX WORK_BASKET_DIST_TARGET_P ON @SCHEMA@.WORK_BASKET_DIST_TARGET_T
( 
    SOURCE_WBID, TARGET_WBID
)
go


CREATE INDEX WBDT_TWB ON @SCHEMA@.WORK_BASKET_DIST_TARGET_T
(   
    TARGET_WBID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.WORK_BASKET_DIST_TARGET_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.BUSINESS_CATEGORY_T
(
    BCID                               BINARY(16)                         NOT NULL ,
    PARENT_BCID                        BINARY(16)                             NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    NAME                               NVARCHAR(254)                      NOT NULL ,
    PRIORITY                           INTEGER                                NULL ,
    SUBSTITUTION_POLICY                INTEGER                            NOT NULL ,
    JNDI_NAME_STAFF_PROVIDER           NVARCHAR(254)                      NOT NULL ,
    DEFAULT_QUERY_TABLE                NVARCHAR(32)                           NULL ,
    CUSTOM_TEXT1                       NVARCHAR(254)                          NULL ,
    CUSTOM_TEXT2                       NVARCHAR(254)                          NULL ,
    CUSTOM_TEXT3                       NVARCHAR(254)                          NULL ,
    CUSTOM_TEXT4                       NVARCHAR(254)                          NULL ,
    CUSTOM_TEXT5                       NVARCHAR(254)                          NULL ,
    CUSTOM_TEXT6                       NVARCHAR(254)                          NULL ,
    CUSTOM_TEXT7                       NVARCHAR(254)                          NULL ,
    CUSTOM_TEXT8                       NVARCHAR(254)                          NULL ,
    EXTENDED_DATA                      IMAGE                                  NULL ,
    CREATION_TIME                      DATETIME                           NOT NULL ,
    LAST_MODIFICATION_TIME             DATETIME                           NOT NULL ,
    CREATED_WITH_VERSION               INTEGER                            NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( BCID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX BUSINESS_CATEGORY_P ON @SCHEMA@.BUSINESS_CATEGORY_T
( 
    BCID
)
go


CREATE INDEX BCG_PARENTBCID ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
    PARENT_BCID
)
go

CREATE INDEX BCG_NAME ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
    NAME
)
go

CREATE INDEX BCG_WSID1 ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
    WSID_1
)
go

CREATE INDEX BCG_WSID2 ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
    WSID_2
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.BUSINESS_CATEGORY_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.BUSINESS_CATEGORY_LDESC_T
(
    BCID                               BINARY(16)                         NOT NULL ,
    LOCALE                             NVARCHAR(32)                       NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    DISPLAY_NAME                       NVARCHAR(64)                           NULL ,
    DESCRIPTION                        NVARCHAR(254)                          NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( BCID, LOCALE )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX BUSINESS_CATEGORY_LDESC_P ON @SCHEMA@.BUSINESS_CATEGORY_LDESC_T
( 
    BCID, LOCALE
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.BUSINESS_CATEGORY_LDESC_T', 'AllowPageLocks', FALSE
go

-- set schema version to: 700
INSERT INTO @SCHEMA@.SCHEMA_VERSION (SCHEMA_VERSION, DATA_MIGRATION) VALUES( 700, 0 )
go


-- View: ProcessTemplate
CREATE VIEW @SCHEMA@.PROCESS_TEMPLATE(PTID, NAME, DISPLAY_NAME, VALID_FROM, TARGET_NAMESPACE, APPLICATION_NAME, VERSION, CREATED, STATE, EXECUTION_MODE, DESCRIPTION, CAN_RUN_SYNC, CAN_RUN_INTERRUP, COMP_SPHERE, CONTINUE_ON_ERROR ) AS
 SELECT @SCHEMA@.PROCESS_TEMPLATE_B_T.PTID, @SCHEMA@.PROCESS_TEMPLATE_B_T.NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.DISPLAY_NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.VALID_FROM, @SCHEMA@.PROCESS_TEMPLATE_B_T.TARGET_NAMESPACE, @SCHEMA@.PROCESS_TEMPLATE_B_T.APPLICATION_NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.VERSION, @SCHEMA@.PROCESS_TEMPLATE_B_T.CREATED, @SCHEMA@.PROCESS_TEMPLATE_B_T.STATE, @SCHEMA@.PROCESS_TEMPLATE_B_T.EXECUTION_MODE, @SCHEMA@.PROCESS_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_TEMPLATE_B_T.CAN_CALL, @SCHEMA@.PROCESS_TEMPLATE_B_T.CAN_INITIATE, @SCHEMA@.PROCESS_TEMPLATE_B_T.COMPENSATION_SPHERE, @SCHEMA@.PROCESS_TEMPLATE_B_T.CONTINUE_ON_ERROR
 FROM @SCHEMA@.PROCESS_TEMPLATE_B_T
go

-- View: ProcessTemplAttr
CREATE VIEW @SCHEMA@.PROCESS_TEMPL_ATTR(PTID, NAME, VALUE ) AS
 SELECT @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.PTID, @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.ATTR_KEY, @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.VALUE
 FROM @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T
go

-- View: ProcessInstance
CREATE VIEW @SCHEMA@.PROCESS_INSTANCE(PTID, PIID, NAME, STATE, CREATED, STARTED, COMPLETED, PARENT_NAME, TOP_LEVEL_NAME, PARENT_PIID, TOP_LEVEL_PIID, STARTER, DESCRIPTION, TEMPLATE_NAME, TEMPLATE_DESCR, RESUMES, CONTINUE_ON_ERROR, IS_MIGRATED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.PROCESS_INSTANCE_B_T.PTID, @SCHEMA@.PROCESS_INSTANCE_B_T.PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.STATE, @SCHEMA@.PROCESS_INSTANCE_B_T.CREATED, @SCHEMA@.PROCESS_INSTANCE_B_T.STARTED, @SCHEMA@.PROCESS_INSTANCE_B_T.COMPLETED, @SCHEMA@.PROCESS_INSTANCE_B_T.PARENT_NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.TOP_LEVEL_NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.PARENT_PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.TOP_LEVEL_PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.STARTER, @SCHEMA@.PROCESS_INSTANCE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_TEMPLATE_B_T.NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_INSTANCE_B_T.RESUMES, @SCHEMA@.PROCESS_TEMPLATE_B_T.CONTINUE_ON_ERROR, @SCHEMA@.PROCESS_INSTANCE_B_T.IS_MIGRATED, @SCHEMA@.PROCESS_INSTANCE_B_T.WSID_1, @SCHEMA@.PROCESS_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.PROCESS_INSTANCE_B_T, @SCHEMA@.PROCESS_TEMPLATE_B_T
 WHERE @SCHEMA@.PROCESS_INSTANCE_B_T.PTID = @SCHEMA@.PROCESS_TEMPLATE_B_T.PTID
go

-- View: ProcessAttribute
CREATE VIEW @SCHEMA@.PROCESS_ATTRIBUTE(PIID, NAME, VALUE, DATA_TYPE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.PIID, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.ATTR_KEY, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.VALUE, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.DATA_TYPE, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.WSID_1, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.WSID_2
 FROM @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
go

-- View: Activity
CREATE VIEW @SCHEMA@.ACTIVITY(PIID, AIID, PTID, ATID, SIID, STID, EHIID, ENCLOSING_FEIID, KIND, COMPLETED, ACTIVATED, FIRST_ACTIVATED, STARTED, STATE, SUB_STATE, STOP_REASON, OWNER, DESCRIPTION, EXPIRES, TEMPLATE_NAME, TEMPLATE_DESCR, BUSINESS_RELEVANCE, SKIP_REQUESTED, CONTINUE_ON_ERROR, INVOKED_INST_ID, INVOKED_INST_TYPE, PREVIOUS_EXPIRATION_TIME, HAS_WORK_ITEM, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ACTIVITY_INSTANCE_B_T.PIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.AIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.PTID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ATID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SIID, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.PARENT_STID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.EHIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ENCLOSING_FEIID, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.KIND, @SCHEMA@.ACTIVITY_INSTANCE_B_T.FINISHED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ACTIVATED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.FIRST_ACTIVATED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STARTED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SUB_STATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STOP_REASON, @SCHEMA@.ACTIVITY_INSTANCE_B_T.OWNER, @SCHEMA@.ACTIVITY_INSTANCE_B_T.DESCRIPTION, @SCHEMA@.ACTIVITY_INSTANCE_B_T.EXPIRES, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.NAME, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.BUSINESS_RELEVANCE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SKIP_REQUESTED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.CONTINUE_ON_ERROR, @SCHEMA@.ACTIVITY_INSTANCE_B_T.INVOKED_INSTANCE_ID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.INVOKED_INSTANCE_TYPE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.PREVIOUS_EXPIRATION_DATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.HAS_WORK_ITEM, @SCHEMA@.ACTIVITY_INSTANCE_B_T.WSID_1, @SCHEMA@.ACTIVITY_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.ACTIVITY_INSTANCE_B_T, @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 WHERE @SCHEMA@.ACTIVITY_INSTANCE_B_T.ATID = @SCHEMA@.ACTIVITY_TEMPLATE_B_T.ATID
go

-- View: ActivityAttribute
CREATE VIEW @SCHEMA@.ACTIVITY_ATTRIBUTE(AIID, NAME, VALUE, DATA_TYPE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.AIID, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.ATTR_KEY, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.ATTR_VALUE, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.DATA_TYPE, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.WSID_1, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.WSID_2
 FROM @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
go

-- View: Event
CREATE VIEW @SCHEMA@.EVENT(EIID, AIID, PIID, EHTID, SIID, NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.EVENT_INSTANCE_B_T.EIID, @SCHEMA@.EVENT_INSTANCE_B_T.AIID, @SCHEMA@.EVENT_INSTANCE_B_T.PIID, @SCHEMA@.EVENT_INSTANCE_B_T.EHTID, @SCHEMA@.EVENT_INSTANCE_B_T.SIID, @SCHEMA@.SERVICE_TEMPLATE_B_T.NAME, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_1, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.EVENT_INSTANCE_B_T, @SCHEMA@.SERVICE_TEMPLATE_B_T
 WHERE @SCHEMA@.EVENT_INSTANCE_B_T.STATE = 2 AND @SCHEMA@.EVENT_INSTANCE_B_T.VTID = @SCHEMA@.SERVICE_TEMPLATE_B_T.VTID
go

-- View: WorkItem
CREATE VIEW @SCHEMA@.WORK_ITEM(WIID, OWNER_ID, GROUP_NAME, EVERYBODY, OBJECT_TYPE, OBJECT_ID, ASSOC_OBJECT_TYPE, ASSOC_OID, REASON, CREATION_TIME, QIID, KIND ) AS
 SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO = 1
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO = 2
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO = 3
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.RETRIEVED_USER_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T, @SCHEMA@.RETRIEVED_USER_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO = 0 AND @SCHEMA@.WORK_ITEM_T.QIID = @SCHEMA@.RETRIEVED_USER_T.QIID
go

-- View: SharedWorkItem
CREATE VIEW @SCHEMA@.SHARED_WORK_ITEM(WSID, OWNER_ID, GROUP_NAME, EVERYBODY, REASON ) AS
 SELECT @SCHEMA@.SWI_T.WSID, @SCHEMA@.SWI_T.OWNER_ID, @SCHEMA@.SWI_T.GROUP_NAME, @SCHEMA@.SWI_T.EVERYBODY, @SCHEMA@.SWI_T.REASON
 FROM @SCHEMA@.SWI_T
 WHERE @SCHEMA@.SWI_T.AUTH_INFO IN ( 1,2,3 )
 UNION ALL SELECT @SCHEMA@.SWI_T.WSID, @SCHEMA@.RETRIEVED_USER_T.OWNER_ID, @SCHEMA@.SWI_T.GROUP_NAME, @SCHEMA@.SWI_T.EVERYBODY, @SCHEMA@.SWI_T.REASON
 FROM @SCHEMA@.SWI_T, @SCHEMA@.RETRIEVED_USER_T
 WHERE @SCHEMA@.SWI_T.QIID = @SCHEMA@.RETRIEVED_USER_T.QIID AND @SCHEMA@.SWI_T.AUTH_INFO = 0
go

-- View: ActivityService
CREATE VIEW @SCHEMA@.ACTIVITY_SERVICE(EIID, AIID, PIID, VTID, PORT_TYPE, NAME_SPACE_URI, OPERATION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.EVENT_INSTANCE_B_T.EIID, @SCHEMA@.EVENT_INSTANCE_B_T.AIID, @SCHEMA@.EVENT_INSTANCE_B_T.PIID, @SCHEMA@.EVENT_INSTANCE_B_T.VTID, @SCHEMA@.SERVICE_TEMPLATE_B_T.PORT_TYPE_NAME,@SCHEMA@.URI_TEMPLATE_B_T.URI, @SCHEMA@.SERVICE_TEMPLATE_B_T.OPERATION_NAME, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_1, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.EVENT_INSTANCE_B_T, @SCHEMA@.SERVICE_TEMPLATE_B_T, @SCHEMA@.URI_TEMPLATE_B_T
 WHERE @SCHEMA@.EVENT_INSTANCE_B_T.STATE = 2 AND @SCHEMA@.EVENT_INSTANCE_B_T.VTID = @SCHEMA@.SERVICE_TEMPLATE_B_T.VTID AND @SCHEMA@.SERVICE_TEMPLATE_B_T.PORT_TYPE_UTID = @SCHEMA@.URI_TEMPLATE_B_T.UTID
go

-- View: QueryProperty
CREATE VIEW @SCHEMA@.QUERY_PROPERTY(PIID, VARIABLE_NAME, NAME, NAMESPACE, GENERIC_VALUE, STRING_VALUE, NUMBER_VALUE, DECIMAL_VALUE, TIMESTAMP_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PIID, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.VARIABLE_NAME, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PROPERTY_NAME, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PROPERTY_NAMESPACE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.GENERIC_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.STRING_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.NUMBER_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.DECIMAL_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.TIMESTAMP_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.WSID_1, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.WSID_2
 FROM @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
go

-- View: QueryPropTempl
CREATE VIEW @SCHEMA@.QUERY_PROP_TEMPL(PTID, NAME, PROPERTY_NAME, URI, QUERY_TYPE, JAVA_TYPE ) AS
 SELECT @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.PTID, @SCHEMA@.VARIABLE_TEMPLATE_B_T.NAME, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PROPERTY_NAME, @SCHEMA@.URI_TEMPLATE_B_T.URI, @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.QUERY_TYPE, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.JAVA_TYPE
 FROM @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T, @SCHEMA@.VARIABLE_TEMPLATE_B_T, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T, @SCHEMA@.URI_TEMPLATE_B_T
 WHERE @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.CTID = @SCHEMA@.VARIABLE_TEMPLATE_B_T.CTID AND @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.PAID = @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PAID AND @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PROPERTY_UTID = @SCHEMA@.URI_TEMPLATE_B_T.UTID
go

-- View: MigrationFront
CREATE VIEW @SCHEMA@.MIGRATION_FRONT(PIID, AIID, SOURCE_PTID, TARGET_PTID, STATE, SUB_STATE, STOP_REASON, SOURCE_ATID, TARGET_ATID, MIGRATION_TIME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.MIGRATION_FRONT_T.PIID, @SCHEMA@.MIGRATION_FRONT_T.AIID, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.SOURCE_PTID, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.TARGET_PTID, @SCHEMA@.MIGRATION_FRONT_T.STATE, @SCHEMA@.MIGRATION_FRONT_T.SUB_STATE, @SCHEMA@.MIGRATION_FRONT_T.STOP_REASON, @SCHEMA@.MIGRATION_FRONT_T.SOURCE_ATID, @SCHEMA@.MIGRATION_FRONT_T.TARGET_ATID, @SCHEMA@.MIGRATION_FRONT_T.MIGRATION_TIME, @SCHEMA@.MIGRATION_FRONT_T.WSID_1, @SCHEMA@.MIGRATION_FRONT_T.WSID_2
 FROM @SCHEMA@.MIGRATION_FRONT_T, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
 WHERE @SCHEMA@.MIGRATION_FRONT_T.MPTID = @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.MPTID
go

-- View: AuditLog
CREATE VIEW @SCHEMA@.AUDIT_LOG(ALID, EVENT_TIME, EVENT_TIME_UTC, AUDIT_EVENT, PTID, PIID, AIID, SIID, SCOPE_NAME, PROCESS_TEMPL_NAME, PROCESS_INST_NAME, TOP_LEVEL_PI_NAME, TOP_LEVEL_PIID, PARENT_PI_NAME, PARENT_PIID, VALID_FROM, VALID_FROM_UTC, ACTIVITY_NAME, ACTIVITY_KIND, ACTIVITY_STATE, CONTROL_LINK_NAME, IMPL_NAME, PRINCIPAL, TERMINAL_NAME, VARIABLE_DATA, EXCEPTION_TEXT, DESCRIPTION, CORR_SET_INFO, USER_NAME, ATID, ADDITIONAL_INFO, OBJECT_META_TYPE ) AS
 SELECT @SCHEMA@.AUDIT_LOG_T.ALID,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME_UTC,@SCHEMA@.AUDIT_LOG_T.AUDIT_EVENT,@SCHEMA@.AUDIT_LOG_T.PTID,@SCHEMA@.AUDIT_LOG_T.PIID,@SCHEMA@.AUDIT_LOG_T.AIID,@SCHEMA@.AUDIT_LOG_T.SIID,@SCHEMA@.AUDIT_LOG_T.VARIABLE_NAME,@SCHEMA@.AUDIT_LOG_T.PROCESS_TEMPL_NAME, @SCHEMA@.AUDIT_LOG_T.PROCESS_INST_NAME,@SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PI_NAME,@SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PIID,@SCHEMA@.AUDIT_LOG_T.PARENT_PI_NAME,@SCHEMA@.AUDIT_LOG_T.PARENT_PIID,@SCHEMA@.AUDIT_LOG_T.VALID_FROM,@SCHEMA@.AUDIT_LOG_T.VALID_FROM_UTC, @SCHEMA@.AUDIT_LOG_T.ACTIVITY_NAME,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_KIND,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_STATE,@SCHEMA@.AUDIT_LOG_T.CONTROL_LINK_NAME,@SCHEMA@.AUDIT_LOG_T.IMPL_NAME,@SCHEMA@.AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.AUDIT_LOG_T.TERMINAL_NAME,@SCHEMA@.AUDIT_LOG_T.VARIABLE_DATA,@SCHEMA@.AUDIT_LOG_T.EXCEPTION_TEXT,@SCHEMA@.AUDIT_LOG_T.DESCRIPTION,@SCHEMA@.AUDIT_LOG_T.CORR_SET_INFO,@SCHEMA@.AUDIT_LOG_T.USER_NAME, @SCHEMA@.AUDIT_LOG_T.ATID, @SCHEMA@.AUDIT_LOG_T.ADDITIONAL_INFO, @SCHEMA@.AUDIT_LOG_T.OBJECT_META_TYPE
 FROM @SCHEMA@.AUDIT_LOG_T
go

-- View: AuditLogB
CREATE VIEW @SCHEMA@.AUDIT_LOG_B(ALID, EVENT_TIME, EVENT_TIME_UTC, AUDIT_EVENT, PTID, PIID, AIID, SIID, VARIABLE_NAME, PROCESS_TEMPL_NAME, TOP_LEVEL_PIID, PARENT_PIID, VALID_FROM, VALID_FROM_UTC, ATID, ACTIVITY_NAME, ACTIVITY_KIND, ACTIVITY_STATE, CONTROL_LINK_NAME, PRINCIPAL, VARIABLE_DATA, EXCEPTION_TEXT, DESCRIPTION, CORR_SET_INFO, USER_NAME, ADDITIONAL_INFO ) AS
 SELECT @SCHEMA@.AUDIT_LOG_T.ALID,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME_UTC,@SCHEMA@.AUDIT_LOG_T.AUDIT_EVENT,@SCHEMA@.AUDIT_LOG_T.PTID,@SCHEMA@.AUDIT_LOG_T.PIID,@SCHEMA@.AUDIT_LOG_T.AIID,@SCHEMA@.AUDIT_LOG_T.SIID,@SCHEMA@.AUDIT_LOG_T.VARIABLE_NAME,@SCHEMA@.AUDIT_LOG_T.PROCESS_TEMPL_NAME, @SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PIID,@SCHEMA@.AUDIT_LOG_T.PARENT_PIID,@SCHEMA@.AUDIT_LOG_T.VALID_FROM,@SCHEMA@.AUDIT_LOG_T.VALID_FROM_UTC,@SCHEMA@.AUDIT_LOG_T.ATID, @SCHEMA@.AUDIT_LOG_T.ACTIVITY_NAME,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_KIND,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_STATE,@SCHEMA@.AUDIT_LOG_T.CONTROL_LINK_NAME,@SCHEMA@.AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.AUDIT_LOG_T.VARIABLE_DATA,@SCHEMA@.AUDIT_LOG_T.EXCEPTION_TEXT,@SCHEMA@.AUDIT_LOG_T.DESCRIPTION,@SCHEMA@.AUDIT_LOG_T.CORR_SET_INFO,@SCHEMA@.AUDIT_LOG_T.USER_NAME, @SCHEMA@.AUDIT_LOG_T.ADDITIONAL_INFO
 FROM @SCHEMA@.AUDIT_LOG_T
 WHERE @SCHEMA@.AUDIT_LOG_T.OBJECT_META_TYPE = 1
go

-- View: ApplicationComp
CREATE VIEW @SCHEMA@.APPLICATION_COMP(ACOID, BUSINESS_RELEVANCE, NAME, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON ) AS
 SELECT @SCHEMA@.APPLICATION_COMPONENT_T.ACOID, @SCHEMA@.APPLICATION_COMPONENT_T.BUSINESS_RELEVANCE, @SCHEMA@.APPLICATION_COMPONENT_T.NAME, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_DELEGATION, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_SUB_TASK, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_FOLLOW_ON_TASK
 FROM @SCHEMA@.APPLICATION_COMPONENT_T
go

-- View: Task
CREATE VIEW @SCHEMA@.TASK(TKIID, ACTIVATED, APPLIC_DEFAULTS_ID, APPLIC_NAME, BUSINESS_RELEVANCE, COMPLETED, CONTAINMENT_CTX_ID, CTX_AUTHORIZATION, DUE, EXPIRES, FIRST_ACTIVATED, FOLLOW_ON_TKIID, IS_AD_HOC, IS_ESCALATED, IS_INLINE, IS_WAIT_FOR_SUB_TK, KIND, LAST_MODIFIED, LAST_STATE_CHANGE, NAME, NAME_SPACE, ORIGINATOR, OWNER, PARENT_CONTEXT_ID, PRIORITY, STARTED, STARTER, STATE, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON, HIERARCHY_POSITION, IS_CHILD, SUSPENDED, TKTID, TOP_TKIID, TYPE, RESUMES, ASSIGNMENT_TYPE, INHERITED_AUTH, INVOKED_INSTANCE_ID, INVOKED_INSTANCE_TYPE, WORK_BASKET, IS_READ, IS_TRANSFERRED_TO_WORK_BASKET, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INSTANCE_T.TKIID, @SCHEMA@.TASK_INSTANCE_T.ACTIVATION_TIME, @SCHEMA@.TASK_INSTANCE_T.APPLICATION_DEFAULTS_ID, @SCHEMA@.TASK_INSTANCE_T.APPLICATION_NAME, @SCHEMA@.TASK_INSTANCE_T.BUSINESS_RELEVANCE, @SCHEMA@.TASK_INSTANCE_T.COMPLETION_TIME, @SCHEMA@.TASK_INSTANCE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_INSTANCE_T.CONTEXT_AUTHORIZATION, @SCHEMA@.TASK_INSTANCE_T.DUE_TIME, @SCHEMA@.TASK_INSTANCE_T.EXPIRATION_TIME, @SCHEMA@.TASK_INSTANCE_T.FIRST_ACTIVATION_TIME, @SCHEMA@.TASK_INSTANCE_T.FOLLOW_ON_TKIID, @SCHEMA@.TASK_INSTANCE_T.IS_AD_HOC, @SCHEMA@.TASK_INSTANCE_T.IS_ESCALATED, @SCHEMA@.TASK_INSTANCE_T.IS_INLINE, @SCHEMA@.TASK_INSTANCE_T.IS_WAITING_FOR_SUBTASK, @SCHEMA@.TASK_INSTANCE_T.KIND, @SCHEMA@.TASK_INSTANCE_T.LAST_MODIFICATION_TIME, @SCHEMA@.TASK_INSTANCE_T.LAST_STATE_CHANGE_TIME, @SCHEMA@.TASK_INSTANCE_T.NAME, @SCHEMA@.TASK_INSTANCE_T.NAMESPACE, @SCHEMA@.TASK_INSTANCE_T.ORIGINATOR, @SCHEMA@.TASK_INSTANCE_T.OWNER, @SCHEMA@.TASK_INSTANCE_T.PARENT_CONTEXT_ID, @SCHEMA@.TASK_INSTANCE_T.PRIORITY, @SCHEMA@.TASK_INSTANCE_T.START_TIME, @SCHEMA@.TASK_INSTANCE_T.STARTER, @SCHEMA@.TASK_INSTANCE_T.STATE, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_DELEGATION, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_SUB_TASK, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_FOLLOW_ON_TASK, @SCHEMA@.TASK_INSTANCE_T.HIERARCHY_POSITION, @SCHEMA@.TASK_INSTANCE_T.IS_CHILD, @SCHEMA@.TASK_INSTANCE_T.IS_SUSPENDED, @SCHEMA@.TASK_INSTANCE_T.TKTID, @SCHEMA@.TASK_INSTANCE_T.TOP_TKIID, @SCHEMA@.TASK_INSTANCE_T.TYPE, @SCHEMA@.TASK_INSTANCE_T.RESUMES, @SCHEMA@.TASK_INSTANCE_T.ASSIGNMENT_TYPE, @SCHEMA@.TASK_INSTANCE_T.INHERITED_AUTH, @SCHEMA@.TASK_INSTANCE_T.INVOKED_INSTANCE_ID, @SCHEMA@.TASK_INSTANCE_T.INVOKED_INSTANCE_TYPE, @SCHEMA@.TASK_INSTANCE_T.WORK_BASKET, @SCHEMA@.TASK_INSTANCE_T.IS_READ, @SCHEMA@.TASK_INSTANCE_T.IS_TRANSFERRED_TO_WORK_BASKET, @SCHEMA@.TASK_INSTANCE_T.WSID_1, @SCHEMA@.TASK_INSTANCE_T.WSID_2
 FROM @SCHEMA@.TASK_INSTANCE_T
go

-- View: TaskTempl
CREATE VIEW @SCHEMA@.TASK_TEMPL(TKTID, APPLIC_DEFAULTS_ID, APPLIC_NAME, BUSINESS_RELEVANCE, CONTAINMENT_CTX_ID, CTX_AUTHORIZATION, DEFINITION_NAME, DEFINITION_NS, IS_AD_HOC, IS_INLINE, KIND, NAME, NAMESPACE, PRIORITY, STATE, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON, TYPE, VALID_FROM, AUTONOMY, ASSIGNMENT_TYPE, INHERITED_AUTH, WORK_BASKET ) AS
 SELECT @SCHEMA@.TASK_TEMPLATE_T.TKTID, @SCHEMA@.TASK_TEMPLATE_T.APPLICATION_DEFAULTS_ID, @SCHEMA@.TASK_TEMPLATE_T.APPLICATION_NAME, @SCHEMA@.TASK_TEMPLATE_T.BUSINESS_RELEVANCE, @SCHEMA@.TASK_TEMPLATE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_TEMPLATE_T.CONTEXT_AUTHORIZATION, @SCHEMA@.TASK_TEMPLATE_T.DEFINITION_NAME, @SCHEMA@.TASK_TEMPLATE_T.TARGET_NAMESPACE, @SCHEMA@.TASK_TEMPLATE_T.IS_AD_HOC, @SCHEMA@.TASK_TEMPLATE_T.IS_INLINE, @SCHEMA@.TASK_TEMPLATE_T.KIND, @SCHEMA@.TASK_TEMPLATE_T.NAME, @SCHEMA@.TASK_TEMPLATE_T.NAMESPACE, @SCHEMA@.TASK_TEMPLATE_T.PRIORITY, @SCHEMA@.TASK_TEMPLATE_T.STATE, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_DELEGATION, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_SUB_TASK, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_FOLLOW_ON_TASK, @SCHEMA@.TASK_TEMPLATE_T.TYPE, @SCHEMA@.TASK_TEMPLATE_T.VALID_FROM, @SCHEMA@.TASK_TEMPLATE_T.AUTONOMY, @SCHEMA@.TASK_TEMPLATE_T.ASSIGNMENT_TYPE, @SCHEMA@.TASK_TEMPLATE_T.INHERITED_AUTH, @SCHEMA@.TASK_TEMPLATE_T.WORK_BASKET
 FROM @SCHEMA@.TASK_TEMPLATE_T
go

-- View: Escalation
CREATE VIEW @SCHEMA@.ESCALATION(ESIID, ACTION, ACTIVATION_STATE, ACTIVATION_TIME, ESCALATION_TIME, AT_LEAST_EXP_STATE, ESTID, FIRST_ESIID, INCREASE_PRIORITY, NAME, STATE, TKIID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESCALATION_INSTANCE_T.ESIID, @SCHEMA@.ESCALATION_INSTANCE_T.ACTION, @SCHEMA@.ESCALATION_INSTANCE_T.ACTIVATION_STATE, @SCHEMA@.ESCALATION_INSTANCE_T.ACTIVATION_TIME, @SCHEMA@.ESCALATION_INSTANCE_T.ESCALATION_TIME, @SCHEMA@.ESCALATION_INSTANCE_T.AT_LEAST_EXPECTED_STATE, @SCHEMA@.ESCALATION_INSTANCE_T.ESTID, @SCHEMA@.ESCALATION_INSTANCE_T.FIRST_ESIID, @SCHEMA@.ESCALATION_INSTANCE_T.INCREASE_PRIORITY, @SCHEMA@.ESCALATION_INSTANCE_T.NAME, @SCHEMA@.ESCALATION_INSTANCE_T.STATE, @SCHEMA@.ESCALATION_INSTANCE_T.TKIID, @SCHEMA@.ESCALATION_INSTANCE_T.WSID_1, @SCHEMA@.ESCALATION_INSTANCE_T.WSID_2
 FROM @SCHEMA@.ESCALATION_INSTANCE_T
go

-- View: EscTempl
CREATE VIEW @SCHEMA@.ESC_TEMPL(ESTID, FIRST_ESTID, PREVIOUS_ESTID, TKTID, CONTAINMENT_CTX_ID, NAME, ACTIVATION_STATE, AT_LEAST_EXP_STATE, INCREASE_PRIORITY, ACTION ) AS
 SELECT @SCHEMA@.ESCALATION_TEMPLATE_T.ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.FIRST_ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.PREVIOUS_ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.TKTID, @SCHEMA@.ESCALATION_TEMPLATE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.ESCALATION_TEMPLATE_T.NAME, @SCHEMA@.ESCALATION_TEMPLATE_T.ACTIVATION_STATE, @SCHEMA@.ESCALATION_TEMPLATE_T.AT_LEAST_EXPECTED_STATE, @SCHEMA@.ESCALATION_TEMPLATE_T.INCREASE_PRIORITY, @SCHEMA@.ESCALATION_TEMPLATE_T.ACTION
 FROM @SCHEMA@.ESCALATION_TEMPLATE_T
go

-- View: EscTemplDesc
CREATE VIEW @SCHEMA@.ESC_TEMPL_DESC(ESTID, LOCALE, TKTID, DISPLAY_NAME, DESCRIPTION ) AS
 SELECT @SCHEMA@.ESC_TEMPL_LDESC_T.ESTID, @SCHEMA@.ESC_TEMPL_LDESC_T.LOCALE, @SCHEMA@.ESC_TEMPL_LDESC_T.TKTID, @SCHEMA@.ESC_TEMPL_LDESC_T.DISPLAY_NAME, @SCHEMA@.ESC_TEMPL_LDESC_T.DESCRIPTION
 FROM @SCHEMA@.ESC_TEMPL_LDESC_T
go

-- View: TaskTemplCProp
CREATE VIEW @SCHEMA@.TASK_TEMPL_CPROP(TKTID, NAME, DATA_TYPE, STRING_VALUE ) AS
 SELECT @SCHEMA@.TASK_TEMPL_CPROP_T.TKTID, @SCHEMA@.TASK_TEMPL_CPROP_T.NAME, @SCHEMA@.TASK_TEMPL_CPROP_T.DATA_TYPE, @SCHEMA@.TASK_TEMPL_CPROP_T.STRING_VALUE
 FROM @SCHEMA@.TASK_TEMPL_CPROP_T
go

-- View: EscTemplCProp
CREATE VIEW @SCHEMA@.ESC_TEMPL_CPROP(ESTID, NAME, TKTID, DATA_TYPE, VALUE ) AS
 SELECT @SCHEMA@.ESC_TEMPL_CPROP_T.ESTID, @SCHEMA@.ESC_TEMPL_CPROP_T.NAME, @SCHEMA@.ESC_TEMPL_CPROP_T.TKTID, @SCHEMA@.ESC_TEMPL_CPROP_T.DATA_TYPE, @SCHEMA@.ESC_TEMPL_CPROP_T.STRING_VALUE
 FROM @SCHEMA@.ESC_TEMPL_CPROP_T
go

-- View: TaskTemplDesc
CREATE VIEW @SCHEMA@.TASK_TEMPL_DESC(TKTID, LOCALE, DESCRIPTION, DISPLAY_NAME ) AS
 SELECT @SCHEMA@.TASK_TEMPL_LDESC_T.TKTID, @SCHEMA@.TASK_TEMPL_LDESC_T.LOCALE, @SCHEMA@.TASK_TEMPL_LDESC_T.DESCRIPTION, @SCHEMA@.TASK_TEMPL_LDESC_T.DISPLAY_NAME
 FROM @SCHEMA@.TASK_TEMPL_LDESC_T
go

-- View: TaskCProp
CREATE VIEW @SCHEMA@.TASK_CPROP(TKIID, NAME, DATA_TYPE, STRING_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INST_CPROP_T.TKIID, @SCHEMA@.TASK_INST_CPROP_T.NAME, @SCHEMA@.TASK_INST_CPROP_T.DATA_TYPE, @SCHEMA@.TASK_INST_CPROP_T.STRING_VALUE, @SCHEMA@.TASK_INST_CPROP_T.WSID_1, @SCHEMA@.TASK_INST_CPROP_T.WSID_2
 FROM @SCHEMA@.TASK_INST_CPROP_T
go

-- View: TaskDesc
CREATE VIEW @SCHEMA@.TASK_DESC(TKIID, LOCALE, DESCRIPTION, DISPLAY_NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INST_LDESC_T.TKIID, @SCHEMA@.TASK_INST_LDESC_T.LOCALE, @SCHEMA@.TASK_INST_LDESC_T.DESCRIPTION, @SCHEMA@.TASK_INST_LDESC_T.DISPLAY_NAME, @SCHEMA@.TASK_INST_LDESC_T.WSID_1, @SCHEMA@.TASK_INST_LDESC_T.WSID_2
 FROM @SCHEMA@.TASK_INST_LDESC_T
go

-- View: EscalationCProp
CREATE VIEW @SCHEMA@.ESCALATION_CPROP(ESIID, NAME, DATA_TYPE, STRING_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESC_INST_CPROP_T.ESIID, @SCHEMA@.ESC_INST_CPROP_T.NAME, @SCHEMA@.ESC_INST_CPROP_T.DATA_TYPE, @SCHEMA@.ESC_INST_CPROP_T.STRING_VALUE, @SCHEMA@.ESC_INST_CPROP_T.WSID_1, @SCHEMA@.ESC_INST_CPROP_T.WSID_2
 FROM @SCHEMA@.ESC_INST_CPROP_T
go

-- View: TaskHistory
CREATE VIEW @SCHEMA@.TASK_HISTORY(TKIID, ESIID, PARENT_TKIID, EVENT, REASON, EVENT_TIME, NEXT_TIME, PRINCIPAL, WORK_ITEM_KIND, FROM_ID, TO_ID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_HISTORY_T.TKIID, @SCHEMA@.TASK_HISTORY_T.ESIID, @SCHEMA@.TASK_HISTORY_T.PARENT_TKIID, @SCHEMA@.TASK_HISTORY_T.EVENT, @SCHEMA@.TASK_HISTORY_T.REASON, @SCHEMA@.TASK_HISTORY_T.EVENT_TIME, @SCHEMA@.TASK_HISTORY_T.NEXT_TIME, @SCHEMA@.TASK_HISTORY_T.PRINCIPAL, @SCHEMA@.TASK_HISTORY_T.WORK_ITEM_KIND, @SCHEMA@.TASK_HISTORY_T.FROM_ID, @SCHEMA@.TASK_HISTORY_T.TO_ID, @SCHEMA@.TASK_HISTORY_T.WSID_1, @SCHEMA@.TASK_HISTORY_T.WSID_2
 FROM @SCHEMA@.TASK_HISTORY_T
go

-- View: EscalationDesc
CREATE VIEW @SCHEMA@.ESCALATION_DESC(ESIID, LOCALE, DESCRIPTION, DISPLAY_NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESC_INST_LDESC_T.ESIID, @SCHEMA@.ESC_INST_LDESC_T.LOCALE, @SCHEMA@.ESC_INST_LDESC_T.DESCRIPTION, @SCHEMA@.ESC_INST_LDESC_T.DISPLAY_NAME, @SCHEMA@.ESC_INST_LDESC_T.WSID_1, @SCHEMA@.ESC_INST_LDESC_T.WSID_2
 FROM @SCHEMA@.ESC_INST_LDESC_T
go

-- View: TaskAuditLog
CREATE VIEW @SCHEMA@.TASK_AUDIT_LOG(ALID, AUDIT_EVENT, CONTAINMENT_CTX_ID, ESIID, ESTID, EVENT_TIME, FAULT_NAME, FAULT_TYPE_NAME, FAULT_NAME_SPACE, FOLLOW_ON_TKIID, NAME, NAMESPACE, NEW_USER, OLD_USER, PARENT_CONTEXT_ID, PARENT_TASK_NAME, PARENT_TASK_NAMESP, PARENT_TKIID, PRINCIPAL, TASK_KIND, TASK_STATE, TKIID, TKTID, TOP_TKIID, VAILD_FROM, WORK_ITEM_REASON, USERS, DESCRIPTION, MESSAGE_DATA ) AS
 SELECT @SCHEMA@.TASK_AUDIT_LOG_T.ALID, @SCHEMA@.TASK_AUDIT_LOG_T.AUDIT_EVENT, @SCHEMA@.TASK_AUDIT_LOG_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_AUDIT_LOG_T.ESIID, @SCHEMA@.TASK_AUDIT_LOG_T.ESTID, @SCHEMA@.TASK_AUDIT_LOG_T.EVENT_TIME_UTC, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_TYPE_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.FOLLOW_ON_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.NAME, @SCHEMA@.TASK_AUDIT_LOG_T.NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.NEW_USER, @SCHEMA@.TASK_AUDIT_LOG_T.OLD_USER, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_CONTEXT_ID, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TASK_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TASK_NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.TASK_AUDIT_LOG_T.TASK_KIND, @SCHEMA@.TASK_AUDIT_LOG_T.TASK_STATE, @SCHEMA@.TASK_AUDIT_LOG_T.TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.TKTID, @SCHEMA@.TASK_AUDIT_LOG_T.TOP_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.VALID_FROM_UTC, @SCHEMA@.TASK_AUDIT_LOG_T.WI_REASON, @SCHEMA@.TASK_AUDIT_LOG_T.USERS, @SCHEMA@.TASK_AUDIT_LOG_T.DESCRIPTION, @SCHEMA@.TASK_AUDIT_LOG_T.MESSAGE_DATA
 FROM @SCHEMA@.TASK_AUDIT_LOG_T
go

-- View: WorkBasket
CREATE VIEW @SCHEMA@.WORK_BASKET(WBID, NAME, TYPE, OWNER, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_T.WBID, @SCHEMA@.WORK_BASKET_T.NAME, @SCHEMA@.WORK_BASKET_T.TYPE, @SCHEMA@.WORK_BASKET_T.OWNER, @SCHEMA@.WORK_BASKET_T.DEFAULT_QUERY_TABLE, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT1, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT2, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT3, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT4, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT5, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT6, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT7, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT8, @SCHEMA@.WORK_BASKET_T.CREATION_TIME, @SCHEMA@.WORK_BASKET_T.LAST_MODIFICATION_TIME, @SCHEMA@.WORK_BASKET_T.WSID_1, @SCHEMA@.WORK_BASKET_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_T
go

-- View: WorkBasketLDesc
CREATE VIEW @SCHEMA@.WORK_BASKET_LDESC(WBID, LOCALE, DISPLAY_NAME, DESCRIPTION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_LDESC_T.WBID, @SCHEMA@.WORK_BASKET_LDESC_T.LOCALE, @SCHEMA@.WORK_BASKET_LDESC_T.DISPLAY_NAME, @SCHEMA@.WORK_BASKET_LDESC_T.DESCRIPTION, @SCHEMA@.WORK_BASKET_LDESC_T.WSID_1, @SCHEMA@.WORK_BASKET_LDESC_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_LDESC_T
go

-- View: WorkBasketDistTarget
CREATE VIEW @SCHEMA@.WORK_BASKET_DIST_TARGET(WBID, NAME, TYPE, OWNER, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, SOURCE_WBID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_DIST_TARGET_T.TARGET_WBID, @SCHEMA@.WORK_BASKET_T.NAME, @SCHEMA@.WORK_BASKET_T.TYPE, @SCHEMA@.WORK_BASKET_T.OWNER, @SCHEMA@.WORK_BASKET_T.DEFAULT_QUERY_TABLE, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT1, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT2, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT3, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT4, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT5, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT6, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT7, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT8, @SCHEMA@.WORK_BASKET_T.CREATION_TIME, @SCHEMA@.WORK_BASKET_T.LAST_MODIFICATION_TIME, @SCHEMA@.WORK_BASKET_DIST_TARGET_T.SOURCE_WBID, @SCHEMA@.WORK_BASKET_T.WSID_1, @SCHEMA@.WORK_BASKET_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_DIST_TARGET_T, @SCHEMA@.WORK_BASKET_T
 WHERE @SCHEMA@.WORK_BASKET_T.WBID = @SCHEMA@.WORK_BASKET_DIST_TARGET_T.TARGET_WBID
go

-- View: BusinessCategory
CREATE VIEW @SCHEMA@.BUSINESS_CATEGORY(BCID, PARENT_BCID, NAME, PRIORITY, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.BUSINESS_CATEGORY_T.BCID, @SCHEMA@.BUSINESS_CATEGORY_T.PARENT_BCID, @SCHEMA@.BUSINESS_CATEGORY_T.NAME, @SCHEMA@.BUSINESS_CATEGORY_T.PRIORITY, @SCHEMA@.BUSINESS_CATEGORY_T.DEFAULT_QUERY_TABLE, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT1, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT2, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT3, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT4, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT5, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT6, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT7, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT8, @SCHEMA@.BUSINESS_CATEGORY_T.CREATION_TIME, @SCHEMA@.BUSINESS_CATEGORY_T.LAST_MODIFICATION_TIME, @SCHEMA@.BUSINESS_CATEGORY_T.WSID_1, @SCHEMA@.BUSINESS_CATEGORY_T.WSID_2
 FROM @SCHEMA@.BUSINESS_CATEGORY_T
go

-- View: BusinessCategoryLDesc
CREATE VIEW @SCHEMA@.BUSINESS_CATEGORY_LDESC(BCID, LOCALE, DISPLAY_NAME, DESCRIPTION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.BCID, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.LOCALE, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.DISPLAY_NAME, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.DESCRIPTION, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.WSID_1, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.WSID_2
 FROM @SCHEMA@.BUSINESS_CATEGORY_LDESC_T
go


-- start import scheduler DDL: createSchemaMSSQL.sql



CREATE TABLE @SCHEMA@.[SCHED_TASK] ( [TASKID] BIGINT NOT NULL ,
               [VERSION] VARCHAR(5) NOT NULL ,
               [ROW_VERSION] INT NOT NULL ,
               [TASKTYPE] INT NOT NULL ,
               [TASKSUSPENDED] TINYINT NOT NULL ,
               [CANCELLED] TINYINT NOT NULL ,
               [NEXTFIRETIME] BIGINT NOT NULL ,
               [STARTBYINTERVAL] VARCHAR(254) NULL ,
               [STARTBYTIME] BIGINT NULL ,
               [VALIDFROMTIME] BIGINT NULL ,
               [VALIDTOTIME] BIGINT NULL ,
               [REPEATINTERVAL] VARCHAR(254) NULL ,
               [MAXREPEATS] INT NOT NULL ,
               [REPEATSLEFT] INT NOT NULL ,
               [TASKINFO] IMAGE NULL ,
               [NAME] VARCHAR(254) NOT NULL ,
               [AUTOPURGE] INT NOT NULL ,
               [FAILUREACTION] INT NULL ,
               [MAXATTEMPTS] INT NULL ,
               [QOS] INT NULL ,
               [PARTITIONID] INT NULL ,
               [OWNERTOKEN] VARCHAR(200) NOT NULL ,
               [CREATETIME] BIGINT NOT NULL ) 
GO

ALTER TABLE @SCHEMA@.[SCHED_TASK] WITH NOCHECK ADD CONSTRAINT [SCHED_TASK_PK] PRIMARY KEY  NONCLUSTERED ( [TASKID] ) 
GO

CREATE INDEX [SCHED_TASK_IDX1] ON @SCHEMA@.[SCHED_TASK] ( [TASKID],
               [OWNERTOKEN] ) 
GO

CREATE CLUSTERED INDEX [SCHED_TASK_IDX2] ON @SCHEMA@.[SCHED_TASK] ( [NEXTFIRETIME] ASC,
               [REPEATSLEFT],
               [PARTITIONID] )
GO

CREATE TABLE @SCHEMA@.[SCHED_TREG] ( [REGKEY] VARCHAR(254) NOT NULL ,
               [REGVALUE] VARCHAR(254) NULL ,
               PRIMARY KEY ( [REGKEY] ) )
GO

CREATE TABLE @SCHEMA@.[SCHED_LMGR] ( [LEASENAME] VARCHAR(254) NOT NULL,
               [LEASEOWNER] VARCHAR(254) NOT NULL,
               [LEASE_EXPIRE_TIME] BIGINT,
               [DISABLED] VARCHAR(5) )
GO

ALTER TABLE @SCHEMA@.[SCHED_LMGR] WITH NOCHECK ADD CONSTRAINT [SCHED_LMGR_PK] PRIMARY KEY  NONCLUSTERED ( [LEASENAME] ) 
GO

CREATE TABLE @SCHEMA@.[SCHED_LMPR] ( [LEASENAME] VARCHAR(254) NOT NULL,
               [NAME] VARCHAR(254) NOT NULL,
               [VALUE] VARCHAR(254) NOT NULL )
GO

CREATE INDEX [SCHED_LMPR_IDX1] ON @SCHEMA@.[SCHED_LMPR] ( [LEASENAME],
               [NAME] ) 
GO

-- end import scheduler DDL: createSchemaMSSQL.sql

